(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2716944,      40020]*)
(*NotebookOutlinePosition[   2717587,      40042]*)
(*  CellTagsIndexPosition[   2717543,      40038]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "Fractals: Mandelbrot & Julia Set in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " "
}], "Title"],

Cell[CellGroupData[{

Cell["Julia Set: Program and Visualization", "Section"],

Cell[BoxData[
    \(TraditionalForm\`\(juliaC = 
        Compile[{x, y, lim, cx, 
            cy}, \[IndentingNewLine]Module[{z, 
              ct = 0}, \[IndentingNewLine]z = 
              x + I\ y; \[IndentingNewLine]While[
              Abs[z] < 4.0 && ct < lim, \[IndentingNewLine]z = 
                z^2 + cx + 
                  I\ cy; \[IndentingNewLine]\(++ct\)]; \
\[IndentingNewLine]ct]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(gr1 = 
        DensityPlot[
          juliaC[x, y, 
            50,  .27334,  .00742], \[IndentingNewLine]{x, \(-1.5\), 
            1.5}, {y, \(-1.5\), 1.5}, PlotPoints \[Rule] 200, Mesh -> False, 
          ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.320513 0.5 0.320513 [
[.01923 -0.0125 -12 -9 ]
[.01923 -0.0125 12 0 ]
[.17949 -0.0125 -6 -9 ]
[.17949 -0.0125 6 0 ]
[.33974 -0.0125 -12 -9 ]
[.33974 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66026 -0.0125 -9 -9 ]
[.66026 -0.0125 9 0 ]
[.82051 -0.0125 -3 -9 ]
[.82051 -0.0125 3 0 ]
[.98077 -0.0125 -9 -9 ]
[.98077 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -24 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .17949 -12 -4.5 ]
[-0.0125 .17949 0 4.5 ]
[-0.0125 .33974 -24 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66026 -18 -4.5 ]
[-0.0125 .66026 0 4.5 ]
[-0.0125 .82051 -6 -4.5 ]
[-0.0125 .82051 0 4.5 ]
[-0.0125 .98077 -18 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1.5)] .01923 -0.0125 0 1 Mshowa
.17949 0 m
.17949 .00625 L
s
[(-1)] .17949 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(-0.5)] .33974 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(0.5)] .66026 -0.0125 0 1 Mshowa
.82051 0 m
.82051 .00625 L
s
[(1)] .82051 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1.5)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.05128 0 m
.05128 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.46795 0 m
.46795 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.72436 0 m
.72436 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.85256 0 m
.85256 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-1.5)] -0.0125 .01923 1 0 Mshowa
0 .17949 m
.00625 .17949 L
s
[(-1)] -0.0125 .17949 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(-0.5)] -0.0125 .33974 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .66026 m
.00625 .66026 L
s
[(0.5)] -0.0125 .66026 1 0 Mshowa
0 .82051 m
.00625 .82051 L
s
[(1)] -0.0125 .82051 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1.5)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05128 m
.00375 .05128 L
s
0 .08333 m
.00375 .08333 L
s
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .21154 m
.00375 .21154 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .46795 m
.00375 .46795 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .59615 m
.00375 .59615 L
s
0 .62821 m
.00375 .62821 L
s
0 .69231 m
.00375 .69231 L
s
0 .72436 m
.00375 .72436 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .85256 m
.00375 .85256 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.17949 .99375 m
.17949 1 L
s
.33974 .99375 m
.33974 1 L
s
.5 .99375 m
.5 1 L
s
.66026 .99375 m
.66026 1 L
s
.82051 .99375 m
.82051 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.05128 .99625 m
.05128 1 L
s
.08333 .99625 m
.08333 1 L
s
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.21154 .99625 m
.21154 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.46795 .99625 m
.46795 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.59615 .99625 m
.59615 1 L
s
.62821 .99625 m
.62821 1 L
s
.69231 .99625 m
.69231 1 L
s
.72436 .99625 m
.72436 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.85256 .99625 m
.85256 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .17949 m
1 .17949 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .5 m
1 .5 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .82051 m
1 .82051 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05128 m
1 .05128 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .46795 m
1 .46795 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .72436 m
1 .72436 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .85256 m
1 .85256 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00FF1E00FF1E00
FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00FF1E00
FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00
FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFB800FFB800FFB800FFD700FFD700FFF500EBFF00FFF500FFF500FFD700
FFD700FFD700FFD700FFD700FFD700FFB800FFB800FFB800FFB800FFB800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFB800FFB800
FFB800FFB800FFB800FFB800FFD700FFD700FFD700FFD700FFD700FFD700FFF500FFF500
FFF500FFD700FFD700FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FF9900FFB800
FFB800FFB800FFB800FFD700FFD70033FF00FF0000FF0000FF0000FF0000FF0000EBFF00
EBFF0000FF0AFF000000FF85EBFF00FFD700FFD700FFD700FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFD700FFD700FFF500EBFF00CCFF00CCFF00EBFF00FFF50000FF85FF0000FF0000
0085FFFF000070FF00FFF500FFD700FFB800FFB800FFB800FFB800FFB800FF9900FF9900
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FFB800FFB800FFB800FFB800
FFB800FFD700FFD700FFF500FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FF0A
FF0000FF0000FF0000FF0000FF0000CCFF00EBFF00FFF500FFD700FFD700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFD700FFD700
FFD700FFF500EBFF00FF0000FF0000FF0000FF00000047FF70FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CCFF00FFD700FFD700FFD700FFB800FFB800FFB800FFB800
FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFD700FFD700FFF500FFF500
FFF500FFF500FFF50000E1FFFF0000FF0000FF0000FF0000FF0000FF000000FFE1FF0000
FF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000CCFF00FFF500FFD700FFD700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFD700FFD700FFD700FFF500
70FF00FF0000FF0000FF0000FF0000FF000000A3FF00FFE100FF85FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000EBFF00FFF500FFF500FFF500FFF500FFF500FFD700
FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF9900FF9900FF9900FF9900FFB800FFD700FFF500CCFF00FF0000FF0000FF0000
FF0000CCFF00AEFF00FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EB00FFAEFF00FFF500FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFF500EBFF00FF0000
FF0000FF000000FFFFFF0000FF0000FF0000FF000000FFFF000AFFFF0000FF0000FF0000
FF0000FF000000A3FF00E1FF00A3FF14FF00CCFF0070FF00FF00007000FFFF0000FF0000
EBFF00FFD700FFB800FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF9900FF9900FF9900FFB800FFB800FFD70051FF00FF000000E1FFFF0000FF00000085FF
00A3FFFF000033FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EBFF00
FFF500FFD700FFD700FFD700FFD700FFD700FFD700FFF500FFF5008FFF00FF000000FFFF
FF0000FF0000FF007AFF0000FF0000FF0000FF0000FF00B8FF0000FF0000FF0000FF0000
FF007AFF000000FFFF00FFE1FF000014FF005100FFFF0000FF0000FF0000FF000000A3FF
FF000000FFE1FFF500FFB800FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900
FF9900FF9900FFB800FFB800FFD700EBFF00FF0000FF0000FF0000FF0000FF000000FFFF
00FFE100FF8500FF66FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0A
EBFF00FFF500FFF500FFD700FFD700FFF500FFF500EBFF00AEFF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFC200FF8500FF47FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00D7FF0000FFD700FFB800FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900
FF9900FFB800FFB800FFD700FFF500AEFF00FF0000FF0000FF0000FF0000FF000000FFFF
00FFC200FFA300FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
AEFF00EBFF00FFF500FFF500FFF500FFF500EBFF00CCFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000E1FF00FFE100FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFE15100FFEBFF00FFF500FFD700FFB800FF9900FF9900FF9900FF9900FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900
FF9900FFB800FFD700FF0000FF0000FF00F5FF0000FF0000FF0000FF0000FF00000066FF
00FFFF00FFFF8F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0099FF0000FF000000A3FF00C2FF00C2FF00A3FF0085FFFF0000FF0000
00FFC2CCFF00EBFF00EBFF00EBFF00EBFF00CCFF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00B8FF0000FF0000FF00F5FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000085FFFF0000FF0000FF0000FFF500FFD700FFB800FF9900FF9900FF9900FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900
FFB800FFD700FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000085FF00C2FF00E1FF00E1FF00E1FF00E1FF00E1FF00C2FF0085FFFF0000
FF00008FFF00CCFF00CCFF00CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFB800FFB800FF9900FF9900FF9900
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800
FFB800FFD700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF005CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000C2FF00FFFF00FFFF00FFFF00FFFF00FFFF00E1FF00C2FF00A3FF0066FF
FF000051FF00AEFF00AEFF00AEFF008FFF008F00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000E1FFEBFF00FFD700FFB800FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800
FFD700EBFF00FF00B8FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF00B8FF007A
FF000000C2FF00FFFF00FFFF00FFE100FFE100FFE100FFE100FFFF00C2FF0066FF0047FF
FF000000FF0A8FFF008FFF008FFF0000FF28FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFB800FFB800FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800
FFF500FF0000FF00B8FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFF0000
00A3FF00FFFF00FFFF00FFE100FFE100FFC200FFC200FFE100FFFFFF0000FF00001400FF
FF000033FF0070FF0070FF0070FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF007AFF0000FF0000FF0000FF0000FF00008FFF00FFD700FFB800FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FFB800FFD700
FFF500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FF
00E1FF00FFFF00FFE100FFC200FFC200FFC200FFC200FFC200FFE1FF0000EB00FFAE00FF
FF000033FF0051FF0051FF0033FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF0099FF0000
FF00000047FFFF0000FF0000FF007AFF0000FF00008FFF00FFD700FFB800FFB800FF9900
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FFB800FFB800FFD700
EBFF00FF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00E1FF00FFE100FFE100FFC200FFC200FFA300FFA300FFA300FFA300FFC2FF0000FF0000
00FF2814FF0033FF0033FF0000FF28FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00C2FF00E1FF00E1FF00E1FF00A3FFFF0000FF0000FF0000FFF500FFD700FFB800FFB800
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFB800FFD700
EBFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00E1FF00FFE100FFC200FFC200FFA300FFA300FFA300FF8500FF8500FF8500FF6600FF47
00FF0A00FF0A14FF0000FF0A00FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FF00E1FF
00FFFF00FFE100FFE100FFFF00E1FF00A3FFFF0000FF0000FFF500FFD700FFB800FFB800
FF9900FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFB800FFD700FFD700
EBFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00001400FF
00FFFF00FFE100FFC200FFC200FFA300FFA300FF8500FF8500FF8500FF6600FF4700FF47
00FF2800FF0A00FF0A00FF28FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FF00FFE1
00FFE100FFC200FFC200FFE100E1FF00C2FFFF0000FF0000FFF500FFD700FFB800FFB800
FFB800FF9900FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFB800FFD700FFD700FFF500
EBFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFFF00FFE100FFC200FFC200FFA300FFA300FF8500FF8500FF6600FF6600FF4700FF47
00FF2800FF2800FF2800FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FFE1
00FFC200FFA300FFA300FFC2FF00000066FFFF0000AEFF00FFF500FFD700FFD700FFB800
FFB800FFB800FF9900FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFB800FFD700FFD700FFF500FFF500
CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B8FF00B8FF005CFF003D
00FFFF00FFE100FFC200FFC200FFA300FFA300FF8500FF8500FF6600FF6600FF6600FF47
00FF4700FF4700FF66FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0099FF0099FF000000FFFF00FFC2
00FFA300FFA300FF8500FFA3EB00FF3300FF00FF0ACCFF00EBFF00FFF500FFD700FFD700
FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF9900FF9900FF9900FF9900FFB800FFB800FFB800FFD700FFD700FFF500FFF500EBFF00
CCFF008FFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0099FF00D7FF00F5FF005C0085FF
00E1FF00FFE100FFC200FFC200FFA300FFA300FF8500FF8500FF8500FF6600FF6600FF66
00FF6600FF6600FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D7FF00F5FF000000FFFF00FFC2
00FFA300FF8500FF6600FF4700FF2814FF0070FF00AEFF00CCFF00EBFF00EBFF00FFF500
FFD700FFD700FFB800FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF9900FF9900FF9900FFB800FFB800FFD700FFD700FFF500CCFF00FF0000FF00008FFF00
8FFF0070FF0014FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5CC00FF3300FF0066FF
00C2FF00FFFF00FFE100FFC200FFC200FFA300FFA300FF8500FF8500FF8500FF6600FF66
00FF8500FF85FF00008F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0099FF00F5FF0000FF000000FFE1
00FFC200FF8500FF6600FF4700FF2814FF0033FF0000FF0AFF000000C2FF00FF850066FF
CCFF00FFF500FFD700FFB800FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900
FF9900FF9900FFB800FFB800FFD700FFF50014FF00FF0000FF0000FF0000FF00001400FF
FF000033FF0014FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFE100FFC200FFA300FFA300FFA300FF8500FF8500FF8500FF85
00FFA300A3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FFE100FFC200FFA300FF8500FF85FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF001EFF000033FF00FFD700FFB800FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900
FF9900FFB800FFB800FFD700FFF500FF0000FF0000FF0000FF00000066FF00A3FF0085FF
5100FF00FF8500FF2800FF47FF00F5FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FFE100FFC200FFC200FFA300FFA300FFA300FFA300FFA3
00FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000AEFF00FFD700FFB800FFB800FF9900FF9900FF9900FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900
FF9900FFB800FFD700CCFF00FF0000FF0000FF0000FF0000FF000000C2FF00E1FF00E1FF
FF000000FF8500FF4700FF6600FFA3FF00F5FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00D7FF000000FFFF00FFE100FFC200FFC200FFC200FFC200FFE100FFFF
7000FF000AFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000C2FF00FFA3FF007AFFF500FFB800FFB800FF9900FF9900FF9900FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900
FFB800FFB800FFF500FF000000A3FFFF0000FF0000FF005C0066FF00E1FF00FFFF00FFE1
00FFC200FF8500FF6600FF8500FFA3FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFF00FFFF00FFFF0066FFFF0000FF0000FF0000
FF00B8CC00FFEB00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000033FF00FFD700FFB800FF9900FF9900FF9900FF9900
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800
FFB800FFD700FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFE100FFC2
00FFA300FFA300FF8500FF8500FFA300E1FFEB00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000AE00FF00C2FFFF0000FF0000FF0000FF0000FF0000
FF0000FF00F5FF00B8FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000EBFF00FFD700FFB800FF9900FF9900FF9900
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800
FFD700FFF500FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FFE100FFC2
00FFC200FFA300FFA300FFA300FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00B8FF00D7FF00000028FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000E1FF00C2FFCCFF00FFD700FFB800FFB800FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FFB800FFB800
FFD700EBFF00FF0000FF0000FF0000FF0000FF0000FF0099000AFF00C2FF00FFFF00FFE1
00FFC200FFC200FFC200FFC200FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00B8FF00F5EB00FFAE00FFAE00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000EB00FF00FFE100FF478FFF00EBFF00FFD700FFB800FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700
8FFF000066FF00FFA3FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FFFF
00FFE100FFE100FFE100FFFF00A3FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00B8FF00F5EB00FFCC00FFFF007AFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EBFF00FFB800FFB800FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFF500
FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C2FF
00C2FF00C2FF00A3FF0066FF0066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF003DFF00D7FF00F5FF00F5FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFB800FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FFB800FFD700FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007AFF00B8FF0000
FF0000FF0000FF0000FF005CFF00D7EB00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF005CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005C0085FFFFF500FFB800FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700CCFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF00D7FF0000
FF0000FF0000FF0000FF005CFF00D7FF00D7FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFB800FFB800
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF003DFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00008F00FFFF0000FF0000FF0000FF0000EBFF00FFB800FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF007AFF007AEB00FF00E1FF00E1FF0085FFFF0000FF0000EBFF00FFB800FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000028FF00FFFF00FFE100FFE100E1FFFF0000FF0000FFF500FFB800FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFD700EBFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFE100FFA300FFC200C2FF000AFF000AFFFFF500FFB800FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD700FFF500
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF007A00FFFF00FF8500FF665100FFFF0000EBFF00FFD700FFB800FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD700FFF500
EBFF0070FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF4751FF00AEFF00FFF500FFD700FFB800FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD700FFF500
CCFF0070FF0014FF0000FF6600FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B8FF00D7
FF00B8FF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EBFF00FFD700FFD700FFB800
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD700EBFF00
FF00000066FFFF00D700FF8500FFA300E1FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B8FF00D7FF00B8FF0099
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EB00FFEB00FF
FF00D7FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFD700FFB800
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700FFF500FF0000
FF000000C2FF00FFE100FFC200FFC200FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B8FF00F5FF00F5FF00F5FF00D7
FF007AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008F00FFFF00F5
FF00D7FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFB800
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700EBFF00FF0000
FF000000C2FF00FFFF00FFE100FFE100E1FF1400FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5EB00FFEB00FFFF00F5FF00D7
FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003300FFFF0000FF007A
FF0099FF001EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFB800
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFD700FF0000FF0000
FF0000FF000000E1FF00E1FF00C2FFFF0000FF0099FF0099FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5AE00FFCC00FFFF00F5FF00D7
FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FF0085FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EBFF00FFD700
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD700FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008F00FFAE00FFFF0000FF0099
FF0000FF0000FF0000FF0000FF00F5FF0000FF00D7FF000000C2FF00E1FF00E1FF00A3FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D700C2FFEBFF00FFD700
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD7008FFF00FF0000
FF0000FF0000FF0000FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000000AFFFF0000FF0000
FF0000FF0000FF0000FF000000C2FF00C2FF00E1FF00FFFF00FFFF00FFFF00FFFF00FFFF
00E1FF00A3FFFF003DFF0000FF0000FF0000FF0000EB00FFFF00D7FF007AFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EBFF00FFD700
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFF500FF000000C2FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FF00A3FF00C2FF
00C2FF00E1FF00FFFF00FFFF00FFE100FFE100FFE100FFE100FFE100FFE100FFE100FFE1
00FFFF00FFFF00E1FF00A3FFFF0099FF00000028FFFF0000FF00B8FF007AFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFD700
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFF500FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FFFF
00FFFF00FFE100FFE100FFE100FFE100FFC200FFC200FFC200FFC200FFC200FFC200FFE1
00FFE100FFE100FFFF00FFFF00E1FF00C2FF0085FFFF001EFF005CFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000AEFF00FFD700
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD7000047FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFE1
00FFE100FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFC2
00FFC200FFE100FFE100FFE100FFFF00E1FF00C2FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFFF0085FFFF0000FFF500FFD700
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFD700CCFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFE1
00FFC200FFC200FFC200FFC200FFA300FFA300FFA300FFA300FFA300FFC200FFC200FFC2
00FFC200FFC200FFE100FFE100FFE100FFFF00E1FF0085FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFC2FF00000066FFFF0000FFD700FFB800
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFD700FFF50051FF00
FF0000FF0000FF0000FF00B8FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF009900C2FF00FFE100FFC2
00FFC200FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFC2
00FFC200FFC200FFC200FFE100FFE100FFE100FFFF00E1FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000033FF00AEFF00FFF500FFD700FFB800
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFD700FFF500
AEFF0000FF4700FFA300FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFE100FFC200FFC2
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA3
00FFA300FFC200FFC200FFC200FFE100FFE100FFFF00FFFF00C2FFFF0000FF0000FF00D7
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FFF500FFD700FFB800
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFD700FFF500
FF000000A3FF00FFE100FFFFFF001EFF003DFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00F5FF005C00E1FF00FFE100FFC200FFA3
00FFA300FFA300FFA300FFA300FF8500FF8500FF8500FF8500FFA300FFA300FFA300FFA3
00FFA300FFC200FFC200FFC200FFC200FFE100FFE100FFFF00E1FF00A3FFFF0000FF0099
FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000AEFF00FFD700FFB800FFB800
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD700FFF500
FF00000066FF00C2FF0085FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF005CFF0000FF0000FF0000FF0000FF0000FF000000E1FF00FFE100FFC200FFA300FFA3
00FFA300FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FFA300FFA3
00FFA300FFA300FFC200FFC200FFC200FFE100FFE100FFFF00E1FF00C2FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008FFF00FFD700FFB800FFB800
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFD700FFF500
FF0000FF0000FF0000FF007AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0099
FF00D7FF00D7FF00B8FF0000FF0000FF0000FF000000FFFF00FFC200FFC200FFA300FFA3
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FFA3
00FFA300FFA300FFC200FFC200FFC200FFE100FFE100FFFF00FFFF00C2FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000C2FFCCFF00FFD700FFB800FFB800
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFF500
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B8FF00F5
FF00F5FF00F5FF00F5FF00B8FF0000FF000000C2FF00FFE100FFC200FFA300FFA300FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FFA3
00FFA300FFA300FFC200FFC200FFC200FFE100FFE100FFFF00FFFF00E1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF001EFF0000FF0000FFF500FFD700FFB800FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFD700
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D7EB00FF
EB00FFEB00FFEB00FFFF00D7FF0000FF00B800FFFF00FFC200FFA300FFA300FF8500FF85
00FF8500FF8500FF8500FF6600FF6600FF6600FF6600FF6600FF8500FF8500FF8500FF85
00FFA300FFA300FFC200FFC200FFC200FFE100FFE100FFFF00FFFF00E1FF00A3FF5100FF
FF005CFF0000FF0000FF0000FF000000FFE10066FFFF0000FFF500FFB800FFB800FF9900
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFD700
FFF500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0099FF00F5EB00FF
CC00FFAE00FFFF00F5FF0099FF000000E1FF00FFE100FFC200FFA300FFA300FF8500FF85
00FF8500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF8500FF8500FF85
00FFA300FFA300FFC200FFC200FFE100FFE100FFE100FFFF00E1FF00E1FF0085FFFF0000
FF001EFF0000FF0000FF0000FF000000FF0A00FFFFFFF500FFD700FFB800FFB800FF9900
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFB800
FFD700EBFF0070FF0000FF4700FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B8EB00FF
AE00FF8F00FF8F00FFFF000000A3FF00FFFF00FFE100FFC200FFA300FFA300FF8500FF85
00FF8500FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF8500FF85
00FFA300FFC200FFC200FFE100FFE100FFE100FFFF00FFFF00E1FF00C2FF0066FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000EBFF00FFD700FFD700FFB800FFB800FF9900
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800
FFD700FFF500CCFF000066FF00C2FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5
CC00FF8F00FF5100FF0028FF00A3FF00E1FF00FFE100FFC200FFA300FF8500FF8500FF85
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF8500FFA3
00FFC200FFE100FFFF00FFFF00FFFF00FFFF00FFFF00E1FF00E1FF00C2FF0066FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFD700FFB800FFB800FF9900FF9900
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800
FFB800FFD700EBFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFC200FFA300FF8500FF8500FF66
00FF6600FF6600FF6600FF4700FF4700FF4700FF4700FF4700FF6600FF6600FF8500FFA3
FF0000FF0000FF00000085FF00E1FF00E1FF00E1FF00E1FF00C2FF00A3FFFF0000FF007A
FF0000FF0000FF0000FF0000FF0000EBFF00FFD700FFD700FFB800FFB800FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800
FFB800FFD700FFF5008FFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFE100FFA300FF8500FF8500FF66
00FF6600FF6600FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF6600FF85FF0000
FF0000FF00B8FF0099FF000000A3FF00C2FF00C2FF00C2FF00C2FF0085FFFF0000FF0000
FF0000FF0000FF00000066FFFF0000FFF500FFD700FFB800FFB800FFB800FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FFB800
FFB800FFD700FFD700EBFF00FF0000FF000000E1FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFFF00FFA300FF8500FF8500FF66
00FF6600FF6600FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF4700FF85FF0000
FF003DCC00FFFF0000FF00000066FF00A3FF00C2FF00A3FF0085FF8F00FFFF0000FF0000
FF0000FF0000FF0000CCFF00FFF500FFD700FFD700FFB800FFB800FF9900FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FFB800
FFB800FFB800FFD700FFF500EBFF00AEFF0000A3FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC200FFA300FF8500FF66
00FF6600FF4700FF4700FF4700FF4700FF2800FF2800FF2800FF2800FF4700FF66FF0000
FF00008F00FFAE00FFFF00000066FF0085FF0085FF0085FF0047FFFF0000FF0000FF0000
FF001EFF0000FF0000FFF500FFD700FFD700FFB800FFB800FFB800FF9900FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FF9900
FFB800FFB800FFD700FFD700FFF500EBFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000028FF00FFC200FFA300FF8500FF66
00FF6600FF4700FF4700FF4700FF2800FF2800FF2800FF2800FF2800FF2800FF47EB00FF
FF00007000FF1400FF0028FF0047FF0066FF0066FF0028FFFF0000FF0000FF0000FF0000
FF00008FFF00EBFF00FFF500FFD700FFB800FFB800FFB800FF9900FF9900FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FFB800FFB800FFB800FFD700FFD700FFF500CCFF00FF000000FFE1FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA300FF8500FF66
00FF6600FF4700FF4700FF4700FF2800FF2800FF2800FF0A00FF0A00FF0A00FF0A00FF47
FF0000FF00005100FF1400FF0028FF0028FF7000FFFF0000FF0000FF000000A3FFFF0000
CCFF00EBFF00FFF500FFD700FFD700FFB800FFB800FFB800FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FFB800FFB800FFB800FFD700FFD700FFF500FFF500CCFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC200FFA300FF85
00FF6600FF6600FF4700FF4700FF2800FF2800FF0A00FF0A00FF0A00FF0A14FF0000FF0A
00FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000AEFF00CCFF00
EBFF00FFF500FFD700FFD700FFB800FFB800FFB800FFB800FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FF9900FFB800FFB800FFB800FFD700FFD700FFF500FFF500CCFF00FF000000FFA3FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF00D7FF003D00FFFF00FFC200FFA3
00FF8500FF6600FF4700FF4700FF2800FF2800FF0A00FF0A14FF0014FF0014FF0033FF00
33FF0014FF00FF00001400FF00A3FFFF0000FF00000028FF8FFF00CCFF00EBFF00EBFF00
FFF500FFD700FFD700FFD700FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FF9900FFB800FFB800FFB800FFD700FFD700FFD700FFF500EBFF00CCFF00AEFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF007AEB00FFCC00FFFF000000A3FFFF0000FF0000
00FFA300FF6600FF6600FF4700FF2800FF2800FF0A00FF0A14FF0014FF0033FF0033FF00
51FF0051FF0051FF0070FF0070FF008FFF00AEFF00AEFF00CCFF00EBFF00EBFF00FFF500
FFF500FFD700FFD700FFB800FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FF9900FFB800FFB800FFB800FFB800FFD700FFD700FFF500FFF500EBFF00EBFF00AEFF00
51FF00FF00000047FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000EB00FFAE00FF7000FFFF0000FF0000FF0000
EB00FF00FFA300FF6600FF4700FF4700FF2800FF0A00FF0A14FF0033FF0033FF0051FF00
51FF0070FF0070FF008FFF00AEFF00AEFF00CCFF00CCFF00EBFF00EBFF00FFF500FFF500
FFD700FFD700FFD700FFB800FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FF9900FFB800FFB800FFB800FFB800FFD700FFD700FFD700FFF500FFF500EBFF00CCFF00
CCFF008FFF0014FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00D7EB00FFFF0099FF0000FF0000FF0000
FF0000FF000000FFA300FF8500FF6600FF4700FF2800FF0A14FF0014FF0033FF0051FF00
51FF0070FF008FFF008FFF00AEFF00CCFF00CCFF00EBFF00EBFF00FFF500FFF500FFF500
FFD700FFD700FFD700FFB800FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FF9900FFB800FFB800FFB800FFB800FFD700FFD700FFD700FFF500FFF500FFF500EBFF00
CCFF00CCFF00AEFF008FFF0051FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00008F00FFFF0000FF0000FF000000FF6600FF4700FF2800FF0A14FF0033FF0051FF00
51FF0070FF008FFF008FFF00AEFF00CCFF00CCFF00EBFF00EBFF00FFF500FFF500FFD700
FFD700FFD700FFD700FFB800FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FF9900FFB800FFB800FFB800FFB800FFB800FFD700FFD700FFD700FFF500FFF500EBFF00
EBFF00CCFF00AEFF00AEFF008FFF0070FF0051FF0014FF0000FF47FF00007000FFFF0000
8F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00F5FF0000FF0000FF0000000AFFFF0000FF000000FF6600FF0A14FF0033FF00
51FF0070FF008FFF008FFF00AEFF00CCFF00CCFF00EBFF00EBFF00FFF500FFF500FFD700
FFD700FFD700FFB800FFB800FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FF9900FFB800FFB800FFB800FFB800FFB800FFD700FFD700FFD700FFF500FFF500EBFF00
EBFF00CCFF00CCFF00AEFF008FFF008FFF0070FF0051FF0033FF0014FF0000FF0A00FF66
FF0000FF0000000AFFFF0000FF0000FF0000FF00F5FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00008F00FFFF00007000FFFF000000FF47
14FF0051FF0070FF008FFF00AEFF00AEFF00CCFF00EBFF00EBFF00FFF500FFF500FFD700
FFD700FFD700FFB800FFB800FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FF9900FFB800FFB800FFB800FFB800FFD700FFD700FFD700FFD700FFF500FFF500EBFF00
EBFF00CCFF00CCFF00AEFF008FFF008FFF0070FF0051FF0051FF0033FF0014FF0000FF0A
00FF2800FF4700FF66FF0000FF0000FF00008F00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000051FF008FFF00AEFF00CCFF00CCFF00EBFF00FFF500FFF500FFF500
FFD700FFD700FFD700FFB800FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FF9900FFB800FFB800FFB800FFB800FFD700FFD700FFD700FFF500FFF500FFF500EBFF00
EBFF00CCFF00CCFF00AEFF008FFF008FFF0070FF0051FF0051FF0033FF0014FF0014FF00
00FF0A00FF2800FF4700FF6600FF8500FFA3FF0000FF0000FF0000FF0000FF0000FF0099
EB00FFFF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000014FF008FFF00CCFF00CCFF00EBFF00FFF500FFF500
FFD700FFD700FFD700FFB800FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FF9900FFB800FFB800FFB800FFB800FFD700FFD700FFD700FFF500FFF500EBFF00EBFF00
CCFF00CCFF00AEFF00AEFF008FFF0070FF0070FF0051FF0051FF0033FF0033FF0014FF00
00FF0A00FF0A00FF2800FF4700FF4700FF6600FFA3EB00FFFF0000FF0000FF00007000FF
AE00FFEB00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000047FFFF000051FF00AEFF00EBFF00EBFF00FFF500
FFF500FFD700FFD700FFB800FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FF9900FFB800FFB800FFB800FFB800FFD700FFD700FFF500FFF500EBFF00EBFF00CCFF00
AEFF00AEFF008FFF0070FF0070FF0051FF0051FF0051FF0033FF0033FF0014FF0014FF00
00FF0A00FF0A00FF2800FF2800FF4700FF6600FF6600FFA3FF0000FF000000A3FFFF0000
CC00FFEB00FFFF007AFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000AEFF00CCFF00EBFF00
FFF500FFD700FFD700FFD700FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FF9900FFB800FFB800FFB800FFD700FFD700FFD700FFF500EBFF00EBFF00CCFF008FFF00
0028FFFF0000FF000000A3FF1400FFFF000014FF0033FF0033FF0014FF0014FF0014FF00
00FF0A00FF0A00FF2800FF2800FF4700FF4700FF6600FF8500FFA300FFC200FFFFFF003D
FF00D7FF005CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFA3FF0000CCFF00
FFF500FFF500FFD700FFD700FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FFB800FFB800FFB800FFB800FFD700FFD700FFF500EBFF00CCFF00AEFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF4700FF0A14FF0000FF0A00FF0A
00FF0A00FF0A00FF2800FF2800FF4700FF4700FF6600FF6600FF8500FFA300FFC2FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CCFF00FFF500FFF500FFD700FFD700FFB800FFB800FFB800FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900
FFB800FFB800FFB800FFD700FFD700FFF500EBFF00CCFF00FF000000A3FFFF0000FF0000
FF00007000FF0028FF0028FF1400FF5100FFFF0000FF000000FF4700FF0A00FF0A00FF0A
00FF0A00FF2800FF2800FF2800FF4700FF4700FF4700FF6600FF6600FF8500FFA3FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFE1
FF0000CCFF00FFF500FFD700FFD700FFB800FFB800FFB800FF9900FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FF9900
FFB800FFB800FFB800FFD700FFF500EBFF008FFF00FF0000FF0000FF0000FF0000FF0000
0028FF0066FF0066FF0047FF0028FF1400FF7000FFFF0000EB00FF00FF4700FF2800FF28
00FF2800FF2800FF2800FF2800FF4700FF4700FF4700FF6600FF6600FF8500FFA300FFC2
0028FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000EBFF00FFF500FFD700FFD700FFB800FFB800FF9900FF9900FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FFB800
FFB800FFB800FFD700FFD700FFF500FF0000FF0000FF001EFF0000FF0000FF00000047FF
0085FF0085FF0085FF0066FFFF0000AE00FF8F00FFFF0000FF000000FF6600FF4700FF28
00FF2800FF2800FF2800FF4700FF4700FF4700FF4700FF6600FF6600FF8500FFA300FFC2
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000A3FFAEFF00EBFF00FFF500FFD700FFB800FFB800FFB800FF9900FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FFB800
FFB800FFD700FFD700FFF500CCFF00FF0000FF0000FF0000FF0000FF00008F00FF0085FF
00A3FF00C2FF00A3FF0066FFFF0000FF0000CC00FFFF003DFF000000FF8500FF4700FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF6600FF6600FF6600FF8500FF8500FFA3
00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000E1FFFF0000FF0000EBFF00FFD700FFD700FFB800FFB800FF9900FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800
FFB800FFD700FFF500FF00000066FFFF0000FF0000FF0000FF0000FF00000085FF00C2FF
00C2FF00C2FF00C2FF00A3FFFF0000FF0099FF00B8FF0000FF000000FF8500FF6600FF47
00FF4700FF4700FF4700FF4700FF4700FF4700FF6600FF6600FF6600FF8500FF8500FFA3
00FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00008FFF00FFF500FFD700FFB800FFB800FFB800FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800
FFD700FFD700EBFF00FF0000FF0000FF0000FF0000FF0000FF007AFF000000A3FF00C2FF
00E1FF00E1FF00E1FF00E1FF0085FFFF0000FF0000FF000000FFA300FF8500FF6600FF66
00FF4700FF4700FF4700FF4700FF4700FF6600FF6600FF6600FF6600FF8500FF8500FFA3
00FFC200FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000EBFF00FFD700FFB800FFB800FFB800FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FFB800FFB800
FFD700FFF500FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FF00C2FF00E1FF
00E1FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFE100FFC200FFA300FF8500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF8500FF8500FF8500FFA3
00FFC200FFE100E1FF00A3FF0028FF5100FF8F00FFCC00FFFF00F5FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000C2FF0066FFCCFF00FFF500FFD700FFB800FFB800FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFD700
FFD700EBFF00FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FF00C2FF00E1FF
00FFFF00FFFF00FFE100FFE100FFE100FFC200FFC200FFA300FF8500FF8500FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF8500FF8500FF8500FFA300FFA3
00FFC200FFE100FFFF00A3FFFF00008F00FF8F00FFAE00FFEB00FFFF00B8FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FF4770FF00EBFF00FFD700FFB800FFB800FFB800FF9900
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFD700
FFF50000FFFF00FF0AFF0000FF0000FF0000FF0000FF001EFF00000085FF00E1FF00E1FF
00FFFF00FFE100FFE100FFE100FFC200FFC200FFA300FFA300FF8500FF8500FF8500FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF8500FF8500FF8500FFA300FFA3
00FFC200FFE100E1FFFF0000FF0099FF00F5AE00FFCC00FFEB00FFFF00F5FF0099FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFD700FFB800FFB800FF9900
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFF500
FF00000066FF00FFE1FF0000FF0000FF0000FF0000FF005C5100FF00A3FF00E1FF00FFFF
00FFFF00FFE100FFE100FFC200FFC200FFC200FFA300FFA300FF8500FF8500FF8500FF85
00FF6600FF6600FF6600FF6600FF6600FF8500FF8500FF8500FF8500FF8500FFA300FFA3
00FFC200FFFFFF00B8FF0000FF00D7EB00FFEB00FFEB00FFEB00FFFF00D7FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFB800FFB800FF9900
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD700FFF500
FF0000FF0000FF001EFF0000FF0000FF0000FF0000FF0000FF0000FF000000E1FF00FFFF
00FFFF00FFE100FFE100FFC200FFC200FFC200FFA300FFA300FFA300FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FFA300FFA300FFC2
00FFE100C2FFFF0000FF0000FF00B8FF00F5FF00F5FF00F5FF00F5FF00B8FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFB800FFB800FF9900
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFD700CCFF00
00C2FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C2FF00FFFF
00FFFF00FFE100FFE100FFC200FFC200FFC200FFA300FFA300FFA300FF8500FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FF8500FFA300FFA300FFC200FFC2
00FFFFFF0000FF0000FF0000FF0000FF00B8FF00D7FF00D7FF0099FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF007AFF0000FF0000FF0000FFF500FFD700FFB800FF9900
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFD7008FFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C2FF00E1FF
00FFFF00FFE100FFE100FFC200FFC200FFC200FFA300FFA300FFA300FFA300FF8500FF85
00FF8500FF8500FF8500FF8500FF8500FF8500FF8500FFA300FFA300FFA300FFC200FFE1
00E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF005CFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000085FF00C2FF0066FFFF0000FFF500FFD700FFB800FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFD700AEFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF0099FF000000A3FF00E1FF
00FFFF00FFE100FFE100FFC200FFC200FFC200FFC200FFA300FFA300FFA300FFA300FFA3
00FF8500FF8500FF8500FF8500FFA300FFA300FFA300FFA300FFA300FFC200FFE100E1FF
FF005CFF00F5FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF003DFF001E00FFFF00FFE100A3FFFF0000FFF500FFD700FFB800FFB800
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFD700FFF500CCFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D7FF0000FF000000C2FF
00FFFF00FFFF00FFE100FFE100FFC200FFC200FFC200FFA300FFA300FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFC200FFC200FFE1FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFFF00FFA300FF47AEFF00FFF500FFD700FFB800FFB800
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD700FFF500AEFF00
33FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00E1FF00FFFF00FFE100FFE100FFE100FFC200FFC200FFC200FFC200FFA300FFA300FFA3
00FFA300FFA300FFA300FFA300FFA300FFA300FFA300FFC200FFC200FFE100C2FFFF0099
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00B8FF0000FF0000FF000051FF00FFF500FFD700FFB800
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD700FF00000066FF
FF000000FFC2FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0085FF00E1FF00FFFF00FFE100FFE100FFE100FFC200FFC200FFC200FFC200FFC200FFA3
00FFA300FFA300FFA300FFA300FFC200FFC200FFC200FFC200FFE100FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FFD700FFB800
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700FFF500FF00000085FF
00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000C2FF00E1FF00FFFF00FFE100FFE100FFE100FFC200FFC200FFC200FFC200FFC2
00FFC200FFC200FFC200FFC200FFC200FFC200FFC200FFE100FFE100FFFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000047FFFFD700FFB800
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700AEFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005C
FF001E0085FF00C2FF00E1FF00FFFF00FFFF00FFE100FFE100FFE100FFC200FFC200FFC2
00FFC200FFC200FFC200FFE100FFE100FFE100FFE100FFFF00FFFF00E1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFB800
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007AFF00B8
FF00000028FFFF0000FF009900A3FF00E1FF00FFFF00FFFF00FFE100FFE100FFE100FFE1
00FFE100FFE100FFE100FFE100FFFF00FFFF00E1FF00C2FF00C2FF00A3FF0047FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C2FFFF0000FFF500FFB800
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700EBFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007AFF00D7
EB00FFFF0000FF0000FF0000FF0000FF003D00A3FF00E1FF00FFFF00FFFF00FFFF00FFFF
00FFFF00E1FF00C2FF00C2FFFF0000FF0000FF0000FF0000FF0000FF0000000AFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0099FF0000FF0000FF0000FF00008FFF00FFD700FFB800
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700EBFF0000C2FFFF00D7
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000A3FF00E1FF00E1FF00C2FF
FF0000FF00D7FF0000FF00F5FF0000FF0000FF0000FF0000FF0099FF0000AE00FF8F00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFB800
FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700EBFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000085FF00A3FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0099FF00D7FF00F5CC00FFAE00FF
FF00F5FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0099FF0099FF000000C2FF00E1FF00E1FFFF0000FF0000FF0000FF0000FFD700FFB800
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFF500FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF0099FF007AFF00003300FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0099FF00D7FF00F5EB00FFEB00FF
FF00F5FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00001400FF00E1FF00FFE100FFE100FFFF00C2FFFF0000FF0000EBFF00FFD700FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD700FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0099FF00D7FF00F58F00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007AFF00D7FF00F5FF00F5FF00F5
FF00B8FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFF00FFC200FFC200FFE100C2FFFF0000FF0000FFF500FFD700FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFD700FFF500FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0099FF00D7EB00FFEB00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0099FF00B8FF00D7FF00B8
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000E1FF00FFA300FF85FF00D70066FFFF0000EBFF00FFD700FFB800FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFD700FFD700EBFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF001EFF00B8FF00D7FF00B8FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FF6614FF0070FF00CCFF00FFF500FFD700FFB800FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD700FFF500
AEFF0051FF0000FF47FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF003DFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000070FF00EBFF00FFF500FFD700FFB800FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFD700EBFF00
FF00005100FF00FF6600FF8500FFFFFF007AFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFD700FFB800FFB800
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFF500000AFF
000AFF00C2FF00FFC200FFA300FFE1FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EBFF00FFD700FFB800FF9900
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800FFF500FF0000
FF000000E1FF00FFE100FFE100FFFF0028FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFB800FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800EBFF00FF0000
FF00000085FF00E1FF00E1FFEB00FFFF007AFF007AFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFB800FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800EBFF00FF0000
FF0000FF0000FF00008F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF003DFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFB800FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FFB800FFB800FFF500FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00D7FF00D7FF005CFF0000FF0000FF0000FF0000FF00D7FF005CFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FFD700FFB800FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFF5000085FF
FF005CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF005CFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000EB00FFFF00D7FF005CFF0000FF0000FF0000FF0000FF00B8FF007AFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFB800FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00F5FF00F5FF00D7FF003DFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000066FF0066FF00A3FF00C2FF00C2FF00C2FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFFFFF0000FF0000FFF500FFB800FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FFB800FFB800EBFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF007ACC00FFEB00FFFF00F5FF00B8FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000A3FF00FFFF00FFE100FFE100FFE100FFFF00E1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFA30066FF8FFF00FFD700FFB800FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFD700
EBFF008FFF0000FF4700FFE1EB00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000AE00FFAE00FFEB00FFFF00F5FF00B8FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFFF00FFC200FFC200FFC200FFC200FFE100FFFF00C2FF000AFF
FF0099FF0000FF0000FF0000FF0000FF0000EBFF00FFD700FFB800FFB800FF9900FF9900
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800FFB800
FFD700CCFF0000C2FF00E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000028FFFF0000FF00D7FF00B8FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFC200FFA300FFA300FFA300FFC200FFC200FFE100E1FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFD700FFB800FF9900FF9900FF9900
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800
FFD700EBFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00B8FF00F5FF0000FF0000FF0000FF0000FF0000
FF000000C2FFAE00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000EB00FF00E1FF00FFA300FF8500FF8500FFA300FFA300FFC200FFE100FFFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFB800FFB800FF9900FF9900FF9900
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900
FFB800FFD70033FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000EB00FFCC00FFFF00B8FF0000FF0000FF00000066FF
00FFFF00FFFF00FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFA300FF8500FF6600FF8500FFC200FFE100FFFF00E1FF0066FF
FF005CFF0000FF000000A3FFFF0000FFF500FFB800FFB800FF9900FF9900FF9900FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900
FFB800FFB800FFF500FF007A00FFA300C2FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D7FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000000AFF7000FF00FFFF00FFE100FFC200FFC2
00FFC200FFC200FFE100FFFFFF0000FF00D7FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00F500FFA300FF6600FF4700FF85FF000000E1FF00E1FF00C2FFFF0000
FF0000FF0000FF0000FF0000CCFF00FFD700FFB800FF9900FF9900FF9900FF9900FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900
FF9900FFB800FFB800FFD700AEFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00D7FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC200FFA300FFA300FFA300FFA3
00FFA300FFC200FFC200FFE100FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00F500FF4700FF2800FF855100FF0085FF00A3FF0066FFFF0000
FF0000FF0000FF0000FFF500FFD700FFB800FFB800FF9900FF9900FF9900FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900
FF9900FF9900FFB800FFB800FFD70033FF00FF0000FF001EFF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF8500FF8500FFA300FFC200FFE1FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000A3FF00FFA300FF8500FF8500FF8500FF85
00FFA300FFA300FFA300FFC200FFE100FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000014FF0033FF00FF00001400FFFF0000FF0000FF0000
FF000014FF00FFF500FFD700FFB800FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900
FF9900FF9900FF9900FFB800FFB800FFD700FFF500CCFF000066FF00FF8500C2FFFF0000
00FF0A33FF0014FF0000FF2800FF4700FF6600FF8500FFC200FFE1FF0000FF0000FF00F5
FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00008F00FFFF000000FF8500FF8500FF6600FF6600FF8500FF85
00FF8500FFA300FFA300FFC200FFC200FFE100FFFF00C2FF0066FF3300FFCC00FFFF00F5
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000014FF0070FF008FFF008FFF00FF0000FF0000CCFF00
FFF500FFD700FFD700FFB800FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF9900FF9900FF9900FF9900FFB800FFB800FFD700FFD700FFF500EBFF00EBFF00CCFF00
AEFF0070FF0014FF0000FF2800FF4700FF6600FF8500FFA300FFC200FFFFFF0000FF00F5
FF00D7FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF8500FF6600FF6600FF6600FF6600FF6600FF85
00FF8500FF8500FFA300FFA300FFC200FFC200FFE100E1FF0085FFFF005CFF00F5FF00D7
FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00008FFF00CCFF00EBFF00FFF500FFF500FFD700
FFD700FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFB800FFD700FFD700FFF500EBFF00
CCFF0000FF0A3300FFEB00FF00FFA300FF8500FFA300FFA300FFC200FFFFFF0000FF0099
FF0099FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF6600FF4700FF4700FF4700FF6600FF6600FF66
00FF8500FF8500FFA300FFA300FFC200FFC200FFE100FFFFFF003DFF005CFF00B8FF00B8
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FFF500FFF500FFD700FFD700
FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF9900FF9900FF9900FF9900FF9900FFB800FFB800FFB800FFD700FFD700FFF500
AEFF00FF00000066FFFF000000FFC200FFA300FFA300FFC200FFE100E1FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF8500FF2800FF2800FF2800FF4700FF4700FF6600FF66
00FF8500FF8500FFA300FFA300FFC200FFC200FFE100FFFFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000EBFF00FFF500FFD700FFD700FFB800
FFB800FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FFB800FFB800FFB800FFD700FFF500
FF0000FF000000C2FF00E1FF00FFE100FFC200FFC200FFE100FFE10085FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF2800FF0A00FF0A00FF2800FF4700FF4700FF6600FF85
00FF8500FF8500FFA300FFA300FFC200FFC200FFE100FFFF1400FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000EBFF00FFD700FFD700FFB800FFB800
FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FFB800FFB800FFD700FFF500
FF0000FF000000A3FF00E1FF00FFFF00FFE100FFE100FFFF00E1FF0066FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFE100FF0A14FF0000FF0A00FF0A00FF4700FF6600FF8500FF85
00FF8500FFA300FFA300FFA300FFC200FFC200FFE100E1FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000EBFF00FFD700FFB800FFB800FFB800
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFD700FFF500
FF0000FF0000FF000000A3FF00E1FF00E1FF00E1FF00C2FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF2833FF0033FF0014FF0000FF28FF0000FF000000FFC200FFA3
00FFA300FFA300FFA300FFC200FFC200FFE100FFE100E1FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF001EEBFF00FFD700FFB800FFB800FF9900
FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFD700
8FFF00FF0000FF0000FF007AFF0000FF00000047FFFF0000FF0000FF0099FF003DFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000033FF0051FF0051FF0033FF00FF0000AE00FFEB00FFFF000000FFE1
00FFC200FFC200FFC200FFC200FFC200FFE100FFFF00E1FF0066FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFF500FFD700FFB800FF9900FF9900
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFD700
8FFF00FF0000FF0000FF0000FF0000FF0000FF007AFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000070FF0070FF0070FF0033FF00FF00001400FFFF0000FF000000FFFF
00FFE100FFC200FFC200FFE100FFE100FFFF00FFFF00A3FFFF0000CC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00B8FF0000FFF500FFB800FFB800FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800
FFF500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF288FFF008FFF008FFF0000FF0AFF00000047FF0066FF00C2FF00FFFF
00FFE100FFE100FFE100FFE100FFFF00FFFF00C2FFFF0000FF007AFF00B8FF003DFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00B8EBFF00FFD700FFB800FF9900FF9900FF9900
FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800
FFD700EBFF0000E1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00008F00FF8FFF00AEFF00AEFF00AEFF0051FF00FF00000066FF00A3FF00C2FF00E1FF
00FFFF00FFFF00FFFF00FFFF00FFFF00C2FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFD700FFB800FFB800FF9900FF9900FF9900
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FFB800
FFB800FFF500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CCFF00CCFF00CCFF00CCFF008FFF00FF0000FF00000085FF00C2FF00E1FF
00E1FF00E1FF00E1FF00E1FF00C2FF0085FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFFFFF0000FF0000FF0000FFD700FFB800FF9900FF9900FF9900FF9900
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900
FFB800FFD700FFF500FF0000FF0000FF00000085FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00F5FF0000FF0000FF00B8FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CCFF00EBFF00EBFF00EBFF00EBFF00CCFF0000FFC2FF0000FF00000085FF00A3FF
00C2FF00C2FF00A3FFFF0000FF0000FF0099FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00008F00FF00FFFF00FFFF0066FFFF0000FF0000FF0000
FF0000FF0000FF00F5FF0000FF0000FFD700FFB800FF9900FF9900FF9900FF9900FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900
FF9900FFB800FFD700FFF500EBFF005100FF00FFE1FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFC200FFE100E1FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CCFF00EBFF00FFF500FFF500FFF500FFF500EBFF00AEFF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FFE100FFA300FFC200FFFFFF0000FF0000FF0000
FF0000FF0000AEFF00FFF500FFD700FFB800FFB800FF9900FF9900FF9900FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900
FF9900FF9900FFB800FFB800FFD700FF0000FF00D7FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF4700FF8500FFC200FFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000AEFF00
EBFF00FFF500FFF500FFD700FFD700FFF500FFF500EBFF0000FF0AFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF6600FF8500FFE100FFFFFF0000FF0000FF0000
FF0000FF0000EBFF00FFD700FFB800FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900
FF9900FF9900FF9900FFB800FFB800FFF50000FFE1FF000000A3FFFF0000FF0000FF0000
FF00005100FF14FF00FF000000FFE100FFFFFF0000FF007AFF0000FF0000FF0000FF0000
FF00B8FF0000FF0000FF0000FF0000FF007AFF0000FF000000FFFFFF00008FFF00FFF500
FFF500FFD700FFD700FFD700FFD700FFD700FFD700FFF500EBFF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000033FF00FF000000A3FF0085FFFF0000FF000000E1FF
FF000051FF00FFD700FFB800FFB800FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF9900FF9900FF9900FF9900FFB800FFB800FFD700EBFF00FF0000FF00007000FFFF0000
70FF00CCFF0014FF0000A3FF00E1FF00A3FFFF0000FF0000FF0000FF0000FF0000000AFF
00FFFFFF0000FF0000FF0000FF000000FFFFFF0000FF0000FF0000EBFF00FFF500FFD700
FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFD700FFF500AEFF00EB00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF005CFF0000
FF0000FF0000FF0000FF0000FF0000AEFF00CCFF00FF0000FF0000FF0000FF0000CCFF00
FFF500FFD700FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFB800FFD700FFF500FFF500FFF500
FFF500FFF500EBFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF85
00FFE100A3FFFF0000FF0000FF0000FF0000FF000070FF00FFF500FFD700FFD700FFD700
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFD700FFD700FFF500CCFF00
FF0000FF0000FF000000FFFFFF0000FF0000FF0000FF0000FF000000FFE1FF0000FF0000
FF0000FF0000FF0000FF000000E1FFFFF500FFF500FFF500FFF500FFF500FFD700FFD700
FFB800FFB800FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FFB800FFB800FFB800FFB800FFB800
FFD700FFD700FFD700CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF000070FF00
0047FFFF0000FF0000FF0000FF0000EBFF00FFF500FFD700FFD700FFD700FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFD700FFD700
FFF500EBFF00CCFF00FF0000FF0000FF0000FF0000FF000000FF0A00E1FFFF0000FF0000
FF0000FF0000FF0000FF0000FFF500FFD700FFD700FFB800FFB800FFB800FFB800FFB800
FF9900FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FF9900FFB800FFB800
FFB800FFB800FFB800FFD700FFF50070FF00FF00000085FFFF0000FF000000FF85FFF500
EBFF00CCFF00CCFF00EBFF00FFF500FFD700FFD700FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFD700FFD700FFD700EBFF0000FF85FF000000FF0AEBFF00EBFF00FF0000FF0000FF0000
FF0000FF000033FF00FFD700FFD700FFB800FFB800FFB800FFB800FF9900FF9900FF9900
FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFB800FFB800FFB800FFD700FFD700FFF500FFF500FFF500FFD700FFD700
FFD700FFD700FFD700FFD700FFB800FFB800FFB800FFB800FFB800FFB800FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFB800FFB800
FFB800FFB800FFB800FFD700FFD700FFD700FFD700FFD700FFD700FFF500FFF500EBFF00
FFF500FFD700FFD700FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800FFB800
FFB800FFB800FFB800FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00
FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF7A00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00
FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00
FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00FF1E00
FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00
FF5C00FF5C00FF5C00FF5C00FF5C00FF5C00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00
FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF3D00FF1E00FF1E00FF1E00FF1E00
FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`006`3oool500000080oooo0P0000040?ooo`800000803oool5000001l0oooo0P0000040?oo
o`800000103oool2000001h0oooo0P00000Q0?ooo`800000103oool2000000@0oooo0P00000P0?oo
o`D000007P3oool500000080oooo0P0000040?ooo`8000000`3oool001d0oooo00<000000?ooo`3o
ool01`3oool010000000oooo0?ooo`00000Q0?ooo`030000003oool0oooo01h0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000L0?ooo`040000003oool0oooo000001l0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000Q0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000020?ooo`007@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo01X0oooo00@000000?ooo`3oool000007`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`005@3oool4000000@0oooo00<0
00000?ooo`3oool0203oool2000001X0oooo100000040?ooo`030000003oool0oooo01P0oooo1000
00020?ooo`040000003oool0oooo000000T0oooo0P00000M0?ooo`040000003oool0oooo000001l0
oooo00@000000?ooo`3oool000002@3oool200000280oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`080?ooo`8000000`3oool001d0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0L0?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`00703oool2000000X0oooo0`00000P0?ooo`8000008@3oool2
000000X0oooo0`00000M0?ooo`8000008@3oool2000000X0oooo0`00000P0?ooo`8000008@3oool2
000000X0oooo0`0000020?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`006`3ooooo0000004000001@3oool001/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo000K0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0
oooo00D000000?ooo`3oool0oooo000000050?ooo`001`3oool500000080oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3l0?ooo`03
0000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P3oool200000?`0oooo0P0000050?ooo`0000<0oooo0000000000000P0000040?ooo`030000003o
ool0oooo00P0oooo0P0000050?ooo`030000003oool0oooo0080oooo3`3o7P3I0?lm00h0oah0103o
ool00`000000oooo0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool>0?lN0=X0ocd03P3o7P040?ooo`030000003oool0
oooo00<0oooo00080?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool00P3oool<0?lN
05h0ocd08P3oG01N0?lm00`0oah0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?ooo``0oah0GP3o?@0R0?mL05h0ocd0303o7P040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo2`3o7P1G0?lm0380oe`0E`3o?@0;0?lN00@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool:0?lN05<0ocd0?03o
G01C0?lm00X0oah0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?ooo`T0oah0D@3o?@130?mL0500ocd02@3o7P040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`8000000`3oool70?lN04h0ocd0C03oG01>0?lm00L0oah00`3oool2000000D0oooo000K0?ooo`03
0000003oool0oooo0080oooo1`3o7P1>0?lm04`0oe`0CP3o?@070?lN00@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3oool60?lN04`0ocd0D`3oG01;0?lm00H0oah0
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`H0oah0B@3o
?@1H0?mL04X0ocd01@3o7P040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooo1@3o7P170?lm05h0oe`0B03o?@040?lN00@0oooo00<000000?ooo`3oool00`3oool0
01/0oooo00<000000?ooo`3oool00P3oool40?lN04H0ocd0H`3oG0150?lm00@0oah0103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`@0oah0AP3o?@1S0?mL04D0
ocd0103o7P040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo
0P3o7P150?lm06P0oe`0A@3o?@020?lN00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3oool00`3o7P00ocd00?lm00120?lm06`0oe`0A03o?@000`3o7P00oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3oool00`3o7P00ocd00?lm000o
0?lm0780oe`0@P3o?@030?ooo`8000001@3oool001/0oooo00<000000?ooo`3oool00P3ooom10?lm
07D0oe`0@03o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo?`3o?@1h0?mL03l0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo
0?ooo`020?ooocl0ocd0N03oG00o0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3ooolm0?lm07d0oe`0?03o?@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo>`3o?@0^0?mL02<0ogX0;`3oG00k0?lm00@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolj0?lm02H0oe`0=P3oNP0V0?mL
03X0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooocT0
ocd08P3oG0110?mj02<0oe`0=`3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`800000
0`3oooli0?lm0280oe`0@@3oNP0S0?mL03L0ocd00`3oool2000000D0oooo000K0?ooo`030000003o
ool0oooo0080oooo=`3o?@0O0?mL04X0ogX0803oG00f0?lm00@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3ooolf0?lm01h0oe`0CP3oNP0O0?mL03D0ocd0103oool0
0`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooc@0ocd07@3oG01E0?mj
01`0oe`0=03o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo<P3o?@0M0?mL05P0ogX07@3oG00b0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3ooolb0?lm01d0oe`0F03oNP0M0?mL0380ocd0103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooc40ocd06`3oG00D0?mj01@0oiT0403o
NP0B0?nI01@0ogX06`3oG00a0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<00000
0?ooo`3oool00P3oool`0?lm01/0oe`0403oNP100?nI0140ogX06P3oG00`0?lm00@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo0P0000030?ooobl0ocd06P3oG00>0?mj04P0oiT03P3oNP0J0?mL
02l0ocd00`3oool2000000D0oooo000K0?ooo`030000003oool0oooo0080oooo;`3o?@0H0?mL00h0
ogX02P3oV@0A0?nh01L0oiT04P3o^0090?nI00d0ogX06@3oG00^0?lm00@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3oool^0?lm01P0oe`02`3oNP0:0?nI00@0okP0
0P3oe`000`3om@00jol00>_o00020?oe00L0omL01`3o^00>0?nI00P0okP01`3oe`040?oe0080omL0
103o^00:0?nI00`0ogX06@3oG00/0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3oool^0?lm01P0oe`02`3oNP0:0?nI00@0okP00P3oe`000`3om@00jol00>_o
00020?oe00L0omL01`3o^00>0?nI00P0okP01`3oe`040?oe0080omL0103o^00:0?nI00`0ogX06@3o
G00/0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool/
0?lm01T0oe`02`3oNP070?nI00D0okP00`3oe`000`0co`00o`000?l000040?l000<0jol000@00?l:
0?l00000ohD0jol0103oe`0E0?nh00<0omL000@0ooD00>_o003<o`00c?l00P3[o`000`3om@000?n5
0?l000020?l000030025o`3o0000L?l00080ooD000<0omL00?nh003o^000103o^0070?nI00/0ogX0
6@3oG00[0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3o
ool[0?lm01T0oe`02@3oNP070?nI00H0okP00P3oe`000`3om@00o`000?l000060?l00003003Qo`00
o`X0o`0000D0o`000P3<o`000`3[o`00ooD00?oG00020?oG00h0okP0103oe`000`3om@00jol00>_o
00040?l0008004Oo00<0L?l00?l0003o00001`3o0000103<o`00omL00?oG003oe`070?nh00D0oiT0
2`3oNP0G0?mL02/0ocd0103oool00`000000oooo0?ooo`030?ooo`004`3oool5000000<0oooo00<0
00000?ooo`3oool00P3ooolZ0?lm01P0oe`02P3oNP050?nI00<0okP00P3oe`060?oe0003003Qo`3o
0000o`0000H0o`0000<00?oQ0?l0003o0000103o00000`00ool0o`000?l000020?l000030<co003o
m@00ooD00080omL02P3o^0040?oG00030?oe001`o`00o`0000D0o`0000@00:?o003oh@00on400?n5
2P3o00000`3[o`00ooD00?oe00040?oe00030?oG003o^000okP00080okP01@3oV@0:0?mj01L0oe`0
:P3o?@040?ooo`030000003oool0oooo00<0oooo000E0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3ooolY0?lm01P0oe`02P3oNP050?nI00050?nh003oe`00ooD00?oe003<o`00
1@3o00000`3<o`00[_l00?l000070?l000030?l0G03o0000o`0000X0o`0000@0j`3o0:ko002^o`00
ooD0303oe`000`3om@00jol00>_o00030?l000800?oo103o0002003oo`03000:o`3o0000o`0000@0
o`0000L00:?o003Qo`00hOl00:?o01Co003<o`00L?l00080o`0000<0L03o0?l0003o00000P3[o`00
0`3oe`00okP00?nh00050?nI00X0ogX05`3oG00Y0?lm00@0oooo00<000000?ooo`3oool00`3oool0
01D0oooo00<000000?ooo`3oool00`3oool2000000<0oooo:@3o?@0H0?mL00X0ogX01@3oV@001@3o
^000omL00?oe003om@00c?l000D0o`0000<0c?l00:ko003o00001`3o00000`3o05`0o`000?l0000:
0?l000040>/0o`2^o`00[_l00?oe00`0omL000<0ooD00>_o003[o`000`3o0002003oo`@0o`000P00
ool00`002_l0o`000?l000040?l00007002So`00hOl00>7o002So`0Do`00c?l0073o00020?l00003
0700o`3o0000o`000080jol000<0omL00?nh003o^0001@3oV@0:0?mj01L0oe`0:@3o?@030?ooo`80
00001@3oool000d0oooo100000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3ooolY0?lm01L0oe`02P3oNP030?nI00<0okP000D0omL0057o003o0000o`00003Qo`020?l00080
08Go00<00:?o0?l0000co`006@3o00000`3[o`00ooD00?oG00070?oG0080ooD000@0Sol00?l0003o
00000?oo0P3o00020?l0NP@0o`000P3o0;P50?l000030?l0NP3o00000?oo00800?oQ00<0o`0001Co
001A0?l01@3o00001@00Xol0o`000?l00000on40ooD000<0okP0103oV@0:0?mj01P0oe`09`3o?@04
0?ooo`030000003oool0oooo00<0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3ooolW0?lm01P0oe`02P3oNP030?nI00<0okP000<0omL00>_o003o00001@3o0002003o
o`03003oh@00ohD00?mV01T0o`0000<00?l:0>_o003om@000P3om@020?oG00<0ooD000<0jol00:ko
003o0000503o00001@00ool00?o2003o`P00ohD00?m700T0o`0000<0o`3G0?l0003oe`000`3o^005
0?nI00T0ogX05`3oG00W0?lm00@0oooo00<000000?ooo`3oool00`3oool001@0oooo0P0000050?oo
o`030000003oool0oooo0080oooo9P3o?@0G0?mL00X0ogX0103oV@020?nh0080omL000<0ooD00:ko
003o00001@3o0002003oo`03003o`P00oj<00?oQ01X0o`0000<0[_l00>_o003[o`00103om@020>_o
00030<co003o0000o`0001@0o`0000@00>7o003oh@00on400?o22P3o00000`00on40D@3o0>_o0002
0?oe00030?oG003o^000oiT000@0oiT02P3oNP0F0?mL02H0ocd0103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?ooobH0ocd05P3oG00:0?mj00D0oiT000<0okP00?oG
003o00000P3o00000`3o0?D0o`000?l000040?l0008006Ko0P00ool00`2?0?l0o`000?l0000<0?l0
00030?l0V@3o0000o`0000800:?o0P00`_l00`00Xol008Go0025o`020?l00003003o`P3<o`00c?l0
00@0jol00P3<o`0F0?l000050?l0^03o0000o`000?l0003o0?D02P3o00000`00QOl0o`000?l00002
0?l000030?oe003oe`00okP000@0oiT02`3oNP0F0?mL02D0ocd0103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?ooobH0ocd05P3oG00:0?mj00D0oiT000<0okP00?oG
003o00000P3o00000`3o0?D0o`000?l000040?l0008006Ko0P00ool00`2?0?l0o`000?l0000<0?l0
00030?l0V@3o0000o`0000800:?o0P00`_l00`00Xol008Go0025o`020?l00003003o`P3<o`00c?l0
00@0jol00P3<o`0F0?l000050?l0^03o0000o`000?l0003o0?D02P3o00000`00QOl0o`000?l00002
0?l000030?oe003oe`00okP000@0oiT02`3oNP0F0?mL02D0ocd0103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?ooobD0ocd05P3oG00:0?mj00D0oiT000<0okP00?oG
003o00000`3o00000`00ool0o`000?l0000G0?l000030025o`00`_l00>7o00D00>7o0P00`_l00`00
QOl0o`000?l0000208oo00@0c?l0;@3o00000`3om@00okP00?nh00040?nI00/0ogX05@3oG00U0?lm
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolT0?lm01H0
oe`02`3oNP040?nI0080okP000<0omL00?l0003o00002`3o00000`3o05`0o`000?l0000>0?l00003
0032o`00ool00?oo00@00?oo00H00>7o0032o`00`_l00:?o001Vo`3o0002057o00<0[_l000<0Sol0
08l0o`2?0?l0:P3o00001000hOl0jol00?oG003o^0050?nI00X0ogX05P3oG00T0?lm00@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo0P0000030?ooob@0ocd05@3oG00;0?mj00D0oiT000@0okP0
0?oG003[o`00o`2h5`3o00000`3o03d0o`2h0?l0NP020?l000030032o`00ool00?oo00D00?oQ00H0
0?oo0032o`00`_l006Ko0017o`3o0002003o2P<0Sol000<00?lX0?l0003o0000;03o0000103om@00
okP00?nh003o^0050?nI00T0ogX05`3oG00R0?lm00<0oooo0P0000050?ooo`006`3oool00`000000
oooo0?ooo`020?ooob80ocd05`3oG0090?mj00D0oiT00`3o^0000`3om@00o`000?l0^00H0?l00004
0<`0o`3o00000:?o002So`800?oo0P00on43003o`P03003oh@00ool0o`000080o`0000@0503o0?l0
000co`00<ol00`1`o`0X0?l000030?l0NP3o0000o`0000@0o`0000@0Sol00?oG003o^000okP01@3o
V@0;0?mj01D0oe`08P3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooo8P3o?@0E0?mL00X0ogX01P3oV@020?nh00030?oG003om@00o`0001X0o`0000D006Ko
003Qo`00hOl00?oo003oh@06003o`P06003oh@3o0000o`000>/0o`2^0?l0o`000P0co`02057o0003
03?o003o0000o`000240o`0000<0o`0m0?l0V@3o00000P3o00000`00Aol0o`000?l000020?l0NP80
o`0000<0Sol00?oG003o^0000P3o^0050?nI00/0ogX05@3oG00Q0?lm00@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolR0?lm01D0oe`02P3oNP060?nI0080okP0
00<0omL00?oe003o00006P3o00001@00I_l00>7o003Qo`00ool00?oQ00H00?o200H00?oQ0?l0003o
0000j`3o0:h0o`3o000203?o0080DOl000<0<ol00?l0003o00008@3o00000`3o03d0o`2I0?l00002
0?l000030017o`3o0000o`000080o`1j0P3o00000`2?o`00omL00?nh00020?nh00D0oiT02`3oNP0E
0?mL0240ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
ob40ocd05@3oG00:0?mj00H0oiT00`3o^0000`3oe`00jol00?l07P0K0?l000800>7o0P00on42003o
`PD00?nS0P00ol820?l00003003o:00Do`005?l00080<ol000<00?lX0?l0003o0000903o00020032
o`<00>7o0P00Xol30?l000030?oe003oe`00omL00080okP01@3oV@0:0?mj01D0oe`08@3o?@040?oo
o`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo8@3o?@0D0?mL00/0
ogX01@3oV@040?nh00030?oG003[o`00o`0001/0o`000P00hOl00`00on400?o2003o`P04003oX`@0
0?n500<00?mV003oA`00o`X00P00o`X00`0Do`000?l:003oh@0T0?l00004001Vo`00hOl00?oo003o
o`800?oQ00@00?oo003Qo`00hOl00:?o0P3o00000`3om@00omL00?oG00020?nh00H0oiT02P3oNP0E
0?mL0200ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
ob00ocd05@3oG00:0?mj00D0oiT00`3o^0030?oG00030>_o003o0000o`0001T0o`0000@0503o003o
o`00ool00?oQ0P00ol83003oX`<00?n50P00ofH2003oA`05003o:000o`X00?l:003o2P00obP09@3o
00001000QOl00?oQ003oh@00on42003o`P04003oh@00hOl00>7o0032o`80o`0000<0ooD00?oG003o
e`000`3o^0060?nI00X0ogX0503oG00P0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3ooolP0?lm01@0oe`02@3oNP050?nI00@0okP00`3oe`000`3om@00jol0
0?l0000K0?l000800?oo00<00?oQ003o`P00ol800`00oj<2003oQ@<00?mV0P00odL4003o:003003o
Q@3o0000o`0002<0o`0000@00>7o003oh@00ol800?o20P00oj<01`00ol80o`000?l00000I_l0o`00
0:ko003om@000`3oe`040?nh00H0oiT0203oNP0E0?mL01l0ocd0103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?ooob00ocd0503oG0090?mj00D0oiT0103o^0030?oG
00030?oe003[o`00o`0001/0o`000P00ool00`00on400?o2003o`P03003oX`800?n50`00ofH2003o
A`@00?lX00<00?n50?l0003o00008`3o00001000hOl00?oQ003o`P00ol82003oX`07003o`P3o0000
o`00001Vo`3o0000[_l00?oe00030?oG00@0okP01P3oV@080?mj01D0oe`07`3o?@040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`8000000`3ooolO0?lm01D0oe`0203oNP050?nI00@0okP00P3o
e`030?oe00030<co003o0000o`0001D0o`000`3o0;P01@3o05`0o`0m003oo`00ool00?oQ00800?o2
0`00oj<2003oQ@@00?mV1000odL00`00ofH0o`000?l0000P0?l000<0o`2I00<0o`00003oo`00ol80
0`00oj<02000ohD00?nS0>/0o`3[0?l0<`3o003o2P3<o`00jol00P3om@020?oG00@0okP01@3oV@0:
0?mj01<0oe`07`3o?@030?ooo`8000001@3oool001/0oooo00<000000?ooo`3oool00P3ooolO0?lm
01<0oe`02@3oNP050?nI00@0okP00P3oe`030?oe00030>_o003<o`00Sol001D0o`0000H0o`2I0?l0
e`3o0=L0o`3e0?l0G000QOl2003Qo`03003oh@00ol800?o200<00?nS0`00ohD7003oIP03003oQ@3o
0000o`000200o`0000H0o`3G0?l0m@3o0?D0o`00003oo`00ol82003oX`03003oQ@00ofH00?m70080
0?lX00@05?l0073o002^o`00c?l00`3[o`00103om@00omL00?oG003oe`020?nh00D0oiT02P3oNP0C
0?mL01h0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
oah0ocd04`3oG00:0?mj00@0oiT00P3o^0030?oG00030?oe003<o`00o`000080o`000P2?o`000`1`
o`005?l00?l0000D0?l00080o`3e00<0c03o03<0o`00I_l00P00`_l01000ool00?oQ003o`P00ol83
003oX`@00?n50P00ofH3003oQ@030?l0002?0?l0o`000200o`0000<0o`2I0?l0m@3o0?D00P3o0000
1P00on400?o2003o`P00ohD00?mV003oA`800?lX00@05?l003?o0000o`X0o`000P00`_l00`00ohD0
06Ko0<co00020?oe00030?oG003o^000okP000D0oiT02@3oNP0C0?mL01h0ocd0103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooah0ocd04`3oG0090?mj00<0oiT0
0`3o^000103oe`00ooD001Co000Do`050?l0000401@0o`3o0000<ol001Co01d0o`0000<00?oo003o
h@00ol801000oj<5003oQ@03003oX`00Xol00:?o02T0o`000P00on400`00ol800?nS003oQ@02003o
Q@P0o`0000D0o`0N0?l0003o0000<ol00?oG00020?nh00D0oiT02@3oNP0D0?mL01`0ocd0103oool0
0`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooah0ocd04`3oG0090?mj
00<0oiT00`3o^000103oe`00ooD001Co000Do`050?l0000401@0o`3o0000<ol001Co01d0o`0000<0
0?oo003oh@00ol801000oj<5003oQ@03003oX`00Xol00:?o02T0o`000P00on400`00ol800?nS003o
Q@02003oQ@P0o`0000D0o`0N0?l0003o0000<ol00?oG00020?nh00D0oiT02@3oNP0D0?mL01`0ocd0
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa`0ocd0503o
G0090?mj00<0oiT00`3o^0000`3oe`00ooD00?l000040?l00007001Vo`00Xol00:?o0025o`1A0?l0
0?n5003o:002003oA`030?l0m@3o0000o`0001T0o`0000<00?oo003oh@00ol800P00ol86003oX`03
003o`P3o0000o`0002`0o`0000<0o`3G0?l0003o00003@3o00000`2^o`00omL00?nh00020?nh00<0
oiT02@3oNP0D0?mL01`0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo
0?ooo`020?oooa`0ocd0503oG0070?mj00D0oiT000@0okP00?oG003oe`00c?l01P3o00001`00`_l0
0>7o003Qo`00hOl0o`00003oQ@00odL00P00ofH00`00oj<0o`3e0?l0000H0?l000030?l0e`3o0000
0?oo00800?oQ1@00ol800`00on400?oo0700o`02000:obT0o`000P3o0=L@0?l000040032o`00oj<0
o`1j0?oe00<0okP0103oV@080?mj01<0oe`0703o?@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo703o?@0C0?mL00P0ogX0103oV@020?nh0080ooD000<0o`00
002So`3o00000P3o00000`3o05`006Ko003Qo`02003oo`04003oh@00ol800?n5003oIP800?n500<0
0?nS0?l0003o00006`3o0004003oo`03001Vo`3o0000o`000080o`0000@0o`2h0<`0o`3<0?l0j`3o
?@3o0000100co`00omL00?oG003o^0050?nI00L0ogX0503oG00K0?lm00@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo0P0000030?oooa/0ocd0503oG0070?mj00@0oiT00P3o^0000`3oe`00o`00
0?l000070?l00004003oo`00on400?oQ003o`P800?nS0`00ohD00`00oj<00>7o0>/0o`0K0?l00080
[P3o00<00<;o0?l0003o00001@3o00020?l0m@030?l0^03o0000o`0003`0o`000P3[o`000`3oe`00
okP00?nI00030?nI00P0ogX04`3oG00K0?lm00<0oooo0P0000050?ooo`006`3oool00`000000oooo
0?ooo`020?oooa/0ocd04`3oG0080?mj00@0oiT000<0okP00?oG003om@002@3o00000`00hOl00?oQ
003oh@02003o`P@00?nS00<00?o20?l0003o00006@3o00001@3o0;P0o`3G0?l0003o000002So04H0
o`0000D00>7o0032o`3<o`00c?l00?oG00020?nh00@0oiT01`3oNP0D0?mL01X0ocd0103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa/0ocd04`3oG0080?mj00@0
oiT000<0okP00?oG003om@002@3o00000`00hOl00?oQ003oh@02003o`P@00?nS00<00?o20?l0003o
00006@3o00001@3o0;P0o`3G0?l0003o000002So04H0o`0000D00>7o0032o`3<o`00c?l00?oG0002
0?nh00@0oiT01`3oNP0D0?mL01X0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?oooaX0ocd0503oG0080?mj00<0oiT00P3o^0000`3oe`00jol00?l000060?l0
00030?l0V@002_l00<;o00800?oo00<00?oQ003o`P00ol800`00ol800`00ool0o`000?l0000H0?l0
00030?l0^03o0?D0j`3o00<0[P3oA@3o00000`3[0?l00?oQ003oA`0208oo00030>_o003oe`00okP0
00@0oiT01`3oNP0D0?mL01X0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?oooaX0ocd0503oG0070?mj00@0oiT000@0okP00?oG002?o`0006Ko0P00oj<80?l0
00800>7o00@00?oo003oh@00on400?oQ0P00ool00`00Xol0o`000?l0000H0?l000030?l0^03o0?D0
j`3o0080c03o00<0o`1j0?l0003o0000B@3o0000103[o`00okP00?nh003o^0020?nI00T0ogX04P3o
G00J0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolJ
0?lm0180oe`02@3oNP040?nI00040?nh003om@00o`000?l000800?oo2P3o00030032o`04002So`00
I_l006Ko001VoaX0o`0000<0o`0m0?l0e`3o0?D00P3o0?E=0?l000030?oG003o^000okP000<0oiT0
203oNP0C0?mL01T0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?oo
o`020?oooaT0ocd04`3oG0090?mj0080oiT00P3o^0000`3oe`00o`000?l0000:0?l000030?l0NP3o
0;P0o`2h00@0o`000P3o05`00`3o0=L0j`3o0?l0000I0?l000030?l0G03o0000o`0004`0o`0000<0
o`1L0025o`3om@000P3o^0030?nI00T0ogX04P3oG00I0?lm00@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3ooolI0?lm01<0oe`02@3oNP020?nI0080okP000<0omL0
0?l0003o00002P3o00000`3o07X0o`2h0?l0^0040?l00080o`1L00<0o`3G0>/0o`3o00006@3o0000
0`3o05`0o`000?l0001<0?l000030?l0G000QOl0ooD00080okP00`3oV@090?mj0180oe`06@3o?@04
0?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3ooolI0?lm01<0oe`0203oNP030?nI
0080okP000<0omL00<co003o00002P3o00000`3o05`0o`3G0?l0e`040?l00080o`1L0P3o0=M[0?l0
00040?oe003o^000okP00?nh0080oiT02@3oNP0B0?mL01T0ocd00`3oool2000000D0oooo000K0?oo
o`030000003oool0oooo0080oooo6@3o?@0B0?mL00T0ogX00`3oV@020?nh00030?oG003o0000o`00
01@0o`0000<0o`0m0?l0003o0000H`3o00000`2?0?l0o`000?l000030?l000040>_o003o^000okP0
0?nh00@0oiT01`3oNP0D0?mL01L0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?oooaT0ocd04P3oG0090?mj00<0oiT00P3o^0000`3oe`00o`000?l0001f0?l0
00<0o`1j00<0j`3o003Qo`00hOl00P00QOl20?l000040>_o003o^000okP00?nh00@0oiT01`3oNP0D
0?mL01L0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
oaL0ocd0503oG0090?mj00<0oiT00P3o^0000`3oe`00o`000?l0001h0?l00004000Xo`00ool00?oQ
003oh@800>7o0P3o0000103om@00okP00?nh003o^0040?nI00P0ogX04`3oG00G0?lm00@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolG0?lm01@0oe`01`3oNP05
0?nI0080okP000<0omL00>_o003o0000N@3o00000`00on400?nS003o`P020032o`8000[o00@0ooD0
0?nh003o^000okP0103oV@080?mj01<0oe`05`3o?@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo5`3o?@0D0?mL00L0ogX01@3oV@020?nh00030?oG003[o`00
o`0007T0o`0000<00?oQ003oX`00ol800P00`_l2000:o`040?oe003o^000okP00?nh00@0oiT0203o
NP0C0?mL01L0ocd0103oool00`000000oooo0?ooo`030?ooo`00203oool2000000@0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`020?oooaL0ocd04`3oG0080?mj00@0oiT00`3o^000
0`3oe`00ooD00?l0001h0?l000040?l0NP00ool00?n5003oIP80D@3o00<0o`000>_o003oe`000`3o
^0040?nI00P0ogX0503oG00F0?lm00@0oooo00<000000?ooo`3oool00`3oool000L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
5`3o?@0C0?mL00P0ogX0103oV@030?nh00040?oG003om@00jol0073o06D0o`000P3o03dC0?l00006
003oA`1Ao`00DOl00:ko003om@00omL00`3o^0040?nI00P0ogX0503oG00F0?lm00@0oooo00<00000
0?ooo`3oool00`3oool000L0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`02
0?ooo`8000000`3ooolF0?lm01@0oe`0203oNP040?nI00<0okP000@0omL00?oe003<o`00L?l00P0D
o`000`00ofH00?oo0?l0001N0?l000050?l0^03o0=L0o`2h0?l0^03o01h05P3o00001@3[o`00omL0
0?oG003oe`00okP000D0oiT01`3oNP0D0?mL01H0ocd00`3oool2000000D0oooo00000`3oool00000
0000000200000080oooo00@000000?ooo`3oool000002@3oool2000000D0oooo00<000000?ooo`3o
ool00P3ooolF0?lm01@0oe`0203oNP040?nI00<0okP000@0omL00>_o003o000006Ko0P3o0=L00`00
ohD00?nS003Qo`1=0?l000030?l0^03o0=L0o`2h0080o`2I303o00020>/0o`80o`3G00<0o`2I0?l0
003o00005@3o0000103om@00omL00?oG003o^0050?nI00P0ogX04`3oG00F0?lm00@0oooo00<00000
0?ooo`3oool00`3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo5P3o?@0D0?mL00P0ogX0103oV@030?nh00040?oG003[o`00
o`00001Vo`80o`3G00<00?n5003oX`00hOl0C@3o00000`3o0;P0o`3G0?l0^0020?l0V@`0o`000P3[
0?l20?l0e`030?l0V@3o0000o`0001D0o`0000@0ooD00?oG003oe`00okP01@3oV@080?mj01<0oe`0
5P3o?@040?ooo`030000003oool0oooo00<0oooo00080?ooo`8000002P3oool3000000@0oooo00<0
00000?ooo`3oool00P3ooolF0?lm01@0oe`0203oNP040?nI00040?nh003oe`00omL00?oe0080o`00
00<00<;o003oh@00on400P00ol800`00ool0o`000?l000190?l00080o`2h0`3o0?D20?l0e`030?l0
NP3o0000o`0000T0o`0000D0S`3o0?l0m@3o0=L0o`3G0?l0V@0H0?l00080omL00P3o^0040?nI00P0
ogX04`3oG00F0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0
0P3ooolF0?lm01@0oe`0203oNP040?nI00040?nh003oe`00omL00>_o0080o`0000<00<;o003oo`00
ool00P00on400`00hOl0503o01@0o`190?l00080o`3e0P3[0?l0103o0?D0o`3G0?l0e`3o09T:0?l0
000303<0o`3o0000o`1j0080o`2I00<0o`0N0?l0003o00005P3o00020?oe0080okP0103oV@080?mj
01@0oe`05@3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo5@3o?@0D0?mL00P0ogX01@3oV@000`3o^000omL00?oG00040?l000<00>7o00<00<;o0?l0003o
09T00P3o09U80?l00080o`3e00<0[P3o0<`0o`3o0?D00P3o0=L00`3o09T0o`000?l000080?l00003
002So`00QOl0o`0001/0o`000P3[o`000`3oe`00okP00?nI00030?nI00P0ogX0503oG00E0?lm00@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolE0?lm01@0oe`0
203oNP040?nI0080okP00P3oe`1F0?l0000308l0o`2^0?l0o`000080o`2I1@3o0000103o0?D0o`00
0?l0e`3o00020032o`800>7o00<00:?o0?l0003o00005`3o00001P3o0=L00<;o0>_o003[o`00omL0
0?nh00@0oiT0203oNP0D0?mL01D0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?oooaD0ocd0503oG0080?mj00@0oiT00P3o^0020?oG05H0o`0000<0S`3o0:h0
o`3o00000P3o09T50?l000040?l0m@3o0000o`3G0?l000800<;o0P00hOl00`00Xol0o`000?l0000G
0?l000060?l0e`00`_l0jol00>_o003oe`00okP0103oV@080?mj01@0oe`05@3o?@040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`8000000`3ooolE0?lm01@0oe`0203oNP040?nI0080okP00P3o
e`000`2?o`00o`000?l000030?l000030?l0V@3o0000o`0004h0o`0000<000[o0?l0003o00001P3o
00020032o`03003Qo`00ool00?oo00@00?oo0P00hOl00`00Xol0o`0m0?l000040?l000040>/0o`3o
0=L0o`1j0?l0NPh0o`000P3[o`000`3oe`00okP00?nI00030?nI00P0ogX0503oG00E0?lm00<0oooo
0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?oooaD0ocd0503oG0080?mj00@0oiT00P3o
^0020?oe00030?l00000`_l0o`0005@0o`0000<004Oo002So`00`_l00P00`_l01000hOl00?oo003o
o`00ool9003oh@<00?oo00P00>7o002So`3o09T0o`2I0?l00000:?l0o`000?l0^080o`1j403o0000
0`3oe`00okP00?nI00030?nI00P0ogX0503oG00E0?lm00@0oooo00<000000?ooo`3oool00`3oool0
01/0oooo00<000000?ooo`3oool00P3ooolE0?lm01@0oe`0203oNP040?nI0080okP00P3om@1H0?l0
0004003Qo`00ool00?oo003oo`D00?oQ1`00ol84003oh@800?oo0P00hOl01000`_l008Go0?l07P3o
05`@0?l00080[_l000<0omL00?nh003oV@000`3oV@080?mj01D0oe`0503o?@040?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo5@3o?@0D0?mL00P0ogX0103oV@02
0?nh0080omL000<004Oo0?l0003o0000E@3o00001000ool00?oQ003oh@00on4?003o`P<00?oQ0P00
ool00`00hOl00<;o0?l0000<0?l000<00?oo00H008Go0?l0003om@00ooD00?oG003o^0040?nI00P0
ogX05@3oG00D0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0
0P3ooolD0?lm01D0oe`0203oNP050?nI00040?nh003oe`00omL00<co05L0o`0000<00?oo003oh@00
on401@00ol86003oX`H00?o21000on400`00ool00>7o0025o`0<0?l000800?o200<0o`00001Vo`3o
00000P3oe`020?nh00@0oiT0203oNP0E0?mL01@0ocd0103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?oooa@0ocd05@3oG0080?mj00D0oiT000@0okP00?oG003oe`00
c?l0E`3o00000`00ool00?oQ003oh@05003o`PH00?nS1P00ol84003oh@03003oo`00hOl008Go00`0
o`000P00ol800`3o000006Ko0?l000020?oG0080okP0103oV@080?mj01D0oe`0503o?@040?ooo`03
0000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo503o?@0E0?mL00P0ogX0
1@3oV@001@3o^000omL00?oG003om@00DOl000@0o`0000<0o`2h0?l0003o0000C@3o00000`3o09T0
0<;o003oh@03003o`P`00?nS1@00ol84003oh@03003oo`00hOl0o`0000d0o`0000<0<ol00:ko003o
m@000P3oe`020?nh00@0oiT0203oNP0E0?mL01@0ocd0103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?oooa@0ocd05@3oG0080?mj00D0oiT00`3o^000103oe`00ooD0
0:ko0000odL2003oX`03003oo`3o0000o`0004h0o`0000@00?oQ003o`P00ol800?o24000oj<3003o
`P<00?oQ0P00ool01@00`_l0o`000?l0003o0000o`3G00X0o`0000D0c?l00?oe003oe`00omL00?nh
00050?nI00P0ogX05@3oG00D0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<00000
0?ooo`3oool00P3ooolD0?lm01D0oe`0203oNP050?nI00<0okP000@0omL00?oe003o00000:?o0P00
on400`00ool0o`0N0?l0?@1:0?l000060?l0m@3o05`0o`1L003Qo`00on400?o21`00oj<4003oQ@L0
0?nS1@00ol82003oh@07003oo`00hOl00:?o002So`3o0000o`2I0?l0?@090?l000030:ko003oe`00
okP00080okP01@3oV@080?mj01D0oe`0503o?@040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`8000000`3ooolD0?lm01D0oe`02@3oNP040?nI00<0okP000@0omL00?oe003o000006Ko0P00`_l0
0`00QOl0o`000?l000130?l000030?l0G03o0000o`0000D0o`000P00hOl00`00on400?o2003oX`03
003oX`/00?n51@00oj<4003o`P800?oQ00@00?oo003Qo`00`_l00<;o303o00000`2?o`00omL00?nh
00020?nh00D0oiT0203oNP0E0?mL01@0ocd00`3oool2000000D0oooo000K0?ooo`030000003oool0
oooo0080oooo503o?@0E0?mL00T0ogX0103oV@030?nh00040?oG003om@00o`00001Vo`800<;o00<0
08Go0?l0003o0000@`3o00000`3o05`0o`000?l000050?l000800>7o00<00?oQ003o`P00oj<00`00
oj<;003oQ@D00?nS1000ol82003oh@04003oo`00hOl00<;o0032o``0o`0000<0Sol00?oG003o^000
0P3o^0050?nI00P0ogX05@3oG00D0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3ooolD0?lm01D0oe`02@3oNP050?nI0080okP000<0omL00?oe003o00000`3o
00000`3o07X0o`000?l000120?l000030?l0V@3o0=L0o`3G0080o`2h103o0002003oo`800?o20`00
oj<=003oQ@@00?nS1000ol82003oh@800?oo0P00`_l;0?l000030032o`3<o`00omL000<0okP01@3o
V@080?mj01D0oe`0503o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooo503o?@0E0?mL00T0ogX01@3oV@030?nh00030?oe003o0000o`0004D0o`000P3o0;P5
0?l0m@040?l0^03o0000o`000032o`800?oQ00<00?o2003oX`00oj<03`00ohD4003oX`@00?o20P00
on42003oo`800>7o203o00001P3o01h0o`000?l0003o0000ooD00?oG00<0okP0103oV@090?mj01L0
oe`04P3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo
4P3o?@0G0?mL00T0ogX01@3oV@030?nh00030?oG003o0000o`0004D0o`000P3o0=L50>/0o`040?l0
e`3o0000o`2h003oo`800?o20P00oj<6003oQ@H00?mV1@00ohD3003oX`@00?o20P00on42003oo`80
0>7o00<00:?o0540o`3o05`01@3o00001@00on4006Ko001Vo`3o0000ooD000<0okP01@3oV@090?mj
01L0oe`04P3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo4P3o?@0G0?mL00T0ogX01@3oV@030?nh00030?oG003om@00o`0004@0o`0000H0o`2I0?l0m@3o
0?D0j`3o0<`0o`2^0?l20?l0m@040?l0V@3o00000>7o003oh@800?o20P00oj<4003oQ@X00?mV0`00
ohD3003oX`800?o21000on401`00ool00>7o003Qo`00hOl008Go0?l0003o01h01@3o00001@00o`X0
0?oo003oo`3om@00omL000<0okP01@3oV@090?mj01L0oe`04P3o?@040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo4P3o?@0G0?mL00T0ogX01@3oV@030?nh0003
0?oG003om@00o`0004@0o`0000H0o`2I0?l0m@3o0?D0j`3o0<`0o`2^0?l20?l0m@040?l0V@3o0000
0>7o003oh@800?o20P00oj<4003oQ@X00?mV0`00ohD3003oX`800?o21000on401`00ool00>7o003Q
o`00hOl008Go0?l0003o01h01@3o00001@00o`X00?oo003oo`3om@00omL000<0okP01@3oV@090?mj
01L0oe`04P3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo4P3o?@0G0?mL00T0ogX01@3oV@040?nh00060?oG003[o`00L?l0073o0000odL00?oo@@3o0002
0?l0^0030>/0o`2^0?l0S`3o0080S`3o00@0o`00002So`00ool00?oQ0P00ol82003oX`@00?n52`00
ofH2003oQ@800?nS0P00ol84003oh@800?oo00@00>7o0032o`00`_l006Ko203o00020>_o0080omL0
0`3o^0050?nI00T0ogX05`3oG00B0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P00
00030?oooa80ocd05`3oG00;0?mj00D0oiT00P3o^0001P3oe`00ooD00<co003<o`0006Ko0032od<0
o`0000<0o`3e0<`0o`2?0?l00P1A0?l01000:?l00:?o003Qo`00on42003o`P03003oX`00ohD00?n5
00800?n53000ofH01@00ohD00?nS003o`P00ol800?oQ00H00?oo0P00hOl20032o`03001Vo`3o0000
o`0000H0o`000P3om@000`3oe`00okP00?nh00070?nI00T0ogX05`3oG00B0?lm00<0oooo0P000005
0?ooo`006`3oool00`000000oooo0?ooo`020?oooa80ocd05`3oG00;0?mj00D0oiT00`3o^0000`3o
e`00jol00>_o001=0?l00004003oo`00ol800?o2003oX`800?n51@00ofH6003oA`<00?mV00<00?n5
003oX`3o00000`3o00000`00QOl00>7o003Qo`03003Qo`050032o`00Xol00:?o0?l0003o07X01P3o
0000103[o`00omL00?oG003oe`020?nh00D0oiT02`3oNP0G0?mL0180ocd0103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa80ocd05`3oG00;0?mj00D0oiT00`3o
^000103oe`00ooD00?oe002?o`1=0?l000800?oQ00<00?nS003oQ@00ohD01000ofH9003oA`03003o
IP00ohD0o`000080o`0000<0o`2h0?l0V@3o00000P00Xol40032o`8008Go1P3o00000`00I_l0o`00
0?oe00020?oG00<0okP01@3oV@0;0?mj01L0oe`04P3o?@040?ooo`030000003oool0oooo00<0oooo
000K0?ooo`030000003oool0oooo0080oooo4P3o?@0G0?mL00/0ogX01P3oV@020?nh00<0omL000<0
jol00?l0003o00000P00hOm90?l000800?oo00<00?nS003oQ@00ohD01000ofH:003oA`05003oQ@3o
0000o`0m0?l0?@3<0?l00P3o0002001Vo`04002So`00`_l00:?o0025o`80S`3o1P3o00000`3<o`00
ooD00?oG00020?oG0080okP01P3oV@0;0?mj01L0oe`04P3o?@040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo4P3o?@0G0?mL00/0ogX01P3oV@020?nh00<0omL0
00<0jol00?l0003o00000P00hOm90?l000800?oo00<00?nS003oQ@00ohD01000ofH:003oA`05003o
Q@3o0000o`0m0?l0?@3<0?l00P3o0002001Vo`04002So`00`_l00:?o0025o`80S`3o1P3o00000`3<
o`00ooD00?oG00020?oG0080okP01P3oV@0;0?mj01L0oe`04P3o?@040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo4P3o?@0G0?mL00/0ogX01P3oV@030?nh0080
omL000<0ooD00>_o002^o`000P00Xom;0?l00003003o`P00oj<00?n500<00?mV1@00odL5003o:003
003oA`00ofH0o`000080o`0000<0S`3o0:h0o`3o00000P00I_l30025o`030017o`3o0000o`000080
o`0000D0o`0N0?l0003o0000o`000?oe00020?oG00@0okP01P3oV@0;0?mj01L0oe`04P3o?@040?oo
o`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo4P3o?@0G0?mL00/0
ogX01`3oV@020?nh00<0omL000<0ooD00>_o003o0000BP3o0002000Xo`03003o`P00oj<00?n500<0
0?mV1000odL7003o:007003oA`3[0?l0o`000?l0001`0?l0503o000Xo`020017o`8006Ko00<002So
0?l0003o0000103o000208oo00030>_o003om@00omL000@0okP01`3oV@0;0?mj01L0oe`04P3o?@04
0?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo4P3o?@0G0?mL
00`0ogX01P3oV@040?nh0080omL000D0ooD00<co003<o`00o`00003oh@1:0?l00003003oX`00ohD0
0?mV00800?mV1000odL3003o:0D00?l:00H00?m70?l0003o0000o`000540o`0D0?l3000Xo`030700
o`3o0000o`000080o`0000<00:?o0?l0003<o`000P3[o`000`3om@00omL00?oG00040?nh00H0oiT0
303oNP0G0?mL0180ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0oooo4P3o
?@0G0?mL00`0ogX01P3oV@040?nh0080omL00`3om@000`3<o`00o`000?l000190?l00004003o`P00
oj<00?n5003oQ@800?mV0`00odL2003o:0D00?l:00@05?l0003o2P00odL00?m72`3o00000`2^o`00
c?l00>_o00020?oe0080omL01@3o^0060?nI00`0ogX05`3oG00B0?lm00<0oooo0P0000050?ooo`00
6`3oool00`000000oooo0?ooo`020?oooa80ocd05`3oG00<0?mj00H0oiT0103o^0020?oG00<0ooD0
00<0c?l00?l0003o0000B@3o00001000ol800?nS003oQ@00ohD2003oIP<00?m70P00obP5003o2P04
01Co0000o`X00?m7003oA`/0o`0000<0[_l00<co003[o`000P3om@020?oG00D0okP01P3oV@0<0?mj
01L0oe`04P3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo4P3o?@0G0?mL00`0ogX01`3oV@040?nh0080omL00`3om@00103<o`00o`00003oX`00oj=30?l0
00060?l0G03o0=L0o`3G0?l0?@00ool00?o20P00oj<00`00ohD00?mV003oA`02003oA`800?lX0P00
o`X401Co00<0<ol000<05?l00?l0000D0?l00P00Xol20?l00004000Xo`2?o`00c?l00<co0080jol0
00<0ooD00?oG003oe`000P3oe`040?nh00L0oiT0303oNP0G0?mL0180ocd0103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa80ocd05`3oG00<0?mj00L0oiT0103o
^0040?oG00030?oe003[o`00c?l00080[_l0@P3o00001P3o07X0j`3o0<`0o`3<0?l0o`00002So`<0
o`0000<00?nS003oIP00ofH00P00odL2003o:0800?l:0`0Do`0203?o00@0DOl00`1`o`00102?o`00
[_l00:ko003<o`030>_o0080ooD00`3oe`050?nh00L0oiT0303oNP0G0?mL0180ocd0103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa80ocd05`3oG00<0?mj00L0
oiT01@3o^0030?oG0080ooD00`3[o`00102^o`00DOl00?l00000Aolo0?l000040>/0o`2^0?l0[P3o
0700o`@0o`0000<0j`3o003oX`00ofH00`00odL00`00obP00?l:003o2P0201Co0080<ol00`1Ao`02
073o000408oo002^o`00[_l00:ko0080c?l00`3[o`020?oe00@0omL01@3o^0070?nI00`0ogX05`3o
G00B0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolB
0?lm01L0oe`0303oNP070?nI00D0okP0103oe`020?oe0080jol00P3<o`000`2?o`005?l00?l0000n
0?l000040?l0e`3[0?l0j`3o0?l0V@H0o`0000L00?nS003oQ@00ohD00?mV003oA`00obP00?l:00<0
5?l000D0<ol0057o001Ao`00DOl0073o000208oo0080[_l00P3<o`020>_o00@0ooD0103oe`050?nh
00L0oiT0303oNP0G0?mL0180ocd0103oool00`000000oooo0?ooo`030?ooo`00503oool2000000D0
oooo00<000000?ooo`3oool00P3ooolB0?lm01L0oe`0303oNP070?nI00D0okP0103oe`020?oe0080
jol00P3<o`000`2?o`005?l00?l0000n0?l000040?l0e`3[0?l0j`3o0?l0V@H0o`0000L00?nS003o
Q@00ohD00?mV003oA`00obP00?l:00<05?l000D0<ol0057o001Ao`00DOl0073o000208oo0080[_l0
0P3<o`020>_o00@0ooD0103oe`050?nh00L0oiT0303oNP0G0?mL0180ocd0103oool00`000000oooo
0?ooo`030?ooo`004`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
4P3o?@0G0?mL00`0ogX01`3oV@050?nh00@0omL0103om@00103[o`00c?l00<co002^o`0208oo0003
057o003o0000o`0004<0o`0000<0S`3o0?l0003o00000P3o00000`00ofH00?m7003o:002003o2P03
01Co000co`00DOl00080DOl000<0L?l008oo002?o`000P2^o`020<co0080jol00`3om@050?oG00D0
okP01`3oV@0<0?mj01L0oe`04P3o?@040?ooo`030000003oool0oooo00<0oooo000C0?ooo`040000
003oool0oooo000000@0oooo0P0000030?oooa80ocd05`3oG00<0?mj00L0oiT01P3o^0040?oG00<0
ooD00P3[o`001`3<o`00[_l00:ko002^o`00Sol0073o001Ao`000P0Do`000`00odL0o`000700o`02
0?l0000308l0o`3o0000o`0003T0o`0000<0o`3e0?l0003o00000P3o00000`002_l0o`000?l00002
003oIP03003o2P0Do`00<ol00080DOl000<0L?l008oo002?o`000P2^o`020<co0080jol00`3om@04
0?oG00H0okP01`3oV@0<0?mj01L0oe`04P3o?@030?ooo`8000001@3oool001<0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`020?oooa80ocd05`3oG00<0?mj00L0oiT01P3o^004
0?oG00<0ooD00P3[o`020<co0080[_l00P2?o`001P1`o`00DOl0057o000co`005?l0003o2P800?mV
0P3o00000`002_l0o`000?l000020?l000030?l0m@3o0000o`0003T0o`0000H0S`3o0?l0003o0000
L03o0?l00000odL201Co0003057o001`o`00Sol000<0[_l000<0c?l00>_o003[o`000`3om@040?oG
00H0okP01`3oV@0<0?mj01L0oe`04P3o?@040?ooo`030000003oool0oooo00<0oooo000C0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3ooolB0?lm01L0oe`0303oNP070?nI
00D0okP01@3oe`030?oe0080jol00P3<o`020:ko0080Sol000H0L?l0057o001Ao`00DOl003?o000D
o`02003o2P03003o:000odL00?mV00@0o`0000<0S`3o0?l0003o0000@`3o0000101Ao`00Sol008oo
002^o`020<co00030>_o003om@00ooD00080ooD0103oe`050?nh00L0oiT0303oNP0G0?mL0180ocd0
103oool00`000000oooo0?ooo`030?ooo`00503oool2000000D0oooo00<000000?ooo`3oool00P3o
oolB0?lm01L0oe`0303oNP070?nI00D0okP0103oe`040?oe0080jol00P3<o`020:ko0080Sol000D0
L?l0057o001Ao`00DOl003?o000301Co0004003o2P00obP00?m7003oIP800?n500<00?nS0?l0003o
0000103o0000103o09T0j`3o0>/0o`3o0=Lo0?l0000401Co002?o`00c?l00<co0080jol00P3om@04
0?oG00D0okP01`3oV@0<0?mj01L0oe`04P3o?@040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo4P3o?@0G0?mL00`0ogX01`3oV@050?nh00@0omL0103om@020>_o
0080c?l00P2^o`0208oo0005073o001Ao`00DOl0057o000co`000`0Do`001000o`X00?lX003oA`00
ofH2003oQ@03003oX`3o0000o`0000@0o`0000@0o`2I0>/0o`3[0?l0o`3G?`3o0000100Do`00Sol0
0<co003<o`020>_o0080ooD0103oe`050?nh00L0oiT0303oNP0G0?mL0180ocd0103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa80ocd05`3oG00<0?mj00L0oiT0
1@3o^0040?oG0080ooD00`3[o`020<co00<0[_l000<0Sol0073o001`o`000`1Ao`0203?o00805?l0
0P00o`X01`00obP00?m7003oA`00odL00?mV003oX`3[0?l0103o0000101`0?l0[P3o0:h0o`3[0?lo
0?l000040017o`3o0000DOl00:ko00<0jol00P3om@030?oG00D0okP01`3oV@0<0?mj01L0oe`04P3o
?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo4P3o?@0G
0?mL00`0ogX01`3oV@050?nh00<0omL00P3om@030>_o00040<co002^o`00[_l008oo00<0L?l0101A
o`0203?o00<05?l00P00o`X2003o:0800?m70P00ofH01P00oj<0o`000?l0003o00000:?o0?l00080
c03o00<0j`3o0?l0NP3o0000@@3o00020:ko00030<co003[o`00ooD000@0omL0103o^0070?nI00`0
ogX05`3oG00B0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0
0P3ooolB0?lm01L0oe`0303oNP070?nI00@0okP0103oe`000`3om@00jol00>_o00020<co000408oo
0000:?l0o`000?l000800:?o00<0503o0?l0000Do`000`0co`0401Co00800?l:0P00obP3003oA`07
003oIP00ohD00?nS003oX`00ol800?oo0?l0?@020?l0e`030?l0G03o0000o`000440o`000P00oj<0
0`3o0000c?l00?oe00020?oe0080omL0103o^0070?nI00`0ogX05`3oG00B0?lm00@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo0P0000030?oooa80ocd05`3oG00<0?mj00H0oiT01@3o^0020?oG
0080ooD000<0jol00<co002^o`002`3o0002003oA`03003o2P0Do`000?l:00@00?l:0P00obP3003o
A`800?mV0P00ohD00`00oj<00?o20?l0001:0?l000040<co003om@00ooD00?oe0080omL0103o^006
0?nI00`0ogX05`3oG00B0?lm00<0oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?oo
oa80ocd05`3oG00<0?mj00H0oiT01@3o^0020?oG0080ooD000<0jol00<co002^o`002`3o0002003o
A`03003o2P0Do`000?l:00@00?l:0P00obP3003oA`800?mV0P00ohD00`00oj<00?o20?l0001:0?l0
00040<co003om@00ooD00?oe0080omL0103o^0060?nI00`0ogX05`3oG00B0?lm00@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolB0?lm01L0oe`0303oNP060?nI
00@0okP00P3oe`001P3om@00jol00>_o003<o`00o`00002So`@0o`0000H0L03o000Xo`00:?l002So
01@0o`1A0?l30?l00003003oA`00o`X00?l:00<00?l:0`00obP4003oA`<00?mV00<00?n5003oX`3o
0000B@3o00001@00on40o`000<co003<o`00ooD00080omL0103o^0060?nI00`0ogX05`3oG00B0?lm
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolB0?lm01L0
oe`02`3oNP070?nI00@0okP000<0omL00?oe003[o`000P2?o`060?l00003000Xo`00I_l006Ko0080
04Oo00<002So01@0o`1`0?l00P3o00000`3[0?l00?m7003o:006003o:0@00?m70`00ofH00`00ohD0
0?nS003o`P02000Xod/0o`0000@0jol00?oe003oe`00omL00`3o^0070?nI00/0ogX05`3oG00B0?lm
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolB0?lm01L0
oe`02`3oNP060?nI00<0okP00`3oe`001@3om@00o`000?l0003o0000o`0N00@0o`0000@004Oo0025
o`00QOl008Go0P00I_l00`3o0000[P3o08l0o`030?l00003003oIP00odL00?lX00@00?lX1@00odL3
003oIP03003oQ@00oj<00?o204/0o`000P00Xol0102^o`00jol00?oe003oe`040?nh00H0oiT02`3o
NP0G0?mL0180ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?oooa80ocd05`3oG00;0?mj00H0oiT00P3o^0030?oG00030?oe003<o`00o`0000D0o`000P2?0?l0
1000QOl00:?o0032o`00Xol2001Vo`80o`0000D0c03o0?l0?@3o03d0o`00003oQ@0:003oA`@00?mV
0P00ohD00`00oj<00?oo003oo`190?l000800>7o0P3o0000103[o`00omL00?oG003oe`020?nh00H0
oiT02`3oNP0G0?mL0180ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo
0?ooo`020?oooa80ocd05`3oG00;0?mj00H0oiT00P3o^0030?oG00030?oe003<o`00o`0000D0o`00
0P2?0?l01000QOl00:?o0032o`00Xol2001Vo`80o`0000D0c03o0?l0?@3o03d0o`00003oQ@0:003o
A`@00?mV0P00ohD00`00oj<00?oo003oo`190?l000800>7o0P3o0000103[o`00omL00?oG003oe`02
0?nh00H0oiT02`3oNP0G0?mL0180ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?oooa80ocd05`3oG00;0?mj00D0oiT00`3o^0001@3oe`00ooD00?oe003o0000
06Ko00H0o`000P00QOl40032o`800:?o00<0o`000?l0V@3o0;P00`3o00000`00ohD00?mV003oA`08
003oA`@00?mV0P00ohD00`00oj<00?oQ003oh@1=0?l0000408oo003om@00omL00?oG00<0okP01@3o
V@0;0?mj01L0oe`04P3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3ooolB
0?lm01L0oe`02`3oNP050?nI0080okP00P3oe`020>_o00H0o`0000D0o`1j0?l00000Xol00:?o0032
o`05003Qo`030025o`3o0000o`000080o`0000<00?nS003oQ@00ofH00P00ofH6003oA`D00?mV0P00
ohD01000oj<00?o2003o`P00oom=0?l000030>_o003oe`00omL000<0okP01@3oV@0;0?mj01L0oe`0
4P3o?@030?ooo`8000001@3oool001/0oooo00<000000?ooo`3oool00P3ooolB0?lm01L0oe`02@3o
NP070?nI0080okP000<0omL00?oe003o0000203o00000`00I_l00<;o0032o`02003Qo`H00?oo00D0
0?oQ003o`P00ol800?nS003oQ@0<003oIP@00?n500L00?nS003o`P00ol800?oQ003Qo`00Xol002So
0080D@3o00<0S`3o0<`0o`3o0?D0@`3o00000`00`_l006Ko0<co00020?oe00030?oG003o^000okP0
00D0oiT02`3oNP0G0?mL0180ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?oooa80ocd05`3oG0090?mj00D0oiT00`3o^0020?oG00030>_o003o0000o`0000L0
o`0000@006Ko0032o`00`_l00>7o0P00ool4003oh@800?o20P00oj<2003oQ@/00?mV1000ohD2003o
X`800?o200@00?oQ003oo`00Xol0o`000`2?0?l0102^0?l0j`3o0?l0^03o0;Q10?l00003003oo`00
odL0L?l00080jol000<0omL00?nh003o^0000P3o^0050?nI00T0ogX05`3oG00B0?lm00@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolB0?lm01L0oe`02@3oNP05
0?nI00<0okP000<0omL00?oe0000ool00P00o`X50?l000030?l07P3o000008Go00<00>7o00<00?oo
003oh@00on400P00on42003o`P<00?nS0`00ohD:003oIP@00?n50P00oj<2003o`P04003oh@00hOl0
o`000?l0V@80o`3e00<0[P3o0<`0o`3[0?l00P3o0?D00`3o09T0o`000?l000130?l000030?oe003o
e`00okP00080okP01@3oV@090?mj01L0oe`04P3o?@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo4P3o?@0G0?mL00T0ogX01@3oV@030?nh00030?oG003om@00
0?oo00800?l:1@3o00000`3o01h0o`000025o`03003Qo`03003oo`00on400?oQ00800?oQ0P00ol83
003oX`<00?n52P00ofH4003oQ@800?nS0P00ol801000on400>7o0?l0003o09T20?l0m@030:h0o`3<
0?l0j`3o0080o`3e00<0o`2I0?l0003o0000@`3o00000`3om@00omL00?nh00020?nh00D0oiT02@3o
NP0G0?mL0180ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?oooa80ocd05`3oG0090?mj00D0oiT00`3o^0000`3om@00o`00001Vo`02003oh@D0o`0000<0o`1L
0540o`00Xol00P00hOl2003oo`800?oQ1000ol83003oX`D00?n51P00ofH6003oQ@800?nS0P00ol80
1000ool0o`2h0?l0003o0=L50>/0o`80o`3GA`3o0000103oe`00okP00?nh003o^0050?nI00T0ogX0
5`3oG00B0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3o
oolB0?lm01L0oe`02@3oNP040?nI00<0okP000@0omL00?oe003o0000o`000P3o01h80?l000800>7o
0P00ool2003oh@@00?o21000oj<?003oQ@800?nS00@00?o2003oh@00on400<;o0P3o00000`3o0;P0
o`3e0?l0m@030?l0m@80o`2hA`3o0000103om@00okP00?nh003o^0050?nI00T0ogX05@3oG00D0?lm
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolD0?lm01D0
oe`0203oNP050?nI00<0okP000<0omL00<co0000`_l02`3o00020032o`800?oo0P00on44003o`P@0
0?nS3@00ohD3003oX`800?o20P00ool40?l00080o`2h0P3o0=L00`3o09T0o`000?l000120?l00003
0?l0NP3o0000o`000080o`0000@0ooD00?oG003o^000okP01@3oV@090?mj01D0oe`0503o?@040?oo
o`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo503o?@0E0?mL00P0
ogX01@3oV@030?nh00030?oG002?o`00o`0000/0o`000P00`_l01000hOl00?oo003oh@00on44003o
`PD00?nS2`00ohD4003oX`04003o`P00on400>7o003Qo`L0o`0000<0o`1L0?l0003o0000@`3o0000
1`00QOl00<;o001Vo`00I_l0o`000?oe003oe`000`3o^0040?nI00T0ogX05@3oG00D0?lm00@0oooo
00<000000?ooo`3oool00`3oool001/0oooo0P0000030?oooa@0ocd05@3oG0080?mj00D0oiT00`3o
^0000`3oe`00Sol00?l0000;0?l000800<;o00@00>7o003oo`00on400?oQ1000ol85003oX`/00?n5
1000oj<01000ol800?oQ003Qo`00hOl70?l000030?l0G03o0000o`0004<0o`0000L008Go0032o`00
I_l006Ko0?l0003om@00omL000<0okP0103oV@090?mj01D0oe`0503o?@030?ooo`8000001@3oool0
01/0oooo00<000000?ooo`3oool00P3ooolD0?lm01D0oe`0203oNP050?nI00<0okP000<0omL00:ko
003o0000203o00000`3o03d0o`2I0?l00002002So`04003Qo`00ool00?oQ003oh@D00?o21`00oj<4
003oQ@L00?nS00<00?o2003oh@00hOl00P3o05`00`3o0?D0o`000?l000180?l000040?l0?@3o01h0
0?oo003oh@800:?o00<0o`000?oe003oe`000`3o^0050?nI00P0ogX05@3oG00D0?lm00@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolD0?lm01D0oe`0203oNP05
0?nI00050?nh003oe`00omL00?oe003<o`002P3o00001@3o0=L0o`000?l0003o00000<;o00800?oo
0`00on43003o`Q000?nS0`00ol800`00on40o`000?l0001>0?l00007003oo`00oj<00?m7003oA`2^
o`00ooD00?oG00030?nh00D0oiT0203oNP0E0?mL01@0ocd0103oool00`000000oooo0?ooo`030?oo
o`006`3oool00`000000oooo0?ooo`020?oooa@0ocd05@3oG0080?mj00@0oiT00P3o^0020?oG0003
0?oe002^o`00<ol000h0o`0000<00>7o003oo`00on400`00on45003o`P`00?nS0`00ol800`00on40
0<;o0?l0V@1?0?l000030?l0^03o0000o`000080o`0000D0DOl00?oe003oe`00omL00?nh00050?nI
00P0ogX05@3oG00D0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3ooolD0?lm01D0oe`0203oNP040?nI0080okP00P3oe`00103o000006Ko0?l00000ol8=0?l0
00030025o`00hOl00?oo00@00?oQ1P00ol86003oX`D00?o20P00on400`00ool0o`000?l0001E0?l0
00040<co003oe`00omL00?nh00D0oiT0203oNP0E0?mL01@0ocd0103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?oooa@0ocd05@3oG0080?mj00@0oiT00P3o^0020?oG
00040?l00000I_l0o`00003o`Pd0o`0000<008Go003Qo`00ool01000on46003o`PH00?nS1@00ol82
003oh@03003oo`3o0000o`0005D0o`0000@0c?l00?oG003oe`00okP01@3oV@080?mj01D0oe`0503o
?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo503o?@0E
0?mL00P0ogX0103oV@001P3o^000omL00?oe003om@00o`000025o`800?oo3P3o00001000`_l00>7o
003oo`00ool3003oh@l00?o20`00on400`00ool0o`000?l0001E0?l000030017o`3oe`00omL00080
okP0103oV@080?mj01@0oe`05@3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000
003oool0oooo0080oooo503o?@0E0?mL00P0ogX0103oV@00103o^000omL00:ko002^o`0@0?l00004
0?l0G03o01h008Go0032o`800>7o0P00ool4003oh@L00?o21@00on43003oo`03003Qo`3o0000o`00
05H0o`000P3om@020?nh00@0oiT0203oNP0D0?mL01D0ocd0103oool00`000000oooo0?ooo`030?oo
o`006`3oool2000000<0oooo5@3o?@0D0?mL00P0ogX0103oV@000`3o^000omL00?l0000?0?l00080
o`1j00@0o`2h0?l00000:?l0o`000P3o09T00`00Xol00>7o003oo`02003oo`T00?oQ0`00ool01P00
hOl00<;o0032o`00`_l00:?o0017oeD0o`0000@00<;o0?l0003om@00ooD00P3o^0040?nI00P0ogX0
503oG00E0?lm00<0oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?oooaD0ocd0503o
G0080?mj00@0oiT000@0okP00?oG003[o`00jol03P3o00020?l0NP030?l0e`3[0?l0o`0000@0o`00
00@0o`0m002So`00hOl00>7o1P00ool00`00hOl00<;o0032o`080?l00003000:o`3o0000o`0004h0
o`0000<0o`2I0?l0003o00000`3o00000`2?o`00omL00?oG00020?nh00@0oiT0203oNP0D0?mL01D0
ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaD0ocd0
503oG0080?mj00@0oiT000H0okP00?oG003[o`00jol00032o`3o0=LI0?l00003002So`00hOl00>7o
00800<;o00@0o`000?l0e`3o0000o`3e1@3o00020?l0V@030?l0002^0?l0S`3o05H0o`000P3oe`02
0?nh00@0oiT0203oNP0D0?mL01D0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?oooaD0ocd0503oG0080?mj00@0oiT000H0okP00?oG003[o`00jol00032o`3o
0=LI0?l00003002So`00hOl00>7o00800<;o00@0o`000?l0e`3o0000o`3e1@3o00020?l0V@030?l0
002^0?l0S`3o05H0o`000P3oe`020?nh00@0oiT0203oNP0D0?mL01D0ocd0103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaD0ocd0503oG0080?mj00@0oiT000@0
okP00?oG003[o`00jol0703o00000`00QOl00:?o0?l000090?l000060?l0V@3o0=L0o`3G0?l0m@3<
0?l0[P3o0P3o0?E80?l000<0o`2I00@0o`000032o`00hOl00>7o1@3o00020?oG00030?nh003oV@00
oiT000<0oiT0203oNP0D0?mL01D0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?oooaD0ocd0503oG0080?mj00@0oiT00P3o^0020?oe01P0o`0000H0o`0N0?l0
V@3o09T0o`1j0?l0000c0?l:0?l000040?l0V@3o0=L0o`3G0?l0m@80j`3o0P3o0?E90?l00080503o
00@00>7o003oh@00on400?oo0P00`_l20?l000040>_o003oe`00omL00?nh00@0oiT0203oNP0D0?mL
01H0ocd0103oool00`000000oooo0?ooo`030?ooo`00203oool2000000@0oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`020?oooaH0ocd04`3oG0080?mj00@0oiT00P3o^0020?oG01P0
o`0000D0o`2I0?l0e`3o0=L0o`3e08l0o`0;0?l000030?l0NP3o0=L0o`3G00<0o`3e0P3o0;Q;0?l0
0004003oo`00ol800?o2003oh@800<;o0P3o0000103om@00omL00?oG003o^0040?nI00P0ogX0503o
G00F0?lm00@0oooo00<000000?ooo`3oool00`3oool000L0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo5P3o?@0C0?mL00P0ogX0
1@3oV@00103o^000omL00?oG003om@0G0?l000030?l0V@3o0=L0o`3G0080j`3o303o00020?l0V@03
0?l0^03o0=L0o`2h04d0o`0000@00>7o003oX`00ohD0o`3G0P00I_l00`3o0000jol00?oG00030?nh
00@0oiT0203oNP0D0?mL01H0ocd0103oool00`000000oooo0?ooo`030?ooo`001`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo0P0000030?oooaH0ocd04`3oG0080?mj
00D0oiT000@0okP00?oG003oe`00ooD05`3o00000`3o09T0o`3G0?l0e`020>/0o``0o`000P3o09T0
0`3o0;P0o`3G0?l0^01=0?l00004003Qo`00oj<00?n50?l0e`8006Ko00<0o`000>_o003oe`000`3o
^0040?nI00P0ogX0503oG00F0?lm00<0oooo0P0000050?ooo`001`3oool010000000oooo0?ooo`00
00090?ooo`8000001@3oool00`000000oooo0?ooo`020?oooaH0ocd0503oG0070?mj00D0oiT000D0
okP00?oG003oe`00omL00>_o000F0?l000050?l07P3o0;P0o`2h0?l0e`3o0;P0G`3o00000`00ool0
0?mV01Co0002073o00030<co003om@00omL000<0okP0103oV@080?mj01@0oe`05P3o?@040?ooo`03
0000003oool0oooo00<0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?oooaH0ocd0503oG0080?mj00@0oiT00`3o^000103oe`00
ooD00:ko001Ao`02003oAa<0o`000P3o03eT0?l00080L?l000<0jol00?oe003oe`000`3o^0040?nI
00P0ogX04`3oG00G0?lm00@0oooo00<000000?ooo`3oool00`3oool000P0oooo0P00000:0?ooo`<0
0000103oool00`000000oooo0?ooo`020?oooaH0ocd0503oG0080?mj00@0oiT00`3o^000103oe`00
jol00?l0001A0?l2003oIP03003oQ@00ool0o`1j07T0o`0000<0ooD00?oG003o^0000P3o^0040?nI
00P0ogX04`3oG00G0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3ooolG0?lm01<0oe`0203oNP040?nI00<0okP000@0ooD0000:o`002_l00<;o0P00ol800`00
oj<00?oQ0?l0001i0?l000040>_o003oe`00okP00?nh00D0oiT01`3oNP0D0?mL01L0ocd0103oool0
0`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaL0ocd04`3oG0080?mj
00@0oiT00`3o^000103om@0000[o000:o`00`_l2003o`P03003oX`00on40o`0007T0o`0000@0jol0
0?oG003o^000okP01@3oV@070?mj01@0oe`05`3o?@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo5`3o?@0C0?mL00P0ogX0103oV@030?nh00040?oe003o0000
o`00003Qo`<00?oQ00<00?oo000Xo`3o0000N@3o00000`3oe`00okP00?nh00030?nI00T0ogX0503o
G00G0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolG
0?lm01@0oe`01`3oNP040?nI00<0okP000@0jol00?l0003o000008Go0`00hOl0103[0?l0o`1j0?l0
NP3o07Yh0?l000030?oG003o^000okP000<0oiT02@3oNP0B0?mL01T0ocd0103oool00`000000oooo
0?ooo`030?ooo`006`3oool2000000<0oooo5`3o?@0D0?mL00L0ogX0103oV@030?nh00030>_o003o
0000o`0000<0o`0000<0S`3o0?l0003o0000H`3o00000`3o03d0o`000?l0000D0?l000030?oG003o
^000okP000<0oiT02@3oNP0B0?mL01T0ocd00`3oool2000000D0oooo000K0?ooo`030000003oool0
oooo0080oooo6@3o?@0B0?mL00T0ogX00P3oV@030?nh00030?oe003o0000o`0006T0o`000P3o0=L2
0?l0G0@0o`000P3o0=L00`3o05`0o`000?l000090?l000040<co003oe`00okP00?nh00<0oiT0203o
NP0C0?mL01T0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?oooaT0ocd04P3oG0090?mj00<0oiT00P3o^0000`3om@0008Go0?l0G01>0?l000030?l0G03o0000
o`0001P0o`0000@0j`3o0?l0e`3o05`0o`1L103o00020?l0^0030?l0NP3o0000o`0000X0o`0000<0
omL00?nh003o^0000P3oV@090?mj01<0oe`06@3o?@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo6@3o?@0B0?mL00T0ogX00`3oV@020?nh00030?oe0000QOl0
o`1L04h0o`0000<0o`1L0?l0003o0000603o0000103[0?l0o`3G0?l0G03o05`40?l00080o`2h00<0
o`1j0?l0003o00002P3o00000`3oe`00okP00?nh00020?nI00T0ogX04`3oG00I0?lm00@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolI0?lm01<0oe`0203oNP03
0?nI0080okP000<0omL00?l0003o0000B`3o00030?l0m@030?l0e`3o03d0o`0001T0o`000`00I_l0
1000Xol00<;o0032o`00`_l:0?l00006003oo`3o0000o`000?l0003om@00okP0103oV@090?mj0180
oe`06P3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo
6P3o?@0B0?mL00T0ogX00P3oV@030?nh00030>_o003o0000o`0004T0o`0000H0o`1j0<`0o`3<0?l0
j`3o0?l0m@3o0;PJ0?l00003002So`00ool00?oo00<00?oQ00<00?oo003Qo`00hOl0203o00001P00
oj<006Ko001Vo`2?o`00omL00?nh00@0oiT01`3oNP0D0?mL01X0ocd0103oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaX0ocd0503oG0070?mj00@0oiT000@0okP0
0?oG003[o`00Sol00P00odL00`00on40j`3o0?l000140?l000<0[P3o00<0j`3o0?l0m@3o0;P06P3o
00000`00ool00?o2003o`P03003o`P06003oh@00ool00?oo0032o`002_l0o`2I1P3o00020>_o0003
0?oG003o^000okP000<0oiT0203oNP0D0?mL01X0ocd0103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?oooaX0ocd0503oG0070?mj00@0oiT00P3o^0001@3oe`00c?l0
0032o`00`_l00>7o04H0o`0000D002So0?l0003o0000o`3G0?l0^00K0?l00003003o`P00oj<00?nS
00800?nS0P00ol82003oh@03003Qo`3o0000o`0000H0o`000P3om@000`3oe`00okP00?nI00030?nI
00P0ogX04`3oG00K0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?oooaX0
ocd0503oG0070?mj00@0oiT00P3o^0001@3oe`00c?l00032o`00`_l00>7o04H0o`0000D002So0?l0
003o0000o`3G0?l0^00K0?l00003003o`P00oj<00?nS00800?nS0P00ol82003oh@03003Qo`3o0000
o`0000H0o`000P3om@000`3oe`00okP00?nI00030?nI00P0ogX04`3oG00K0?lm00<0oooo0P000005
0?ooo`006`3oool00`000000oooo0?ooo`020?oooa/0ocd04`3oG0080?mj00@0oiT000<0okP00?oG
003[o`00?`3o00000`3o0;P0o`3e0?l0m@070?l000030032o`2^0?l0[P3o01/0o`0000<0j`3o003Q
o`00oj<00`00ohD2003oX`04003o`P00on400?oQ003oo`P0o`000P3oe`020?nh00@0oiT01`3oNP0D
0?mL01/0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
oa/0ocd0503oG0070?mj00D0oiT000@0okP00?oG000co`00<ol0?@3o0000103[0?l0c03o0<`0o`3o
0;P40?l00003001Vo`00ool00?oo00800?oo7@3o00001`00oj<00?n5003oQ@00ofH00?n5003o`P00
on400P00ool00`00hOl006Ko0?l0G0030?l00003002So`3o0000ooD000<0okP0103oV@080?mj01<0
oe`0703o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo
703o?@0C0?mL00P0ogX0103oV@020?nh0080ooD000<0o`1j003oX`00`_l0403o00020?l0ebT0o`00
0P002_l00`1`0?l00?oo003oh@05003o`P800?oQ00<00?oo0?l0003o0=L06@3o00001`3o0?D00?nS
003oIP00ofH00?m7003oQ@3o00000`00hOl00`00`_l0o`000?l000040?l000040<co003oe`00okP0
0?nh00D0oiT01`3oNP0D0?mL01`0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?oooa`0ocd0503oG0090?mj00<0oiT00`3o^0000`3oe`00[_l00?l0000>0?l0
00030?l0e`3o0000o`0002`0o`0000<00?o2003oX`00oj<01000oj<3003o`P03003oh@00ool0o`00
01X0o`0000L0o`3e003oA`00odL00?lX003oQ@1A0?l008Go00800:?o00<006Ko0?l0003o00000`3o
00000`3om@00omL00?nh00020?nh00<0oiT02@3oNP0D0?mL01`0ocd0103oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa`0ocd0503oG0090?mj00<0oiT00`3o^000
0`3oe`00[_l00?l0000>0?l000030?l0e`3o0000o`0002`0o`0000<00?o2003oX`00oj<01000oj<3
003o`P03003oh@00ool0o`0001X0o`0000L0o`3e003oA`00odL00?lX003oQ@1A0?l008Go00800:?o
00<006Ko0?l0003o00000`3o00000`3om@00omL00?nh00020?nh00<0oiT02@3oNP0D0?mL01`0ocd0
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa`0ocd0503o
G0090?mj00@0oiT00`3o^0001@3oe`00<ol00?l0003o0000o`0N00P0o`000`00ohD01000oj<00?o2
003oh@00on4Y0?l000800:?o00<00?nS003oQ@00ohD00`00ohD4003oX`03003o`P00on400?oo01d0
o`0000@05?l003?o003o0000503o1@3o000201Co00040?oe003oe`00okP00?nh00@0oiT02@3oNP0C
0?mL01h0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
oah0ocd04`3oG0090?mj00D0oiT00P3o^0001P3oe`00ooD00?oe003<o`0006Ko003oQ@800<;o00@0
o`00003o2P0co`005?l00P00obP00`00odL00?mV003oQ@02003o`P03003oh@3o0000o`000080o`3e
00<0o`2I0?l0003o00007`3o00000`2?0?l0o`00003oQ@02003oQ@800?mV1000ohD3003oX`800?o2
00L00?oQ003oo`00`_l00<;o001Vo`0c0?l0c03o0080o`3e5@3o0000100Do`00L?l008oo002?o`03
0?l000030<co003om@00omL00080omL00P3o^0040?nI00X0ogX04`3oG00N0?lm00@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolN0?lm01<0oe`02P3oNP050?nI
0080okP00`3oe`00203om@00jol00>_o003[o`00c?l00:ko001`o`005?l00P00obP00`00odL00?mV
003oQ@02003oX`03003o`P00ool0o`000080o`3e00<0o`3G0?l0003o0000803o00000`00ohD00?mV
003oIP05003oIP<00?n50`00oj<2003o`P06003oh@00hOl00>7o0025o`3o05`0o`3e0P3o0=L00`3o
09T0o`000?l0000C0?l0000308oo003<o`00jol000<0ooD00P3oe`040?nh00D0oiT02@3oNP0C0?mL
01l0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0oooo7`3o?@0C0?mL00X0
ogX01@3oV@040?nh0080omL00P3om@00103[o`00c?l0003o2P0c0?l20>/0o`03003oX`00ohD00?nS
00800?nS00<00?o2003oo`3o00000`3o09TR0?l00003003oIP00odL00?m700800?m71000ofH2003o
Q@<00?nS0P00ol801@00on400?oo003oo`3o03d0o`1L00<0o`2h5`3o0000103<o`00ooD00?oe003o
m@020?oG00@0okP01@3oV@080?mj01D0oe`07`3o?@030?ooo`8000001@3oool001/0oooo00<00000
0?ooo`3oool00P3ooolO0?lm01D0oe`0203oNP060?nI00@0okP00`3oe`00103om@00[_l00?l00000
I_l20?l00003003o`P00oj<00?nS00800?o200<00?oQ003Qo`3o0000903o00000`00ohD00?lX003o
:002003o:0800?m70`00ofH2003oQ@<00?nS0P00ol800`00on400?oo003oo`0L0?l000030>_o003o
m@00omL00080omL0103o^0040?nI00X0ogX0503oG00P0?lm00@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3ooolO0?lm01D0oe`0203oNP060?nI00@0okP00`3oe`00
103om@00[_l00?l00000I_l20?l00003003o`P00oj<00?nS00800?o200<00?oQ003Qo`3o0000903o
00000`00ohD00?lX003o:002003o:0800?m70`00ofH2003oQ@<00?nS0P00ol800`00on400?oo003o
o`0L0?l000030>_o003om@00omL00080omL0103o^0040?nI00X0ogX0503oG00P0?lm00@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolP0?lm01@0oe`02@3oNP07
0?nI00<0okP00P3oe`00103om@00o`000?l00000`_l2003Qo`03003oh@00ol800?o200<00?oQ00<0
08Go0?l0003o00008`3o00001@00obP00?l:003o2P00o`X00?lX00800?m70P00ofH3003oQ@<00?nS
0P00ol801000on400?oo003oo`0D0?lK0?l000040>_o003oe`00omL00?oG00<0okP01@3oV@0:0?mj
01D0oe`0803o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo803o?@0E0?mL00X0ogX01P3oV@020?nh0080omL000@0ooD00?l0003o00000:?o0P00hOl00`00
ool00?oQ003oh@02003oo`03003Qo`00I_l0o`0002<0o`0000<00?oQ003o2P0Do`000`00o`X00`00
odL00?mV003oQ@03003oQ@@00?nS0P00ol800`00on400>7o003Qo`0L0?l000030>_o003oe`00okP0
00<0okP01@3oV@0;0?mj01@0oe`08@3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`03
0000003oool0oooo0080oooo8@3o?@0E0?mL00X0ogX01@3oV@020?nh0080omL000@0ooD00?l0003o
0000o`000P00Xol3003Qo`800<;o9P3o00000`00obP0<ol003?o000201Co0003003o:03o0000o`00
00800?o21@00oj<2003o`P800?oQ0P00hOlK0?l000030?l07P3[o`00omL000<0okP01P3oV@0:0?mj
01D0oe`08@3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo8@3o?@0E0?mL00/0ogX01@3oV@030?nh00040?oG002?o`00o`000?l00080o`1j0P3o00001P00
Aol0o`000?l0003o0000o`2I0?l0?B<0o`0000<0<ol0057o001Ao`000P0co`000`3o0000[P3o0>/0
o`020?l00003003oh@00ol800?o200@00?o200D00?oQ003oo`00hOl00>7o001Vo`0K0?l000040?oe
003oe`00okP00?nh00H0oiT02P3oNP0E0?mL0280ocd0103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?ooob40ocd05@3oG00;0?mj00D0oiT00`3o^000103oe`00Sol0
0?l0003o00020?l0NP80o`0000H004Oo0?l0003o0000o`000?l0V@3o03dS0?l0000303?o001Ao`00
DOl00080<ol000<0o`000:h0o`3[0?l00P3o00000`00on400?o2003o`P04003o`P05003oh@00ool0
0>7o003Qo`00I_l06`3o0000103om@00omL00?nh003o^0060?nI00X0ogX05@3oG00R0?lm00@0oooo
00<000000?ooo`3oool00`3oool001/0oooo0P0000030?ooob80ocd05@3oG00;0?mj00D0oiT00P3o
^0000`3oe`00Sol00?l000050?l000030?l0NP3o0000o`0002H0o`000`1`o`0203?o00030?l0000D
0?l0o`000080o`0000<00?oo003oh@00ol800P00ol82003oh@800?oo0P00Xol00`3o0000c03o0?l0
000G0?l000030?l0^03o0000ooD000<0okP01@3oV@090?mj01L0oe`08P3o?@030?ooo`8000001@3o
ool001/0oooo00<000000?ooo`3oool00P3ooolR0?lm01L0oe`02@3oNP050?nI00<0okP000<0ooD0
0?l0003o0000;03o00001000obP0Sol008oo002?o`02003o2P030?l00000Aol006Ko00800<;o00<0
0?oo003oh@00on400`00on42003oo`060032o`3o0000o`000?l0NP3o0;P0o`0m5`3o0000103o0;P0
jol00?oG003o^0050?nI00/0ogX05@3oG00T0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0
oooo00<000000?ooo`3oool00P3ooolT0?lm01H0oe`02P3oNP050?nI00040?nh003oe`00jol0003Q
obX0o`000P2?0?l0102?o`00[_l00:ko002^o`02057o00030?l00000I_l00:?o00800<;o00<00>7o
003oo`00ool01000ool00`00`_l0o`000?l0000>0?l000030?l0G03o0000o`0000/0o`0000<0omL0
0?nh003o^000103oV@0;0?mj01H0oe`0903o?@040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo9@3o?@0E0?mL00/0ogX0103oV@020?nh00030?oe003o0000o`00
02/0o`00103<o`0208oo0080o`0000<008Go0032o`00`_l01P00hOl00`00`_l008Go0?l0000H0?l0
0003003oo`3o0000o`000080o`0000<0omL00?nh003oV@00103oV@0:0?mj01H0oe`09@3o?@040?oo
o`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo9@3o?@0F0?mL00/0
ogX0103oV@000`3o^000omL00?oe00040?l000030025o`3o0000o`0000P0o`0000D0o`3e0?l0003o
0000o`000?l0^00F0?l00080c?l0103[o`020<co0003003o`P3o0000o`00008008Go00<00:?o0032
o`00`_l00P00Xol20?l000030?l0V@3o0000o`0000`0o`0000<0S`3o003oo`00ool00P00I_l60?l0
00060?l0m@3o0000o`000?l0003oe`00okP01@3oV@0:0?mj01H0oe`09P3o?@040?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo9@3o?@0F0?mL00/0ogX0103oV@00
0`3o^000omL00?oe00040?l000030025o`3o0000o`0000P0o`0000D0o`3e0?l0003o0000o`000?l0
^00F0?l00080c?l0103[o`020<co0003003o`P3o0000o`00008008Go00<00:?o0032o`00`_l00P00
Xol20?l000030?l0V@3o0000o`0000`0o`0000<0S`3o003oo`00ool00P00I_l60?l000060?l0m@3o
0000o`000?l0003oe`00okP01@3oV@0:0?mj01H0oe`09P3o?@040?ooo`030000003oool0oooo00<0
oooo000C0?ooo`D000000`3oool00`000000oooo0?ooo`020?ooobH0ocd05P3oG00:0?mj00D0oiT0
00L0okP00?oG003om@00ooD00>_o001A0?l00?oQ00X0o`0000@00?o2003oh@00on400>7o5P3o0000
0`3<o`00jol00>_o00040?oe0080jol000<0[_l00?l0003o0000603o00000`00on400?nS003o`P02
003oo`H0o`0000@0[_l00?oe003oe`00omL00P3o^0040?nI00T0ogX0603oG00V0?lm00@0oooo00<0
00000?ooo`3oool00`3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooobL0ocd05P3oG00:0?mj00D0oiT00`3o^0000`3oe`00o`000?l0e`090?l00005003oA`00ohD0
0?o2003o`P00ool05@3o00000`2^o`00jol00?oe00020?oe0080omL00`3om@000`3[o`000?l:0?l0
000H0?l00003003oIP00ohD00?oQ00800?oo1P3o00000`3[o`00omL00?nh00020?nh00<0oiT02P3o
NP0H0?mL02L0ocd0103oool00`000000oooo0?ooo`030?ooo`005@3oool00`000000oooo0?ooo`03
0?ooo`8000000`3ooolW0?lm01P0oe`02P3oNP040?nI00<0okP000D0ooD0003oh@3o0000o`00002S
o`050?l000030540o`0Do`00o`0000800?oQ00<00?oo0?l0003o07X01@3o00020?l0^0@0o`000P3o
07X20?l00004003oo`3o0000o`0008oo0080ooD0203oe`000`3om@00jol00?l0000H0?l0000303?o
003o00000:?o008008Go0P3o00001@00hOl0o`000?l0001Ao`00omL000<0okP00`3oV@0:0?mj01L0
oe`0:@3o?@030?ooo`8000001@3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooobT0ocd05`3oG00:0?mj00D0oiT00P3o^0000`3oe`00jol00>_o00020?l000070700
o`3o0000o`00073o003<o`005?l0002So`02003Qo`03002So`3o0000o`0000@0o`0000<000[o003o
o`00ool0103o0002003oo`<0o`000P3[o`000`3om@00omL00?oG000:0?oG00040?oe002^o`00[_l0
0>/0o``0o`0000<0o`1L0?l0003o00001P3o00000`2^o`00c?l00?l000040?l000050<co003om@00
ooD00?oG003o^0001@3oV@0:0?mj01P0oe`0:@3o?@040?ooo`030000003oool0oooo00<0oooo000E
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3ooolY0?lm01L0oe`02P3oNP05
0?nI0080okP000<0omL00>_o003[o`000P3o00001`1`0?l0o`000?l0001`o`00c?l001Co0000Xol0
0P00hOl00`00Xol0o`000?l000040?l00003000:o`00ool00?oo00@0o`000P00ool30?l00080jol0
00<0ooD00?oG003oe`002P3oe`00103om@00[_l00:ko003[0?l<0?l000030?l0G03o0000o`0000H0
o`0000<0[_l00<co003o0000103o00001@3<o`00ooD00?oe003oe`00okP000D0oiT02P3oNP0H0?mL
02T0ocd0103oool00`000000oooo0?ooo`030?ooo`00503oool2000000D0oooo00<000000?ooo`3o
ool00P3ooolZ0?lm01L0oe`02P3oNP050?nI00@0okP000<0omL00?oe003om@00103om@000`3[o`00
o`000?l000080?l00004003oQ@00on400?oQ002So`H0o`0000<0L?l00?oe003oe`000`3oe`0:0?nh
0080omL00P3om@000`3<o`00o`000?l000020?l00003003oo`3o0000o`0000@0o`0000<00?oQ0?l0
003o00001P3o00000`00hOl0ooD00?oe00040?oe0080omL00`3o^0050?nI00X0ogX0603oG00Z0?lm
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool[0?lm01L0
oe`02`3oNP050?nI00L0okP00`3oe`000`3<o`00o`000?l000070?l00003073o0000Aol004Oo00@0
o`000P3[o`000`3om@00omL00?oG00020?oG00h0okP00`3oe`00103om@00jol00<co003<o`060?l0
0003003o2P00hOl0o`0000L0o`0000<0ooD00?oG003oe`001P3o^0070?nI00T0ogX06@3oG00[0?lm
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool[0?lm01T0
oe`02`3oNP070?nI00H0okP000H0omL00?oe003om@00L?l00?l00000QOl30?l00004003oQ@3om@00
jol00>_o0080c?l000<0jol00?oe003oe`000P3oe`0E0?nh00@0omL000@0jol0003oQ@3o00000?l:
0`3[o`060?l0000403?o003oe`00omL00?oG00D0okP01`3oV@0;0?mj01T0oe`0;03o?@040?ooo`03
0000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo;03o?@0I0?mL00`0ogX0
2P3oV@040?nh0080omL0103om@070?oG00P0okP03P3oV@070?nh00L0omL00P3om@020>_o00030?oe
003oe`00omL000@0okP02P3oV@0;0?mj01P0oe`0;P3o?@040?ooo`030000003oool0oooo00<0oooo
000K0?ooo`030000003oool0oooo0080oooo;03o?@0I0?mL00`0ogX02P3oV@040?nh0080omL0103o
m@070?oG00P0okP03P3oV@070?nh00L0omL00P3om@020>_o00030?oe003oe`00omL000@0okP02P3o
V@0;0?mj01P0oe`0;P3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3oool^
0?lm01T0oe`03@3oNP090?nI0180okP05`3oV@0A0?nh00X0oiT03P3oNP0H0?mL02l0ocd00`3oool2
000000D0oooo000K0?ooo`030000003oool0oooo0080oooo;`3o?@0J0?mL00h0ogX0B03oV@0>0?mj
01X0oe`0;`3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo<03o?@0J0?mL0140ogX0@03oV@0@0?mj01/0oe`0<03o?@040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo<@3o?@0K0?mL01@0ogX04P3oV@0@0?mj01@0oiT0
503oNP0K0?mL0340ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?oo
o`020?oooc80ocd07@3oG01H0?mj01d0oe`0<P3o?@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo<P3o?@0M0?mL05P0ogX07@3oG00b0?lm00@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooold0?lm01`0oe`0E@3oNP0M0?mL
03@0ocd0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooocD0
ocd07`3oG01>0?mj01h0oe`0=P3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`800000
0`3ooolf0?lm0200oe`0BP3oNP0O0?mL03L0ocd00`3oool2000000D0oooo000K0?ooo`030000003o
ool0oooo0080oooo=`3o?@0S0?mL0440ogX08P3oG00i0?lm00@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3ooolg0?lm02<0oe`0@@3oNP0R0?mL03T0ocd0103oool0
0`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooocX0ocd09P3oG00f0?mj
02H0oe`0>P3o?@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo>`3o?@0_0?mL02<0ogX0;P3oG00k0?lm00@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3oooll0?lm07`0oe`0?P3o?@040?ooo`030000003oool0oooo00<0oooo
000K0?ooo`030000003oool0oooo0080oooo?`3o?@1h0?mL03l0ocd0103oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?ooocl0ocd0N03oG00o0?lm00@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooom00?lm07D0oe`0@@3o?@040?oo
o`030000003oool0oooo00<0oooo000K0?ooo`8000000`3ooom20?lm0780oe`0@@3o?@00103o7P00
oooo0?ooo`3oool2000000D0oooo000K0?ooo`030000003oool0oooo0080oooo00<0oah00?lm003o
?@00@P3o?@1/0?mL04@0ocd000<0oah00?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?ooo`80oah0A@3o?@1X0?mL04D0ocd00P3o7P040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo103o7P150?lm06<0oe`0AP3o
?@040?lN00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool4
0?lN04D0ocd0H`3oG0160?lm00@0oah0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?ooo`@0oah0B03o?@1N0?mL04L0ocd01@3o7P040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo1@3o7P1:0?lm05P0oe`0B@3o?@060?lN00@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool60?lN04/0ocd0
D`3oG01<0?lm00H0oah0103oool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0oooo1`3o
7P1>0?lm04`0oe`0CP3o?@070?lN00<0oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`02
0?ooo`L0oah0CP3o?@1<0?mL04h0ocd01`3o7P040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo2@3o7P1@0?lm04<0oe`0D@3o?@090?lN00@0oooo00<000000?oo
o`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool:0?lN05<0ocd0?03oG01C0?lm00X0
oah0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`/0oah0
E`3o?@0b0?mL05L0ocd02`3o7P040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003o
ool0oooo0080oooo303o7P1N0?lm0280oe`0GP3o?@0<0?lN00@0oooo00<000000?ooo`3oool00`3o
ool000L0oooo1@0000020?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool00P3oool<
0?lN05h0ocd08P3oG01N0?lm00`0oah0103oool00`000000oooo0?ooo`030?ooo`002@3oool00`00
0000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool>
0?lN0=X0ocd03P3o7P040?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P3oool2000000<0oooo3P3o7P3I0?lm00l0oah00`3oool20000
00D0oooo00090?ooo`030000003oool0oooo00P0oooo0P0000050?ooo`030000003oool0oooo0?`0
oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?`0oooo00<000000?ooo`3oool00`3oool000P0oooo0P00
000:0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`050000003oool0oooo0?ooo`000000
1@3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo
000K0?ooool000000@0000050?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.89184, -1.82524, 0.0122009, \
0.0122009}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(gr12 = 
        DensityPlot[
          juliaC[x, y, 150,  .2834,  .0007], \[IndentingNewLine]{x, \(-1.5\), 
            1.5}, {y, \(-1.5\), 1.5}, PlotPoints \[Rule] 200, Mesh -> False, 
          ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.320513 0.5 0.320513 [
[.01923 -0.0125 -12 -9 ]
[.01923 -0.0125 12 0 ]
[.17949 -0.0125 -6 -9 ]
[.17949 -0.0125 6 0 ]
[.33974 -0.0125 -12 -9 ]
[.33974 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66026 -0.0125 -9 -9 ]
[.66026 -0.0125 9 0 ]
[.82051 -0.0125 -3 -9 ]
[.82051 -0.0125 3 0 ]
[.98077 -0.0125 -9 -9 ]
[.98077 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -24 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .17949 -12 -4.5 ]
[-0.0125 .17949 0 4.5 ]
[-0.0125 .33974 -24 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66026 -18 -4.5 ]
[-0.0125 .66026 0 4.5 ]
[-0.0125 .82051 -6 -4.5 ]
[-0.0125 .82051 0 4.5 ]
[-0.0125 .98077 -18 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1.5)] .01923 -0.0125 0 1 Mshowa
.17949 0 m
.17949 .00625 L
s
[(-1)] .17949 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(-0.5)] .33974 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(0.5)] .66026 -0.0125 0 1 Mshowa
.82051 0 m
.82051 .00625 L
s
[(1)] .82051 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1.5)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.05128 0 m
.05128 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.46795 0 m
.46795 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.72436 0 m
.72436 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.85256 0 m
.85256 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-1.5)] -0.0125 .01923 1 0 Mshowa
0 .17949 m
.00625 .17949 L
s
[(-1)] -0.0125 .17949 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(-0.5)] -0.0125 .33974 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .66026 m
.00625 .66026 L
s
[(0.5)] -0.0125 .66026 1 0 Mshowa
0 .82051 m
.00625 .82051 L
s
[(1)] -0.0125 .82051 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1.5)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05128 m
.00375 .05128 L
s
0 .08333 m
.00375 .08333 L
s
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .21154 m
.00375 .21154 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .46795 m
.00375 .46795 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .59615 m
.00375 .59615 L
s
0 .62821 m
.00375 .62821 L
s
0 .69231 m
.00375 .69231 L
s
0 .72436 m
.00375 .72436 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .85256 m
.00375 .85256 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.17949 .99375 m
.17949 1 L
s
.33974 .99375 m
.33974 1 L
s
.5 .99375 m
.5 1 L
s
.66026 .99375 m
.66026 1 L
s
.82051 .99375 m
.82051 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.05128 .99625 m
.05128 1 L
s
.08333 .99625 m
.08333 1 L
s
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.21154 .99625 m
.21154 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.46795 .99625 m
.46795 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.59615 .99625 m
.59615 1 L
s
.62821 .99625 m
.62821 1 L
s
.69231 .99625 m
.69231 1 L
s
.72436 .99625 m
.72436 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.85256 .99625 m
.85256 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .17949 m
1 .17949 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .5 m
1 .5 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .82051 m
1 .82051 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05128 m
1 .05128 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .46795 m
1 .46795 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .72436 m
1 .72436 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .85256 m
1 .85256 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF2400FF2400FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF2400FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF2400FF2400FF2400
FF2400FF2400FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF2400FF2400
FF2400FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400
FF2400FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00
FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00
FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00
FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00B6FF000024FF92FF00DBFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00
FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00DBFF0092FF000049FF
B6FF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00
FFDB00FFDB00FFDB00FFFF00DBFF000092FF0000FFFF006D00DBFF00B6FF006DFFB6FF00
92FF009200FF0049FF0049FFB6FF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00
FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00
FFDB00FFFF00FFFF00DBFF00FF00000049FFFF000092FF00B6FF00006DFF00B6FF00DBFF
FF006DFF00000092FFB6FF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600
FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFFF00FFFF00
FFFF00FFFF00DBFF0092FF000092FF00DBFF00DBFF00FFFF00DBFF00DBFFFF000000FF00
FF00000092FF00DBFF00B6FF006DFFB6FF00B6FF00DBFF00FFFF00FFFF00FFDB00FFDB00
FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00
DBFF00DBFF00B6FF000049FF00B6FF00DBFF00B6FFFF000000FF00FF000000B6FF00DBFF
00FFFF00DBFF00DBFF0092FF92FF00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00
FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00FFFF00B6FF0092FF00B6FF00
DBFF00DBFF00B6FF00006DFF0092FF00DBFF00DBFF00FFFF00FFFF00FFFF00FFDB00FFB6
FF000000B6FF00DBFF00DBFF00FFFFFF00000092FF0049FFB6FF00FFFF00FFFF00FFFF00
FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00B6FF00
0049FF0092FFFF000000FFFF00DBFF00DBFF00DBFF0092FF00FFB600FFDB00FFFF00FFFF
00FFFF00DBFF00DBFF00B6FF006DFFB6FF00DBFF00DBFF00B6FF0092FF00B6FF00FFFF00
FFFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FFB600FFB600FFB600FFB600FFDB00FFDB00DBFF000092FF4900FF00B6FF00B6FF0092FF
0049FF6DFF0049FF00FF0000FF002400B6FF00DBFF00FFFF00FFFF00FFFF00FFDB00FFDB
00FFFF00FFFF00DBFF00FFFF00FFFF00DBFF00B6FF00B6FF24FF00B6FF00DBFF00FFFF00
FFFF00FFFF00FFFF00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00DBFF00B6FF0024FF00
00B6FF00B6FF00DBFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFFF00FFFF
00FFFF00FFFF00DBFFFF0000FF000049FF006DFF000049FF0092FF00B6FF00B6FF4900FF
006DFFDBFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600
FFB600FFB600FFB600FFDB00FFDB00DBFF000092FF00DBFF00FFFF00DBFF00DBFF0092FF
FF00000092FF00FF24DB00FFFF009200DBFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00DBFF00DBFF0092FF0092FF6DFF00DBFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00DBFF0092FF000092FF0092FF
00DBFF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFFF
00FFFF00FFFF00DBFFFF00B6DB00FF00FF240092FFFF0000006DFF00DBFF00DBFF00FFFF
00DBFF0092FFDBFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600
FFB600FFB600FFDB00FFDB00FFFF006DFF000092FF00DBFF00FFFF00FFFF00DBFF00B6FF
FF00B600FFDB00FF6D00FFB600FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00DBFF00B6FF00B6FF00B6FFFF000092FF00
DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF0092FF00FF000000B6FF00B6FF
00B6FF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFB600FF6DFF0024FF00B6006DFF00DBFF00FFFF00FFFF
00DBFF0092FF00FF00FFFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600
FFB600FFDB00FFFF00DBFF006DFF0024FF00FF00DB00FFFF00FFFF00FFFF00FFFF00FFFF
00FFDB00FFB600FF9200FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00DBFF00B6FF00B6FF0092FF0092FFFF0000
92FF00DBFF00DBFF00DBFF00DBFF00DBFF00DBFF0092FF00FF00000092FF0092FF00B6FF
00B6FF00B6FF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFB600FFB600FF9200FFB600FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF0092FF24FF006DFF00DBFF00FFFF00FFDB00FFB600FFB600FFB600FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600
FFDB00FFDB00DBFF000092FF0092FFFF009200FFB600FFDB00FFFF00FFFF00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00B6FF00B6FF0092FF0092FF006DFF0049FF
24FF00B6FF00B6FF00B6FF00B6FF00B6FF00B6FF0000FF00006DFF006DFF0092FF0092FF
00B6FF00B6FF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00FFFF00FFFF
00FFDB00FFDBFF00B6006DFF0092FFDBFF00FFDB00FFDB00FFB600FFB600FFB600FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00
FFDB00FFFF000092FF00DBFF00DBFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFFF00FFFF00FFFF00DBFF00DBFF00B6FF0092FF0092FF006DFF006DFF0049FF
0000FF92FF00B6FF00B6FF00B6FF00B6FF006DFF000000FF0049FF006DFF006DFF006DFF
006DFF0092FF00B6FF00DBFF00DBFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFFF00DBFF00DBFF0092FFFFFF00FFDB00FFDB00FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00
FFFF00DBFF009200FF00DBFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFFF00FFFF00FFFF00DBFF00B6FF0092FFFF0000FF00000000FF0024FF0024FF
0024FF49FF0092FF0092FF0092FF0092FF0049FF000024FF0024FF0024FFFF0000FF0000
FF0024FF00000092FF00B6FF00DBFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFFF00FFFF00FFFF00FFFFDB00FFDBFF00FFFF00FFDB00FFB600FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00
FFFF00006DFF0092FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFFF00FFFF00DBFF0092FFFF0000FF0049FF0024FF0000FF00000000FF
0000FF24FF006DFF006DFF006DFF006DFF0000FF000000FF0000FFFF0000FF0000FF0000
FF0049FF006DFF000000B6FF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFFF00FFFF00FFFF00FFFF0092FF0092FFFFFF00FFDB00FFDB00FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00
DBFF000092FF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFFF00FFFF00DBFFFF0024FF0092FF006DFF0000FF0000FF00002400FF
2400FF00FF0049FF0049FF0049FF0049FF0000FF242400FF4900FFFF0000FF0000FF0000
FF0049FF0092FF0092006DFF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00DBFF00DBFF00DBFF0092FFDBFF00FFFF00FFDB00FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00
B6FF00006DFF00B6FF00DBFF00DBFF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00DBFFFF0092FF00B6FF0092FF0000FF0000FF00006D00FF
4900FF00FF2424FF0049FF0049FF0024FF0000FF494900FF6D00FFFF0000FF0000FF0000
FF006DFF0092FF00B6FF006D00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00DBFF00DBFF00B6FF006DFFB6FF00FFFF00FFDB00FFDB00FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00
92FF0000B6FF00B6FF00B6FF00B6FF00DBFF00DBFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB
00FFDB00FFDB00FFDB00FFFF00DBFFFF0000FF00B6FF00DBFF00DBFF00FFB600FF9200FF
B600FF00FF2400FF0024FF0024FF0000FF0000FF496D00FF9200FFDB00FFFF0000FF006D
FF00B6FF00B6FF00B6FF002400DBFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB
00FFFF00FFFF00DBFF00DBFF00B6FF00B6FF00B6FF92FF00FFFF00FFDB00FFDB00FFB600
FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00FFFF00
B6FF000092FF0092FF006DFFFF0000FF000000B6FF00FFFF00FFDB00FFDB00FFDB00FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFDB00FFDB00FFDB00FFDB00FFFFFF006DFF00B6FF00DBFF00FFDB00FFB600FF9200FF
00FF9200FF2400FF0000FF0000FF0000FF0000FF49006DFF9200FFB600FFDB00FFFF00FF
FF00DBFF00DBFF00B6FF004900FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB
00FFFF00DBFF0092FF0049FF006DFF0092FF0092FF92FF00FFFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFFF00DBFF00
B6FF000049FF0049FFFF0000FF0049FF0092FF009200DBFF00FFDB00FFDB00FFDB00FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFDB00FFDB00FFDB00FFFF006DFFFF00DBDB00FFDB00FFDB00FF00FFDB
00FF6D00FF2400FF2400FF0000FF0000FF2400FF4900FF926D00FFB600FFDB00FFFF00FF
FF00FFFF00FFFF006D00B6FF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB
00FFFF00B6FFFF0092FF0049FF00000049FF006DFFB6FF00DBFF00FFFF00FFDB00FFDB00
FFDB00FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00
B6FF004900FF0024FFFF0000FF0000FF00B6FF00B600DBFF00FFDB00FFDB00FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF00B6FFFF004900FFB600FF92
00FF4900FF4900FF2400FF2400FF2400FF2400FF4900FF6D00FFDBFF0000FF00FFDB00FF
FF00DBFF009200DBFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFDBFF0092FF00DBFF0000FF00000024FF9200FFB6FF00DBFF00FFFF00FFFF00FFDB00
FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00DBFF00
B6FF006DFF002400FF6D00FFDB00FFFF00FFFF000000FFDB00FFDB00FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF6D
00FF4900FF4900FF2400FF2400FF2400FF4900FF4900FF6D00FF9200FFB600FFFF00DBFF
00DBFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFFFFF00FFDB00FF6D00FF4900FF6DFF00B6FF00DBFF00DBFF00FFFF00FFFF00
FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00FFFF00DBFF00DBFF00B6FF00B6FF00
92FF006DFF0024FF0000FFB6FF00DBB600FF00FFDB00FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF6D00FF6D
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF9200FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFDB00FF4924FF006DFF0092FF0092FF00B6FF00DBFF00DBFF00
FFFF00FFFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600
FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF0092FF0049FF000049FF0049FFDB00FF
24FF0024FF0024FF0000FF2400FF4900FF6D00FF9200FF9200FF9200FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF9200FF9200FF92
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF92
00FF9200FF9200FF6D00FF4900FF2400FF0024FF0024FF00DB00FF0049FF0024FF24FF00
92FF00DBFF00FFFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600
FFB600FFB600FFDB00FFDB00FFFF0092FF000024FF006DFF00B6FF0092FF006DFF0024FF
2400FF00FF6D00FF2400FF2400FF4900FF6D00FF9200FF9200FF9200FF9200FF9200FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF9200FF92
00FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF92
00FF9200FF6D00FF6D00FF4900FF2400FF2400FFB62400FF0000FF0049FF0092FF00B6FF
0092FFFF000092FF00FFFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200
FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600
FFB600FFDB00FFDB00FFFF00B6FF00006DFF00B6FF00DBFF00B6FF0092FF0049FFFF0000
FF00009200FF00FF6D00FF4900FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF92
00FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF92
00FF9200FF6D00FF6D00FF6D00FF4900FF929200FFFF0000FF00004900FF0092FF00B6FF
00DBFF00B6FF0092FFB6FF00FFFF00FFDB00FFDB00FFB600FFB600FFB600FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600
FFDB00FFDB00FFFF00006DFFFF000000DBFF00DBFF00DBFF00DBFF00B6FFFF0024FF0024
FF006DDB00FF00FFB600FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF6D00FF6D00FF92FF006DDB00FFFF0000FF0000FF00490092FF00B6FF
00DBFF00DBFF00FFFFFF00000092FFDBFF00FFDB00FFDB00FFB600FFB600FFB600FF9200
FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600
FFDB00FFFF009200FF00DBFF00DBFF00FFFF00DBFF00DBFF00DBFF00B6FF0049FFFF0092
FF00DBFF00FF00FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FFFFFF00FFFF00B6FF0092FF002400B6FF00DBFF
00DBFF00DBFF00FFFF00DBFF00DBFF0024FFFFFF00FFDB00FFB600FFB600FFB600FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00
FFDB00DBFF000092FF00B6FF00DBFF00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF0092FF
0092FF00FFFF00FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FFB600FFDBFF006DFF00FFFF006D0092FF00DBFF00DBFF
00FFFF00FFFF00FFFF00DBFF00B6FF0092FFDBFF00FFDB00FFDB00FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00
FFFF00DBFF000024FFFF002400FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFDB00FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FFB600FFB600FFDB00FFFF00DBFF00DBFF00DBFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF0092FF0024FFDBFF00FFFF00FFDB00FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF00
DBFF0000FF0000FF2400FFDB00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB
00FFDB00FFDB00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFDB00FFDB00FF2400FF49DBFF00FFFF00FFDB00FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00DBFF00
0092FF0092FF00B6FF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDBFF0049006DFF0092FFDBFF00FFDB00FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFDB00FFDB000049FF
00DBFF00DBFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00DBFF006DFFFFFF00FFDB00FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF00B600FF
00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00DBFF0000FFFFFF00FFDB00FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF000049FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00DBFF0049FFFFFF00FFDB00FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF000092FF
00DBFF00DBFF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00DBFF0092FFFFFF00FFDB00FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF000000FF
00B6FF00B6FF00B6FF00DBFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFFF00DBFF00B6FF00B6FF2400FFFFFF00FFDB00FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF006DFF00
0092FF006DFFFF006D0024FF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFDB00FFDB00FFDB00FFDB00DBFFFF00490092FF0092FF49FF00FFFF00FFDB00FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFFF00DBFF00
0049FF0000FFFF0000FF00DB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB6FF0092FF00000024FF0049FFDBFF00FFFF00FFDB00FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF00
92FF002400FF6D00FF00FFB600FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FF9200FF92FF00009200FF92FF00DBFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF00
B6FF006DFF0000FF0000FF4900FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FF9200FF6D00FF006DFF00B6FF00DBFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF00
6DFF000000FF9200FF00FFB600FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFDB9200FF0000FF49FF00DBFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF006DFF00
006DFF2400FFFF0000FF00B600FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFDB00FFDBFF00DBFF0000FF0000006DFF24FF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF00DBFF000092FF
0092FF0092FFFF002400DBFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF0049FFFF006D006DFF0092FF0092FFB6FF00FFFF00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF0092FF0000DBFF
00B6FF00DBFF00DBFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00DBFF00B6FF00B6FF00B6FF00DBFF6DFF00FFFF00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF0000B6FF00B6FF
00DBFF00DBFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00DBFF00DBFF00B6FF00B6FFFFFF00FFDB00
FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF000049FF00B6FF
00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF0049FFFFFF00FFDB00
FFDB00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF000000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0024FFFFFF00FFDB00
FFDB00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00DBFF0000B6FF00DBFF
00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00B6FFDBFF00FFDB00
FFDB00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFFF006D00FF00DBFF
00DBFF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB6
00FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00B6FF00FF49FFFF00FFDB00
FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFFF000000FF00B6FF
006DFF006DFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00DBFF0092FF0092FF0049FFFFFF00FFDB00
FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFFF00DBFF00FF0000
2400FFFF00FF00FFB600FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFB6FF00922400FF0024FFDBFF00FFFF00FFDB00
FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF00
6DFF0000FF2400FFB600FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFDB
00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FF496DFF00DBFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF00
6DFF00FF0000FF009200FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00DBFF00DBFF00DBFF00DBFF00FFFF00FFFF
00FFFF00FFDB00FFDB00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00DBFFFF0092FF000049FF00DBFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF00
00B6FF0092FF00B6FF00DBFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00DBFF00DBFF00DBFF00B6FF0092FF0092FFFF0049FF006DFF004900DBFF
00DBFF00FFFF00FFDB00FFDB00FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF92
00FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00DBFF0092FF006DFF00B6FFDBFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00DBFF00
FF00B600B6FF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00DBFF00DBFF00DBFF00B6FF0092FFFF0049FF006DFF0000FF00B6FF00B6FF00920000FF
FF006D0092FF00FFFF00FFDB00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF92
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF92
00FF9200FF9200FF9200FF9200FFB600FFB600FFDB00FFDB00FFFF00DBFF0092FF006DFF
00B6FF00B6FF00B6FF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00DBFF00DBFF00B6FF00B6FFFF0049DBFF00FFDB00FFDB00FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00
0000FF00DBFF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF
00DBFF00DBFF00B6FF0049FFFF0000FF00B6FF0092FF00B6FF00DBFF00DBFF00DBDB00FF
FF00B6FF00DB00B6FF00FFDB00FFDB00FFB600FFB600FF9200FF9200FF9200FF9200FF92
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FFB600FFB600FFDB00DBFF0092FFFF0024FF00B6FF00B6
FF0000FF0092FF00240092FF00B6FF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00DBFF00DBFF00DBFF00DBFF0024FFFFFF00FFDB00FFDB00FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00
B6FF0000B6FF00B6FF00DBFF00FFFF00FFFF00FFFF00DBFF00DBFF00DBFF00DBFF00DBFF
00DBFF00B6FF006DFFFF0049FF006DFF0092FF00B6FF00B6FF00DBFF00DBFF00DBFF00FF
FF00DBFF00B6FF006D00FFFF00FFDB00FFB600FFB600FF9200FF9200FF9200FF9200FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FFB600FFB600FFDB00FFFFFF00DBFF00DBFF00FFFF00DBFF00DB
FF00B6FF00B6FF00B6FF0049006DFF00B6FF00DBFF00DBFF00DBFF00DBFF00DBFF00DBFF
00FFFF00FFFF00FFFF00FFFF00DBFF00B6FF00B6FF92FF00FFFF00FFDB00FFDB00FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00
DBFF000049FF006DFF0092FF00FFFF00FFFF00DBFF00DBFF00DBFF00DBFF00DBFF00DBFF
00B6FF0092FFFF00FFFF0092FF0092FF0092FF0092FF00B6FF00B6FF00DBFF00DBFF00FF
FF00FFFF00FF4900FF0049FF00FFDB00FFB600FFB600FF9200FF9200FF9200FF9200FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FFB600FFB600FFDB006DFFFF00B6FF00DBFF00FFFF00DBFF00DB
FF00B6FF00B6FF0092FF00922400FF0092FF00B6FF00DBFF00DBFF00DBFF00DBFF00DBFF
00DBFF00DBFF00FFFF00FFFF00DBFF006DFF006DFFDBFF00FFFF00FFDB00FFDB00FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00
FFFF00B6FF004900FF00FF4900FFFF00DBFF00DBFF00DBFF00DBFF00DBFF00DBFF00B6FF
00B6FF006DFFFF0024FF006DFF006DFF006DFF0092FF0092FF00B6FF00DBFF00DBFF00FF
FF00FFDB00FFFF00FFFF00DB00DBFF00FFB600FFB600FF9200FF9200FF9200FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF9200FF9200FFB600FFDB006DFFFF0000FF00FFFF00FFFF00FFFF00DBFF00DB
FF00B6FF0092FF0092FF006DFF00490024FF00B6FF00B6FF00DBFF00DBFF00DBFF00DBFF
00DBFF00DBFF00DBFF00B6FF00FF4900FF49B6FF00FFFF00FFDB00FFDB00FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00
FFFF00FFFF00B6FF000024FF0049FF00B6FF00DBFF00DBFF00DBFF00DBFF00B6FF00B6FF
0092FF006DFFFF0000FF0049FF0049FF0049FF0000FF0000FF006DFF00B6FF00FFFF00FF
DB00FFDB00FFFF00FFFF00FF00B6FF00FFB600FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF9200FF9200FFB600FFDBFF0000FF00FFDB00FFFF00FFFF00FFFF00DBFF00B6
FF0092FF006DFF006DFF006DFF006D0000FF0092FF00B6FF00B6FF00B6FF00DBFF00DBFF
00DBFF00DBFF00B6FF0049FF0024FFB6FF00FFFF00FFFF00FFDB00FFDB00FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00
FFDB00FFFF00DBFF00FF00000092FF00B6FF00DBFF00DBFF00DBFF00B6FF00B6FF00B6FF
0092FF0049FFFF0024FF0049FF0024FF0000FF0000FF0000FF0000FF0049FF00FFFF00FF
DB00FFDB00FFDB00FFFF009200FFFF00FFB600FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF9200FF9200FFDBFF00B6FF00FFDB00FFDB00FFFF00FFFF00FFFF0092
FF0000FF0000FF0024FF0049FF0049FF0000006DFF0092FF00B6FF00B6FF00B6FF00DBFF
00DBFF00DBFF00B6FF0092FF00DBFFDBFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00
FFDB00FFFF00FFFF0092FF0000B6FF00B6FF00DBFF00DBFF00B6FF00B6FF00B6FF0092FF
0092FF0049FFFF0000FF0024FF0000FF0000FF0000FF0000FF0000FF0000FF00FFDB00FF
DB00FFDB00FFB600FF4900FF00FFFF00FFB600FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF9200FF9200FFB60049FFB600FFDB00FFDB00FFDB00FFFF00FFFF0000
FF0000FF0000FF0000FF0000FF00246D00FF006DFF0092FF00B6FF00B6FF00B6FF00B6FF
00DBFF00DBFF00B6FF0092FF92FF00FFFF00FFFF00FFDB00FFDB00FFB600FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00
FFDB00FFDB00FFFF00DBFF0024FF000000FF00FFDB00B6FF00B6FF00B6FF00B6FF0092FF
0092FF006DFF6D00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000DB00FFDB00FF
B600FFB600FFDB00FFFF00FF00DBFF00FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF9200FFB6FF00FFDB00FFB600FFB600FFB600FFDB00FFFF0000
FF0000FF0000FF0000FF0000FF00000024FF006DFF0092FF0092FF00B6FF00B6FF00B6FF
00B6FF00FFDB0000FF00FF00DBFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600
FFDB00FFDB00FFFF00FFFF00DBFF0092FF000000FF0092FF00B6FF00B6FF0092FF0092FF
0092FF006DFF0024FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000B600FFB600FF
B600FFB600FFDB00FFFF00FF00FFB600FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D
00FF6D00FF6D00FF6D00FF6D00FF92FF00B6FF00FFB600FFB600FFB600FFB600FFFF0000
FF0000FF0000FF0000FF00002400FF0049FF006DFF0092FF0092FF0092FF00B6FF0092FF
0092FF0024FF92FF00DBFF00FFFF00FFFF00FFDB00FFDB00FFB600FFB600FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600
FFDB00FFDB00FFDB00FFFF00FFFF00DBFF0049FF000092FF0092FF00B6FF0092FF0092FF
006DFF006DFF0049FF0000FFFF0000FF0000FF0000FF0000FF0000B600FF9200FF9200FF
9200FF9200FF2400FF00FFDB00FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF6D00FF6D00FF6D00FFB6FF00009200FF9200FF9200FF9200FF9200FF
B600FFFF0000FF00002400FF0024FF0049FF006DFF006DFF0092FF0092FF00B6FF0092FF
0092FF49FF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600
FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00B6FF0024FF006D00FFFF00000092FF0092FF
006DFF006DFF0049FF0024FF0000FF2400FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF
9200FFB600FFFF00FF00FF9200FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF6D00FF92FF00DBDB00FF9200FF6D00FF6D00FF6D00FF
4900FF2400FF2400FF0000FF0024FF0049FF006DFF006DFF0092FF006DFFFF000000FF24
6DFF00B6FF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600
FFB600FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00B6FF0092FF000024FF006DFF0092FF
006DFF006DFF0049FF0024FF0024FF0000FF2400FF4900FF4900FF6D00FF6D00FF6D00FF
4900FFFF00FF00FFB600FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FFDB9200FF6D00FF4900FF4900FF
2400FF2400FF0000FF0024FF0024FF0049FF006DFF006DFF0092FF0049FF0000FF92FF00
DBFF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600
FFB600FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00DBFF0092FF0049FF004900FF
0049FF006DFF0049FF0024FF0024FF0000FF0000FF2400FF4900FF4900FF4900FF9200FF
DB00FF00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FFDBFF00246D00FF4900FF
2400FF0000FF0000FF0024FF0024FF0049FF006DFF0049FF2400FF6DFF00B6FF00DBFF00
DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600
FFB600FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00DBFF00DBFF00B6FF0092FF00
24FF0000FF240024FF0049FF0000FF0000FF0000FF2400FF2400FF9200FFB600FF00FF6D
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900FFB6FF00DB
6D00FF0000FF6D00FF0000FFFF00000000FF24FF006DFF0092FF00B6FF00DBFF00DBFF00
FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600
FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00DBFF00DBFF00B6FF00
92FF0092FF0049FF0049FF0000FF2400FF2400FFDB00FF2400FF4900FF2400FF2400FF24
00FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF0000FF0000FF0000FF0000FF00
00FF0000FF0024FF0024FF0049FF006DFF0092FF0092FF00B6FF00DBFF00DBFF00FFFF00
FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600
FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00DBFF00DBFF00B6FF00
B6FF0092FF0092FF006DFF006DFF0049FF0049FF0024FF0024FF0000FF0000FF0000FF00
00FF0000FF0000FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF24
00FF2400FF2400FF2400FF2400FF2400FF0000FF0000FF0000FF0024FF0024FF0024FF00
49FF0049FF0049FF006DFF006DFF0092FF00B6FF00B6FF00DBFF00DBFF00DBFF00FFFF00
FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600
FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00
B6FF00B6FF0092FF0092FF006DFF006DFF0049FF0049FF0049FF0024FF0024FF0000FF00
00FF0000FF0000FF0000FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400FF24
00FF2400FF2400FF2400FF2400FF0000FF0000FF0000FF0024FF0024FF0024FF0049FF00
49FF006DFF006DFF0092FF0092FF0092FF00B6FF00B6FF00DBFF00DBFF00FFFF00FFFF00
FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600
FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00DBFF00DBFF00
DBFF00B6FF00B6FF0092FF0092FF006DFF006DFF0049FF0049FF0049FF0024FF0024FF00
00FF0000FF0000FF0000FF0000FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400FF24
00FF2400FF2400FF2400FF2400FF0000FF0000FF0024FF0024FF0024FF0049FF0049FF00
49FF006DFF006DFF0092FF0092FF00B6FF00B6FF00DBFF00DBFF00DBFF00FFFF00FFFF00
FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600
FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00DBFF00DBFF00
DBFF00B6FF00B6FF0092FF0092FF006DFF006DFF006DFF0049FF0049FF0024FF0024FF00
24FF0000FF0000FF0000FF0000FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400FF24
00FF2400FF2400FF2400FF2400FF0000FF0000FF0024FF0024FF0024FF0049FF0049FF00
6DFF006DFF006DFF0092FF0092FF00B6FF00B6FF00DBFF00DBFF00DBFF00FFFF00FFFF00
FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600
FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00DBFF00DBFF00
DBFF00B6FF00B6FF0092FF0092FF006DFF006DFF006DFF0049FF0049FF0024FF0024FF00
24FF0000FF0000FF0000FF0000FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400FF24
00FF2400FF2400FF2400FF2400FF0000FF0000FF0024FF0024FF0024FF0049FF0049FF00
6DFF006DFF006DFF0092FF0092FF00B6FF00B6FF00DBFF00DBFF00DBFF00FFFF00FFFF00
FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600
FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00DBFF00DBFF00
DBFF00B6FF00B6FF0092FF0092FF006DFF006DFF0049FF0049FF0049FF0024FF0024FF00
24FF0000FF0000FF0000FF0000FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400FF24
00FF2400FF2400FF2400FF2400FF0000FF0000FF0000FF0024FF0024FF0049FF0049FF00
49FF006DFF006DFF0092FF0092FF00B6FF00B6FF00DBFF00DBFF00DBFF00FFFF00FFFF00
FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600
FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00
B6FF00B6FF0092FF0092FF0092FF006DFF006DFF0049FF0049FF0024FF0024FF0024FF00
00FF0000FF0000FF0000FF0000FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF24
00FF2400FF2400FF2400FF2400FF2400FF0000FF0000FF0000FF0024FF0024FF0049FF00
49FF0049FF006DFF006DFF0092FF0092FF00B6FF00B6FF00DBFF00DBFF00FFFF00FFFF00
FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600
FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00DBFF00DBFF00DBFF00
B6FF00B6FF0092FF006DFF006DFF0049FF0049FF0049FF0024FF0024FF0024FF0000FF00
00FF0000FF0000FF0000FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF2400FF2400FF2400FF2400FF2400FF2400FF0000FF0000FF0000FF0000FF0024FF00
24FF0049FF0049FF006DFF006DFF0092FF0092FF00B6FF00B6FF00DBFF00DBFF00FFFF00
FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600
FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00DBFF00DBFF00B6FF00
92FF0092FF006DFF0049FF0024FF0024FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF49
00FF2400FFDB00FF2400FF2449FF0049FF0092FF0092FF00B6FF00DBFF00DBFF00DBFF00
FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600
FFB600FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00DBFF00DBFF00B6FF0092FF00
6DFF0024FF000000FFFF00000000FF6D00FF0000FF6D00FFFF00DB00FFB600FF4900FF24
00FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6DB600FF9200FF2400FF
2400FF0000FF0000FF0000FF0049FF0024FF00FF2424FF0092FF00B6FF00DBFF00DBFF00
FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600
FFB600FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00DBFF00B6FF006DFF002400FF
0049FF006DFF0049FF0024FF0024FF0000FF0000FF2400FF4900FF6D00FFFF002400FFDB
00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF6D00FF6DDB00FF9200FF4900FF4900FF4900FF
2400FF0000FF0000FF0024FF0024FF0049FF006DFF0049FF4900FF49FF0092FF00DBFF00
DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600
FFB600FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00DBFF0092FF000000FF0049FF0092FF
006DFF006DFF0049FF0024FF0024FF0000FF2400FF2400FF4900FF4900FF6D00FF9200FF
00FFDB00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF6D00FF6D00FFB6FF00FF4900FF6D00FF6D00FF6D00FF4900FF
4900FF2400FF0000FF0024FF0024FF0049FF006DFF006DFF0092FF006DFF0024FF92FF00
B6FF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600
FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00B6FF006DFF0000FF24FF0000006DFF0092FF
006DFF006DFF0049FF0024FF0000FF2400FF2400FF4900FF6D00FF6D00FF6D00FF9200FF
DB00FFFF00DB00FF9200FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF49
00FF6D00FF6D00FF6D00FF6D00FF92FF00FFB600FF9200FF9200FF6D00FF6D00FF6D00FF
6D00FF6D00FF2400FF0000FF0024FF0049FF006DFF006DFF0092FF0092FFFF00006D00FF
24FF00B6FF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600
FFDB00FFDB00FFDB00FFFF00FFFF00DBFF0049FF000092FF0092FF00B6FF0092FF0092FF
006DFF006DFF0049FF0024FF2400FFFF0000FF0000B600FF9200FF9200FF9200FF9200FF
9200FFFF000000FFB600FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF9200FFDB2400FF9200FF9200FF9200FF9200FFB600FFFF0000
FF0000FF0000FF0000FF00000000FF0049FF006DFF006DFF0092FF0092FF00B6FF0092FF
0092FF49FF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600
FFDB00FFDB00FFFF00FFFF00DBFF0092FF000024FF0092FF0092FF00B6FF0092FF0092FF
0092FF006DFF0049FF2400FFFF0000FF0000FF0000FF0000FF0000B600FFB600FFB600FF
B600FFFF00FFFF00B600FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF49
00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF9200FFB6FF00FFDB00FFB600FFB600FFB600FFB600FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00000024FF006DFF0092FF0092FF0092FF00B6FF00B6FF
0092FF0000FF92FF00DBFF00FFFF00FFFF00FFDB00FFDB00FFB600FFB600FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00
FFDB00FFDB00FFFF00DBFF0000FF000000FF00FFDB00B6FF00B6FF00B6FF00B6FF0092FF
0092FF006DFF0024FFFF0000FF0000FF0000FF0000FF0000FF0000DB00FFB600FFB600FF
B600FFDB00FFFF00FF00FFB600FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF9200FF9200DBFFFF00FFDB00FFB600FFB600FFDB00FFDB00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF00006D00FF006DFF0092FF0092FF00B6FF00B6FF00B6FF
00B6FF00FFDB0000FF24FF00DBFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00
FFDB00FFFF00FFFF0092FF000092FF00B6FF00DBFF00DBFF00B6FF00B6FF00B6FF00B6FF
0092FF006DFF6D00FFFF0024FF0000FF0000FF0000FF0000FF0000FF00FFDB00FFDB00FF
DB00FFB600FF0049FF00FFB600FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FFB600FFFF4900FFB600FFDB00FFDB00FFDB00FFFF00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0024FF00000049FF0092FF0092FF00B6FF00B6FF00B6FF
00DBFF00DBFF00B6FF00B6FF92FF00FFFF00FFFF00FFDB00FFDB00FFB600FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00
FFDB00FFFF00DBFF0000DBFF0092FF00B6FF00DBFF00DBFF00DBFF00B6FF00B6FF00B6FF
0092FF006DFFFF0000FF0049FF0049FF0024FF0000FF0000FF0092FF00FFFF00FFDB00FF
DB00FFFF00FFFF00B600FFDB00FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FFB600FFFFFF0092DB00FFDB00FFDB00FFFF00FFFF00FFFF0049FF0000
FF0000FF0000FF0000FF0024FF0049FF00240049FF0092FF00B6FF00B6FF00B6FF00DBFF
00DBFF00DBFF00B6FF0092FFFF0000DBFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00
FFFF00FFFF00B6FF000024FF0049FF00B6FF00DBFF00DBFF00DBFF00DBFF00B6FF00B6FF
00B6FF0092FF0000FFFF006DFF006DFF006DFF006DFF0092FF00B6FF00DBFF00FFFF00FF
DB00FFFF00FFFF000000FFDB00FFB600FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FFB600B6FFFF00FFFF00FFDB00FFDB00FFFF00FFFF00FFFF00B6FF006D
FF0000FF0000FF0049FF0049FF0049FF0000006DFF0092FF00B6FF00B6FF00DBFF00DBFF
00DBFF00DBFF00B6FF0049FF0024FFB6FF00FFFF00FFFF00FFDB00FFDB00FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00
FFFF00B6FF0000FF4900FF4900B6FF00DBFF00DBFF00DBFF00DBFF00DBFF00DBFF00DBFF
00B6FF00B6FF0024FFFF0049FF006DFF0092FF0092FF00B6FF00DBFF00DBFF00FFFF00FF
FF00FFFF0000006DFF00FFDB00FFB600FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF92
00FF9200FFB600FFB600DBFFFF00DBFF00FFDB00FFFF00FFFF00FFFF00DBFF00DBFF00B6
FF0092FF0092FF006DFF006DFF006DFF0024006DFF00B6FF00B6FF00DBFF00DBFF00DBFF
00DBFF00DBFF00DBFF00FFFF00FF494900FFB6FF00FFFF00FFDB00FFDB00FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00
DBFF00006DFF006DFF00DBFF00FFFF00FFFF00DBFF00DBFF00DBFF00DBFF00DBFF00DBFF
00DBFF00B6FF0092FF2400FFFF0092FF0092FF00B6FF00B6FF00DBFF00DBFF00FFFF00DB
FF00B6006DFF00FFDB00FFB600FFB600FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF92
00FF9200FFB600FFB600FFDB0049FF4900FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00B6
FF00B6FF0092FF0092FF0092FF0092FF00FF0092FF00B6FF00DBFF00DBFF00DBFF00DBFF
00DBFF00DBFF00FFFF00FFFF0092FF006DFF0049FFDBFF00FFFF00FFDB00FFDB00FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00
92FF0000B6FF00B6FF00DBFF00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00DBFF00DBFF
00DBFF00DBFF00B6FF006DFFFF0049FF00B6FF00B6FF00B6FF00DBFF00DBFF00FFFF00DB
FF00DB00FFFF00FFDB00FFB600FFB600FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF92
00FF9200FFB600FFB600FFDB00FFFFFF006DFF00B6FF00DBFF00FFFF00DBFF00DBFF00DB
FF00B6FF00B6FF0092FF006DFF0049006DFF00B6FF00DBFF00DBFF00DBFF00DBFF00DBFF
00DBFF00FFFF00FFFF00FFFF00DBFF00B6FF00B6FFB6FF00FFFF00FFDB00FFDB00FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00
0024FF00DBFF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00DBFF00DBFF00DBFF00B6FF0092FFFF0024FF0092FF0000FF00B6FF00B6FF00240092FF
00DBFF00FFDB00FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF92
00FF9200FFB600FFB600FFDB00FFDB00B6FFFF00DBFF00B6DB00FFFF00DBFF00DBFF00DB
FF00B6FF0092FF00B6FF00000049FF00B6FF00DBFF00DBFF00DBFF00DBFF00FFFF00FFFF
00FFFF00FFFF00FFFF00DBFF00DBFF00DBFF00DBFF0000FFFFFF00FFDB00FFDB00FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00DBFF00
FF004900B6FF00B6FF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00DBFF00DBFF00DBFF00B6FF00B6FF00B6FF006DFF0092FF00DBFF00FFFF
00FFDB00FFDB00FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF92
00FF9200FFB600FFB600FFB600FFDB00FFFF0092FFFF006D0000FFFF0092FF00B6FF00B6
FF0000FF006DFF00490092FF00B6FF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00B6FFFF00B6DBFF00FFDB00FFDB00FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF00
00B6FF006DFF0092FF00DBFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFDB
00FFDB00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FFB600FFB600FFDB00FFDB00FFFF00DBFF00DBFFFF0049FF006DFF0049
0092FF0092FF00B6FF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00DBFF00B6FF0092FF00B6FFDBFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF00
49FF00FF0000FF009200DBFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB
00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00FFFF00FFFF00DBFF00DBFF
00DBFF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFFFF0092FF00006DFF00DBFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF00
6DFF0000FF4900FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB6
00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFDB00FFDB00FFB600FF246DFF00DBFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFFF00DBFF000024FF
2400FFFF009200FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB6
00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFDB00FFDB00FFDB00FFDB00FFB6FF00FF2400FFFF0000DBFF00FFFF00FFDB00
FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFFF000049FF0092FF
0092FF00DBFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB6
00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFFF006DFF006DFF00B6FF0000FFFFFF00FFDB00
FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFFF0000FF4900B6FF
00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00DBFF00DBFF6D00FFFFFF00FFDB00
FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00DBFF0000B6FF00DBFF
00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00B6FFDBFF00FFDB00
FFDB00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF000024FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FFFFFF00FFDB00
FFDB00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF000049FF00DBFF
00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00DBFF00B6FF0049FFFFFF00FFDB00
FFDB00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFFF0000B6FF00B6FF
00DBFF00DBFF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00DBFF00DBFF00B6FF00B6FFFFFF00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF006DFF0000DBFF
00B6FF00B6FF00B6FF00DBFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFFF00DBFF00DBFF00B6FF00DBFF92FF00FFFF00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF00B6FF000092FF
0092FF006DFFFF006D0049FF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00DBFFFF00240092FF0092FF0092FFDBFF00FFFF00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF0024FF00
006DFFFF0000FF0000FF00DB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFDBFF00B6FF00002400FF006DFF6DFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF00
49FF000000FF9200FF00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FF9200FFB69200FF0000FF6DFF00DBFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF00
B6FF006DFF0000FF0000FF6D00FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FF9200FF4900FF006DFF00B6FF00DBFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF00
92FF009200FFFF000000FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FF9200FFB66D00FF2400FF92FF00DBFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFFF00DBFF00
0049FF0024FFFF0000FF009200FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFDBFF00DBFF00000000FF0049FFDBFF00FFFF00FFDB00FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFFF0049FF00
0092FF0092FFFF004900DBFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB
00FFDB00FFDB00FFDB00FFFF0024FFFF006D006DFF0092FF6DFF00FFFF00FFDB00FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF002400FF
00B6FF00B6FF00DBFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00DBFF00B6FF00B6FF00B6FF0000FFFFFF00FFDB00FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF000092FF
00DBFF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00DBFF00DBFF0092FFFFFF00FFDB00FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF000049FF
00DBFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00FFFF0049FFFFFF00FFDB00FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF000000FF
00DBFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00DBFFB600FFFFFF00FFDB00FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFDB00FFFF00006DFF
00DBFF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00FFFF00DBFF00DBFF0049FFFFDB00FFDB00FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00DBFF00
0092FF006DFFFF004900FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFDB00B6FF0092FF0092FFDBFF00FFDB00FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFFF00
DBFF0000FF4900FF2400FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFDB00FF2400FF00DBFF00FFFF00FFDB00FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00
FFFF00DBFF000024FF0092FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF
00DBFF00FFFF00FFDB00FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FFB600FFB600FFDB00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFF00FFFFFF00240024FFDBFF00FFFF00FFDB00FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00
FFDB00DBFF000092FF00B6FF00DBFF00FFFF00FFFF00FFFF00DBFF00DBFF0092FFFF006D
FF00FFFF006D00FFDB00FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FFB600FFFF0092FF0092FF00DBFF00DBFF00FFFF
00FFFF00FFFF00FFFF00DBFF00B6FF0092FFDBFF00FFDB00FFDB00FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600
FFDB00FFFF000024FF00DBFF00DBFF00FFFF00DBFF00DBFF00DBFF00B6FFFF0024FF0092
FF00B6FF00FF00FFFF00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FFB6FF00FFFF00DBFF00920049FF00B6FF00DBFF
00DBFF00DBFF00FFFF00DBFF00DBFF9200FFFFFF00FFDB00FFB600FFB600FFB600FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600
FFDB00FFDB00DBFF000092FFFF000000FFFF00DBFF00DBFF00B6FF0092FFFF0049FF0000
FF0000DB00FFFF006D00FF9200FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D
00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF92
00FF9200FF9200FF6D00FF6D00FF6D00FFB6DB00FFFF006DFF0024FF002400B6FF00DBFF
00DBFF00DBFF00DBFFFF0000006DFFFFFF00FFDB00FFDB00FFB600FFB600FFB600FF9200
FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600
FFB600FFDB00FFDB00FFFF00B6FF000092FF00B6FF00DBFF00B6FF0092FF4900FFFF0000
FF00009200FF00FF9200FF4900FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF92
00FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D
00FF6D00FF6D00FF6D00FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF92
00FF9200FF6D00FF6D00FF6D00FF4900FF6D9200FFFF0000FF00000049FF0092FF00B6FF
00DBFF00B6FF006DFFB6FF00FFFF00FFDB00FFDB00FFB600FFB600FFB600FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600
FFB600FFB600FFDB00FFDB00FFFF0092FF00FF00000092FF00B6FF0092FF0049FF0000FF
2400FF00FFB600FF2400FF2400FF4900FF6D00FF6D00FF9200FF9200FF9200FF9200FF92
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF6D00FF6D
00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF92
00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF92
00FF9200FF9200FF6D00FF4900FF2400FF2400FF6D2400FF0024FF006DFF0092FF00B6FF
006DFF0024FF92FF00FFFF00FFDB00FFDB00FFB600FFB600FFB600FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600
FFB600FFB600FFB600FFDB00FFDB00FFFF00DBFF0092FF0024FF000024FF0049FFDB00FF
24FF0024FF0000FF0000FF2400FF4900FF6D00FF9200FF9200FF9200FF9200FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF6D
00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF9200FF92
00FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF92
00FF9200FF9200FF6D00FF4900FF2424FF0024FF0024FF00DB00FF0049FF0049FF49FF00
92FF00DBFF00FFFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00FFFF00DBFF00DBFF00B6FF0092FF00
92FF006DFF0024FF0000FF4900FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF6D
00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF9200FF92
00FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFDBB600FFFF00DB00FFB624FF006DFF0092FF00B6FF00B6FF00DBFF00DBFF00
FFFF00FFFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00DBFF00
B6FF006DFF004900FF6D00FFDB00FFFF00FF00FFFF00FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFDB00FFDB00FFDB00FFFF00DBFF00DBFF00FFFF00FFB600FF92
00FF6D00FF4900FF4900FF2400FF2400FF2400FF4900FF4900FF6D00FF9200FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB
00FFDBFF0000FF00FFDB00FF6D00FF2400FF6DFF00B6FF00DBFF00DBFF00FFFF00FFFF00
FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00
B6FF009200FF0024FFFF0000FF0000FF00DBFF009200FFDB00FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFDB00FFDB00FFDB00FFFF00DBFFFF0092FF00DBDB00FFFF00FFFF000000FFDB
00FF6D00FF4900FF2400FF2400FF2400FF2400FF4900FF4900FF9200FFB6FF004900B6FF
00DBFF00FFFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB
00DBFFFF00B6FF00B6FF0000FF00000024FF4900FFB6FF00DBFF00FFFF00FFFF00FFDB00
FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFFF00DBFF00
B6FF00006DFF0049FFFF0000FF0049FF009200B6FF00FFFF00FFDB00FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB
00FFDB00FFDB00FFDB00FFFF00B6FFFF006DFF00FFFF00FFFF00FFDB00FFB600FF6D00FF
00FF9200FF4900FF2400FF0000FF0000FF2400FF2400FF6D00FFDBDB00FFDB00FFDB00FF
FF00DB006DFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB
00DBFFFF0092FF0092FF0049FF00000049FF0049FFB6FF00DBFF00FFFF00FFDB00FFDB00
FFDB00FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00FFFF00
92FF000092FF0092FF006DFF0049FF0092FF00DBFF00FFFF00FFDB00FFDB00FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB
00FFDB00FFDB00FFFF00FFFFFF0049FF00B6FF00DBFF00DBFF00FFDB00FFB600FF9200FF
006DFF00FF4900FF0000FF0000FF0000FF0000FF2400FF929200FFB600FFDB00FFFF00FF
FF00DBFF00B6FF006D00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB
00FFFF00B6FFFF0000FF0000006DFF0092FF0092FFB6FF00FFFF00FFFF00FFDB00FFDB00
FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00
92FF0000B6FF00B6FF00B6FF00DBFF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB
00FFDB00FFDB00FFFF00DBFFFF0024FF00B6FF00B6FF00B6FF006DFF0000DB00FF9200FF
6D00FF00FF4900FF0024FF0024FF0000FF0000FF24B600FF9200FFB600FFFF00FFFF00DB
FF00DBFF00B6FF000000DBFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB
00FFFF00DBFF00DBFF00B6FF00B6FF00B6FF00B6FF92FF00FFFF00FFDB00FFDB00FFB600
FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00
B6FF00006DFF00B6FF00DBFF00DBFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB
00FFDB00FFFF00FFFF00DBFFFF006DFF00B6FF0092FF006DFF0000FF0000FF00006D00FF
4900FF00FF4924FF0049FF0049FF0024FF0000FF244900FF6D00FFFF0000FF0000FF0000
FF0092FF00B6FF009200DBFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB6
00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFFF00FFFF00DBFF00DBFF00DBFF00B6FF006DFFB6FF00FFFF00FFDB00FFDB00FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFFF00
DBFF000092FF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFFF00FFFF00DBFF006DFFFF0092FF0092FF0049FF0000FF0000FF00004900FF
2400FF00FF2449FF0049FF0049FF0049FF0000FF002400FF2400FFFF0000FF0000FF0000
FF006DFF0092FF002400DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00DBFF00DBFF00DBFF0092FFDBFF00FFDB00FFDB00FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00
FFFF000092FF0092FF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFFF00FFFF00DBFF00B6FFFF0000FF006DFF0049FF0000FF0000FF00000000FF
0000FF00FF006DFF006DFF006DFF006DFF0024FF000000FF0000FFFF0000FF0000FF0024
FF0049FF00000092FF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00FFFF00FFFF0092FF006DFFFFFF00FFDB00FFDB00FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00
FFFF00DBFF00DB00FF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00DBFF00B6FF0092FFFF0000FF0024FF0000FF00000024FF0024FF
0024FF49FF0092FF0092FF0092FF0092FF0049FF000024FF0024FF0024FF0000FFFF0000
FF00000092FF00B6FF00DBFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFFF00FFFF00FFFF00DBFF9200FFDBFF00FFFF00FFDB00FFB600FFB600FFB600
FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFDB00
FFDB00FFFF000092FF00DBFF00DBFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00DBFF00DBFF00B6FF0092FF006DFF006DFF006DFF006DFF0049FF
0000FF6DFF00B6FF00B6FF00B6FF00B6FF0092FF000000FF0049FF006DFF006DFF0092FF
0092FF00B6FF00DBFF00DBFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFFF00DBFF00DBFF0092FFFFFF00FFDB00FFDB00FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600
FFDB00FFDB00DBFF000092FF006DFFFF00B600FFDB00FFDB00FFFF00FFFF00FFFF00FFDB
00FFDB00FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00B6FF00B6FF0092FF0092FF006DFF006DFF
00FF00B6FF00B6FF00B6FF00B6FF00B6FF00B6FF0024FF000049FF006DFF0092FF0092FF
00B6FF00B6FF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFFF00FFFF
00FFDB00FFB6FF00920092FF0092FFDBFF00FFDB00FFDB00FFB600FFB600FFB600FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600
FFB600FFDB00FFFF00DBFF006DFF0024FF000092FF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFB600FF9200FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00B6FF00B6FF00B6FF0092FF0092FFFF0000
92FF00DBFF00DBFF00DBFF00DBFF00DBFF00DBFF0092FF00FF00000092FF0092FF00B6FF
00B6FF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFDB00FFDB00FFDB00FFDB00FFB600FF9200FFB600FFDB00FFFF00FFFF00FFFF00FFFF
00FFFFFF00DB24FF006DFF00DBFF00FFFF00FFDB00FFB600FFB600FFB600FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600
FFB600FFB600FFDB00FFDB00FFFF0000FF000092FF00DBFF00FFFF00FFFF00DBFF006DFF
FF00B6FF002400FF6D00FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00DBFF00B6FF00B6FF00B6FFFF000092FF00
DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF0092FF00FF000000B6FF00B6FF
00B6FF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB
00FFDB00FFFF00FFFF00FFFF00FFB600FF6D00FFDBFF00B600B6FF00DBFF00FFFF00FFFF
00DBFF0092FF6DFF00FFFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600
FFB600FFB600FFB600FFDB00FFDB00DBFF000092FF00DBFF00FFFF00DBFF00DBFF006DFF
FF00000092FF00FF24DB00FFFF00B600DBFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB
00FFFF00FFFF00FFFF00FFFF00DBFF00DBFF00DBFF00DBFF0092FF0092FF92FF00DBFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00DBFF006DFF000092FF0092FF
00DBFF00DBFF00DBFF00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFFF
00FFFF00FFFF00DBFFFF0092DB00FF00FF240092FFFF00000092FF00DBFF00DBFF00FFFF
00DBFF0092FFDBFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FFB600FFB600FFB600FFB600FFDB00FFDB00DBFF00006DFF4900FF00B6FF00B6FF0092FF
0049FF6DFF0049FF00FF0000FF000000DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB
00FFFF00FFFF00FFFF00FFFF00FFFF00DBFF00B6FF00B6FF24FF00B6FF00DBFF00FFFF00
FFFF00FFFF00FFFF00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00DBFF00B6FF0024FF00
00B6FF00B6FF00DBFF00FFFF00FFFF00DBFF00FFFF00FFFF00FFDB00FFDB00FFFF00FFFF
00FFFF00DBFF00B6FFFF0024FF000049FF006DFF000049FF0092FF00B6FF00B6FF4900FF
0092FFDBFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFFF00FFFF00B6FF0092FF00B6FF00
DBFF00DBFF00B6FF00006DFF00B6FF00DBFF00DBFF00FFFF00FFFF00FFFF00FFDB00FFB6
0092FF00DBFF00DBFF00DBFF00FFFFFF00000092FF0049FFB6FF00FFFF00FFFF00FFFF00
FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00B6FF00
0049FF0092FFFF000000FFFF00DBFF00DBFF00B6FFFF000000FFB600FFDB00FFFF00FFFF
00FFFF00DBFF00DBFF0092FF006DFFB6FF00DBFF00DBFF00B6FF0092FF00B6FF00FFFF00
FFFF00FFDB00FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFFF00FFFF00
FFFF00FFFF00DBFF0092FF000092FF00DBFF00DBFF00FFFF00DBFF00B6FFFF000000FF00
FF000000B6FF00DBFF00B6FF0049FFB6FF00DBFF00DBFF00FFFF00FFFF00FFDB00FFDB00
FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFFF00FFFF00
DBFF00B6FF00B6FF00006DFF00B6FF00DBFF0092FFFF000000FF00FF000000DBFF00DBFF
00FFFF00DBFF00DBFF0092FF92FF00DBFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00
FFDB00FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00
FFDB00FFDB00FFDB00FFFF00B6FF000092FFFF0000FF006D00DBFF00B6FF006DFFB6FF00
92FF00FF00000049FFFF0000DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00
FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00
FFDB00FFFF00FFFF00B6FF000049FF0049FF9200FF92FF00B6FF00006DFF00B6FF00DBFF
FF006D0000FF0092FFDBFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600
FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFDB00FFDB00FFDB00FFFF00FFFF00DBFF00B6FF000049FF92FF00DBFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00
FFDB00FFDB00FFDB00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00DBFF0092FF000024FF
B6FF00DBFF00FFFF00FFFF00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00
FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00FFDB00
FFDB00FFDB00FFDB00FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00FFDB00
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFDB00FFDB00FFDB00FFDB00
FFDB00FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FFB600FFB600
FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600FFB600
FFB600FFB600FFB600FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200
FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF9200FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400
FF2400FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400
FF2400FF2400FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF2400FF2400
FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF2400FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF2400FF2400FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF6D00
FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF6D00FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900
FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF4900FF2400FF2400FF2400FF2400
FF2400FF2400FF2400FF2400FF2400FF2400FF2400FF2400
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`006`3oool500000080oooo0P0000040?ooo`800000803oool5000001l0oooo0P0000040?oo
o`800000103oool2000001h0oooo0P00000Q0?ooo`800000103oool2000000@0oooo0P00000P0?oo
o`D000007P3oool500000080oooo0P0000040?ooo`8000000`3oool001d0oooo00<000000?ooo`3o
ool01`3oool010000000oooo0?ooo`00000Q0?ooo`030000003oool0oooo01h0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000L0?ooo`040000003oool0oooo000001l0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000Q0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000020?ooo`007@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo01X0oooo00@000000?ooo`3oool000007`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`005@3oool4000000@0oooo00<0
00000?ooo`3oool0203oool2000001X0oooo100000040?ooo`030000003oool0oooo01P0oooo1000
00020?ooo`040000003oool0oooo000000T0oooo0P00000M0?ooo`040000003oool0oooo000001l0
oooo00@000000?ooo`3oool000002@3oool200000280oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`080?ooo`8000000`3oool001d0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0L0?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`00703oool2000000X0oooo0`00000P0?ooo`8000008@3oool2
000000X0oooo0`00000M0?ooo`8000008@3oool2000000X0oooo0`00000P0?ooo`8000008@3oool2
000000X0oooo0`0000020?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`006`3ooooo0000004000001@3oool001/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo000K0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0
oooo00D000000?ooo`3oool0oooo000000050?ooo`001`3oool500000080oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3l0?ooo`03
0000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P3oool200000?`0oooo0P0000050?ooo`0000<0oooo0000000000000P0000040?ooo`030000003o
ool0oooo00P0oooo0P0000050?ooo`030000003oool0oooo0080oooo3`3o903H0?m900l0ob@0103o
ool00`000000oooo0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool>0?lT06L0odT0303oK@1W0?m900h0ob@0103oool0
0`000000oooo0?ooo`030?ooo`00203oool2000000X0oooo0`0000040?ooo`030000003oool0oooo
0080oooo303o901M0?m902@0ofd0G@3oB@0<0?lT00@0oooo00<000000?ooo`3oool00`3oool001/0
oooo00<000000?ooo`3oool00P3oool<0?lT05d0odT0903oK@1M0?m900`0ob@0103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`/0ob@0EP3oB@0d0?m]05H0odT0
2`3o90040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo2P3o
901B0?m903h0ofd0DP3oB@0:0?lT00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<00000
0?ooo`3oool00P3oool90?lT0500odT0A03oK@1@0?m900T0ob@0103oool00`000000oooo0?ooo`03
0?ooo`006`3oool2000000<0oooo1`3o901>0?m904`0ofd0CP3oB@070?lT00<0oooo0P0000050?oo
o`006`3oool00`000000oooo0?ooo`020?ooo`L0ob@0CP3oB@1<0?m]04h0odT01`3o90040?ooo`03
0000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo1P3o901;0?m905@0ofd0
B`3oB@060?lT00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3o
ool50?lT04X0odT0F03oK@1:0?m900D0ob@0103oool00`000000oooo0?ooo`030?ooo`006`3oool0
0`000000oooo0?ooo`020?ooo`D0ob@0AP3oB@1P0?m]04H0odT01@3o90040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo103o90150?m906@0ofd0A@3oB@040?lT
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool40?lT04D0
odT0I03oK@150?m900@0ob@0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo
0?ooo`020?ooo`80ob@0A03oB@1Z0?m]04@0odT00P3o90040?ooo`030000003oool0oooo00<0oooo
000K0?ooo`030000003oool0oooo0080oooo00<0ob@00?m9003oB@00@P3oB@1/0?m]04@0odT000<0
ob@00?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0oooo00<0ob@0
0?m9003oB@00?`3oB@1b0?m]0480odT00`3oool2000000D0oooo000K0?ooo`030000003oool0oooo
0080oooo@03oB@1f0?m]0400odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?ooocl0odT0N03oK@0o0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3ooolo0?m907P0ofd0?`3oB@040?ooo`030000003oool0oooo00<0oooo
000K0?ooo`030000003oool0oooo0080oooo?03oB@1n0?m]03`0odT0103oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?oooc/0odT0:`3oK@0Y0?nB02`0ofd0>`3oB@04
0?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo>P3oB@0U0?m]
03P0oi809@3oK@0j0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3ooolg0?m902<0ofd0@P3oTP0S0?m]03L0odT0103oool00`000000oooo0?ooo`030?ooo`00
6`3oool2000000<0oooo=`3oB@0S0?m]0480oi808`3oK@0g0?m900<0oooo0P0000050?ooo`006`3o
ool00`000000oooo0?ooo`020?ooocH0odT0803oK@1:0?nB0200ofd0=P3oB@040?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo=@3oB@0M0?m]0580oi807@3oK@0e
0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooold0?m9
01`0ofd0EP3oTP0L0?m]03@0odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?oooc80odT06`3oK@1L0?nB01/0ofd0<P3oB@040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo<P3oB@0K0?m]05`0oi806`3oK@0b0?m900@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooola0?m901/0ofd04`3o
TP0E0?nf00h0oi805@3o]P0C0?nB01/0ofd0<@3oB@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo<03oB@0J0?m]0100oi80@P3o]P0@0?nB01X0ofd0<03oB@04
0?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3oool_0?m901X0ofd03@3oTP0;0?nf
00H0om/0:03o]P060?oK00/0okH03@3oTP0J0?m]02l0odT00`3oool2000000D0oooo000K0?ooo`03
0000003oool0oooo0080oooo;P3oB@0I0?m]00d0oi802@3o]P0C0?oK01H0okH04`3of`090?nf00d0
oi806@3oK@0^0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0
0P3oool/0?m901T0ofd0303oTP090?nf00<0om/00`3oo`001P3Ko`00]_l0000To`009?l0T_l00=_o
00L0ool01`3of`0>0?nf00L0om/01`3oo`001P3Ko`00T_l00019o`00BOl0]_l00=_o00<0ool00`3o
f`090?nf00`0oi806@3oK@0/0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<00000
0?ooo`3oool00P3oool/0?m901T0ofd0303oTP090?nf00<0om/00`3oo`001P3Ko`00]_l0000To`00
9?l0T_l00=_o00L0ool01`3of`0>0?nf00L0om/01`3oo`001P3Ko`00T_l00019o`00BOl0]_l00=_o
00<0ool00`3of`090?nf00`0oi806@3oK@0/0?m900@0oooo00<000000?ooo`3oool00`3oool001/0
oooo00<000000?ooo`3oool00P3oool/0?m901P0ofd02`3oTP060?nf00L0om/000H0ool00=_o003K
o`0009;o0000o`3o06d2003Ko`03002fo`00KOl0]_l00080T_l000@0TP3o0019o`00BOl0]_l00`3o
o`0F0?oK00<0ool000@0fol00?l00000BOl0o`000P2Bo`000`2fo`0006go002fo`02003Ko`030?l0
K@3o000009;o0080]_l000<0ool00?oK003of`001@3of`060?nf00/0oi806@3oK@0[0?m900@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool[0?m901L0ofd02`3o
TP050?nf00@0om/01@3oo`00103Ko`00T_l0002Bo`00T_l2003Ko`06003oo`00fol00=_o003Ko`3o
00000?l00P3o00001000T_l00=_o002fo`00KOl30;Ko00040=_o003oo`00ool00?oo00h0om/00`3o
o`020=_o0080]_l000@004Wo002fo`00fol00;Ko0P3o00000`00o`00o`00002fo`02003Ko`03003o
o`00fol00=_o008009;o00<0T_l00=_o003oo`00103oo`040?oK00D0okH02`3oTP0G0?m]02/0odT0
103oool00`000000oooo0?ooo`030?ooo`004`3oool5000000<0oooo00<000000?ooo`3oool00P3o
oolZ0?m901L0ofd02P3oTP050?nf0080om/00`3oo`00102fo`00T_l00;Ko002fo`020=_o00040;Ko
0000KOl009;o002Bo`800=_o1000ool01@00om/00?nf0?l0003o00000;Ko00800=_o00H00?oo0?l0
003o000009;o0019o`2fo`040?oo00X0om/0103oo`000`2fo`0004Wo002Bo`020?l00004003oo`00
fol00=_o003Ko`8009;o00<00?nf003of`00ool00`00ool2003Ko`800;Ko00@006go0;Ko003Ko`00
fol00P2fo`000`2Bo`00]_l00?oo00020?oo0080om/01@3o]P0:0?nB01L0ofd0:P3oB@040?ooo`03
0000003oool0oooo00<0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3ooolY0?m901L0ofd02P3oTP050?nf0080om/000@0fol0002Bo`00T_l0B@3o0P00]_l2002Bo`04
0019o`1]o`00BOl00?l00080o`0T00<00;Ko003Ko`00ool00`00ool2003of`<00?oo00<00=_o003o
o`00ool00P00fol2002fo`0402Co002fo`00]_l00=_o00D0ool00P3of`050?oo00040=_o002fo`00
]_l002Co00800;Ko0P00fol6003oo`800?oK1@00ool01`00fol0o`000?l0003o0000BOl006go0000
BOl00P00T_l2002fo`0404T0o`00KOl006go0=_o0080om/01@3o]P0:0?nB01L0ofd0:@3oB@040?oo
o`030000003oool0oooo00<0oooo000E0?ooo`030000003oool0oooo00<0oooo0P0000030?ooobT0
odT05`3oK@0:0?nB00D0okH00P3of`00103Ko`0009;o002Bo`190?l2002fo`8009;o00@004Wo06go
0019o`00o`000P3o02@00`00]_l00=_o003oo`03003oo`800?oK0`00ool00`00fol00?oo003oo`02
003Ko`800;Ko00@09?l00;Ko002fo`00fol01@3oo`020?oK00D0ool000@0fol00;Ko002fo`009?l0
0P00]_l2003Ko`H00?oo0P00om/5003oo`07003Ko`3o0000o`000?l00019o`00KOl00019o`02002B
o`800;Ko00@0B@3o001]o`00KOl0fol00P3of`050?nf00X0oi805`3oK@0Y0?m900<0oooo0P000005
0?ooo`003@3oool4000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
obL0odT0603oK@0:0?nB00@0okH00`3of`001@3Ko`0009;o003Ko`00fol00?oo00800=_o0P00T_l0
103o000009;o003o903K0?l20?l0TP03003Ko`00ool00?oo00800?oo0`00om/5003oo`D00=_o0`00
T_l00`1]o`00fol00?oo00090?oo00030=_o002Bo`0009;o008009;o1@00fol5003oo`<00?oK1000
ool01`00fol0o`2f0?l0]P3K0?l00?lT002Bo`3o00000P00KOl2003Ko`05003oo`00fol00=_o002B
o`3Ko`000`3of`040?nf00X0oi80603oK@0W0?m900@0oooo00<000000?ooo`3oool00`3oool001D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooobL0odT05P3oK@0:0?nB00D0
okH00`3of`000`3oo`00KOl0002Bo`02003Ko`800?oo00L00=_o002fo`00]_l0o`2f003of`00ofd0
0?nf00@00?oo1P00om/5003oo`@00=_o1000]_l00`3o0000T_l00=_o00020=_o00@0ool00`3Ko`00
0`2Bo`00o`00002fo`03002fo`@00=_o1@00ool:003of`04003o]P00ofd0o`0T0?l0]P8006go00<0
0=_o003oo`00ool00P00fol00`00T_l00?l00?oo00030?oK00D0okH02@3oTP0G0?m]02L0odT0103o
ool00`000000oooo0?ooo`030?ooo`00503oool2000000D0oooo00<000000?ooo`3oool00P3ooolV
0?m901H0ofd02`3oTP040?nf00070?oK003oo`00fol00=_o001]o`009?l00?l0f`07003oo`04003o
f`00okH00?nB003o]PX00?oK1@00ool4003Ko`800;Ko0`00T_l00`3o0000T_l00=_o00070=_o0003
09;o003o000009;o008009;o0`00]_l3003Ko`D00?oo2000om/3003o]P03003oTP00okH00?oo00L0
0?oo00<009;o02Co001]o`000P3Ko`000`3oo`00om/00?nf00030?nf00/0oi805P3oK@0V0?m900@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolU0?m901L0ofd0
2P3oTP040?nf0080om/000H0fol0002Bo`00T_l009;o0?l0TP00okH2003of`800?oo1000om/5003o
]PP00?oK1@00ool3003Ko`800;Ko0`00T_l00`00KOl004Wo02Co00080;Ko0003003o0000KOl006go
00<009;o0P00]_l3003Ko`D00?oo2000om/5003o]P<00?oK0`00ool3003of`050?l0]P00KOl009;o
002Bo`3Ko`000P3of`040?nf00/0oi805P3oK@0U0?m900@0oooo00<000000?ooo`3oool00`3oool0
01/0oooo00<000000?ooo`3oool00P3ooolU0?m901L0ofd02P3oTP040?nf0080om/000H0fol0002B
o`00T_l009;o0?l0TP00okH2003of`800?oo1000om/5003o]PP00?oK1@00ool3003Ko`800;Ko0`00
T_l00`00KOl004Wo02Co00080;Ko0003003o0000KOl006go00<009;o0P00]_l3003Ko`D00?oo2000
om/5003o]P<00?oK0`00ool3003of`050?l0]P00KOl009;o002Bo`3Ko`000P3of`040?nf00/0oi80
5P3oK@0U0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3o
oolU0?m901H0ofd02P3oTP040?nf0080om/000<0ool0002Bo`00fol00P00fol00`00ool00?oK003o
f`07003of`D00?nf2P00om/3003oo`<00=_o00<00;Ko002Bo`00T_l00`00KOl01000BOl0003o09;o
002Bo`040;Ko0080KOl000<0003o0019o`00KOl01000KOl00`00T_l00;Ko002fo`02003Ko`@00?oo
1`00om/6003o]PT00?oK00H00?oo003Ko`00fol00=_o002Bo`3oo`020?oK00@0okH02P3oTP0F0?m]
02D0odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooob@0
odT05P3oK@0:0?nB00D0okH000@0om/00?oo003Ko`00TP3o0P00fol3003oo`P00?oK1P00okH9003o
f`<00?oo00@00=_o002fo`00]_l009;o0P3o00020000o`<002Co0P19o`0409;o0080BOl00`009?l3
0?l000060?l0903o000009;o002Bo`00]_l00=_o1000ool7003of`H00?nf2000om/5003oo`040=/0
o`3Ko`00ool00?oK00D0okH02P3oTP0F0?m]02@0odT0103oool00`000000oooo0?ooo`030?ooo`00
6`3oool2000000<0oooo903oB@0E0?m]00/0oi800`3o]P030?oK00030?oo0000KOl009;o00L00?oo
1P00om/6003o]PX00?oK0P00ool01P00fol009;o002Bo`3o0000o`190?l090<0o`000P000?l202Co
00@0KOl00P00o`020000o`@0o`0000H0o`190?l0K@3o0000o`00002fo`00fol2003oo`T00?oK1P00
okH8003of`D00?oo0P00T_l0103oo`00om/00?oK003of`050?nf00T0oi805@3oK@0T0?m900<0oooo
0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?ooob80odT05@3oK@0;0?nB00D0okH00`3o
f`000`3Ko`0009;o003Ko`03003Ko`@00?oo1P00om/7003o]PT00?oK0P00ool01@00fol0o`0T0?l0
903o0980o`1]00@0o`000P0T0?l2003o00@0BOl00P00ob@00`0T0?l0B@3o0?l000030?l000060?l0
B@3o0980o`2B0?l0TP00KOl00=_o0P00ool8003of`L00?nf1P00om/4003oo`@00=_o00<009;o0=_o
003oo`000P3of`050?nf00/0oi805@3oK@0R0?m900@0oooo00<000000?ooo`3oool00`3oool001/0
oooo00<000000?ooo`3oool00P3ooolQ0?m901H0ofd02P3oTP050?nf00<0om/000@0ool00;Ko0000
KOl00;Ko1000fol3003oo`H00?oK2P00okH7003of`06003oo`00fol0o`2B0?l0TP3o0;H0o`2B103o
00001@1]0?l0B@3o003o9000ob@09?l00080BOl000D09?l0003oB@00odT0B@3o06d0o`040?l00006
0?l0K@3o0980o`2f0?l0]P3o06d00=_o0P00ool7003of`T00?nf1@00om/4003oo`<00=_o00@00;Ko
001]o`2fo`00ool00`3of`050?nf00X0oi805P3oK@0Q0?m900@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3ooolQ0?m901H0ofd02P3oTP050?nf00<0om/000@0ool0
0;Ko0000KOl00;Ko1000fol3003oo`H00?oK2P00okH7003of`06003oo`00fol0o`2B0?l0TP3o0;H0
o`2B103o00001@1]0?l0B@3o003o9000ob@09?l00080BOl000D09?l0003oB@00odT0B@3o06d0o`04
0?l000060?l0K@3o0980o`2f0?l0]P3o06d00=_o0P00ool7003of`T00?nf1@00om/4003oo`<00=_o
00@00;Ko001]o`2fo`00ool00`3of`050?nf00X0oi805P3oK@0Q0?m900@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolQ0?m901D0ofd02P3oTP060?nf00<0om/0
00<0ool009;o0000]_l01000]_l2003Ko`800?oo1@00om/=003o]PD00?oK00D00?oo003Ko`3o0000
o`000?l0]P020?l0f`80o`3o00<0]P3o0980o`2f0?l00P00ob@01000o`009?l002Co0000o`02003o
B@0306d0o`2B0?l0f`3o0080o`0000<0o`1]0?l0]P3o0;H00P3o0;H00`3o02@00=_o003oo`06003o
f`d00?nf0`00om/3003oo`800=_o1000]_l00`2Bo`00ool00?oK00020?oK00H0okH02P3oTP0E0?m]
0240odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooob00
odT05@3oK@0:0?nB00H0okH00P3of`030?oo00030;Ko0000T_l009;o008006go0P3o00000`00]_l0
0?oo003oo`03003ofa000?nf1@00om/01P00ool0o`1]0?l0K@3o0;H0o`3K0?l0o`80f`3o00<0]P3o
0980o`00oi800P00ob@4003o00800?m900<006go0980o`2f0?l00P3K0?l00`3o0?l0o`3K0?l0f`02
0?l0]P030?l0B@00ool00?oo00D00?oK3`00okH2003of`800?oo00<00=_o002Bo`00BOl00P00KOl2
002Bo`0409;o003oo`00ool00?oo0080om/01P3o]P0:0?nB01D0ofd0803oB@040?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo803oB@0E0?m]00P0oi801`3o]P03
0?oK0080ool000@0fol00;Ko0000BOl004Wo0P3o00000`3o04T0o`2B0?l0TP02003Ko`<00?oK4`00
okH3003of`800?oo00<006go0?l0f`3K0?l00`3K0?l00`00om/00?m]003o9002003o90800?l000H0
0?lT003oB@00odT00?nB06d0o`2f0?l20=/0o`<0o`3o0P3o06d00`00]_l00?oo003of`04003ofa40
0?nf00H00?oK003oo`00ool00;Ko0?l0TP3o04T20?l000040019o`00KOl0]_l00=_o0080ool00`3o
f`060?nf00T0oi805@3oK@0P0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<00000
0?ooo`3oool00P3ooolO0?m901D0ofd02@3oTP050?nf00@0om/00`3oo`00103Ko`00]_l004T0o`00
9?l30?l00080o`2f0P00fol2003ofaH00?nf0`00om/00`00ool00=_o002fo`020?l0B@03003o]P00
oi800?m900800?m91000ob@2003oB@03003oK@00om/0o`000080o`3o00<0f`3o0?l0f`3o09800P00
fol01000ool00?oK003of`00om/E003o]P800?oK00<0o`2B0?l0f`3o00000P3o000010009?l0TP3o
0;Ko003Ko`030?oo00@0om/0103o]P0:0?nB01D0ofd07`3oB@040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo7`3oB@0E0?m]00T0oi801@3o]P040?oK00<0ool0
00@0fol00;Ko00190?l002Co0`3o00020?l0]P800=_o0P00om/F003o]P<00?oK00<00?oo003Ko`00
]_l00P3o04T00`00okH00?nB003oB@02003oB@@00?lT0P00odT00`00ofd00?oK0?l000020?l0o`03
0=/0o`3o0=/0o`2B00800=_o00@00?oo003of`00om/00?oK5@00okH2003of`030?l0TP3o0=/0o`00
0080o`0000@002Co0980o`2fo`00fol00`3oo`040?oK00@0okH02P3oTP0E0?m]01l0odT0103oool0
0`000000oooo0?ooo`030?ooo`006`3oool2000000<0oooo7`3oB@0C0?m]00X0oi801@3o]P040?oK
0080ool00`3Ko`000`2fo`00KOl002@0o`0206d0o`030=/0o`3o0?l0o`0000<00?oK7`00okH00`00
oi800?m]003oB@02003oB@<00?lT0`00odT00`00ofd00?nB003o]P02003oo`800=_o00<00?oo003o
f`00om/00P00om/I003o]P03003oo`3o0?l0f`3o0080K@3o00<0B@3o06go002fo`000`3Ko`020?oo
00@0om/01@3o]P0:0?nB01<0ofd07`3oB@030?ooo`8000001@3oool001/0oooo00<000000?ooo`3o
ool00P3ooolO0?m901<0ofd02@3oTP050?nf0080om/00`3oo`020=_o00<0]_l000<0T_l006go000T
o`000P00okH00`3o0=/0]P3o003of`0N003o]P@00?nB0P00ofd9003oB@800?m]00<00?nB003o]P00
okH08P00okH01@00om/00?m9003oB@0To`00KOl00080T_l00P2fo`020=_o00<0ool00P3of`050?nf
00T0oi80503oK@0N0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3ooolN0?m901<0ofd02@3oTP050?nf0080om/000D0ool00=_o003Ko`00T_l004Wo00030019
o`040=/0o`0To`009?l002Co00800?lT00<00?m9003oK@00oi800`00oi8G003o]PP00?nB0P00ofd9
003oB@800?m]1000oi8K003o]PD00?nB00D00?m]003oB@00ob@00?lT003o000202Co00060=/0o`00
BOl004Wo000To`0To`00T_l00P3Ko`000`3oo`00om/00?oK00050?nf00T0oi804`3oK@0N0?m900@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolN0?m901<0ofd0
2@3oTP030?nf00<0om/000L0ool009;o00009?l002Co001]o`00]_l009;o008006go00<002Co02@0
o`00ofd00`00ob@00`00odT00?m]003oTP05003oTQ800?nf2@00oi85003oK@H00?m91@00ofd5003o
TQH00?nf1`00oi82003oK@07003oB@00ob@00?lT003o9000okH0903o0000o`020019o`03002Bo`00
]_l009;o0080o`0000@0T_l00?oo003of`00om/01@3o]P080?nB01<0ofd07P3oB@040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo7P3oB@0C0?m]00T0oi800`3o
]P030?oK00070?oo002Bo`0002Co000To`00KOl00;Ko002Bo`02001]o`03000To`0T0?l00?m]00<0
0?lT00<00?m9003oK@00oi801@00oi8B003o]PT00?nB1@00ofd6003oB@D00?m]1@00oi8F003o]PL0
0?nB0P00ofd01`00odT00?lT003o9000ob@00?nf02@0o`000?l00P00BOl00`00T_l00;Ko002Bo`02
0?l0000409;o003oo`00om/00?oK00D0okH0203oTP0C0?m]01h0odT0103oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa`0odT0503oK@090?nB00<0okH00`3of`00
0`3oo`00]_l0001]o`02002fo`03003Ko`00]_l009;o008004Wo0P3o0000102B0?l00?m]003oB@00
odT3003oK@P00?nB2P00okH>003oTPP00?m]0P00odT6003oK@T00?nB4@00okH8003oTP<00?m]0P00
odT01000oi80TP3o0?l0003o000204T0o`03002Bo`00]_l00=_o00800;Ko00<009;o0;Ko003oo`00
0`3of`030?nf00T0oi80503oK@0L0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3ooolL0?m901@0ofd01`3oTP040?nf0080om/00P3oo`000`00KOl0o`00003K
o`04003Ko`07002fo`3o02@0o`0T0?l0903o06d0f`3o003o]P04003oK@/00?nB1000okHA003oTQ40
0?m]3`00oi89003o]P/00?nB0P00ofd2003oTP040?l0K@3K0?l0o`000?l00080o`1900<009;o002f
o`00fol00P00fol01000ool0o`00002Bo`3Ko`030?oK00@0okH01`3oTP0D0?m]01`0odT0103oool0
0`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa/0odT0503oK@080?nB
00@0okH000@0om/00?oo002B0?l0TP3o0P00fol00`00ool00=_o003Ko`02003Ko`07002fo`00BOl0
04Wo0?l0TP3o0=/0o`3o003o]P0T003oTQ<00?m]9@00oi801000ool0o`3o0?l0]P3o09820?l09003
002fo`00fol00=_o00800=_o00@00?oo003Ko`00fol002Co0P3oo`000`3of`00okH00?nf00020?nf
00P0oi80503oK@0K0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?oooa/0
odT0503oK@070?nB00@0okH00P3of`001@3Ko`0009;o002Bo`00]_l00=_o00D00?oo0`00fol2002B
o`03003oo`00okH00?nB02<00?nB4`00ofdS003oTP800?nf00@00?oK0?l0K@3o0?l0o`1]0P00T_l2
003Ko`@00?oo00<00=_o002fo`00T_l00P3Ko`020?oK00@0okH01`3oTP0D0?m]01/0odT00`3oool2
000000D0oooo000K0?ooo`030000003oool0oooo0080oooo6`3oB@0C0?m]00P0oi80103o]P000`3o
f`00ool00=_o0002000To`030?l09000ool00?oo00T00?oo00@00?oK003o]P00okH00?nf8P00oi8C
003oKB800?nB0`00okH00`00om/00?oo003Ko`03003Ko`L00?oo00H009;o000To`3Ko`00fol00?oo
003of`040?nf00P0oi804`3oK@0K0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3ooolK0?m901<0ofd0203oTP040?nf00030?oK003oo`00fol0008002Co00<0
o`0T003oo`00ool02@00ool01000om/00?nf003o]P00okHR003oTQ<00?m]8P00oi83003o]P03003o
f`00ool00=_o00<00=_o1`00ool01P00T_l002Co0=_o003Ko`00ool00?oK00@0okH0203oTP0C0?m]
01/0odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaX0
odT0503oK@070?nB00@0okH000@0om/00?oo003Ko`000?l00P00ob@00`00om/00?oo003oo`05003o
o`D00?oK1000okHQ003oTQ<00?m]8@00oi85003o]P800?oK2@00ool2003of`06003o9000odT00?m9
0=_o003oo`00om/0103o]P070?nB01@0ofd06P3oB@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo6P3oB@0D0?m]00L0oi80103o]P00103of`00fol0002Bo`00
T_l2002fo``00?oK1P00okHP003oTQ<00?m]8000oi86003o]Pd00?oK00H0o`19001]o`00KOl009;o
0=_o003of`040?nf00L0oi80503oK@0J0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3ooolJ0?m90180ofd02@3oTP020?nf00<0om/000<004Wo003Ko`00fol0
0P00ool<003of`L00?nf7`00oi8C003oKAh00?nB2@00okH;003of`800?oo0`00fol01000KOl0ool0
0?oK003of`020?nf00T0oi804P3oK@0J0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3ooolI0?m901<0ofd0203oTP030?nf0080om/000<0ool00;H0o`00fol0
1@00ool9003of`/00?nf7000oi8C003oKAd00?nB2P00okH;003of`@00?oo00<00=_o0000o`3oo`00
0P3of`030?nf00P0oi804`3oK@0I0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3ooolI0?m901<0ofd0203oTP030?nf0080om/000<0ool00;H0o`00fol01@00
ool9003of`/00?nf7000oi8C003oKAd00?nB2P00okH;003of`@00?oo00<00=_o0000o`3oo`000P3o
f`030?nf00P0oi804`3oK@0I0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P000003
0?oooaT0odT04`3oK@080?nB00<0okH00P3of`000`3oo`0004Wo003oo`05003oo`T00?oK3000okHK
003oTQ<00?m]7000oi8<003o]PX00?oK1000ool00`00fol004Wo0?oo00020?oK00<0okH0203oTP0C
0?m]01T0odT00`3oool2000000D0oooo000K0?ooo`030000003oool0oooo0080oooo6@3oB@0B0?m]
00T0oi800`3o]P020?oK00030?oo0000T_l00=_o00<00=_o0P00ool8003of`h00?nf6`00oi8B003o
KA/00?nB3@00okH:003of`800?oo0`00fol01000T_l0ool00?oK003of`030?nf00T0oi804P3oK@0I
0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolI0?m9
0180ofd02@3oTP030?nf0080om/000<0ool00000o`00]_l00`00]_l00`00fol00?oo003of`05003o
fa800?nf6@00oi8B003oKA/00?nB3P00okH9003of`03003oo`00fol00;Ko00800;Ko00@0903o0?oo
003of`00om/00`3o]P090?nB0180ofd06@3oB@040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo5`3oB@0D0?m]00T0oi800`3o]P020?oK00040?oo001]o`0009;o
001]o`80o`1]00<002Co003oo`00om/01000om/D003o]QP00?nB4P00ofdI003oTQ@00?nf1@00om/0
0`00fol0o`19002Bo`02002Bo`0404Wo003oo`00om/00?oK00D0okH01`3oTP0D0?m]01L0odT0103o
ool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaL0odT0503oK@07
0?nB00D0okH00P3of`00103oo`00fol00019o`000?l20?l000030?l0f`00om/00?nf01P00?nf6000
oi8B003oKAT00?nB6@00okH01`3o0980o`00000To`009?l004Wo0=_o003oo`000P3of`050?nf00L0
oi80503oK@0G0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0
0P3ooolG0?m901@0ofd01`3oTP050?nf0080om/000@0ool00=_o0000BOl0003o0P3o00000`3o0=/0
0?oK003o]P0H003o]QP00?nB4P00ofdI003oTQT00?nf00L0o`2B0?l000009?l002Co0019o`3Ko`00
ool00080om/01@3o]P070?nB01@0ofd05`3oB@040?ooo`030000003oool0oooo00<0oooo00080?oo
o`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0080oooo5`3oB@0C0?m]
00P0oi80103o]P030?oK00040?oo003Ko`00T_l002@0o`80K@3o00<00?nf003oTP00okH06@00okHG
003oTQ<00?m]6000oi8H003o]P800?nB00H0o`000980o`2B0?l0T_l00=_o003oo`030?oK00@0okH0
203oTP0C0?m]01L0odT0103oool00`000000oooo0?ooo`030?ooo`001`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3ooolG0?m901<0
ofd0203oTP040?nf00<0om/000@0ool00=_o002fo`00KOl00P00o`000`00odT00?nB003o]P0I003o
]QH00?nB5000ofdH003oTQP00?nf00<00?nB003oK@00o`000P1]o`000`2fo`00fol00?oo00030?oK
00@0okH0203oTP0C0?m]01L0odT0103oool00`000000oooo0?ooo`030?ooo`001`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo0P0000030?oooaH0odT0503oK@080?nB
00@0okH00`3of`00103oo`00fol006go00000?l20980o`03003o]P00oi800?nf01T00?nf5P00oi8E
003oKAH00?nB6P00okH01`00om/0TP3o0000o`000?l0BOl00=_o003oo`000`3of`040?nf00P0oi80
503oK@0F0?m900<0oooo0P0000050?ooo`0000<0oooo0000000000000P0000020?ooo`040000003o
ool0oooo000000T0oooo0P0000050?ooo`030000003oool0oooo0080oooo5P3oB@0D0?m]00P0oi80
103o]P030?oK00040?oo001]o`0006go02@0o`80o`0000<0o`2f003of`00okH06P00okHE003oTQD0
0?m]5P00oi8H003o]P800?oK00L0o`3K0?l0003o0000o`00001]o`0To`00ool000<0om/0103o]P08
0?nB01@0ofd05P3oB@040?ooo`030000003oool0oooo00<0oooo00070?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oooaH0odT0503oK@08
0?nB00@0okH00`3of`00103oo`00KOl0001]o`0T0?l20?l000030?l0]P00om/00?nf01X00?nf5@00
oi8E003oKAH00?nB6000okH2003of`070?l0f`3o0000o`000?l00000KOl09?l00?oo00030?oK00@0
okH0203oTP0D0?m]01H0odT0103oool00`000000oooo0?ooo`030?ooo`00203oool2000000X0oooo
0`0000040?ooo`030000003oool0oooo0080oooo5P3oB@0D0?m]00P0oi80103o]P00103of`00ool0
0?oo003Ko`03002Bo`80o`0T00<00=_o003of`00om/02000om/B003o]Q@00?nB5`00ofdE003oTQ40
0?nf2000om/00`00ool004Wo0?l0K@02001]o`8009;o00@0]_l00?oo003oo`00om/0103o]P080?nB
01@0ofd05P3oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo5P3oB@0D0?m]00P0oi80103o]P001P3of`00ool00?oo002Bo`000=_o002fo`<00=_o00<00?oo
003of`00om/02P00om/@003o]Q@00?nB6@00ofdC003oTPl00?nf2P00om/00`00ool00=_o002fo`03
002fo`05003Ko`1]o`00ool00?oo003of`00103o]P080?nB01@0ofd05P3oB@040?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo5P3oB@0D0?m]00P0oi80103o]P00
0`3of`00ool00?oo0002002fo`800=_o1000ool>003of`h00?nf4P00oi8K003oKA400?nB3`00okH;
003of`800?oo1000fol2002fo`80ool000<0om/00?nf003o]P000`3o]P070?nB01@0ofd05P3oB@04
0?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo5@3oB@0E0?m]
00L0oi80103o]P020?oK0080ool000<004Wo002fo`00fol01@00ool@003of``00?nf4P00oi8K003o
KA400?nB3P00okH<003of`D00?oo0P00fol00`00BOl0ool00?oo00020?oK00@0okH0203oTP0D0?m]
01D0odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaD0
odT05@3oK@070?nB00@0okH00P3of`020?oo00030019o`00]_l00=_o00D00?oo4000om/<003o]Q80
0?nB6`00ofdA003oTPh00?nf3000om/5003oo`800=_o00<004Wo0?oo003oo`000P3of`040?nf00P0
oi80503oK@0E0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?oooaD0odT0
503oK@080?nB00@0okH00P3of`020?oo00030000o`00ool00?oo00D00?oo4`00om/;003o]Ph00?nB
7P00ofd@003oTP/00?nf3`00om/7003oo`03000To`3oo`00ool00080om/0103o]P080?nB01@0ofd0
5@3oB@030?ooo`8000001@3oool001/0oooo00<000000?ooo`3oool00P3ooolE0?m901@0ofd0203o
TP040?nf0080om/00P3Ko`000`00]_l00=_o003Ko`05003ooa@00?oK2P00okH=003oTR000?m]3P00
oi8;003o]Q000?oK1@00ool2003Ko`03002fo`3Ko`00fol00080om/0103o]P080?nB01@0ofd05@3o
B@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo5@3oB@0D
0?m]00P0oi801@3o]P00103of`00ool00?oo001]0?l3003Ko`<00?oo5`00om/8003o]Pd00?nB8@00
ofd=003oTPX00?nf4`00om/3003oo`03003Ko`00]_l00?m90080ool000<0om/00?nf003o]P000`3o
]P080?nB01@0ofd05@3oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooo5@3oB@0D0?m]00P0oi801@3o]P001@3of`00ool00?oo00000?l00;Ko008006go0P00
oolJ003of`L00?nf2`00oi8R003oK@d00?nB1`00okHG003of`800=_o0P00T_l01000BOl0ool00?oo
003of`050?nf00P0oi80503oK@0E0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3ooolE0?m901@0ofd0203oTP050?nf00070?oK003oo`00ool00=_o003o0000
903o0?l0o`02003o]PD00?oK3P00ool8003of`H00?nf2`00oi8T003oK@/00?nB1P00okHG003of`06
003o]P3o0980o`2B02@0o`009?l0fol00P3oo`000`3of`00okH00?nf00030?nf00P0oi80503oK@0E
0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolE0?m9
01@0ofd0203oTP050?nf00070?oK003oo`00ool00=_o003o0000903o0?l0o`02003o]PD00?oK3P00
ool8003of`H00?nf2`00oi8T003oK@/00?nB1P00okHG003of`06003o]P3o0980o`2B02@0o`009?l0
fol00P3oo`000`3of`00okH00?nf00030?nf00P0oi80503oK@0E0?m900@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolD0?m901D0ofd02@3oTP040?nf00<0om/0
00@0ool00=_o001]o`000?lT0P00okH2003ofaH00?oo1000om/5003o]PX00?nB9P00ofd9003oTPH0
0?nf2`00om/<003oo`800?oK0P00odT00`1]o`00fol00?oo00030?oK00@0okH02@3oTP0E0?m]01@0
odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa@0odT0
5@3oK@090?nB00@0okH00`3of`00103oo`00fol006go003o00020?l0TQ000?oo1`00fol4003oo`80
0?oK1000okH9003oTRL00?m]2@00oi84003o]P@00?oK5@00ool01`00fol0o`2B0?l0003o0000BOl0
0=_o003oo`000`3of`040?nf00T0oi805@3oK@0D0?m900@0oooo00<000000?ooo`3oool00`3oool0
01/0oooo00<000000?ooo`3oool00P3ooolD0?m901D0ofd02@3oTP040?nf00<0om/000@0ool00=_o
0000]_l009;o0P00]_l00`00fol00?oo003oo`0:003oo`@00=_o00L00;Ko002Bo`00T_l009;o0?l0
B@3o06d0o`1900<00=_o00<00?oo003of`00om/00`00okH9003oTRP00?m]2000oi83003o]P<00?oK
5`00ool01`00fol009;o001]o`00KOl00;Ko0=_o003oo`000`3of`040?nf00T0oi805@3oK@0D0?m9
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?oooa@0odT05@3oK@090?nB00D0
okH00`3of`000`3Ko`00o`2f002fo`03003Ko`X00?oo0`00fol2002fo`03002Bo`3o04T0o`1]0080
o`000P3o0;H01`3o0980003o0000o`3o06d009;o003oo`00om/01000okH6003oTRX00?m]2000oi82
003o]P800?oK0P00ool00`00fol009;o001]o`04002fo`@00=_o2`00ool2003Ko`<00;Ko00<0o`19
0=_o003of`000P3of`050?nf00T0oi805@3oK@0D0?m900<0oooo0P0000050?ooo`006`3oool00`00
0000oooo0?ooo`020?oooa@0odT05@3oK@090?nB00D0okH00`3of`000`3Ko`00o`2f002fo`03003K
o`X00?oo0`00fol2002fo`03002Bo`3o04T0o`1]0080o`000P3o0;H01`3o0980003o0000o`3o06d0
09;o003oo`00om/01000okH6003oTRX00?m]2000oi82003o]P800?oK0P00ool00`00fol009;o001]
o`04002fo`@00=_o2`00ool2003Ko`<00;Ko00<0o`190=_o003of`000P3of`050?nf00T0oi805@3o
K@0D0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolD
0?m901D0ofd02@3oTP050?nf00<0om/000<0ool00000o`00fol01000fol6003oo`D00=_o00H00;Ko
0019o`00BOl0o`000?l0]P3o09820?l0]P<0o`3K0P3K0?l00`3o0;H0o`3K002fo`03003of`800?nf
1P00oi8[003oK@L00?nB0P00okH01@00om/00=_o002Bo`00T_l0o`0T0080o`2f0P3o00000`3o0980
o`0T002Bo`02002fo`<00=_o2@00ool5003Ko`03000To`3oo`00om/00080om/01@3o]P090?nB01D0
ofd0503oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo
503oB@0E0?m]00T0oi801@3o]P030?oK00030?oo002fo`000;Ko00800;Ko00<00=_o003oo`00ool0
0P00ool7003Ko`06002fo`00KOl0o`190?l0B@3o06d0o`2B0`3o0;H30?l0f`80o`3o00@0o`3K0?l0
]P3o06d00?oo0P00om/2003o]PD00?nB;P00ofd3003oTP<00?nf00<00?oK003oo`3o0=/00P3o0=/0
0`3o0?l0o`3K0?l0f`040?l0]P040?l0B@00KOl006go002fo`L00=_o1@00ool01P00fol00;Ko002f
o`00]_l0T_l00?oo00<0om/01@3o]P090?nB01D0ofd0503oB@040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo503oB@0E0?m]00T0oi801@3o]P030?oK00030?oo
003Ko`0004Wo008006go00<009;o003oo`00ool02000fol00`00]_l009;o0?l0o`050?l0TP<0o`2f
0P3o0=/40?l0o`0404T0o`00BOl00?oK003of`800?nf1@00oi8^003oK@<00?nB0`00okH00`00om/0
06go0?l0]P020?l0f`030?l0o`3o0=/0o`3K00<0o`2f0P3o098202@0o`03002Bo`00]_l00=_o00P0
0=_o0P00ool01P00fol006go001]o`00KOl0fol00?oo00<0om/01@3o]P090?nB01D0ofd0503oB@04
0?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo503oB@0E0?m]
00/0oi801@3o]P020?oK00060?oo002fo`00B@3o04T0o`00odT00?oo2000fol2002fo`03001]o`3o
02@0o`1]00<0o`1]0`3o09800`3o0;H0o`3K0?l0f`030?l0o`030=/0o`3o0?l0o`3K00800=_o0P00
okH4003oTS000?m]0P00oi82003o]P03003of`00KOl0o`0000@0o`3o0P3o0=/20?l0]P80o`2B00@0
o`1]0?l0B@3o04T002Co0P00]_l9003Ko`03002fo`00odT00?m90080]_l000<0ool00?oK003of`00
1@3o]P0;0?nB01D0ofd0503oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003o
ool0oooo0080oooo503oB@0E0?m]00/0oi801@3o]P020?oK00060?oo002fo`00B@3o04T0o`00odT0
0?oo2000fol2002fo`03001]o`3o02@0o`1]00<0o`1]0`3o09800`3o0;H0o`3K0?l0f`030?l0o`03
0=/0o`3o0?l0o`3K00800=_o0P00okH4003oTS000?m]0P00oi82003o]P03003of`00KOl0o`0000@0
o`3o0P3o0=/20?l0]P80o`2B00@0o`1]0?l0B@3o04T002Co0P00]_l9003Ko`03002fo`00odT00?m9
0080]_l000<0ool00?oK003of`001@3o]P0;0?nB01D0ofd0503oB@040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo503oB@0E0?m]00/0oi801@3o]P020?oK0080
ool00P2fo`000`009?l004Wo002fo`05003Ko`<00;Ko00<009;o001]o`3o0000103o04T30?l00003
0?l0K@3o0;H0o`3o0080o`3o0P3K0?l20?l0o`800;Ko00<00?nf003oTP00oi800P00oi8a003oK@80
0?nB0P00okH01000om/0o`000?l0o`3K0?l30?l0o`040?l0f`3o0;H0o`2B0?l0TPD0o`1]00<0003o
002Bo`00]_l00`00]_l5003Ko`04002fo`00BOl002Co0;Ko00<0ool00P3of`050?nf00/0oi805@3o
K@0D0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?oooa80odT05`3oK@0;
0?nB00D0okH00`3of`001P3oo`00fol00=_o003o000009;o002fo`@00=_o1000]_l00`00T_l004Wo
0?l090020?l0B@030?l0903o0000o`0000<0o`0000@0o`190?l0o`3o0?l0o`3o0`3K0?l0103o0980
0?oo003oo`00okH4003oTS800?m]0`00oi800`00om/0o`2f0?l0o`030=/0o`80o`3o00D0o`2B0?l0
003o0000o`000?l090030?l0B@030?l00000KOl009;o00@00;Ko1000fol01000]_l009;o003Ko`3K
o`020?oo00<0om/01@3o]P0;0?nB01L0ofd04P3oB@030?ooo`8000001@3oool001/0oooo00<00000
0?ooo`3oool00P3ooolB0?m901L0ofd02`3oTP060?nf0080om/00`3oo`000`2Bo`000;Ko002fo`03
003Ko`@00;Ko0P00T_l01000BOl0o`000?l0903o02@70?l000030?l0o`3K0?l0f`3o0080f`3o00D0
]P3o04T0o`00ool00?oo003o]P02003oTS@00?m]0`00oi800`00okH004Wo0;H0o`040=/0o`030?l0
o`3o0000o`0000@0o`000P3o02@00`1]0?l006go002Bo`05002fo`<00=_o00<00;Ko002Bo`2Bo`00
0`3oo`020?oK00H0okH02`3oTP0G0?m]0180odT0103oool00`000000oooo0?ooo`030?ooo`006`3o
ool00`000000oooo0?ooo`020?oooa80odT05`3oK@0;0?nB00H0okH00`3of`020?oo00030=_o000T
o`00003o00800?oK1@00]_l2002Bo`03001]o`1]0?l0o`0000P0o`000`3K0?l20;H0o`040=/0o`3o
0?l00=_o003Ko`800?nB=P00ofd2003oTP03003o]P3o0?l0f`3o00@0]P3o00<0f`3o0?l0003o0000
1P3o000010009?l006go002Bo`00T_l5002fo`800?oK00@0003o003o003Ko`00ool0103of`060?nf
00/0oi805`3oK@0B0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3ooolB0?m901P0ofd02`3oTP060?nf0080om/00`3oo`001@3Ko`00T_l00000o`000?l009;o
00800;Ko1000T_l00`00KOl002Co0?l000080?l000D0]P3o00D0f`3o0?l0o`00okH00?nf003oTP0V
003oK@`00?m91`00ofd00`00oi80o`2f0?l0o`050;H0o`H0o`000P0T0?l00`00BOl006go002Bo`03
002Bo`03002fo`00T_l009;o008002Co00@0T_l00=_o003oo`00ool00`3of`060?nf00`0oi805`3o
K@0B0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolB
0?m901P0ofd02`3oTP060?nf0080om/00`3oo`001@3Ko`00T_l00000o`000?l009;o00800;Ko1000
T_l00`00KOl002Co0?l000080?l000D0]P3o00D0f`3o0?l0o`00okH00?nf003oTP0V003oK@`00?m9
1`00ofd00`00oi80o`2f0?l0o`050;H0o`H0o`000P0T0?l00`00BOl006go002Bo`03002Bo`03002f
o`00T_l009;o008002Co00@0T_l00=_o003oo`00ool00`3of`060?nf00`0oi805`3oK@0B0?m900@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolB0?m901P0ofd0
2`3oTP060?nf00@0om/00P3oo`000`3Ko`00BOl004Wo0002002Bo`04002fo`00T_l009;o002Bo`80
06go00<004Wo0000o`000?l01P3o00000`2f0?l0TP3o0980o`030980o`0402@0o`00om/00?nB003o
TPX00?m]0P00odTG003oKA@00?m91000ofd00`00okH0o`000980o`050980o`80]P3o0P3o0000100T
0?l002Co000To`00BOl2001]o`<009;o00<00;Ko002Bo`00T_l00P19o`000`3Ko`00ool00?oo0004
0?oK00H0okH02`3oTP0H0?m]0180odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?oooa80odT0603oK@0;0?nB00H0okH0103of`020?oo00060=_o002fo`00]_l0
02Co001]0?l0o`000`00T_l2001]o`050019o`009?l002Co0000o`0T0?l01P1]0?l30980o`030;H0
o`3o0?l00?nB00D00?m]4P00odT;003oKAX00?m900@00?m]003oTP3o0=/0f`3o0P2B0?l306d0o`80
B@3o0P0T0?l010000?l002Co000To`00BOl2001]o`06002Bo`00KOl006go0?l00000ob@0KOl00P2f
o`000`3Ko`00ool00?oo00040?oK00H0okH02`3oTP0H0?m]0180odT0103oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa80odT0603oK@0;0?nB00L0okH0103of`02
0?oo0080fol000<0]_l009;o00009?l00P00KOl01000T_l006go001]o`00BOl3000To`030000o`0T
0?l0B@3o0080B@3o101]0?l00`190?l0o`3o003o]P03003oKC`00?m900D00?m]003of`2B0?l0TP3o
06d0o`0204T0o`<0903o00D0003o000To`009?l002Co0019o`02001]o`05002Bo`00BOl004Wo0000
o`2Bo`000`3Ko`020?oo00@0om/01`3o]P0;0?nB01P0ofd04P3oB@040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`8000000`3ooolB0?m901P0ofd02`3oTP070?nf00D0om/00`3oo`020=_o0007
09;o0019o`00BOl004T0o`00BOl006go0019o`03000To`80003o0P0T0?l304T0o`80TP3o00<0f`3o
003oK@00ofd0@000odT01P00ofd00?oK003of`3o02@0K@3o04T0o`80903o0P000?l3000To`040019
o`00KOl004Wo02@0o`80KOl000<0]_l00=_o003Ko`000`3oo`050?oK00L0okH02`3oTP0H0?m]0180
odT00`3oool2000000D0oooo000K0?ooo`030000003oool0oooo0080oooo4P3oB@0H0?m]00/0oi80
1`3o]P050?oK00<0ool00P3Ko`001`2Bo`00BOl004Wo00190?l004Wo001]o`00BOl00`009?l20000
o`80903o0`190?l20980o`030=/0o`00ofd00?m]04000?m900H00?m]003of`00om/0o`0T06d0o`19
0?l202@0o`80003o0`009?l01000BOl006go0019o`0T0?l206go00030;Ko003Ko`00fol000<0ool0
1@3of`070?nf00/0oi80603oK@0B0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3ooolB0?m901P0ofd0303oTP060?nf00D0om/0103oo`020=_o0080]_l000@0
T_l002Co0000ob@002Co0P00BOl30000o`<0903o00@0TP3o0;H0o`00ofd00?m]?000odT:003o9003
003oB@00okH0o`3K0080K@3o00<0003o06d0o`000?l00P3o000010000?l09?l006go002Bo`020;Ko
0080fol0103oo`050?oK00L0okH02`3oTP0H0?m]0180odT0103oool00`000000oooo0?ooo`030?oo
o`006`3oool00`000000oooo0?ooo`020?oooa80odT0603oK@0<0?nB00L0okH01@3of`030?oo00@0
fol000<0]_l009;o002Bo`000`19o`02003o9004003of`00ob@00?lT003oB@`00?lT<`00odT8003o
90T00?l00P0To`0204Wo000406go002Bo`00T_l00;Ko00<0fol0103oo`040?oK00P0okH0303oTP0H
0?m]0180odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
oa80odT0603oK@0<0?nB00L0okH01@3of`040?oo00<0fol00P2fo`0209;o00<0KOl00P19o`0302Co
00H00?l01`00ob@`003oB@P00?lT1@00o`0302Co00@0BOl00`1]o`000`2Bo`00]_l00;Ko00040=_o
00@0ool0103of`080?nf00`0oi80603oK@0B0?m900@0oooo00<000000?ooo`3oool00`3oool001/0
oooo00<000000?ooo`3oool00P3ooolB0?m901P0ofd0303oTP070?nf00D0om/01@3oo`030=_o0080
]_l00`2Bo`0206go00@0BOl00P0To`05003o00P00?lT;@00odT8003o90@00?l0100To`0304Wo0080
KOl0102Bo`020;Ko00<0fol01@3oo`040?oK00P0okH0303oTP0H0?m]0180odT0103oool00`000000
oooo0?ooo`030?ooo`00503oool2000000D0oooo00<000000?ooo`3oool00P3ooolB0?m901P0ofd0
303oTP070?nf00D0om/01@3oo`030=_o0080]_l00`2Bo`0206go00@0BOl00P0To`05003o00P00?lT
;@00odT8003o90@00?l0100To`0304Wo0080KOl0102Bo`020;Ko00<0fol01@3oo`040?oK00P0okH0
303oTP0H0?m]0180odT0103oool00`000000oooo0?ooo`030?ooo`004`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080oooo4P3oB@0H0?m]00`0oi801`3o]P070?oK00<0ool0
103Ko`020;Ko00<0T_l00P1]o`0404Wo00<09?l01000o`08003o92`00?m92000ob@3003o00@09?l0
1019o`0206go00<0T_l00P2fo`040=_o00<0ool01P3of`080?nf00`0oi80603oK@0B0?m900@0oooo
00<000000?ooo`3oool00`3oool001<0oooo00@000000?ooo`3oool00000103oool2000000<0oooo
4P3oB@0H0?m]00`0oi801`3o]P070?oK00<0ool0103Ko`020;Ko00<0T_l0101]o`0204Wo00@09?l0
0`00o`08003o92`00?m92000ob@3003o00@09?l00P19o`0406go00<0T_l00P2fo`040=_o00<0ool0
1P3of`080?nf00`0oi80603oK@0B0?m900<0oooo0P0000050?ooo`004`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080oooo4P3oB@0H0?m]00`0oi801`3o]P070?oK00<0ool0
103Ko`020;Ko00<0T_l0101]o`0204Wo00@09?l00`00o`08003o92`00?m92000ob@3003o00@09?l0
0P19o`0406go00<0T_l00P2fo`040=_o00<0ool01P3of`080?nf00`0oi80603oK@0B0?m900@0oooo
00<000000?ooo`3oool00`3oool001<0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?oooa80odT0603oK@0<0?nB00L0okH01`3of`030?oo00@0fol00P2fo`0309;o0080KOl0
1019o`0402Co00<00?l02000ob@/003oB@P00?lT1000o`0302Co00@0BOl00P1]o`0309;o0080]_l0
103Ko`030?oo00H0om/0203o]P0<0?nB01P0ofd04P3oB@040?ooo`030000003oool0oooo00<0oooo
000D0?ooo`8000001@3oool00`000000oooo0?ooo`020?oooa80odT0603oK@0<0?nB00L0okH01@3o
f`050?oo00<0fol00P2fo`0409;o0080KOl00`19o`0402Co00@00?l02000ob@]003oB@P00?lT1@00
o`0202Co00@0BOl00P1]o`0309;o0080]_l00`3Ko`050?oo00@0om/0203o]P0<0?nB01P0ofd04P3o
B@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo4P3oB@0H
0?m]00`0oi801`3o]P050?oK00D0ool00`3Ko`020;Ko00@0T_l00P1]o`0304Wo00@09?l01000o`08
003o92d00?m92000ob@5003o00809?l01019o`0206go00<0T_l00P2fo`030=_o00D0ool0103of`08
0?nf00`0oi80603oK@0B0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3ooolB0?m901P0ofd0303oTP070?nf00D0om/0103oo`040=_o0080]_l000@0T_l006go
001]o`00KOl01019o`0302Co00D00?l02000ob@`003oB@L00?lT1P00o`0302Co0080BOl00`1]o`02
09;o0080]_l00`3Ko`040?oo00@0om/0203o]P0<0?nB01P0ofd04P3oB@040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo4P3oB@0H0?m]00`0oi801`3o]P050?oK
00@0ool00`3Ko`00102fo`00T_l009;o001]o`0204Wo00809?l02@00o`08003o93<00?m93000ob@0
1000odT00?lT003o9000om/2003o90<0BOl00P2Bo`000`2fo`00fol00=_o00020=_o00<0ool0103o
f`080?nf00`0oi80603oK@0B0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<00000
0?ooo`3oool00P3ooolB0?m901P0ofd02`3oTP070?nf00D0om/0103oo`020=_o0080]_l000@0T_l0
06go000To`00003o0P3o00000`000?l0K@3o0000o`0206d0o`030?l0f`00okH00?m900X00?lT?000
odT2003oK@030;H0o`2B0?l0903o0080903o0`000?l20019o`04000To`00ob@09?l009;o0080]_l0
0P3Ko`040?oo00D0om/01P3o]P0<0?nB01P0ofd04P3oB@040?ooo`030000003oool0oooo00<0oooo
000K0?ooo`8000000`3ooolB0?m901P0ofd02`3oTP070?nf00D0om/00`3oo`020=_o00070;Ko001]
o`00KOl002@0o`00BOl006go0019o`03000To`80003o0P0T0?l00`190?l0K@3o0?l09002003of`03
003oK@00odT00?m903h00?m90P00ofd00`3K0?l0TP3o0980o`0304T0o`80903o0P000?l3000To`04
0019o`00KOl004Wo04T0o`80BOl000<0T_l00=_o003Ko`000`3oo`050?oK00L0okH02`3oTP0H0?m]
0180odT00`3oool2000000D0oooo000K0?ooo`030000003oool0oooo0080oooo4P3oB@0H0?m]00/0
oi801`3o]P050?oK00<0ool00P3Ko`001`2fo`00KOl006go000T0?l004Wo001]o`00BOl00`009?l2
0000o`80903o00<0B@3o06d0o`3o02@00P00om/00`00ofd00?m9003oB@0n003oB@800?m]00<0f`3o
0980o`2B0?l00`190?l202@0o`80003o0`009?l01000BOl006go0019o`190?l204Wo000309;o003K
o`00fol000<0ool01@3of`070?nf00/0oi80603oK@0B0?m900@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3ooolB0?m901P0ofd02`3oTP070?nf00@0om/00P3oo`03
0=_o000509;o00000?l004Wo0019o`00T_l00P00KOl01@00BOl002Co000To`009?l0003o00<0903o
0P190?l01@1]0?l0TP3o0980o`00om/00?m]03`00?m90`00ofd00`00okH0o`3o04T0o`0406d0o`<0
B@3o00<0903o0000o`009?l00P009?l01000BOl006go001]o`00T_l2001]o`03000To`2Bo`00]_l0
0080fol00P3oo`040?oK00L0okH02`3oTP0H0?m]0180odT0103oool00`000000oooo0?ooo`030?oo
o`006`3oool00`000000oooo0?ooo`020?oooa80odT0603oK@0;0?nB00H0okH0103of`020?oo0006
0=_o002fo`00]_l006go0000ob@0o`000P00KOl01000T_l006go001]o`00BOl2000To`030000o`0T
0?l0903o0080B@3o0`1]0?l20980o`040=/0o`3o0=/00?nB003oKAX00?m92`00ofdB003oB@D00?m]
00<00?nB0?l0o`2f0?l00`2B0?l606d0o`0502@0o`000?l002Co000To`00BOl00P00KOl3002Bo`03
0?l0001]0?l09?l00080]_l000<0fol00?oo003oo`00103of`060?nf00/0oi80603oK@0B0?m900@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolB0?m901P0ofd0
2`3oTP060?nf00@0om/00P3oo`000`3Ko`00BOl004Wo0002002Bo`04002fo`00T_l009;o002Bo`80
06go00@004Wo000To`009?l0903o0P3o00020;H0o`H0TP3o00<0o`00003o]P00ofd00`00ofdD003o
BAL00?m]0P00odT:003oK@800?nB00<00?oK02@0o`2B0?l0102B0?l00`2f0?l0o`000?l000040?l0
0080003o00<004Wo001]o`00KOl00`00T_l00`00]_l009;o002Bo`0204Wo00030=_o003oo`00ool0
00@0om/01P3o]P0;0?nB01P0ofd04P3oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`03
0000003oool0oooo0080oooo4P3oB@0G0?m]00`0oi801P3o]P020?oK00<0ool000@0fol009;o0000
9?l002Co0P00T_l00`00]_l009;o002Bo`02002Bo`04001]o`00BOl0903o02@0o`H0o`001@2f0?l0
0`3o0?l0o`2f003oTP07003oK@`00?m99P00ofd01@00oi800?nf003o]P3o0?l0f`3o00D0]P3o2@3o
00000`009?l006go002Bo`03002Bo`800;Ko00D009;o0000o`000?l0T_l00=_o00020?oo00<0om/0
1P3o]P0;0?nB01P0ofd04P3oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003o
ool0oooo0080oooo4P3oB@0G0?m]00`0oi801P3o]P020?oK00<0ool000@0fol009;o00009?l002Co
0P00T_l00`00]_l009;o002Bo`02002Bo`04001]o`00BOl0903o02@0o`H0o`001@2f0?l00`3o0?l0
o`2f003oTP07003oK@`00?m99P00ofd01@00oi800?nf003o]P3o0?l0f`3o00D0]P3o2@3o00000`00
9?l006go002Bo`03002Bo`800;Ko00D009;o0000o`000?l0T_l00=_o00020?oo00<0om/01P3o]P0;
0?nB01P0ofd04P3oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo
0080oooo4P3oB@0G0?m]00/0oi801P3o]P030?oK0080ool000<0fol0003o00000?l00P00om/5002f
o`8009;o00<006go000To`3o00001`3o00000`3K0?l0]P3o0;H0o`020;H0o`030=/0o`3o0?l00?nf
00800?nB=P00ofd2003oTP800=_o00@0o`3o0=/0o`2f0?l0]P3o0`3K0?l90?l0000406d0o`00KOl0
09;o002Bo`D00;Ko0P00om/010000?l09?l00=_o003oo`040?oK00H0okH02`3oTP0G0?m]0180odT0
103oool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0oooo4P3oB@0G0?m]00/0oi801P3o
]P020?oK00<0ool000<0T_l0002Bo`00]_l00`00fol5002fo`03002Bo`00KOl0K@3o0080o`0T1P3o
00000`3o0?l0f`3o0=/0o`020=/0o`030;H0o`00BOl00?nf00<00?nB=000ofd2003oTP05003o]P00
ool00?oo04T0o`2f0?l0103K0?l00`3o0?l0o`000?l000050?l00080o`0T00@0o`000019o`00T_l0
09;o1000]_l3003Ko`800;Ko00@0T_l00?oo003oo`00ool00P3of`060?nf00/0oi805`3oK@0B0?m9
00<0oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?oooa80odT05`3oK@0;0?nB00D0
okH00`3of`001P3oo`00fol00=_o0000fol009;o002fo`@00=_o1000]_l00`00T_l006go0?l00003
0?l0B@050?l0903o0000o`000?l0003o09800P3o0?l30=/0o`030?l0o`3o0;H00?oK00<00?nB<P00
ofd4003oTP04003o]P00ool00?oo0?l0TP<0f`3o0`3o0?l00`3o04T0o`000?l000030?l000060?l0
903o04T0o`190?l09000BOl009;o1000]_l4003Ko`04002fo`00T_l0o`000=_o0080ool00`3of`05
0?nf00/0oi805`3oK@0B0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3ooolD0?m901D0ofd02`3oTP050?nf0080om/00P3oo`020;Ko0003000To`00BOl00;Ko
00D00=_o1000]_l00`00T_l0003o0?l0K@040?l0K@80o`2B00<0o`2f0?l0f`3o0?l00P3o0?l0103K
0?l0o`3o0?l00000om/2003o]P800?nB<@00ofd4003oTP03003o]P00]_l00;Ko0080o`3o0P3K0?l3
0?l0o`030?l0]P3o06d0o`000080o`00103o04T00`3o000006go002Bo`03002fo`D00=_o00@00;Ko
0019o`009?l0]_l00`3oo`020?oK00D0okH02`3oTP0E0?m]01@0odT0103oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa@0odT05@3oK@0;0?nB00D0okH00P3of`00
0`3oo`00]_l0003oB@02003oB@03002fo`00fol00=_o00L00=_o0P00]_l010009?l0o`190?l0B@3o
06d20?l0TP80o`2f0P3o0=/40?l0o`030?l00000KOl00?oK00800?nf0P00oi8`003oK@@00?nB0P00
okH2003Ko`030?l0f`3o0?l0f`3o00<0o`3o0P3o0=/0103o0;H0o`2B0?l0TP3o09840?l0K@040?l0
9000KOl00;Ko002fo`P00=_o00<00?oo003oB@190?l00P2fo`000`3oo`00om/00?oK00050?nf00/0
oi805@3oK@0D0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0
0P3ooolD0?m901D0ofd02`3oTP050?nf0080om/000<0ool00;Ko0000odT00P00odT00`00]_l00=_o
003Ko`07003Ko`800;Ko00@002Co0?l0B@3o04T0o`1]0P3o09820?l0]P80o`3K103o0?l00`3o0000
06go003of`02003o]P800?nB<000ofd4003oTP800?nf0P00fol00`3o0=/0o`3o0=/0o`030?l0o`80
o`3K00@0o`2f0?l0TP3o0980o`2B103o06d0103o02@006go002fo`00]_l8003Ko`03003oo`00odT0
B@3o0080]_l000<0ool00?oK003of`001@3o]P0;0?nB01D0ofd0503oB@040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo503oB@0E0?m]00T0oi801@3o]P030?oK
00030?oo003Ko`0006go008006go00<00=_o003oo`00ool02@00fol01000]_l009;o02@0o`0T0?l2
0?l0TP<0o`2f0P3o0=/01P3o0?l0o`3K0?l0f`3o0;H006go003of`<00?nf0`00oi8^003oK@D00?nB
0P00okH2003of`030019o`190?l0o`3o00<0o`3o0P3o0=/30?l0]PD0o`2B00<0o`3o002Bo`00]_l0
2000fol2003oo`06002Bo`00KOl004Wo0019o`3Ko`00ool00`3of`050?nf00T0oi805@3oK@0D0?m9
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolD0?m901D0
ofd02@3oTP050?nf00<0om/000<0ool009;o0000]_l00P00]_l00`00fol00?oo003oo`03003oo`L0
0=_o00@00;Ko001]o`00KOl0o`19103o0;H20?l0f`060?l0o`3o0=/0o`3K0?l0f`00ool00?oK0`00
okH3003oTRh00?m]1@00oi82003o]P800?oK00@00?oo0?l0K@3o0;H0o`3K0P3o0?l30?l0f`<0o`2f
00H0o`2B0?l0K@3o04T0o`19001]o`00]_l7003Ko`@00?oo00H00=_o002fo`00]_l00;Ko0;Ko003o
o`030?oK00D0okH02@3oTP0E0?m]01@0odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool0
0`000000oooo0?ooo`020?oooa@0odT05@3oK@090?nB00D0okH00`3of`000`3oo`0002Co003Ko`04
003Ko`T00?oo0`00fol2002fo`03002Bo`3o02@0o`2B0080o`000P3o0;H01@3o02@009;o002Bo`00
fol00?oK00800?nf1`00oi8[003oK@H00?nB0P00okH3003of`03002fo`3o0=/0o`2f0080f`3o0`3o
0=/20?l0]P030?l0TP3o0;H0o`00008004Wo00<00;Ko003Ko`00fol00`00fol6003oo`D00=_o00<0
003o0?oo003of`000P3of`050?nf00T0oi805@3oK@0D0?m900@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3ooolD0?m901D0ofd02@3oTP050?nf00<0om/000<0fol0
0?l0B@00]_l00P00]_l2003Ko`/00?oo1000fol4002fo`03001]o`00T_l00=_o00800?oo0P00om/2
003o]PP00?nB:P00ofd6003oTP@00?nf00@00?oK003oo`00T_l0o`1]0P000?l00`3o0980o`2f0?l0
]P020?l000030?l0K@3o04T009;o00800;Ko0`00fol:003oo`800=_o0P00]_l00`3o0;H0fol00?oK
00020?oK00D0okH02@3oTP0E0?m]01@0odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool2
000000<0oooo503oB@0E0?m]00T0oi801@3o]P030?oK00030=_o003o04T00;Ko00800;Ko0P00fol;
003oo`@00=_o1000]_l00`00KOl009;o003Ko`02003oo`800?oK0P00okH8003oTRX00?m]1P00oi84
003o]P04003of`00ool009;o0?l0K@80003o00<0o`2B0?l0]P3o0;H00P3o00000`3o06d0o`19002B
o`02002fo`<00=_o2P00ool2003Ko`800;Ko00<0o`2f0=_o003of`000P3of`050?nf00T0oi805@3o
K@0D0?m900<0oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?oooa@0odT05@3oK@09
0?nB00@0okH00`3of`00103oo`00fol0002fo`00KOl2002Bo`03003Ko`00ool00?oo01D00?oo0`00
om/3003o]PP00?nB:000ofd9003oTP<00?nf0P00om/01`00ool00=_o003Ko`00fol0o`190?l0K@3o
04T00`00T_l00`00]_l00=_o003Ko`02003Ko``00?oo00L00=_o002fo`00T_l009;o002fo`3Ko`00
ool000<0om/0103o]P090?nB01D0ofd0503oB@040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo503oB@0E0?m]00T0oi80103o]P030?oK00040?oo003Ko`00BOl0
0?l00080o`2B00<00=_o003oo`00ool04`00ool4003of`@00?nf2@00oi8W003oK@T00?nB1000okH2
003of`@00?oo1`00fol@003oo`060?l0TP3o0000o`0006go003Ko`00ool00`3of`040?nf00T0oi80
5@3oK@0D0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3o
oolD0?m901D0ofd02@3oTP040?nf00<0om/000@0ool00=_o001]o`000?m90`00om/<003oo`/00?oK
1P00okH9003oTRH00?m]2P00oi85003o]P@00?oK5P00ool2003of`06003o]P00ob@00?lT06go003K
o`00ool00`3of`040?nf00T0oi805@3oK@0D0?m900@0oooo00<000000?ooo`3oool00`3oool001/0
oooo00<000000?ooo`3oool00P3ooolE0?m901@0ofd0203oTP050?nf00070?oK003oo`00ool00=_o
00009?l0903o0?l0TP02003o]QL00?oK1P00okH;003oTR@00?m]2`00oi86003o]PP00?oK3P00ool5
003of`06003o]P3o0?l0o`3o02@0o`3o0000fol00P3oo`000`3of`00okH00?nf00030?nf00P0oi80
503oK@0E0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3o
oolE0?m901@0ofd0203oTP050?nf00070?oK003oo`00ool00=_o00009?l0903o0?l0TP02003o]QL0
0?oK1P00okH;003oTR@00?m]2`00oi86003o]PP00?oK3P00ool5003of`06003o]P3o0?l0o`3o02@0
o`3o0000fol00P3oo`000`3of`00okH00?nf00030?nf00P0oi80503oK@0E0?m900@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolE0?m901@0ofd0203oTP050?nf
00040?oK003oo`00ool00019o`8009;o00<00=_o003of`00om/05P00om/7003o]Pd00?nB8P00ofd;
003oTPL00?nf6P00om/01P00ool006go001]o`00KOl00;Ko0000o`80ool000<0om/00?nf003o]P00
0`3o]P080?nB01@0ofd05@3oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003o
ool0oooo0080oooo5@3oB@0D0?m]00P0oi801@3o]P001P3of`00ool00?oo0000odT00;Ko003Ko`<0
0?oo4`00om/:003o]Pd00?nB8@00ofd=003oTPP00?nf5`00om/2003oo`@00=_o00@0K@3o0?oo003o
o`00om/01@3o]P080?nB01@0ofd05@3oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`80
00000`3ooolE0?m901@0ofd0203oTP040?nf0080om/00P3Ko`000`00]_l00=_o003Ko`05003ooa00
0?oK2`00okH>003oTR000?m]3@00oi8:003o]Q@00?oK1@00ool2003Ko`03002fo`3Ko`00fol00080
om/0103o]P080?nB01@0ofd05@3oB@030?ooo`8000001@3oool001/0oooo00<000000?ooo`3oool0
0P3ooolE0?m901@0ofd0203oTP040?nf0080om/00P3oo`000`009?l00?oo003oo`05003oo`l00?oK
2`00okH@003oTQh00?m]3P00oi8;003o]Q<00?oK1`00ool00`000?l0ool00?oo00020?oK00@0okH0
203oTP0D0?m]01D0odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?oo
o`020?oooaD0odT0503oK@080?nB00@0okH00P3of`020?oo00030019o`00fol00=_o00D00?oo3000
om/>003o]Q400?nB6`00ofdB003oTP`00?nf4000om/5003oo`03003Ko`00]_l004Wo0080ool00P3o
f`040?nf00L0oi805@3oK@0E0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<00000
0?ooo`3oool00P3ooolE0?m901@0ofd0203oTP040?nf0080om/00P3oo`000`00BOl00=_o003Ko`05
003oo``00?oK3P00okHA003oTQ/00?m]4P00oi8<003o]Q000?oK1@00ool00`00fol00;Ko0019o`02
0?oo0080om/0103o]P070?nB01D0ofd05@3oB@040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo5P3oB@0D0?m]00L0oi801@3o]P000`3of`00ool00?oo0002002f
o`@00=_o0P00ool;003of`l00?nf4@00oi8K003oKA800?nB3P00okH>003of`<00?oo0`00fol2002f
o`80ool000<0om/00?nf003o]P000P3o]P080?nB01@0ofd05P3oB@040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo5P3oB@0D0?m]00P0oi80103o]P001@3of`00
ool00?oo001]o`000=_o00@00;Ko00<00=_o003oo`00om/02@00om/?003o]Q<00?nB6@00ofdD003o
TQ000?nf3000om/01`00ool00=_o003Ko`00fol00;Ko003Ko`2Bo`000P3oo`000`3of`00okH00?nf
00020?nf00P0oi80503oK@0F0?m900@0oooo00<000000?ooo`3oool00`3oool000P0oooo0P000004
0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool00P3ooolF0?m901@0ofd0203oTP04
0?nf00040?oK003oo`00ool00;Ko008009;o00D006go0?l0K@3o06d004Wo003oo`08003ofa400?nf
5@00oi8G003oKA@00?nB4P00okH:003of`03003Ko`3o02@009;o00<009;o00@0fol00?oo003oo`00
om/0103o]P080?nB01@0ofd05P3oB@040?ooo`030000003oool0oooo00<0oooo00070?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oo
oaH0odT0503oK@080?nB00@0okH00`3of`000`3oo`009?l0001]o`030?l000030?l0f`00om/00?oK
01P00?nf5P00oi8E003oKAD00?nB6`00okH00`00om/0o`2f0?l0000202@0o`03001]o`1]o`00ool0
00<0om/0103o]P080?nB01@0ofd05P3oB@040?ooo`030000003oool0oooo00<0oooo00070?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool2000000<0oooo5P3oB@0D0?m]
00P0oi80103o]P030?oK00030?oo000To`0006go00<0o`0000<0o`3K003of`00om/06000okHF003o
TQD00?m]5@00oi8K003o]P03003of`3o0;H0o`000080903o00<006go06go003oo`000`3of`040?nf
00P0oi80503oK@0F0?m900<0oooo0P0000050?ooo`001`3oool010000000oooo0?ooo`0000090?oo
o`8000001@3oool00`000000oooo0?ooo`020?oooaH0odT0503oK@080?nB00@0okH00`3of`00103o
o`00fol004Wo00000?l20980o`03003of`00okH00?nf01P00?nf5P00oi8E003oKAH00?nB6P00okH0
0`00oi800?nf0980o`020000o`0306go003Ko`00ool000<0om/0103o]P080?nB01@0ofd05P3oB@04
0?ooo`030000003oool0oooo00<0oooo00070?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?oooaL0odT04`3oK@080?nB00@0okH00`3of`00
103oo`00fol00;Ko001]o`02003o0003003oK@00oi800?nf01L00?nf6000oi8D003oKAH00?nB6P00
okH00`00oi800?m9003o000206go00030;Ko003Ko`00ool000<0om/0103o]P080?nB01<0ofd05`3o
B@040?ooo`030000003oool0oooo00<0oooo00080?ooo`8000002P3oool3000000@0oooo00<00000
0?ooo`3oool00P3ooolG0?m901<0ofd0203oTP040?nf00<0om/000@0ool00=_o002Bo`00TP3o0P3o
0002003oTQP00?nf6000oi8C003oKAL00?nB6P00okH00`00oi800?nf06d0o`0202@0o`0309;o003K
o`00ool000<0om/0103o]P080?nB01<0ofd05`3oB@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo5`3oB@0D0?m]00L0oi801@3o]P020?oK00040?oo003Ko`00
04Wo000To`80o`0000<0o`2B003o]P00okH05`00okHI003oTQ800?m]6000oi8I003o]P03003of`3o
0=/0o`000080003o00<004Wo0=_o003oo`000P3of`050?nf00L0oi80503oK@0G0?m900@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolG0?m901@0ofd01`3oTP05
0?nf0080om/000@0ool00=_o0000BOl002Co0P3o00000`3o09800?nf003o]P0G003o]QT00?nB4P00
ofdH003oTQT00?nf00<00?oK0?l0f`3o00000P000?l00`00BOl0fol00?oo00020?oK00D0okH01`3o
TP0D0?m]01L0odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?oooaL0odT0503oK@070?nB00D0okH00P3of`00103oo`00BOl0002Bo`00T_l20?l0B@03003Ko`00
om/00?oK00<00?oK5000okHI003oTQ800?m]6000oi8D003o]PD00?oK00<00?oo000To`3o06d00P00
KOl00`00T_l0KOl00?oo00020?oK00<0okH02@3oTP0D0?m]01L0odT0103oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaT0odT04P3oK@090?nB00<0okH00P3of`00
103oo`00903o002fo`00]_l2003Ko`03003oo`00om/00?oK00L00?oK3P00okHK003oTQ800?m]6@00
oi8B003o]PH00?oK00<00?oo003Ko`00]_l00`00]_l010000?l0ool00?oK003of`030?nf00T0oi80
4P3oK@0I0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?oooaT0odT04P3o
K@090?nB00<0okH00P3of`00103oo`0009;o003Ko`00fol3003oo`X00?oK3@00okHK003oTQ800?m]
6`00oi8>003o]PP00?oK0P00ool4003Ko`04002Bo`3oo`00om/00?oK00<0okH02@3oTP0B0?m]01T0
odT00`3oool2000000D0oooo000K0?ooo`030000003oool0oooo0080oooo6@3oB@0C0?m]00P0oi80
0`3o]P020?oK00030?oo0000BOl00=_o00@00?oo2P00om/<003o]Q`00?nB4`00ofdK003oTP`00?nf
2@00om/6003oo`040019o`3oo`00om/00?oK00<0okH0203oTP0C0?m]01T0odT0103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaT0odT04`3oK@080?nB00<0okH0
0P3of`000`3oo`00003o003Ko`04003oo`/00?oK2P00okHM003oTQ<00?m]7000oi8;003o]PT00?oK
1@00ool00`00fol0]P3o0?oo00020?oK00<0okH0203oTP0C0?m]01T0odT0103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaT0odT04`3oK@080?nB00<0okH00P3o
f`000`3oo`00003o003Ko`04003oo`/00?oK2P00okHM003oTQ<00?m]7000oi8;003o]PT00?oK1@00
ool00`00fol0]P3o0?oo00020?oK00<0okH0203oTP0C0?m]01T0odT0103oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaX0odT04P3oK@090?nB0080okH00P3of`00
103oo`0006go003Ko`00fol3003oo`/00?oK2@00okHN003oTQ<00?m]7`00oi87003o]P`00?oK00D0
0?oo003Ko`00fol00=_o0019o`030?oK0080okH02@3oTP0B0?m]01X0odT0103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaX0odT0503oK@070?nB00@0okH000@0
om/00=_o0000T_l006go0P3o04T=003of`H00?nf8000oi8C003oKB000?nB1P00okH<003of`06002f
o`00T_l009;o002Bo`3Ko`00om/0103o]P070?nB01@0ofd06P3oB@040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo6P3oB@0D0?m]00L0oi80103o]P00103of`00
ool00=_o0000odT2003o90800?oK2@00ool2003of`D00?nf8@00oi8C003oKB400?nB1000okH5003o
f`L00?oo00L00?oK003o9000o`000?l00=_o003oo`00om/000@0okH01`3oTP0D0?m]01X0odT0103o
ool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa/0odT04`3oK@08
0?nB00@0okH000<0om/00?oo003Ko`000P009?l00`00T_l00?oo003oo`05003oo`@00=_o00<00?oo
003of`00okH00P00okHR003oTQ<00?m]8P00oi83003o]P03003of`00ool00?oo00T00?oo00H0o`0T
000To`3Ko`00fol00?oo003of`040?nf00P0oi804`3oK@0K0?m900@0oooo00<000000?ooo`3oool0
0`3oool001/0oooo0P0000030?oooa/0odT04`3oK@080?nB00@0okH000<0om/00?oo003Ko`000P00
9?l00`00T_l00?oo003oo`05003oo`@00=_o00<00?oo003of`00okH00P00okHR003oTQ<00?m]8P00
oi83003o]P03003of`00ool00?oo00T00?oo00H0o`0T000To`3Ko`00fol00?oo003of`040?nf00P0
oi804`3oK@0K0?m900<0oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?oooa/0odT0
503oK@070?nB00@0okH00P3of`001@3Ko`0009;o002Bo`00]_l00=_o00@00?oo0P00fol2002Bo`04
0?l0K@3o0?l0o`1]003of`800?nf8`00oi8C003oKB@00?nB00@00?nf003oo`00T_l009;o0`00fol5
003oo`03003Ko`00]_l009;o0080fol00P3of`040?nf00L0oi80503oK@0K0?m900@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolK0?m901@0ofd0203oTP040?nf
00040?oK003oo`0002Co000To`800=_o00<00?oo003Ko`00fol00P00fol01`00]_l0o`0T0?l0903o
0980o`2f0?l0o`00ool09@00oi8C003oKB@00?nB00@00?nf0?l0o`3o0=/0o`2B0P00BOl00`00]_l0
0=_o003Ko`02003Ko`04003oo`00fol00=_o0980o`80ool000<0om/00?nf003o]P000P3o]P080?nB
01@0ofd06`3oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo703oB@0D0?m]00L0oi80103o]P020?oK0080fol000<009;o0?l00000ool00`00fol01000]_l0
09;o0?l0B@3o04T20?l000040=/0o`3o06d00?nB003oTP800?m]2`00oi89003o]Pl00?nB4@00ofdA
003oTP@00?nf2`00oi84003oK@03003o]P3K0?l0o`1]00<0o`0T00<00;Ko003Ko`00fol00`00fol0
0`3o000006go0?oo00030?oK00@0okH01`3oTP0D0?m]01`0odT0103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?oooa`0odT0503oK@090?nB00<0okH00`3of`000`3o
o`00]_l0002Bo`02002fo`03003Ko`00]_l009;o0080B@3o0P3o0000102B0?l00?nB003oB@00odT3
003oK@P00?nB4@00okH9003oTPH00?m]0P00odT8003oK@h00?nB2P00okH8003oTP<00?m]0P00odT0
1000ofd0TP3o0?l0003o00020019o`03002Bo`00]_l00=_o00800;Ko00<006go0;Ko003oo`000`3o
f`030?nf00T0oi80503oK@0L0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<00000
0?ooo`3oool00P3ooolL0?m901@0ofd02@3oTP030?nf00<0om/000<0ool00;Ko0000T_l00P00]_l0
0`00fol00;Ko002Bo`0204T0o`80o`0000@0TP3o003oTP00odT00?m90`00ofd8003oTQ400?nf2@00
oi86003oK@800?m92000ofd>003oTPX00?nf2000oi83003oK@800?m900@00?m]0980o`3o0000o`00
0P00BOl00`00T_l00;Ko003Ko`02002fo`03001]o`2fo`00ool000<0om/00`3o]P090?nB01@0ofd0
703oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo7P3o
B@0C0?m]00P0oi80103o]P030?oK00070?oo002Bo`00o`000?l00000T_l00;Ko002Bo`020019o`03
0000o`0T0?l00?nf00<00?lT00<00?m9003oK@00ofd01`00oi8F003o]PD00?nB1@00ofd6003oB@D0
0?m]2@00oi8B003o]PH00?nB00<00?m]003oB@00ob@00P00ob@00`00ofd0903o000To`02001]o`03
002Bo`00]_l006go008002Co00@0T_l00?oo003of`00om/0103o]P090?nB01<0ofd07P3oB@040?oo
o`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo7P3oB@0C0?m]00T0
oi801@3o]P020?oK00060?oo003Ko`00fol009;o000To`0002Co0P00BOl0103K0?l09?l002Co0000
o`02003o9003003oB@00ofd00?nB00@00?nB6`00okH4003oTP800?m]2@00odT2003oK@P00?nB5`00
okH4003oTP04003oK@00odT00?lT003o90<09?l000H0f`3o0019o`00BOl004Wo04Wo002Bo`020=_o
00030?oo003of`00om/000D0okH02@3oTP0C0?m]01h0odT0103oool00`000000oooo0?ooo`030?oo
o`006`3oool00`000000oooo0?ooo`020?oooah0odT0503oK@090?nB00D0okH00P3of`030?oo0080
fol00P2fo`0209;o000506go000To`000?m9003oB@00om/09000okH00`00oi800?m]003oK@09003o
B@800?m]1000oi8N003o]P03003of`2f0?l0o`3K00800?nf00<09?l006go002Bo`000`2fo`020=_o
00<0ool00P3of`050?nf00T0oi804`3oK@0O0?m900@0oooo00<000000?ooo`3oool00`3oool001/0
oooo0P0000030?oooal0odT04`3oK@0:0?nB00D0okH0103of`020?oo00<0fol000<0]_l006go0019
0?l00P1]0?l00`3K0?l0o`3o003oo`0I003o]P@00?oK00<00?oo003Ko`00fol00P00ool00`00okH0
0?nB003oK@03003oB@<00?lT0`00odT00`00ofd00?nB003o]P0N003o]P<00?oK00<0o`000?l0o`3K
0?l00P1]0?l00`0T0?l0KOl00;Ko00030=_o0080ool0103of`050?nf00X0oi804`3oK@0O0?m900<0
oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?oooal0odT05@3oK@090?nB00D0okH0
103of`030?oo00040=_o002fo`00TP3o000To`<0o`0000@0o`3K0?l0TP00om/00?oK5@00okH3003o
f`06003oo`00fol00=_o0?l0TP3o0=/0f`3o0P3o0?l00`3o00000?oK003oK@02003oB@@00?lT0`00
odT01`00oi800?nf0?l0B@3o04T00;Ko003Ko`00ool00`00om/F003o]P800?oK0P00fol20?l0]P<0
o`0000@002Co04T0o`2fo`00fol00`3oo`040?oK00@0okH02P3oTP0E0?m]01l0odT0103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooal0odT05@3oK@090?nB00D0
okH0103of`030?oo00040=_o002fo`00TP3o000To`<0o`0000@0o`3K0?l0TP00om/00?oK5@00okH3
003of`06003oo`00fol00=_o0?l0TP3o0=/0f`3o0P3o0?l00`3o00000?oK003oK@02003oB@@00?lT
0`00odT01`00oi800?nf0?l0B@3o04T00;Ko003Ko`00ool00`00om/F003o]P800?oK0P00fol20?l0
]P<0o`0000@002Co04T0o`2fo`00fol00`3oo`040?oK00@0okH02P3oTP0E0?m]01l0odT0103oool0
0`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooob00odT05@3oK@080?nB
00L0okH00`3of`020?oo00040=_o002fo`0006go0019o`80o`0000<0o`190?l0TP00]_l00P00ool0
0`00om/00?nf003o]P0?003o]PD00?oK00@00?oo002fo`3o06d0o`1]0`3o0?l20=/0o`030;H0o`1]
0?l00?nB00800?m900<00?lT003o0000o`000`00ob@00`00ofd00?oK0=/0o`030=/0o`040?l0f`00
KOl00?oo003oo`<00?oK4`00okH3003of`800=_o0P3o09800`3o04T0o`000?l000020019o`040;Ko
003Ko`00ool00?oo00<0om/01P3o]P090?nB01D0ofd0803oB@040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo803oB@0E0?m]00X0oi801P3o]P020?oK00<0ool0
00<0T_l0002Bo`00T_l00P00KOl00`00BOl009;o003Ko`02003oo`800?oK3`00okH5003of`800?oo
00<0o`190?l0]P3o0;H00P3o0=/01P3o0?l0f`3o0=/0o`2f0?l0TP3o001]o`800?m91000o`02003o
9003003oTP2B0?l0]P3o0080f`3o00<0o`3o0?l0f`3o0;H00P3o06d00`00ool00?oK003of`03003o
fa000?nf0`00om/2003oo`03002fo`3o0000o`00008006go0P00T_l0102fo`00ool00?oo003oo`02
0?oK00H0okH02P3oTP0E0?m]0200odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?ooob40odT05@3oK@0:0?nB00H0okH00`3of`000`3oo`00T_l0002fo`03002f
o`800=_o0`00ool3003of`d00?nf1P00om/00`00ool00=_o0?l090040?l0]P060?l0K@3o0000o`00
0=/0o`2B0?l0K@3o0P00odT01000o`009?l002Co0000o`02003o90030;H0o`2B0?l0]P3o0080o`3o
0P3o0=/01@3o0;H0o`000?l00000fol00?oo00D00?oK3@00okH5003of`800?oo0P00fol5002fo`03
09;o003oo`00om/00080om/01P3o]P0:0?nB01D0ofd08@3oB@040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo8@3oB@0F0?m]00X0oi801@3o]P030?oK00040?oo
002fo`0006go002fo`<00=_o1000ool5003of`T00?nf1`00om/2003oo`06003Ko`3o06d0o`2f0?l0
]P3o0980o`1]103o00001@1]0?l0B@3o003oB@00odT09?l00080BOl000D09?l0003o9000ob@0B@3o
06d0o`040?l000060?l0TP3o0;H0o`2B0?l0TP00fol00?oo1`00om/:003o]PH00?oK0`00ool4003K
o`04002fo`00KOl0]_l00?oo00<0om/01@3o]P0:0?nB01H0ofd08@3oB@040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo8@3oB@0F0?m]00X0oi801@3o]P030?oK
00040?oo002fo`0006go002fo`<00=_o1000ool5003of`T00?nf1`00om/2003oo`06003Ko`3o06d0
o`2f0?l0]P3o0980o`1]103o00001@1]0?l0B@3o003oB@00odT09?l00080BOl000D09?l0003o9000
ob@0B@3o06d0o`040?l000060?l0TP3o0;H0o`2B0?l0TP00fol00?oo1`00om/:003o]PH00?oK0`00
ool4003Ko`04002fo`00KOl0]_l00?oo00<0om/01@3o]P0:0?nB01H0ofd08@3oB@040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`8000000`3ooolR0?m901D0ofd02`3oTP050?nf0080om/000<0
ool00=_o0000T_l01000fol4003oo`H00?oK1`00okH8003of`800?oo00<00=_o001]o`3o09800P3o
09800`3o04T0o`000?l000020?l0000404T0o`0T0?l00?lT003o90@0BOl00P00o`0202@0o`@0o`00
00D0o`1]0?l0TP3o02@0o`0T003Ko`02003oo`T00?oK1`00okH6003of`@00?oo1000fol00`00T_l0
fol00?oK00020?oK00D0okH02`3oTP0E0?m]0280odT00`3oool2000000D0oooo000K0?ooo`030000
003oool0oooo0080oooo903oB@0E0?m]00T0oi801@3o]P030?oK00030?oo0000T_l009;o00D00?oo
2000om/6003o]PT00?oK0P00ool01P00fol00;Ko0?l0003o0000o`1]0?l0B@@0o`000P000?l2003o
00@0KOl00P0To`020000o`<0o`0000<0o`0T0?l0B@3o00000P00T_l00`00fol00?oo003oo`0:003o
f`H00?nf1P00om/7003oo`03002Bo`00KOl0ool000<0om/00`3o]P0;0?nB01D0ofd0903oB@040?oo
o`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo903oB@0F0?m]00X0
oi801@3o]P00103of`00ool00=_o003K0?l5003oo`P00?oK1P00okH7003of`@00?oo00H00=_o002f
o`00T_l009;o0?l0003o02@30?l000<002Co0P19o`0409;o0080BOl00`009?l20000o`80o`0000@0
09;o002fo`00]_l00=_o0`00ool9003of`H00?nf2000om/3003oo`800=_o00@0TP3o0=_o003oo`00
om/01@3o]P0:0?nB01H0ofd0903oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000
003oool0oooo0080oooo9@3oB@0F0?m]00X0oi80103o]P020?oK00030?oo0000T_l00=_o00800=_o
00<00?oo003of`00om/01`00om/6003o]PL00?oK1000ool2003Ko`800;Ko00<009;o001]o`00KOl0
0`00KOl01000BOl0003o06go001]o`040;Ko0080T_l000<0003o0019o`00KOl00P00KOl2002Bo`04
002fo`00fol00=_o003Ko`<00?oo2P00om/5003o]PT00?oK00H00?oo003Ko`00fol00=_o002Bo`3o
o`020?oK00@0okH02P3oTP0F0?m]02D0odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool0
0`000000oooo0?ooo`020?ooobD0odT05P3oK@0;0?nB00@0okH00P3of`001@3Ko`0009;o002Bo`00
KOl0o`2f00<00?oK0`00ool3003of`D00?nf2000om/5003oo`<00=_o0P00]_l3002Bo`8006go00<0
0?l00;Ko002fo`001P2fo`000`0To`0004Wo001]o`03002Bo`800;Ko0`00fol5003oo`P00?oK1@00
okH4003of`800?oo0P00om/00`00okH0o`2B002Bo`02002Bo`030=_o003of`00om/000@0okH02P3o
TP0G0?m]02D0odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?ooobD0odT05P3oK@0;0?nB00@0okH00P3of`001@3Ko`0009;o002Bo`00KOl0o`2f00<00?oK0`00
ool3003of`D00?nf2000om/5003oo`<00=_o0P00]_l3002Bo`8006go00<00?l00;Ko002fo`001P2f
o`000`0To`0004Wo001]o`03002Bo`800;Ko0`00fol5003oo`P00?oK1@00okH4003of`800?oo0P00
om/00`00okH0o`2B002Bo`02002Bo`030=_o003of`00om/000@0okH02P3oTP0G0?m]02D0odT0103o
ool00`000000oooo0?ooo`030?ooo`004`3oool5000000<0oooo00<000000?ooo`3oool00P3ooolV
0?m901H0ofd02`3oTP040?nf00070?oK003oo`00fol00=_o001]o`009?l0002Bo`08003oo`03003o
]P00oi800?nf00800?nf2000om/5003oo`<00=_o0`00]_l3002Bo`030?l0002Bo`00fol000L0fol0
00<0T_l00?l00000T_l00P00T_l2002fo`@00=_o1@00ool:003of`04003o]P00oi800?nf003of`L0
0?oo00<0o`3K02Co001]o`000P3Ko`000`3oo`00om/00?nf00030?nf00/0oi805P3oK@0V0?m900@0
oooo00<000000?ooo`3oool00`3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooobL0odT05P3oK@0:0?nB00D0okH00`3of`000`3oo`000?l0002Bo`02003Ko`800?oo
00L00=_o001]o`00KOl0o`2f0?l09000ofd00?nf00X00?oK1@00ool4003Ko`@00;Ko00<0o`0009;o
003Ko`000P3Ko`040?oo00<0fol000<0T_l00?l00000]_l00`00]_l4003Ko`D00?oo1P00om/4003o
o`04003o]P00ofd00?oK0?l0]P800;Ko00<00=_o003oo`00ool00P00fol00`00T_l0KOl00?oo0003
0?oK00D0okH02@3oTP0G0?m]02L0odT0103oool00`000000oooo0?ooo`030?ooo`005@3oool00`00
0000oooo0?ooo`030?ooo`8000000`3ooolW0?m901P0ofd02P3oTP040?nf00<0om/000D0fol0002B
o`00fol00=_o003oo`02003Ko`8006go00@0o`00002Bo`00ob@0f`3o0P3o0;H00`00fol00?oo003o
o`02003oo`<00?oK1@00ool5003Ko`<009;o00<0T_l00=_o003oo`002@3oo`000`3Ko`00KOl0002B
o`02002Bo`D00=_o1@00ool3003of`@00?oo00L00=_o0?l0TP3o0980f`3o003o9000T_l0o`000080
09;o0P00fol01@00ool00=_o003Ko`00T_l0fol000<0om/0103o]P0:0?nB01P0ofd09`3oB@030?oo
o`8000001@3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooobT0
odT05`3oK@0:0?nB00D0okH00P3of`00103Ko`0006go001]o`190?l2002fo`8009;o00<004Wo06go
0019o`000`3o00000`00fol00?oo003oo`03003oo`800?oK1P00ool2003Ko`800;Ko00@09?l00;Ko
002fo`00fol01@3oo`020?oK00D0ool000@0fol00;Ko002fo`009?l00P00]_l2003Ko`800?oo00@0
0=_o003oo`00ool00?oo0P00om/4003oo`08003Ko`00]_l0o`0T0?l0903o0000BOl006go0000BOl2
002Bo`800;Ko00@0B@3o002Bo`00T_l0fol00P3of`050?nf00X0oi805`3oK@0Y0?m900@0oooo00<0
00000?ooo`3oool00`3oool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooobT0odT05`3oK@0:0?nB00D0okH00P3of`00103Ko`0006go001]o`190?l2002fo`8009;o00<0
04Wo06go0019o`000`3o00000`00fol00?oo003oo`03003oo`800?oK1P00ool2003Ko`800;Ko00@0
9?l00;Ko002fo`00fol01@3oo`020?oK00D0ool000@0fol00;Ko002fo`009?l00P00]_l2003Ko`80
0?oo00@00=_o003oo`00ool00?oo0P00om/4003oo`08003Ko`00]_l0o`0T0?l0903o0000BOl006go
0000BOl2002Bo`800;Ko00@0B@3o002Bo`00T_l0fol00P3of`050?nf00X0oi805`3oK@0Y0?m900@0
oooo00<000000?ooo`3oool00`3oool001@0oooo0P0000050?ooo`030000003oool0oooo0080oooo
:P3oB@0G0?m]00X0oi801@3o]P020?oK00<0ool000@0]_l009;o002fo`00]_l00P3Ko`00102fo`00
06go002fo`00]_l2003Ko`@00?oo00@00?oK003o]P00T_l009;o0`00fol01P00ool0o`000?l00000
T_l004Wo0;Ko00@0ool02P3of`040?oo00030;Ko0000BOl009;o0080o`0000@00?oo003Ko`00fol0
0;Ko0P3o00000`00okH00?oK003oo`03003oo`800=_o0P00T_l01000KOl0]_l00=_o003Ko`020;Ko
000309;o002fo`00ool00080ool00P3of`050?nf00X0oi805`3oK@0Z0?m900@0oooo00<000000?oo
o`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool[0?m901L0ofd02`3oTP050?nf00@0
om/01@3oo`00103Ko`00T_l0002Bo`00T_l2003Ko`06003oo`00fol00=_o002fo`3o00000?l00P3o
00001000]_l00=_o002fo`00BOl20;Ko0080fol00`3oo`0>0?oK00<0ool000P0fol00;Ko002fo`00
]_l0001]o`00]_l00=_o002Bo`80o`0000<00?l00?l00000fol00P00fol00`00ool00=_o003Ko`02
002Bo`0309;o003Ko`00ool000@0ool0103of`050?nf00/0oi805`3oK@0[0?m900@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool[0?m901T0ofd02`3oTP060?nf
00L0om/000H0ool00;Ko002fo`0009;o0?l0003o06d2003Ko`03002fo`00KOl0]_l00080T_l000@0
o`000019o`3o0000fol00`3oo`0F0?oK00<0ool000@0]_l00019o`00BOl0TP3o0P2Bo`000`2fo`00
06go002fo`02003Ko`030?l0K@000?l009;o0080fol000<0ool00?oK003of`001@3of`060?nf00/0
oi80603oK@0/0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0
0P3oool/0?m901T0ofd0303oTP090?nf00<0om/00`3oo`001P3Ko`00]_l00019o`00BOl0T_l00=_o
00L0ool01`3of`0>0?nf00L0om/01`3oo`001P3Ko`00T_l0000To`009?l0]_l00=_o00<0ool00`3o
f`090?nf00`0oi806@3oK@0/0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<00000
0?ooo`3oool00P3oool/0?m901T0ofd0303oTP090?nf00<0om/00`3oo`001P3Ko`00]_l00019o`00
BOl0T_l00=_o00L0ool01`3of`0>0?nf00L0om/01`3oo`001P3Ko`00T_l0000To`009?l0]_l00=_o
00<0ool00`3of`090?nf00`0oi806@3oK@0/0?m900@0oooo00<000000?ooo`3oool00`3oool001/0
oooo0P0000030?ooobh0odT06@3oK@0=0?nB00T0okH04`3of`0F0?nf01<0om/02@3o]P0=0?nB01T0
ofd0;P3oB@030?ooo`8000001@3oool001/0oooo00<000000?ooo`3oool00P3oool_0?m901X0ofd0
3@3oTP0;0?nf00H0om/0:03o]P060?oK00/0okH03@3oTP0J0?m]02l0odT0103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooc00odT06P3oK@0@0?nB0480okH0403o
TP0J0?m]0300odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?oooc40odT06`3oK@0C0?nB01D0okH03P3oTP0E0?nf01<0oi806`3oK@0a0?m900@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolb0?m901/0ofd0G03oTP0K0?m]
0380odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooc80
odT06`3oK@1L0?nB01/0ofd0<P3oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000
003oool0oooo0080oooo=03oB@0L0?m]05H0oi80703oK@0d0?m900@0oooo00<000000?ooo`3oool0
0`3oool001/0oooo00<000000?ooo`3oool00P3ooole0?m901d0ofd0DP3oTP0M0?m]03D0odT0103o
ool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0oooo=P3oB@0P0?m]04X0oi80803oK@0f
0?m900<0oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?ooocL0odT08`3oK@120?nB
02<0ofd0=`3oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo=`3oB@0S0?m]0480oi808`3oK@0g0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3ooolj0?m902D0ofd0>03oTP0U0?m]03X0odT0103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooc/0odT0;03oK@0Y0?nB02/0ofd0>`3o
B@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo?03oB@1n
0?m]03`0odT0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
ocl0odT0N03oK@0o0?m900@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3ooolo0?m907P0ofd0?`3oB@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000
003oool0oooo0080oooo@03oB@1f0?m]0400odT0103oool00`000000oooo0?ooo`030?ooo`006`3o
ool2000000<0oooo@P3oB@1b0?m]0440odT000@0ob@00?ooo`3oool0oooo0P0000050?ooo`006`3o
ool00`000000oooo0?ooo`020?ooo`030?lT003oB@00odT00480odT0K03oK@140?m900030?lT003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool2
0?lT04@0odT0JP3oK@140?m90080ob@0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?ooo`@0ob@0A@3oB@1T0?m]04D0odT0103o90040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo103o90150?m906@0ofd0A@3oB@040?lT00@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool50?lT04H0odT0
H03oK@160?m900D0ob@0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?oo
o`020?ooo`D0ob@0BP3oB@1H0?m]04X0odT01@3o90040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo1P3o901;0?m905@0ofd0B`3oB@060?lT00@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo0P0000030?ooo`L0ob@0CP3oB@1<0?m]04h0odT01`3o90030?oo
o`8000001@3oool001/0oooo00<000000?ooo`3oool00P3oool70?lT04h0odT0C03oK@1>0?m900L0
ob@0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`T0ob@0
D03oB@140?m]0500odT02@3o90040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003o
ool0oooo0080oooo2P3o901B0?m903h0ofd0DP3oB@0:0?lT00@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3oool;0?lT05H0odT0=03oK@1F0?m900/0ob@0103oool0
0`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo``0ob@0G@3oB@0T0?m]
05d0odT0303o90040?ooo`030000003oool0oooo00<0oooo00070?ooo`D000000P3oool2000000@0
oooo0P0000050?ooo`030000003oool0oooo0080oooo303o901M0?m902@0ofd0G@3oB@0<0?lT00@0
oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo3P3o901W0?m900`0ofd0I`3oB@0>0?lT00@0
oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`8000000`3oool?0?lT0=P0odT03`3o90030?ooo`8000001@3oool000T0oooo00<0
00000?ooo`3oool0203oool2000000D0oooo00<000000?ooo`3oool0o03oool00`000000oooo0?oo
o`030?ooo`002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0o03oool00`000000oooo0?ooo`030?ooo`00203oool2000000X0oooo0`0000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo02H0oooo00D000000?ooo`3oool0oooo000000050?ooo`006`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001@3oool001/0ooooo`0000010000
00D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.89184, -1.82524, 0.0122009, \
0.0122009}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(gr2 = 
        DensityPlot[
          juliaC[x, y, 
            50,  .27334,  .00742], \[IndentingNewLine]{x, \(-0.1\), \(- \
.5\)}, {y, \(- .1\),  .4}, PlotPoints \[Rule] 200, Mesh -> False, 
          ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.22115 2.40385 0.211538 1.92308 [
[.01923 -0.0125 -12 -9 ]
[.01923 -0.0125 12 0 ]
[.25962 -0.0125 -12 -9 ]
[.25962 -0.0125 12 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.74038 -0.0125 -12 -9 ]
[.74038 -0.0125 12 0 ]
[.98077 -0.0125 -12 -9 ]
[.98077 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -24 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -18 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -18 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -18 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -18 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-0.5)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-0.4)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(-0.3)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(-0.2)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(-0.1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-0.1)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(0.1)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(0.2)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(0.3)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(0.4)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000001BFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00C1FF00C1FF0098FF0045FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF9800EBFF0098FF006EFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000001BFF0045FF001BFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
001BFF006EFF0045FF6000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FFF900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00EBFF00C1FF006EFF0045FF6000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FFA600FFCF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC1
00C1FF006EFF006EFF001BFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00003700FF0D00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF7C00FF7C00FFA600FFCF00DDFF008A00FFFF0000FF0000FF0000FF0000FF00008AFF00
FF00003700FF0D00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000006EFF006EFF0045FF0D00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF5300FF5300FF7C00FF7C00FFA600FFA600FFF900DDFF00DDFF00FFF900FFF900FFF900
DDFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00C1FF00EBFF0098FF0045FF001BFF6000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00008A00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600
FFCF00FFF9008AFF00FF0000FF00006000FFFF0000FF0000FF0000FF0000FF0000FF0000
00FF1BFF00530D00FF001BFF0D00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000001BFF001BFF0D00FF3700FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00
FFA600FFA600FFCF00FFF900FFF900FF0000FF0000FF0000FF0000FF0000FF000060FF00
8AFF00FF00008A00FF8A00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000045FF006EFF0045FF001BFF0D00FF3700FFDD00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF007CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00
FF7C00FF7C00FFA600FFA600FFA600FFCF00FFF900FFF900B3FF00DDFF00DDFF00FFF900
DDFF00B3FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000EBFF0098FF0045FF001BFF0D00FF3700FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
B300FF6000FFDD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2900FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF7C00
FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00
FFCF00FFF900DDFF008AFF00FF0000FF0000FF00000D00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF6EFF00003700FF0D00FF3700FF8A00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003700FF0D00FF
0D00FF3700FF3700FF8A00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2900FF2900FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600
FFCF00FFCF00FFCF00FFF900DDFF00B3FF008AFF00FF0000FF0000FF0000FF0000FF0000
FF0000FF000060FF0037FF00FF00008A00FF6000FFDD00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003700FF0045FF0045FF
001BFF0D00FF0D00FF3700FF8A00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600
FFA600FFA600FFA600FFCF00FFCF00FFF900FFF900DDFF008AFF0060FF00FF0000FF00F9
8AFF00B3FF00B3FF00B3FF0000FF1BFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000006EFF006EFF0045FF
001BFF001BFF0D00FF3700FF6000FFFF00F9FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00CFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FFA600
FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900
FFF900FFF900DDFF00DDFF00B3FF0037FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000EBFF0098FF001BFF
001BFF0D00FF0D00FF3700FF8A00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000DD00FFB300FFB300FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF5300FF5300
FF5300FF5300FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00
FFF900FFF900FFF900FFF900FFF900DDFF00B3FF00FF0000FF0000FF00000098FF0D00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF9800FF98FF0000FF0000
3700FF3700FF3700FF6000FFDD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
B300FF6000FF6000FF6000FF6000FF8A00FF8A00FFFF00F9FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF5300
FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFF900FFF900FFF900DDFF00DDFF00B3FF008AFF0037FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000DFF0000FF1BFF0000DD00FF
8A00FF8A00FF8A00FFFF00F9FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00006000FF
3700FF3700FF3700FF3700FF3700FF6000FF6000FF8A00FFFF00CFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900DDFF00DDFF008AFF00
00FFC10DFF00FF0000FF0000FF0000FF000037FF0060FF0060FF0060FF0000FFC1FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00006000FF0D00FF
001BFF0D00FF0D00FF0D00FF3700FF3700FF6000FF6000FF8A00FFFF00CFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900DDFF00
DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF0060FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000001BFF0045FF
0045FF001BFF001BFF0D00FF0D00FF3700FF3700FF6000FF8A00FFB300FFFF00F9FF007C
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900
FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF008AFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000D00FF006EFF006EFF
0045FF001BFF001BFF0D00FF0D00FF3700FF3700FF6000FF8A00FFB300FFFF00F9FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900
FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
8AFF0060FF00FF0000FF0000FF0000FF0000FF0000B300FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C1FF00C1FF0098FF
001BFF0D00FF0D00FF0D00FF3700FF3700FF6000FF6000FF8A00FFB300FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00
B3FF00B3FF008AFF000DFF00FF007CFF000000FF986000FF8A00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC100FFEBFF0000
FF0000FF00003700FF3700FF3700FF6000FF6000FF8A00FFB300FFFF00F9FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00
DDFF00DDFF00B3FF00B3FF008AFF008AFF0037FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF6E00FF6E00FFEBFF0029
FF0053DD00FF8A00FF6000FF6000FF6000FF8A00FF8A00FFDD00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0029FF007CFF0029FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900
DDFF00DDFF00DDFF00DDFF00B3FF00B3FF008AFF0037FF00B300FFFF0000FF00006000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF1B0DFF0000FF1B00FF98FF0000
FF00CFDD00FFB300FF8A00FF8A00FF8A00FFB300FFDD00FFFF00F9FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00CFFF00CFFF00CFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900
FFF900FFF900DDFF00DDFF00DDFF00DDFF00B3FF00B3FF008AFF0060FF0060FF00FF0000
FF0000FF0000FF0000FF0000FF00000DFF0037FF0037FF0037FF0037FF0000FF1BFF0000
FF0000FF00CFDD00FFDD00FFDD00FFDD00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00CFDD00FFDD00FFDD00FFFF00F9FF00CFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900
FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F9DD00FFDD00FF
B300FFB300FFB300FFB300FFB300FFB300FFDD00FFDD00FFFF00CFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF000DFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00F9B300FFB300FF8A00FF8A00FF8A00FF8A00FF
8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FFDD00FFFF00CFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900
FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF0060FF00
0DFF00FF0029FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000B300FF8A00FF6000FF6000FF6000FF6000FF6000FF
6000FF6000FF8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFDD00FFFF00CFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF00
60FF000DFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00F96000FF6000FF3700FF3700FF3700FF3700FF6000FF
6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFDD00FFFF00CF
FF0053FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF0060FF0037FF0000FF1BFF00F9FF0029FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00008A00FF3700FF3700FF3700FF3700FF3700FF3700FF3700FF3700FF
3700FF6000FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FFB300FFDD00FFDD00FF
FF00A6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF0060FF0037FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00008A00FF3700FF0D00FF0D00FF0D00FF0D00FF0D00FF0D00FF3700FF3700FF
3700FF3700FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FFB300FFB300FFDD00FF
FF00CFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00
B3FF008AFF008AFF0060FF0037FF0000FF1BFF0000FF0000FF0000FF0000FF00000D00FF
6000FFB300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000DD00FF0D00FF001BFF001BFF001BFF001BFF0D00FF0D00FF0D00FF0D00FF3700FF
3700FF3700FF3700FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FFB300FFB300FF
FF00F9FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF008AFF008AFF008AFF0060FF0037FF0000FF1B00FF4500FF4500FFEBFF0000
6000FFB300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000001BFF0045FF0045FF0045FF001BFF001BFF001BFF0D00FF0D00FF0D00FF3700FF
3700FF3700FF3700FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FFB300FFB300FF
DD00FFFF00F9FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00
B3FF00B3FF00B3FF00B3FF008AFF008AFF0060FF0060FF0037FF000DFF00FF0000FF00CF
DD00FFFF00A6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
001BFF006EFF006EFF0045FF0045FF0045FF001BFF001BFF0D00FF0D00FF0D00FF3700FF
3700FF3700FF3700FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FFB300FFB300FF
DD00FFFF00F9FF00A6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF0060FF0037FF0000FF45FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003700FF
0098FF0098FF0098FF006EFF0045FF0045FF001BFF001BFF0D00FF0D00FF0D00FF3700FF
3700FF3700FF3700FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FFB300FFB300FF
B300FFDD00FFFF00F9FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF0060FF0037FF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000C1FF
00C1FF00C1FF0098FF006EFF0045FF001BFF001BFF0D00FF0D00FF0D00FF3700FF3700FF
3700FF3700FF3700FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FFB300FFB300FF
B300FFDD00FFFF00F9FF00CFFF0029FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900
FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF0060FF0037FF00
00FF1BFF0000FF0000FF00000D00FF8A00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFEB00FFEB
00FFEB00EBFF0098FFB300FFFF0000FF00006000FF3700FF3700FF3700FF3700FF3700FF
3700FF3700FF6000FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FFB300FFB300FF
B300FFDD00FFFF00F9FF00F9FF00A6FF0053FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF5300FF5300
FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF0060FF00
60FF0037FF000DFF0000FF1BFF0000FF00F9FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC100FF9800FFC1
00FFC100C1FFFF0000FF0000FF0000FF0000FF00008A00FF6000FF6000FF6000FF6000FF
6000FF6000FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FF8A00FFB300FFB300FF
DD00FFDD00FFFF00F9FF00CFFF00A6FF007CFF0029FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF00
8AFF0060FF0060FF0037FF000DFF00FF0000FF0000FF0000FF0000B300FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF9800FF6E00FF6E00FF6E00FF98
00FFC1FF0000FF0000FF0000FF0000FF0000FF0000DD00FF8A00FF6000FF6000FF6000FF
6000FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FF
DD00FFDD00FFFF00F9FF00A6FF0029FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2900FF2900FF2900FF2900FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF0060FF0060FF0037FF000DFF0000FF4500FF1BFF0000FF0000FF0000
FF007CFF0000FF0000FF0000FF000000FF6E00FF4500FF4500FF4500FF4500FF4500FF6E
00FFC1FF0000FF0000FF0053FF0029FF0000FF0053B300FF8A00FF8A00FF8A00FF6000FF
6000FF6000FF6000FF8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FFDD00FF
DD00FFFF00F9FF007CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2900FF2900FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF008AFF008AFF008AFF008AFF0060FF0060FF0037FF0037FF0037FF000DFF000DFF00
0DFF0000FF1B00FF1B0DFF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF4500FF45
0D00FFFF0000FF0029FF007CFF00CFFF00F9DD00FFB300FFB300FF8A00FF8A00FF8A00FF
8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FFDD00FFDD00FF
FF00F9FF007CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF000DFF0000FF1B00FF45
FF0000FF0000FF0000FF00A6FF00CFFF00F9DD00FFDD00FFB300FFB300FF8A00FF8A00FF
8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FFB300FFDD00FFDD00FFFF00CF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF00
60FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF0000FF1B00FF45
FF0000FF0000FF0000FF0053FF00CFFF00F9DD00FFDD00FFB300FFB300FFB300FFB300FF
B300FFB300FFB300FFB300FFB300FFB300FFB300FFDD00FFDD00FFFF00F9FF00CFFF0053
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF5300FF5300FF5300FF5300FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
60FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF000DFF000DFF0000FF1B
00FFC1FF0000FF0000FF0000FF007CFF00CFFF00F9DD00FFDD00FFDD00FFB300FFB300FF
B300FFB300FFB300FFB300FFB300FFDD00FFDD00FFDD00FFFF00F9FF007CFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF7C00FF7C00FF7C00FF7C00FF5300FF5300FF5300FF5300FF5300FF5300FF5300FF5300
FF5300FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF000DFF0000FF1B
00C1FFFF0000FF0000FF0000FF0000FF0000FF00CFFF00F9FF00F9DD00FFDD00FFDD00FF
DD00FFDD00FFDD00FFDD00FFDD00FFDD00FFFF00F9FF00F9FF0053FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF000DFF00
00FF45FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007CFF00CFFF00F9FF00F9
FF00F9FF00F9FF00F9FF00F9FF00F9FF00CFFF00CFFF00A6FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FFA600FFA600FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0037FF0037FF000DFF00
00FF45FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053FF007C
FF0000FF0000FF0000FF0000FF0000FF0000FF0053FF0029FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FFCF00FFA600FFA600FFA600FFA600FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0037FF0037FF00
00FF1BFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
DDFF00FFF900FFCF00FFCF00FFA600FFA600FFA600FFA600FFA600FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0037FF0037FF00
0DFF0000FF4500EBFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000DDFF00FFF900FFCF00FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FF7C00FF7C00FF7C00FF7C00FF7C00FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0037FF00
0DFF0000FF1BFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000DDFF00FFCF00FFCF00FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF7C00FF7C00FF7C00FF7C00FF7C00
FF7C00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0037FF00
37FF000DFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000DDFF00FFF900FFCF00FFCF00FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF00
37FF000DFF0000FF45FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000045FFDD00FFB3FF00DDFF00FFF900FFCF00FFCF00FFCF00
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF00
37FF0037FF000DFF0000FF6EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00006000FFB3FF00DDFF00FFF900FFCF00
FFCF00FFCF00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF00
60FF0037FF0037FF0000FF1B00FF450098FF3700FFDD00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000037FF00DDFF00FFF900
FFCF00FFCF00FFCF00FFCF00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF00
60FF0037FF0037FF000DFF0000FF98FF007CDD00FFFF00F9FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003700FFDDFF00
FFF900FFF900FFCF00FFCF00FFCF00FFCF00FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0037FF000DFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000B300FFFF000060FF00
DDFF00FFF900FFF900FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0037FF0037FF0000FF1BFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000045FFFF002960FF00
B3FF00DDFF00FFF900FFF900FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF00
60FF0060FF0060FF0037FF000DFF0000FFC1FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
37FF00B3FF00DDFF00FFF900FFF900FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF00
60FF0060FF0060FF0037FF0037FF000DFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000B3FF00DDFF00FFF900FFF900FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFA600FFA600FFA600
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF00
8AFF0060FF0060FF0060FF0037FF000DFF0000FF1BFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
6000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000B3FF00DDFF00FFF900FFF900FFF900FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF00
8AFF0060FF0060FF0060FF0037FF0037FF000DFF0000FF1BFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
3700FF6000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00008AFF00DDFF00FFF900FFF900FFF900FFF900FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF00
8AFF008AFF0060FF0060FF0060FF0037FF0037FF000DFF0000FF1B00FF6EFF0000FF0000
FF0000FF0000FF0000FF0000FF0053FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0D00FF3700FF6000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8A00FF3700FFFF000060FF00B3FF00DDFF00FFF900FFF900FFF900FFF900FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF00
8AFF008AFF0060FF0060FF0060FF0060FF0037FF0037FF000DFF0000FF1B00FF4500FF6E
00FFC100C1FF0045FF0D00FF3700FF8A00FFDD00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0D00FF0D00FF3700FFFF00F9FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000098FF00FF458AFF00B3FF00DDFF00DDFF00FFF900FFF900FFF900FFF900FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF0060FF0060FF0060FF0037FF0037FF0037FF000DFF0000FF1B00FF45
006EFFFF0000FF00003700FF6000FF8A00FFB300FFFF00A6FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0D00FF0D00FF3700FF8A00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000DFF00B3FF00DDFF00DDFF00FFF900FFF900FFF900FFF900FFF900
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF00
8AFF008AFF008AFF0060FF0060FF0060FF0060FF0037FF0037FF000DFF0000FF1B00FFC1
FF0000FF00A6FF00F98A00FF8A00FF8A00FFB300FFFF00F9FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0D00FF0D00FF3700FF6000FFB300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000060FF00B3FF00DDFF00DDFF00FFF900FFF900FFF900FFF900
FFF900FFF900FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF00
8AFF008AFF008AFF0060FF0060FF0060FF0060FF0037FF0037FF000DFF0000FF1BFF0000
FF0000FF00A6FF00F9DD00FFB300FFDD00FFFF00F9FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0D00FF0D00FF3700FF6000FF8A00FFFF00A6FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000045FF8AFF00B3FF00DDFF00DDFF00FFF900FFF900FFF900
FFF900FFF900FFF900FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF0060FF0060FF0060FF0037FF0037FF000DFF0000FF1BFF0000
FF0000FF0000FF00A6FF00CFFF00F9FF00CFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0D00FF0D00FF3700FF6000FF8A00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00008AFF00B3FF00DDFF00DDFF00FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0037FF000DFF0000FF1BFF00F9
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0D00FF3700FF3700FF6000FF8A00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000B300FFFF0000FF000060FF00B3FF00DDFF00DDFF00DDFF00FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF00
8AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0037FF0037FF0000FF1BFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0D00FF3700FF3700FF6000FF8A00FFFF00F9FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000001BFFFF00CFFF00008AFF00B3FF00DDFF00DDFF00DDFF00DDFF00FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0037FF0037FF000DFF0000FF6E
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
3700FF3700FF6000FF6000FF8A00FFDD00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF9837FF008AFF00B3FF00B3FF00DDFF00DDFF00DDFF00FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0037FF0037FF000DFF0000FF45
FF00A6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
3700FF3700FF6000FF6000FF8A00FFFF00CFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000DFF008AFF00B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00
FFCF00FFCF00FFCF00FFCF00FFCF00FFCF00FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0037FF000DFF0000FF1B
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
6000FF6000FF6000FF8A00FFB300FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00008AFF00B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFCF00FFCF00FFCF00FFCF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0037FF0037FF000DFF00
00FF98FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
6000FF6000FF8A00FF8A00FFDD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF6E60FF00B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00
DDFF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0037FF000DFF00
00FF1B00EBFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
6000FF8A00FF8A00FFB300FFDD00FFFF007CFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00008A00FF8AFF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00
DDFF00DDFF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0037FF0037FF00
0DFF0000FF1B00FF4500FF9800EBFF0D00FF8A00FFDD00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8A00FF8A00FFB300FFDD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00003700FFB300FFFF00000DFF008AFF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00
DDFF00DDFF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0037FF00
37FF000DFF0000FF1B00FF6EFF0000FF00F9DD00FFFF00F9FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
B300FFB300FFDD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000098FFFF00000DFF0060FF008AFF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0037FF00
37FF000DFF000DFF0000FF6EFF0000FF0053FF00A6FF0053FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
B300FFDD00FFFF00F9FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000DFF0060FF008AFF008AFF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF00
37FF0037FF000DFF0000FF45FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
DD00FFFF00CFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000DFF0060FF008AFF008AFF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF00
37FF0037FF000DFF0000FF1BFF0053FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000037FF0060FF008AFF008AFF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF00
37FF0037FF0037FF000DFF0000FF6EFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007CFF0000
FF000000FF4560FF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF00
60FF0037FF0037FF000DFF0000FF1B00FF98FF0000FF0000FF0000FF00CFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003700FFB300FFFF0000
FF000037FF0060FF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF00
60FF0037FF0037FF0037FF000DFF0000FF1B00FF4500FF98FF0000DD00FFFF00CFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF6E00FF45
37FF0060FF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF00
60FF0060FF0037FF0037FF0037FF000DFF0000FF1B00FF45FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000DFF0037FF00
60FF0060FF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF00
60FF0060FF0037FF0037FF0037FF000DFF000DFF0000FF1B00C1FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF1B37FF0060FF00
60FF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF00
60FF0060FF0060FF0037FF0037FF0037FF000DFF000DFF0000FF1BFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00008A00FFFF00A6FF0000FF000000FF1B37FF0060FF0060FF00
8AFF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF00
60FF0060FF0060FF0060FF0037FF0037FF0037FF000DFF000DFF0000FF1B00FF6E00FFC1
FF0029FF00A6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000DFF0037FF0060FF0060FF0060FF00
8AFF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF00
60FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF000DFF000DFF0000FF1B00FF45
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF4500FF1B0DFF0037FF0037FF0060FF0060FF0060FF008AFF00
8AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF000DFF000DFF000DFF0000FF1B
00FF45FF0000FF00000D00FFFF00A6FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF6E00FF1B0DFF0037FF0037FF0037FF0060FF0060FF0060FF008AFF008AFF00
8AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF00
00FF1B00FF1B00FF4500FF98FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF007CFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007CFF007C
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0DFF000DFF0037FF0037FF0037FF0060FF0060FF0060FF0060FF008AFF008AFF008AFF00
8AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
FFF900FFF900FFF900FFF900FFF900DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF000DFF000DFF00
0DFF0000FF1B00FF1B00FF4500FF6E00FF9800EBFFFF0000FF0000FF0029FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000B300FFB300FFFF00F9FF0000DD00FF8A00FF
8A00FFB300FFDD00FFFF00F9FF0000FF0000FF0000FF0000FF0053FF00F9FF00F9FF00F9
FF0053FF0000FF0000FF0000FF0000FF0000FF0000FF0000
37FF0037FF0037FF0060FF0060FF0060FF0060FF0060FF008AFF008AFF008AFF008AFF00
8AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900FFF900
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF00
0DFF000DFF0000FF1B00FF1B00FF4500FF4500FF6E00FF9800FFC100C1FFFF0000FF0000
FF0000FF0053FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0D00FF0D00FF0D00FF0D00FF0D00FF3700FF3700FF3700FF3700FF3700FF6000FF6000FF
6000FF6000FF8A00FF8A00FF8A00FFB300FFB300FFB300FFB300FFDD00FFDD00FFDD00FF
FF00F9FF00A6FF0000FF0000FF0000FF0000FF0000FF0000
37FF0037FF0060FF0060FF0060FF0060FF0060FF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF00
0DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF4500FF4500FF6E00FF6E00FF9800FFC1
00FFC100FFEB00EBFF00EBFF00C1FF00C1FF00C1FF0098FF0098FF0098FF006EFF006EFF
0045FF0045FF0045FF001BFF001BFF001BFF0D00FF0D00FF0D00FF0D00FF3700FF3700FF
3700FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FF
DD00FFDD00FFFF00CFFF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF00
0DFF000DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF4500FF4500FF4500FF6E00FF6E
00FF9800FF9800FFC100FFC100FFEB00FFEB00EBFF00EBFF00C1FF00C1FF0098FF0098FF
006EFF006EFF0045FF0045FF0045FF001BFF001BFF001BFF0D00FF0D00FF0D00FF3700FF
3700FF3700FF3700FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FF8A00FFB300FF
B300FFDD00FFDD00FFFF00CFFF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF00
37FF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF4500FF4500FF4500FF6E
00FF6E00FF9800FF9800FFC100FFC100FFEB00FFEB00EBFF00EBFF00C1FF00C1FF0098FF
0098FF006EFF006EFF0045FF0045FF0045FF001BFF001BFF001BFF0D00FF0D00FF0D00FF
3700FF3700FF3700FF3700FF6000FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FF
B300FFB300FFB300FFDD00FFFF00F9FF007CFF0000FF0000
60FF0060FF0060FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF00
37FF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF1B00FF4500FF4500FF6E
00FF6E00FF6E00FF9800FF9800FFC100FFC100FFEB00EBFF00EBFF00C1FF00C1FF0098FF
0098FF006EFF006EFF0045FF0045FF0045FF001BFF001BFF001BFF0D00FF0D00FF0D00FF
0D00FF3700FF3700FF3700FF3700FF6000FF6000FF6000FF6000FF6000FF8A00FF8A00FF
8A00FFB300FFB300FFB300FFDD00FFFF00F9FF00CFFF0000
60FF0060FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF00
37FF000DFF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF4500FF4500FF45
00FF6E00FF6E00FF9800FF9800FFC100FFEB00FFEB00EBFF00C1FF00C1FF0098FF0098FF
006EFF006EFF006EFF0045FF0045FF0045FF001BFF001BFF001BFF0D00FF0D00FF0D00FF
0D00FF3700FF3700FF3700FF3700FF3700FF6000FF6000FF6000FF6000FF6000FF8A00FF
8A00FF8A00FFB300FFB300FFB300FFDD00FFFF00F9FF0000
60FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF00
37FF000DFF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF4500FF4500FF45
00FF6E00FF6E00FF9800FFC100FFC100FFEB00EBFF00C1FF0098FF0098FF006EFF006EFF
006EFF0045FF0045FF0045FF0045FF001BFF001BFF001BFF001BFF0D00FF0D00FF0D00FF
0D00FF0D00FF3700FF3700FF3700FF3700FF6000FF6000FF6000FF6000FF6000FF8A00FF
8A00FF8A00FF8A00FFB300FFB300FFDD00FFDD00FFFF00CF
60FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF00
37FF0037FF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF4500FF4500FF6E
00FF6E00FF9800FFC100FFEB00EBFFFF0000FF0000FF0000FF0000FF0000FF00006000FF
001BFF001BFF001BFF001BFF001BFF001BFF001BFF001BFF0D00FF0D00FF0D00FF0D00FF
0D00FF3700FF3700FF3700FF3700FF3700FF3700FF6000FF6000FF6000FF6000FF6000FF
8A00FF8A00FF8A00FF8A00FFB300FFB300FFDD00FFFF00F9
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF00
37FF000DFF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF4500FF4500FF6E
00FF9800FFC1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000DD00FF0D00FF0D00FF001BFF0D00FF0D00FF0D00FF0D00FF0D00FF0D00FF0D00FF
0D00FF3700FF3700FF3700FF3700FF3700FF3700FF6000FF6000FF6000FF6000FF6000FF
8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FFDD00FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF00
37FF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF4500FF4500FF6E00FF98
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000B300FF3700FF0D00FF0D00FF0D00FF0D00FF0D00FF0D00FF0D00FF0D00FF
3700FF3700FF3700FF3700FF3700FF3700FF3700FF6000FF6000FF6000FF6000FF6000FF
8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFDD00FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF00
37FF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF4500FF4500FF6E00FFC1FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00006000FF3700FF3700FF0D00FF0D00FF0D00FF0D00FF3700FF3700FF
3700FF3700FF3700FF3700FF3700FF3700FF6000FF6000FF6000FF6000FF6000FF6000FF
8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF00
37FF000DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF4500FF6EFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0053FF0053FF0053FF0029FF0000FF0000FF0000FF0000
FF0000FF0000FF00008A00FF6000FF3700FF3700FF3700FF3700FF3700FF3700FF3700FF
3700FF3700FF3700FF3700FF3700FF3700FF6000FF6000FF6000FF6000FF6000FF6000FF
8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF00
0DFF000DFF000DFF000DFF0000FF1B00FF1B00FF4500FF98FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0053FF007CFF007CFF007CFF0053FF0000FF0000FF0000FF0000
FF0000FF0000FF00008A00FF6000FF6000FF3700FF3700FF3700FF3700FF3700FF3700FF
3700FF3700FF3700FF3700FF3700FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF
8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF00
0DFF000DFF000DFF0000FF1B00FF1B00FF4500FF6EFF00CFFF0000FF0000FF0000FF0000
FF0000FF0000FF0053FF007CFF00A6FF00A6FF00A6FF00A6FF0029FF0000FF0000FF0000
FF0000FF0000DD00FF8A00FF6000FF6000FF6000FF3700FF3700FF3700FF3700FF3700FF
3700FF3700FF3700FF3700FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF
8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF00
0DFF000DFF0000FF1B00FF1B00FF4500FF6E00EBFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0029FF007CFF00A6FF00A6FF00CFFF00CFFF00CFFF00CFFF00A6FF0053FF007C
FF00CFDD00FFB300FF8A00FF6000FF6000FF6000FF6000FF6000FF3700FF3700FF3700FF
3700FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF8A00FF
8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF00
0DFF000DFF0000FF1B00FF4500FF98FF0000B300FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0053FF00A6FF00A6FF00CFFF00CFFF00CFFF00F9FF00F9FF00F9FF00F9DD00FF
DD00FFB300FF8A00FF8A00FF8A00FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF
6000FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF8A00FF
8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF00
0DFF0000FF1B00FF1B00FF6EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF007CFF00A6FF00CFFF00CFFF00F9FF00F9FF00F9FF00F9DD00FFDD00FFDD00FF
B300FFB300FF8A00FF8A00FF8A00FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF
6000FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF8A00FF8A00FF
8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF00
00FF1B00FF1B00FF45FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF007CFF00A6FF00CFFF00CFFF00F9FF00F9DD00FFDD00FFDD00FFDD00FFB300FF
B300FFB300FF8A00FF8A00FF8A00FF8A00FF6000FF6000FF6000FF6000FF6000FF6000FF
6000FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FF
8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FFB300FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF00
00FF1B00FF4500FF6EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF007CFF00CFFF00CFFF00F9FF00F9FF00F9DD00FFDD00FFDD00FFB300FFB300FF
B300FFB300FF8A00FF8A00FF8A00FF8A00FF8A00FF6000FF6000FF6000FF6000FF6000FF
6000FF6000FF6000FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FF8A00FF8A00FF
8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FFB300FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF0000FF1B
00FF4500FFEBFF00000045FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00A6FF00CFFF00CFFF00F9FF00F9DD00FFDD00FFDD00FFDD00FFB300FFB300FF
B300FFB300FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF6000FF6000FF6000FF
6000FF6000FF6000FF6000FF6000FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF
8A00FF8A00FF8A00FFB300FFB300FFB300FFB300FFB300FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF0000FF1B00FF45
FF0000FF0000FF00A6DD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0029FF00A6FF00CFFF00CFFF00F9FF00F9DD00FFDD00FFDD00FFDD00FFB300FFB300FF
B300FFB300FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF
8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF
8A00FF8A00FFB300FFB300FFB300FFB300FFB300FFB300FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF0000FF1B00FF1B00FF6E
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF007CFF00A6FF00CFFF00F9FF00F9DD00FFDD00FFDD00FFDD00FFB300FFB300FF
B300FFB300FFB300FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF
8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF
8A00FFB300FFB300FFB300FFB300FFB300FFB300FFDD00FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00
DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00DDFF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF0000FF1B00FF45FF0000
FF0053FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00A6FF00CFFF00F9FF00F9FF00F9DD00FFDD00FFDD00FFB300FFB300FF
B300FFB300FFB300FFB300FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF
8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF
B300FFB300FFB300FFB300FFB300FFB300FFDD00FFDD00FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF0000FF1B00FF1B00FF6EFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00A6FF00CFFF00F9FF00F9FF00F9DD00FFDD00FFDD00FFDD00FFB300FF
B300FFB300FFB300FFB300FFB300FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF
8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FFB300FF
B300FFB300FFB300FFB300FFB300FFB300FFDD00FFDD00FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF0000FF1B00FF4500FF98FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF007CFF00CFFF00CFFF00F9FF00F9DD00FFDD00FFDD00FFDD00FFB300FF
B300FFB300FFB300FFB300FFB300FFB300FFB300FF8A00FF8A00FF8A00FF8A00FF8A00FF
8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FFB300FF
B300FFB300FFB300FFB300FFDD00FFDD00FFDD00FFDD00FF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
37FF0037FF0037FF0037FF000DFF000DFF000DFF0000FF1B00FF1B00FF4500FF98FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF007CFF00A6FF00CFFF00CFFF00F9FF00F9DD00FFDD00FFDD00FFDD00FF
B300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FF8A00FF8A00FF
8A00FF8A00FF8A00FF8A00FF8A00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FF
B300FFB300FFB300FFDD00FFDD00FFDD00FFDD00FFFF00F9
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF00
37FF0037FF0037FF0037FF000DFF000DFF0000FF1B00FF4500FF6E00FF9800FFEB0045FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF007CFF00A6FF00CFFF00F9FF00F9FF00F9DD00FFDD00FFDD00FF
DD00FFDD00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FF
B300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FF
B300FFB300FFDD00FFDD00FFDD00FFDD00FFFF00F9FF00F9
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF00
37FF0037FF0037FF000DFF000DFF0000FF1B00FF4500FFC1FF0000FF0029FF00003700FF
FF00F9FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00A6FF00CFFF00F9FF00F9FF00F9DD00FFDD00FF
DD00FFDD00FFDD00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FF
B300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FF
DD00FFDD00FFDD00FFDD00FFDD00FFFF00F9FF00F9FF00CF
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF00
37FF0037FF000DFF000DFF0000FF1B00FF4500FFC1FF0000FF0000FF00A6FF00F9B300FF
DD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00A6FF00CFFF00F9FF00F9FF00F9DD00FF
DD00FFDD00FFDD00FFDD00FFDD00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FF
B300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFDD00FFDD00FF
DD00FFDD00FFDD00FFFF00F9FF00F9FF00F9FF00CFFF00A6
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF00
37FF0037FF000DFF000DFF0000FF1B00FFC1FF0000FF0000FF0000FF0000FF00CFFF00CF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF007CFF00A6FF00CFFF00F9FF00F9FF00F9
DD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFB300FFB300FFB300FFB300FF
B300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFDD00FFDD00FFDD00FFDD00FF
DD00FFDD00FFFF00F9FF00F9FF00CFFF00A6FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF00
37FF000DFF000DFF0000FF1B00FF45FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053FF00A6FF00CFFF00F9FF00F9
FF00F9FF00F9DD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FF
DD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FF
FF00F9FF00F9FF00F9FF00CFFF00A6FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF00
37FF000DFF000DFF0000FF1B00FF4500FFEBFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007CFF00CFFF00CFFF00CF
FF00F9FF00F9FF00F9FF00F9DD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FF
DD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFFF00F9
FF00F9FF00F9FF00CFFF00A6FF0029FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF00
0DFF000DFF0000FF1B00FF45FF0000FF007CFF00CFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0029FF00A6FF00A6FF00CF
FF00CFFF00CFFF00F9FF00F9FF00F9FF00F9FF00F9FF00F9DD00FFDD00FFDD00FFDD00FF
DD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFDD00FFFF00F9FF00F9FF00F9
FF00CFFF00CFFF0053FF0000FF0000FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF00
0DFF000DFF0000FF1B00FF6EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053FF007CFF00A6
FF00A6FF00A6FF00A6FF00CFFF00CFFF00CFFF00F9FF00F9FF00F9FF00F9FF00F9FF00F9
FF00F9FF00F9DD00FFDD00FFFF00F9FF00F9FF00F9FF00F9FF00F9FF00F9FF00F9FF00CF
FF00A6FF0053FF0000FF0000FF0000FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF00
0DFF000DFF0000FF1B00FF6E8A00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0029FF0053FF00A6FF00CFFF00CFFF00CFFF00CFFF00F9FF00F9
FF00F9FF00F9FF00F9FF00F9FF00F9FF00F9FF00F9FF00F9FF00F9FF00CFFF00CFFF00A6
FF0053FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF00
0DFF0000FF1B00FF45FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007CFF00A6FF00A6FF00A6FF00CF
FF00CFFF00CFFF00CFFF00F9FF00F9FF00F9FF00CFFF00CFFF00CFFF00CFFF00A6FF007C
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF00
0DFF0000FF1B00FF4500FFC1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0029
FF007CFF00A6FF00A6FF00CFFF00CFFF00CFFF00CFFF00CFFF00CFFF00A6FF007CFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF00
00FF1B00FF1B00FF4500FFC1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF007CFF00A6FF00A6FF00A6FF00A6FF00A6FF007CFF0029FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF000DFF00
00FF1B00FF1B00FF4500FF98FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0053FF007CFF007CFF007CFF0053FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF000DFF0000FF1B
00FF1B00FF4500FF6E00FF9800C1FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0053FF0053FF0029FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF000DFF0000FF1B00FF1B
00FF4500FF6E00FF6E00FF9800FFEBFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
37FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF0000FF1B00FF1B00FF4500FF6E
00FF9800EBFF006EFF00C1FF00EBFF0098FF0D00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF00
37FF0037FF0037FF0037FF000DFF000DFF000DFF0000FF1B00FF1B00FF6EFF0000FF0000
FF0000FF0000FF0000FF0000FF0000001BFF001BFF6000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF00
37FF0037FF0037FF000DFF000DFF000DFF0000FF1B00FF4500FFC1FF0000FF0000FF0000
FF0000FF007CFF00A6FF0000FF00006000FF3700FF6000FFDD00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF00
37FF0037FF0037FF000DFF000DFF0000FF1B00FF45FF0000FF0000FF0000FF0000FF0000
FF0000FF00A6FF00F9FF00F9B300FF8A00FF6000FF8A00FFB300FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF00
37FF0037FF000DFF000DFF0000FF1B00FF4500FF6EFF0000FF0000FF0000FF0000FF0000
FF0000FF00CFFF00F9DD00FFB300FFB300FF8A00FFB300FFDD00FFFF00CFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF00
37FF000DFF000DFF0000FF1B00FF45FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00A6FF00F9DD00FFDD00FFB300FFB300FFDD00FFFF00F9FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF00
0DFF000DFF0000FF1B00FF45FF0000FF0000FF007CFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00CFFF00F9FF00F9FF00F9FF00F9FF00F9FF007CFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF000DFF00
0DFF000DFF0000FF1B00FF6EFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF007CFF00A6FF00A6FF00A6FF00A6FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF00
0DFF0000FF1B00FF45FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF00
0DFF0000FF1B00FF45FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF00
00FF1B00FF1B00FF4500FFC1FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF00
00FF1B00FF4500FF6E00FF98FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF0000FF1B
00FF4500FF6EFF0000FF00000D00FF3700FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF0000FF1B00FF45
00FF98FF0000FF0000FF00A6FF00CF8A00FFDD00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
37FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF0000FF1B00FF4500FF98
FF0000FF0000FF0000FF00A6FF00F9DD00FFFF00F9FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF0000FF1B00FF1B00FF6EFF0000
FF0000FF0000FF0000FF0000FF00A6FF00A6FF0053FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF0000FF1B00FF45FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF000DFF000DFF000DFF0000FF1B00FF1B00FF45FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF000DFF000DFF000DFF0000FF1B00FF1B00FF6EFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF000DFF000DFF000DFF0000FF1B00FF1B00FF4500FF6E00FFC1001BFF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF45FF0000FF0000FF00CF
DD00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF000DFF000DFF000DFF0000FF1B00FF1B00FF4500FF98FF0000FF0000FF00A6
FF00A6FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF008AFF00
8AFF008AFF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF45FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
0DFF000DFF000DFF000DFF000DFF0000FF1B00FF4500FF6EFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF00
0DFF000DFF000DFF000DFF0000FF1B00FF1B00FF4500FF6E00C1FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF00
0DFF000DFF000DFF000DFF0000FF1B00FF1B00FF4500FF6EFF0000FF0000FF00A6FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
37FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF00
0DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF4500FF98FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
37FF0037FF0037FF0037FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF00
0DFF000DFF000DFF0000FF1B00FF1B00FF4500FF4500FFEBFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
37FF0037FF0037FF0037FF0037FF0037FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF000DFF000DFF00
0DFF000DFF0000FF1B00FF1B00FF1B00FF4500FF6E00FF98FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF000DFF000DFF000DFF00
0DFF000DFF0000FF1B00FF1B00FF1B00FF4500FF6E00FF98FF0000FF00A6FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF00
0DFF0000FF1B00FF1B00FF1B00FF1B00FF4500FF6E00FF98FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF00
00FF1B00FF1B00FF1B00FF1B00FF4500FF4500FF6E00FF98FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
0DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF0000FF1B
00FF1B00FF1B00FF1B00FF1B00FF4500FF4500FF6E00FF9800C1FFFF0053FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF00
0DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF0000FF1B00FF1B
00FF1B00FF1B00FF1B00FF4500FF4500FF4500FF6E00FF9800C1FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF0060FF00
60FF0060FF0060FF0060FF0060FF0060FF0060FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF000DFF000DFF000DFF00
0DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF1B
00FF1B00FF1B00FF1B00FF4500FF4500FF4500FF6E00FF9800FFC13700FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF00
0DFF000DFF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF1B00FF1B00FF1B
00FF1B00FF4500FF4500FF4500FF4500FF6E00FF6E00FF9800FFC18A00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0DFF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF00
0DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF00
0DFF000DFF0000FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B
00FF4500FF4500FF4500FF4500FF4500FF6E00FF6E00FF9800FFC100FFEBFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0DFF000DFF000DFF000DFF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF00
0DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF0000FF1B00FF1B00FF1B
00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF4500FF45
00FF4500FF4500FF4500FF4500FF6E00FF6E00FF6E00FF9800FFC100FFEBFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0DFF000DFF000DFF000DFF000DFF000DFF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF000DFF00
0DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF00
0DFF000DFF000DFF000DFF0000FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B
00FF1B00FF1B00FF1B00FF1B00FF4500FF4500FF4500FF4500FF4500FF4500FF4500FF45
00FF4500FF4500FF6E00FF6E00FF6E00FF6E00FF9800FF9800FFC100FFC100EBFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF0037FF00
37FF0037FF0037FF0037FF0037FF000DFF000DFF000DFF000DFF000DFF000DFF000DFF00
0DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF000DFF0000FF1B00FF1B
00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF1B00FF4500FF4500FF4500FF45
00FF4500FF4500FF4500FF4500FF4500FF4500FF4500FF4500FF4500FF4500FF6E00FF6E
00FF6E00FF6E00FF6E00FF6E00FF6E00FF9800FF9800FF9800FFC100FFC100FFEB00C1FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00703oool2000000@0oooo0P0000040?ooo`800000
;P3oool2000000@0oooo0P0000050?ooo`<00000;@3oool2000000@0oooo0P0000040?ooo`800000
;`3oool2000000@0oooo0P0000030?ooo`@00000;P3oool2000000@0oooo0P0000030?ooo`D00000
0@3oool001/0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000/0?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000002d0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`0^0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00@3oool001/0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo0000
00P0oooo1@00000/0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0;03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo02d0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`010?ooo`005@3oool400000080oooo00@000000?ooo`3oool00000
2@3oool2000002L0oooo100000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000009`3oool400000080oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0U
0?ooo`@000000P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo02H0oooo1000
00020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00@3oool001/0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`000000;@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000002d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000]0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool00@3oool001`0oooo0P00000:0?ooo`<00000
;@3oool2000000/0oooo0P00000^0?ooo`8000002P3oool2000002l0oooo0P00000:0?ooo`800000
;`3oool2000000X0oooo0P0000030?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3oooom000000P0oooo000K0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000203oool001/0oooo00<000000?ooo`3oool0n@3oool00`000000oooo0?ooo`06
0?ooo`00203oool2000000@0oooo0P0000030?ooo`D000000`3oool00`000000oooo0?ooo`3i0?oo
o`030000003oool0oooo00H0oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3i0?ooo`030000003oool0oooo00H0oooo00070?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool200000?T0oooo0P0000080?oo
o`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?oooo<0o`00103oool00`000000oooo0?ooo`060?oo
o`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3ooooc0?l000@0oooo00<000000?ooo`3oool01P3oool000P0oooo0P00000:0?ooo`80
00001@3oool00`000000oooo0?ooo`020?oooo<0o`00103oool00`000000oooo0?ooo`060?ooo`00
6`3oool00`000000oooo0?ooo`020?oooo<0o`00103oool00`000000oooo0?ooo`060?ooo`006`3o
ool00`000000oooo0?ooo`020?oooo<0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool0
0`000000oooo0?ooo`020?oooo<0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`00
0000oooo0?ooo`020?oooo<0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000
oooo0?ooo`020?oooo<0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool2000000<0oooo
l`3o00030?ooo`800000203oool001/0oooo00<000000?ooo`3oool00P3ooooc0?l000@0oooo00<0
00000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3ooooc0?l000@0oooo00<00000
0?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3ooooc0?l000@0oooo00<000000?oo
o`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3ooooc0?l000@0oooo00<000000?ooo`3o
ool01P3oool001/0oooo00<000000?ooo`3oool00P3ooooc0?l000@0oooo00<000000?ooo`3oool0
1P3oool001/0oooo00<000000?ooo`3oool00P3ooooc0?l000@0oooo00<000000?ooo`3oool01P3o
ool001/0oooo00<000000?ooo`3oool00P3ooooc0?l000@0oooo00<000000?ooo`3oool01P3oool0
01/0oooo00<000000?ooo`3oool00P3ooooc0?l000@0oooo00<000000?ooo`3oool01P3oool001/0
oooo00<000000?ooo`3oool00P3ooooc0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo
0P0000030?oooo<0o`000`3oool2000000P0oooo000K0?ooo`030000003oool0oooo0080ooool`3o
00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080ooool`3o0004
0?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080ooool`3o00040?oo
o`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080ooool`3o00040?ooo`03
0000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080ooool`3o00040?ooo`030000
003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080ooool`3o00040?ooo`030000003o
ool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080ooool`3o00040?ooo`030000003oool0
oooo00H0oooo000K0?ooo`030000003oool0oooo0080ooool`3o00040?ooo`030000003oool0oooo
00H0oooo000K0?ooo`030000003oool0oooo0080ooool`3o00040?ooo`030000003oool0oooo00H0
oooo000K0?ooo`8000000`3ooooc0?l000<0oooo0P0000080?ooo`006`3oool00`000000oooo0?oo
o`020?oooo<0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`02
0?oooo<0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?oo
oo<0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?oooo<0
o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?oooo<0o`00
103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?oooo<0o`00103o
ool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`80o`000P006oo_
0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3oool20031
o`8009So00<004Go0?l0003o0000k03o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`80
00000`3oool20031o`8009So00<004Go0?l0003o0000k03o00030?ooo`800000203oool001/0oooo
00<000000?ooo`3oool00P3oool01@00oiP00>_o002Ho`00V?l006ko0>h0o`00103oool00`000000
oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`050?l000006ol004Go0015o`00
6ol02P3o000010006ol006ko0015o`1P0?oP0?l000@0oooo00<000000?ooo`3oool01P3oool001/0
oooo00<000000?ooo`3oool00P3oool00`3on@00o`000?l0000<0?l00004003[o`00`Ol006ko0015
o`80H03ogP3o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080
oooo00<0ojH00?o?003o00002P3o0002003o`@040031o`00K_l006ko000Ko`d0o`0000<0=`3o00d0
o`3o0000d03o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080
oooo00<0ojH00?o?003o00002P3o0002003o`@040031o`00K_l006ko000Ko`d0o`0000<0=`3o00d0
o`3o0000d03o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080
oooo0P3oO0020?nV00030?o?003Mo`00RP3o00H0o`000P2:o`000`3o0000=`3o00d0o`0<0?l000<0
06ko00<004Go00d0o`3o0000c`3o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000
003oool0oooo0080oooo0P3oD`030?ml0080ojH00P3on@020=go00@0ooT000<0gOl00?l0003o0000
2`3o00001`00`Ol00>_o003[o`00V?l004Go000Ko`1P0?l03`3o00000`2:0?l0o`000?l0002m0?l0
00@0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000050?ooo`030000003oool0oooo0080
oooo1@3oD`040?ml00H0ojH000<0oll00?oi002:o`000`3o00000`1P0?l0o`000?l000050?l00006
003o6`3o05<0o`1C00d0o`006ol03@3o3P3o0002000Ko`0300d0o`0g0?l0o`000;d0o`00103oool0
0`000000oooo0?ooo`060?ooo`004`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0080oooo00<0obT00?mC003oD`001P3oD`060?ml0080ojH000@0oll00?oi003on@00ooT01`3o
0000101Po`00R_l00?l0003o000208X0o`d0o`000P00AOl01000K_l004Go000Ko`0=0?l203L0o`03
0=d0o`3o0000o`000100o`0000<0o`1l0?l0003o0000YP3o00040?ooo`030000003oool0oooo00H0
oooo000C0?ooo`040000003oool0oooo000000@0oooo0P0000030?ooo`@0obT01`3oD`060?ml00@0
ojH000<0oll00?oi003on@000P2co`020=go00040?oi003Mo`00/ol00;?o00l0o`000P00jol01000
V?l004Go000Ko`0=0?l203L0oa80o`0000@0/`3o0600o`3M0?l0g@3oYP3o00030?ooo`800000203o
ool001<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`@0obT01`3o
D`060?ml00@0ojH000<0oll00?oi003on@000P2co`020=go00040?oi003Mo`00/ol00;?o00l0o`00
0P00jol01000V?l004Go000Ko`0=0?l203L0oa80o`0000@0/`3o0600o`3M0?l0g@3oYP3o00040?oo
o`030000003oool0oooo00H0oooo000C0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00P3oool60?lY00L0oe<01P3oO0050?nV00H0oll00P3on@000`3Mo`00R_l00?l000030?l0
000300d0o`3o0000o`0000H0o`000P00ofh0103o0000=`3o00d0o`0g0?l208X0o`l0o`000P0g0?l2
00d0o`<0=`3o00<0RP3o0?l0003o0000X`3o00040?ooo`030000003oool0oooo00H0oooo000D0?oo
o`8000001@3oool00`000000oooo0?ooo`020?ooo`L0obT02@3oD`070?ml00H0ojH0103oc`000`3o
n@00gOl00;?o000208[o00P0o`0000L0H?l003Oo000go`00o`0008X0o`1P0?l0g@3o0100o`0000D0
=`3o0015o`00AOl004Go000Ko`0300d0o`0303L0o`2:0?l0o`000:<0o`00103oool00`000000oooo
0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`X0obT0203oD`080?ml00L0ojH00P3o
c`030?oi00030=go002:o`00H?l00080o`0000<0o`3i08[o002co`000`2co`000`00oa/0o`000?l0
000A0?l000<006ko00<004Go000Ko`006ol00P0=0?l00`0g0?l0H03o0?l0n@0K0?l000030?l0c`3o
0000o`0008D0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`02
0?ooo`030?l0003o:@00obT000P0obT02P3oD`070?ml00L0ojH0103oc`070?oi00<0gOl000<0/ol0
03Oo003o00004@3o00000`00jol009So002Ho`02000Ko`<03@3o00<0=`3o08X0o`3o00006P3o0000
0`3M0?l0/`3o0;<0o`260?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?oo
o`3oool00P3oool20?l000X0obT02P3oD`080?ml00P0ojH01P3oc`060?oi00030=go002co`00o`00
00<0o`0000<009So00d0o`3o00002@3o0002003oV0<0o`00100g0?l00`1P0?l0g@3o0?l0000F0?l0
00030;<0o`1P0?l0H03o00<0H03o0`2:0?l00`3o0?T0o`000?l000210?l000@0oooo00<000000?oo
o`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3oool20?l000X0obT02P3oD`080?ml00P0
ojH01P3oc`060?oi00030=go002co`00o`0000<0o`0000<009So00d0o`3o00002@3o0002003oV0<0
o`00100g0?l00`1P0?l0g@3o0?l0000F0?l000030;<0o`1P0?l0H03o00<0H03o0`2:0?l00`3o0?T0
o`000?l000210?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool0
0P3oool40?l000T0obT02`3oD`090?ml00L0ojH01`3oc`040?oi0080gOl00P2co`000`2:o`00=ol0
0?l0000:0?l0000500go0000oa/0o`000?l0003M0?l0102:0?l00`3o0?T0o`000?l0000E0?l00003
0600o`0g0?l0=`3o00@0=`3o0`1P0?l00`2:0?l0o`3?0?l000210?l000@0oooo00<000000?ooo`3o
ool01P3oool001/0oooo00<000000?ooo`3oool00P3oool40?l000/0obT02`3oD`090?ml00T0ojH0
1P3oc`050?oi0080gOl000@0R_l0003o`@00ol403Ol01@3o0000100go`00H?l0063o001Po`02003o
`A`0o`0000<0H03o00d0o`006ol0100=0?l203L0o`<0H03o00<0RP3o0?l0c`3o0000P03o00040?oo
o`030000003oool0oooo00H0oooo000K0?ooo`8000000`3oool50?l000/0obT02`3oD`090?ml00X0
ojH01P3oc`050?oi00@0gOl0202co`000`2:o`00H?l0063o000L0?l00003000Ko`00AOl004Go00<0
01_o0P0=0?l303L0o`040600o`2:0?l0/`3o0?l0n@80o`1lOP3o00030?ooo`800000203oool001/0
oooo00<000000?ooo`3oool00P3oool50?l000`0obT02`3oD`0;0?ml00P0ojH0203oc`060?oi00L0
gOl0102co`000`2:o`00o`000?l0000G0?l000803@3o0P00K_l01000AOl001_o000Ko`006ol200d0
o`<0=`3o00@0H03o08X0o`2c0?l0o`3iP03o00040?ooo`030000003oool0oooo00H0oooo000K0?oo
o`030000003oool0oooo0080oooo1@3o000<0?lY00/0oe<02`3oO0080?nV00P0oll01P3on@070=go
00@0/ol000<0R_l00?l0003o00005`3o000200d0o`8006ko00@004Go000Ko`006ol001_o0P0=0?l3
03L0o`040600o`2:0?l0/`3o0?l0nH00o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool0
0`000000oooo0?ooo`020?ooo`H0o`00303o:@0;0?mC00/0og`02P3oYP070?o?00T0ooT0103Mo`03
0;?o000308[o001Po`00o`0000D0o`000P2c0?l?0?l000<00<7o00<009So000Ko`0=0?l00`0=0?l2
03L0o`<0H03o00<0RP3o0;<0o`3o0000P03o00040?ooo`030000003oool0oooo00H0oooo000K0?oo
o`030000003oool0oooo0080oooo1P3o000<0?lY00`0oe<02`3oO00;0?nV00T0oll01`3on@050=go
0080/ol00P2:o`00100=o`00o`1l0?l00000oiP20600o`0308X0o`3o0000o`0000`0o`000P00ol40
1000on/0o`000?l0003o000403L0o`<0H03o00<0RP3o0;<0o`3o0?T0P@3o00040?ooo`030000003o
ool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo1P3o000=0?lY00d0oe<02`3oO00:
0?nV00X0oll01`3on@050=go00<0/ol00P2:o`000`0go`00o`000?l0000>0?l000<00?m^00@00?o[
0?l0:@3o05<0g@3o0P2:0?l30600o`<0RP3o00<0g@3o0?l0003o0000<P3o0000103o02T0o`1l0?l0
O03o02U:0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3o
ool60?l000d0obT03@3oD`0<0?ml00/0ojH02@3oc`090?oi00D0gOl00P2co`00102:o`00=ol003Oo
002c0?l20?l000030600o`3o0000o`0000L0o`0000P00?lK00go0000oa/00?lK003oV03o0000o`3?
0=d0o`80/`3o0`2:0?l20;<0o`030=d0o`3o0?T0o`0003<0o`00103o0<m:0?l000@0oooo00<00000
0?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3oool60?l000d0obT03P3oD`0<0?ml
00/0ojH02`3oc`080?oi00D0gOl00`2co`000`2:o`00H?l0063o00080?l0000300go000go`00=ol0
00<0=ol000@00?lK0?l0003o0000o`3?1@3M0?lf0?l000030?l0c`3M0?l0g@3o0080g@3o00<0o`3i
0?l0c`3o0000B03o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo
0080oooo1P3o000=0?lY00h0oe<0303oO00;0?nV00/0oll0203on@050=go00<0/ol000<0R_l0063o
001Po`00203o00000`0=o`00=ol003Oo000303Oo0004003o6`3o0000o`000?l0c`D0g@3o=P3o0000
0`3o0<l0g@3o0=d0o`020=d0o`030?l0n@3o0<l0o`0004P0o`00103oool00`000000oooo0?ooo`06
0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`H0o`003@3o:@0>0?mC00d0og`02`3oYP0;0?o?
00T0ooT0103Mo`050;?o00@0R_l02P1Po`000`0go`00o`000?l0000f0?l000030?l0n@3M0?l0g@3o
00P0/`3o0P3M0?l00`3o0<l0o`000?l000160?l000@0oooo00<000000?ooo`3oool01P3oool001/0
oooo0P0000030?ooo`H0o`003`3o:@0=0?mC00d0og`03@3oYP0:0?o?00T0ooT01P3Mo`060;?o00L0
R_l00`1Po`000`0=o`00o`000?l0000`0?l000040?l0n@2c0?l0/`3o0;<0o`X0RP3o102c0?l00`3M
0?l0o`3?0?l0c`160?l000<0oooo0P0000080?ooo`006`3oool00`000000oooo0?ooo`020?ooo`H0
o`003`3o:@0=0?mC00d0og`03@3oYP0<0?o?00P0ooT01`3Mo`090;?o00D0R_l000<0H?l000go003o
02T0<03o00000`2c0?l0RP3o0600o`080600o`H0RP3o0P2c0?l20=d0o`030?l0c`3o0000o`0004<0
o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`D0o`00
3P3o:@0?0?mC00l0og`0303oYP0<0?o?00X0ooT0203Mo`070;?o00@0R_l000<0H?l000go003o0000
;P3o00000`3o0?T0H03o0600o`0503L0o`H0H03o1@2:0?l30;<0o`030=d0o`3o0<l0o`1C04<0o`00
103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`D0o`003P3o
:@0?0?mC00l0og`03@3oYP0<0?o?00/0ooT02@3Mo`070;?o0080R_l000H0H?l003Oo000go`000?lK
0?l0n@3o02TX0?l00080RP3o2`0g0?l60600o`<0RP3o0P2c0?l20=d0o`030?l0YP3o0000o`000440
o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`D0o`00
3P3o:@0?0?mC00l0og`03@3oYP0<0?o?00/0ooT02@3Mo`070;?o0080R_l000H0H?l003Oo000go`00
0?lK0?l0n@3o02TX0?l00080RP3o2`0g0?l60600o`<0RP3o0P2c0?l20=d0o`030?l0YP3o0000o`00
0440o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`@0
o`003`3o:@0?0?mC0100og`03@3oYP0<0?o?00/0ooT02P3Mo`060;?o0080R_l00P1Po`000`0go`00
o`000?l0000W0?l0000308X0o`0g0?l0=`3o00L03@3o1@0g0?l50600o`<0RP3o0`2c0?l00`3M0?l0
o`3?0?l000120?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool0
0P3oool40?l000l0obT03`3oD`0@0?ml00h0ojH03@3oc`0<0?oi00T0gOl01@2co`0308[o0003063o
000go`000?lK00H0o`000P0=0?l00`1P0?l0/`3o0?l0000K0?l000030=d0o`0=0?l001_o00@001_o
1@0=0?l503L0o`D0H03o102:0?l20;<0o`030?l0n@3o0000o`000440o`00103oool00`000000oooo
0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`80o`00403o:@0@0?mC0100og`03P3o
YP0>0?o?00`0ooT02P3Mo`040;?o00@0R_l000@0H?l003Oo000go`000?lK0P00odD01@00on/0o`00
0?l0001P0?l0/`3o01`0o`0000<001_o0015o`00AOl00P00AOl4000Ko`<03@3o1@0g0?l50600o`@0
RP3o0P2c0?l00`3M0?l0o`3i0?l000110?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo
00<000000?ooo`3oool00P3oool00`3o0000obT00?lY000>0?lY0140oe<0403oO00@0?nV00d0oll0
303on@0:0=go00H0/ol00P2:o`03063o000303Oo000=o`00o`000080o`3?00<0g@3o0?l0YP3o0000
6P3o00000`006ol006ko001^o`040015o`<001_o0`0=0?l503L0o`D0H03o102:0?l20;<0o`040=d0
o`3o0?T0o`2V0?l0YT00o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool2000000<0oooo
00<0o`000?lY003o:@003P3o:@0A0?mC0100og`0403oYP0=0?o?00`0ooT02P3Mo`060;?o0080R_l0
0`1Po`000`0go`003Ol00?l000020?l0c`030=d0o`3o0:H0o`0001X0o`0000<001_o001^o`00K_l0
1000AOl3000Ko`<03@3o1@0g0?l50600o`@0RP3o0P2c0?l0103M0?l0o`3i0?l0YP3o0:I00?l000<0
oooo0P0000080?ooo`006`3oool00`000000oooo0?ooo`020?oooa40obT04@3oD`0@0?ml0100ojH0
3P3oc`0<0?oi00X0gOl01P2co`0408[o0003063o000go`000?m501h0o`0000@0=`3o002Ho`00V?l0
09So0P00K_l20015o`<001_o0`0=0?l503L0o`D0H03o102:0?l30;<0o`030=d0o`3o0?T0o`3i0400
o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?oooa00obT0
4@3oD`0A0?ml0140ojH03P3oc`0>0?oi00P0gOl01P2co`0408[o0003063o000go`00o`0001d0o`00
0`00`Ol01000V?l006ko001^o`00AOl2000Ko`@03@3o1P0g0?l50600o`@0RP3o0`2c0?l01@3M0?l0
o`3i0?l0n@3o0<l0o`0Y03h0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`l0obT04P3oD`0A0?ml0140ojH03P3oc`0?0?oi00X0gOl01P2co`0208[o0004
063o000go`00=ol0003o6`<0o`000P0=0?l00`2:0?l0o`000?l0000A0?l000@00?o[00@00>_o002H
o`2c0?l0/`3o0P3o00000`1P0?l0=`3o03L0o`0703L0o`H0H03o102:0?l30;<0o`060=d0o`3o0?T0
o`3i0?l0n@3o0:H0o`1C?@3o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003o
ool0oooo0080oooo303o:@0D0?mC0180og`04@3oYP0@0?o?00d0ooT02`3Mo`060;?o0080R_l00`1P
o`000`0go`003Ol0003o6`020?l000030?l0n@3o0000o`000100o`0000<00?o1003oV000oiP00P00
ol400`00`Ol0o`000?l000040?l00080RP3o301P0?l508X0o`80/`3o0P3M0?l20?l0n@040?l0c`3o
0:H0o`1l0?l0:C`0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?oo
o`020?ooo`X0obT0503oD`0D0?ml0180ojH0403oc`0=0?oi00/0gOl01P2co`0408[o0080H?l000<0
=ol000go000=o`001@3o00000`2c0?l0o`000?l000090?l00003003oV000ofh00?m^00800?m^00<0
0?nH003o`@3o00001P3o00020=d0o`0308X0o`1P0?l0H03o00L0H03o1@2:0?l40;<0o`80g@3o0P3o
0?T00`3o0:H0o`0Y0?l0000m0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<00000
0?ooo`3oool00P3oool:0?lY01@0oe<0503oO00B0?nV0100oll03@3on@0;0=go00H0/ol0102:o`02
063o000303Oo000=o`003Ol000D0o`0000<0/`3o0?l0003o00002@3o00000`00oiP00?m^003oKP02
003oKP03003oV000ol40o`0000H0o`000P3M0?l00`2:0?l0H03o0600o`070600o`D0RP3o102c0?l2
0=d0o`80o`3i00<0o`2V0?l0:@3o0000?@3o00040?ooo`030000003oool0oooo00H0oooo000K0?oo
o`030000003oool0oooo0080oooo1`3o:@0F0?mC01D0og`04P3oYP0@0?o?00h0ooT02`3Mo`060;?o
00D0R_l00`1Po`000`0go`003Ol0003oA@02003o6`<0o`0000<0o`1l0?l0003o00000`3o0002003o
KPH00?m500@00?m^003o`@3o0000o`000P3o05<00`3o02T0o`000?l0D`020;<0o`<0RP3o1@1P0?l6
08X0o`@0/`3o0P3M0?l00`3o0?T0o`1l0?l0O0100?l000@0oooo00<000000?ooo`3oool01P3oool0
01/0oooo00<000000?ooo`3oool00P3oool20?lY01X0oe<05@3oO00C0?nV0140oll03`3on@0;0=go
00L0/ol01@2:o`02063o00@0=ol00`0=o`03003o6`H03Ol00P00oa/3003oA@0300d0o`3o0000o`0Y
0080o`1l00<0o`3?0?l0n@3M0?l00`2c0?l<08X0o`@0/`3o0P3M0?l00`3o0?T0o`1l0?l000110?l0
00@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3ooolK0?mC01H0
og`04`3oYP0A0?o?0100ooT02`3Mo`070;?o00H0R_l01@1Po`0903Oo00@03Ol00P00oa/01000odD0
o`000?l0003o00020?l0YP030?l0c`3o0?T0g@3o0080g@3o0P2c0?l808X0o`D0/`3o0`3M0?l00`3o
0<l0o`000?l000120?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo0P0000030?oooaP0
oe<05`3oO00E0?nV0180oll03`3on@0<0=go00P0/ol01`2:o`07063o00H0=ol00P0=o`02003o6`04
003oA@3o0000o`000?l00080o`1C00<0o`3?0?l0n@3M0?l00P3M0?l=0;<0o`80g@3o0P3o0?T00`3o
0<l0o`1C0?l000130?l000<0oooo0P0000080?ooo`006`3oool00`000000oooo0?ooo`020?oooaH0
oe<06@3oO00E0?nV0180oll0403on@0<0=go00T0/ol0202:o`08063o00<0=ol00`0=o`000`00oa/0
0?o10?l000030?l000030?l0O03o0<l0o`3i00@0g@3o202c0?l40=d0o`030?l0n@3o07`0o`1l04H0
o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?oooaH0oe<0
6@3oO00E0?nV0180oll0403on@0<0=go00T0/ol0202:o`08063o00<0=ol00`0=o`000`00oa/00?o1
0?l000030?l000030?l0O03o0<l0o`3i00@0g@3o202c0?l40=d0o`030?l0n@3o07`0o`1l04H0o`00
103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`D0og`02`3o
D`0N0?ml01H0ojH04P3oc`0A0?oi00`0gOl02P2co`0908[o00H0H?l00`0go`0200go0003003o6`00
`Ol0o`0000D0o`0000@0o`3?0?l0n@3o0?T0o`3i2`3M0?l20?l0n@030?l0D`3o0000o`0004H0o`00
103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooobd0og`05P3o
YP0C0?o?0140ooT03P3Mo`090;?o00T0R_l01P1Po`0403Oo000300go0000odD0o`0000P0o`0000<0
o`1l0?l0c`3o0?T01`3o0?T30?l0c`030?l0YP3o0000o`0004L0o`00103oool00`000000oooo0?oo
o`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`80ojH0:P3oO00G0?nV01@0oll04@3on@0>
0=go00X0/ol02@2:o`05063o00<0=ol000<03Ol0003oA@3o00002P3o00000`3o05<0o`1l0?l00007
0?l000030?l0D`3o02T0o`0004P0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`00
0000oooo0?ooo`020?ooo`030?o?003oYP00ojH000<0ojH08`3oO00J0?nV01@0oll04@3on@0?0=go
00/0/ol02@2:o`04063o00<0=ol000<00?lK0?l0003o0000GP3o00040?ooo`030000003oool0oooo
00H0oooo000K0?ooo`030000003oool0oooo0080oooo00<0oll00?nV003oYP000`3oYP0S0?ml01X0
ojH0503oc`0A0?oi00l0gOl02`2co`0908[o00@0H?l00`0go`000`00oa/0o`000?l0001N0?l000@0
oooo00<000000?ooo`3oool01P3oool000P0oooo0P0000040?ooo`8000000`3oool5000000<0oooo
00<000000?ooo`3oool00P3oool00`3Mo`00ooT00?o?00020?o?00H0ojH0703oO00K0?nV01D0oll0
4`3on@0=0=go00`0/ol02@2:o`03063o00<0=ol000<03Ol0003oA@00jol0GP3o00040?ooo`030000
003oool0oooo00H0oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`@0o`0000<0gOl00?oi003oc`002@3oYP0D0?ml01h0ojH0
5@3oc`0C0?oi00h0gOl0302co`0808[o00D0H?l000<0=ol000go0000oa/0G`3o00040?ooo`030000
003oool0oooo00H0oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
0`3oool2000000<0oooo1P3o0000103Mo`00oll00?o?003oc`0=0?nV00L0og`08P3oYP0G0?o?01<0
ooT03`3Mo`0=0;?o00L0R_l0101Po`0203Oo000300go003o0000o`0005d0o`000`3oool2000000P0
oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`L0o`000P3Mo`000`3on@00oll00?o?000d0?nV01L0oll0503on@0>0=go00d0
/ol0202:o`04063o000303Oo000=o`000?m505h0o`00103oool00`000000oooo0?ooo`060?ooo`00
1`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool50?l000060015o`3M0?l0/ol00;?o003Mo`00ooT0103oc`0`0?nV01P0oll0503on@0@
0=go00`0/ol01`2:o`04063o0080=ol000<03Ol0003oKP00ofh0G03o00040?ooo`030000003oool0
oooo00H0oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool00P3oool50?l0
00060015o`3M0?l0/ol00;?o003Mo`00ooT0103oc`0`0?nV01P0oll0503on@0@0=go00`0/ol01`2:
o`04063o0080=ol000<03Ol0003oKP00ofh0G03o00040?ooo`030000003oool0oooo00H0oooo000K
0?ooo`030000003oool0oooo0080oooo2@3o0000101P0?l0/ol00=go003on@040?o?02d0ojH06@3o
c`0D0?oi0140gOl0302co`0708[o00@0H?l00P0go`02003o6`03003oA@00V?l0=`3o0080g@3oE`3o
00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo2`3o0000
100go`00gOl00?oi003on@040?o?02X0ojH06P3oc`0E0?oi0100gOl0302co`0708[o00@0H?l00P0g
o`0200go0003003oV03o07`0g@3o0080o`3iE`3o00040?ooo`030000003oool0oooo00H0oooo000K
0?ooo`030000003oool0oooo0080oooo303o00000`0g0?l0gOl00=go00020?oi00D0oll0903oYP0L
0?o?01H0ooT04@3Mo`0<0;?o00P0R_l00`1Po`000`0go`003Ol000go001L0?l000@0oooo00<00000
0?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3oool;0?l000050;<0o`3o0000H?l0
063o003Mo`000P3on@080?o?01l0ojH07@3oc`0F0?oi0140gOl0302co`0808[o00<0H?l00`0go`00
0`00oa/0o`000?l0001I0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?oo
o`3oool00P3oool;0?l000060015o`3o02T0H?l0063o002co`00gOl00P3on@090?o?01T0ojH08@3o
c`0F0?oi0180gOl03@2co`0708[o00<0H?l00P0go`000`0=o`000?o10?l0001I0?l000@0oooo00<0
00000?ooo`3oool01P3oool001/0oooo0P0000030?ooo`/0o`0000H004Go0?l0:@1Po`00H?l00;?o
003Mo`020?oi00T0oll06@3oYP0Q0?o?01H0ooT04P3Mo`0=0;?o00L0R_l00`1Po`0203Oo000300go
0000ol40o`0005T0o`000`3oool2000000P0oooo000K0?ooo`030000003oool0oooo0080oooo3`3o
00000`0go`00/ol00=go00030?oi00/0oll04`3oYP0R0?o?01L0ooT04P3Mo`0=0;?o00L0R_l00`1P
o`0303Oo000300go003o0000o`0005P0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool0
0`000000oooo0?ooo`020?oooa40o`0000<0/ol00=go003on@000P3on@0B0?o?00@0ojH0:@3oc`0G
0?oi0180gOl03P2co`0708[o00@0H?l000<0=ol000go0000oa/0F@3o00040?ooo`030000003oool0
oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo00<0H03o0?l0003o00003`3o00000`2c
o`00gOl00=go00030?oi03`0oll0603on@0D0=go00`0/ol01`2:o`04063o0080=ol000<03Ol0003o
6`00oa/0E`3o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080
oooo00<0=`3o0600o`3o00003`3o00000`2:o`00gOl00=go00050?oi03X0oll0603on@0D0=go00d0
/ol01`2:o`04063o0080=ol00P0=o`000`00oa/00?m^0?l000060?l000030?l0D`3o0000o`0004/0
o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`0303L0
o`1P0?l0o`0000l0o`0000<0R_l00=go003Mo`001@3on@0j0?o?01P0ooT0503Mo`0=0;?o00L0R_l0
101Po`0203Oo00803Ol000<00?lK003oKP3o00001P3o00000`3o05<0o`000?l0001;0?l000@0oooo
00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3oool0100=0?l0=`3o0600
o`1P0?l;0?l0000408X0o`0g0?l0o`00063o0080/ol000<0gOl00?oi003on@000`3on@0h0?o?01T0
ooT0503Mo`0=0;?o00L0R_l01@1Po`0303Oo000400go0000oa/00?m5003oKP800?o100@00<7o0015
o`0=0?l0=`3o0P2:0?l00`3M0?l0o`000?l000180?l000@0oooo00<000000?ooo`3oool01P3oool0
01/0oooo00<000000?ooo`3oool00P3oool200d0o`80=`3o00<0o`3i0?l0003o00002@3o00000`00
V?l00?m508[o00020;?o0080gOl01@3on@0e0?o?01/0ooT05@3Mo`0<0;?o00P0R_l0101Po`0403Oo
000300go0000oa/00?m5008006ko0P3o00001P0g0?l0H03o08X0o`2:0?l0/`3o0?l0YTT0o`00103o
ool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`803@3o0P0g0?l0
0`2:0?l0o`000?l0000;0?l0000300go002co`00/ol00080gOl01P3on@0c0?o?01`0ooT05@3Mo`0=
0;?o00L0R_l01@1Po`0303Oo000300go0000oa/00?o10080o`0000<0o`2V0?l0n@2:0?l00`2:0?l0
0`2c0?l0o`3i0?l000180?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?oo
o`3oool00P3oool200d0o`80=`3o00<0H03o0;<0o`3o0000303o0002063o00030;?o003Mo`00gOl0
00P0ooT0;`3oc`0M0?oi01D0gOl03@2co`0708[o00D0H?l00`0go`000`0=o`000?lK0?l000020?l0
00040?l0YP3o0?T0g@3o0;<0o`80g@3o00<0o`3i0?l0003o0000B03o00040?ooo`030000003oool0
oooo00H0oooo000K0?ooo`8000000`3oool200d0o`80=`3o00<0H03o08X0o`3o0:H0303o00020015
o`0308[o002co`00gOl00080gOl01`3on@0]0?o?01h0ooT05@3Mo`0=0;?o00T0R_l00`1Po`0303Oo
000300go0000oa/0o`0000<0o`0000<0o`2V0?l0c`3o0?T00P3o0<m;0?l000<0oooo0P0000080?oo
o`006`3oool00`000000oooo0?ooo`020?ooo`803@3o0P0g0?l00`1P0?l0RP3o0?l0YP0<0?l00080
04Go00<0R_l00;?o003Mo`000P3Mo`070?oi02d0oll07P3on@0E0=go00d0/ol02@2:o`03063o00<0
=ol000<03Ol0003o6`3o00000`3o00000`3o0:H0o`3?0?l0n@020?l0cd/0o`00103oool00`000000
oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`803@3o0P0g0?l00`1P0?l0RP3o
0?l0000>0?l0000308[o002co`00gOl00080gOl02@3on@0Z0?o?01l0ooT05@3Mo`0=0;?o00T0R_l0
1@1Po`00100go`003Ol0003o6`3o0?UC0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo
00<000000?ooo`3oool00P3oool01P0=0?l0=`3o03L0o`0g0?l0H03o08X0o`/0o`0000H0/`3o0?l0
003o0000o`00063o002co`040=go00T0ooT09P3oc`0Q0?oi01H0gOl03P2co`0808[o00D0H?l00P0g
o`000`00oa/0o`000?l0001B0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<00000
0?ooo`3oool00P3oool01`0=0?l0=`3o03L0o`0g0?l0H03o08X0o`3o0?T02P3o00001P006ol0o`3?
0?l0003o0000R_l00;?o00D0gOl02`3on@0Q0?o?02<0ooT05P3Mo`0>0;?o00T0R_l0101Po`0203Oo
000300go0000ofh0o`000580o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`80=`3o0`1P0?l00`2:0?l0g@3o0?l0000:0?l00004003oV00go`00=ol008[o
0080/ol0103Mo`0?0?oi01X0oll09P3on@0F0=go00h0/ol02@2:o`04063o0080=ol000@03Ol0003o
A@3o0:H0o`2VD@3o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo
0080oooo0P0g0?l30600o`0308X0o`3M0?l0o`0000X0o`0000@00?nH03Oo000go`00R_l00P2co`04
0=go00l0ooT06P3oc`0V0?oi01H0gOl03P2co`0908[o00@0H?l00P0go`00100=o`000?m50?l0YP3o
0:IA0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3oool2
03L0o`<0H03o00<0RP3o0?l0c`3o00002`3o000200go000308[o002co`00/ol000D0gOl04@3on@0D
0?o?02P0ooT05`3Mo`0>0;?o00T0R_l01@1Po`000`0go`003Ol0003o6`1C0?l000@0oooo00<00000
0?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3oool40600o`0308X0o`2c0?l0o`00
00h0o`0000<0R_l00;?o002co`001@3Mo`0H0?oi00D0oll0<03on@0G0=go0100/ol0202:o`04063o
0080=ol000<03Ol0003oV000oiP0D@3o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`03
0000003oool0oooo0080oooo0P1P0?l308X0o`030=d0o`3o0000o`0000/0o`000P00ofh00`1Po`00
/ol00;?o00060=go04X0ooT06@3Mo`0@0;?o00P0R_l01@1Po`001@0go`003Ol0003o6`00oa/00>_o
0500o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool2000000<0oooo00L0H03o08X0o`2:
0?l0RP3o0;<0o`3M0?l0o`1l00`0o`000P2:0?l00`2:o`00/ol00;?o00020;?o00H0gOl0B03on@0I
0=go0100/ol0202:o`05063o0080=ol00P0=o`001000oa/00?m5003oV000jol200d0o`0308X0o`3M
0?l0o`0004P0o`000`3oool2000000P0oooo000K0?ooo`030000003oool0oooo0080oooo0P2:0?l2
0;<0o`030=d0o`3o0000o`0000T0o`0000<0=`3o0;<0o`3o00000P0=o`000`2:o`00/ol00;?o0002
0;?o00H0gOl0A`3on@0J0=go0100/ol02@2:o`05063o00<0=ol000@03Ol0003o6`00ofh0o`000P3o
0?T00`3M0?l0o`3i0?l000180?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<00000
0?ooo`3oool00P3oool208X0o`80/`3o00<0g@3o0?l0003o00002@3o00000`0g0?l0/`3o0?l00002
00go000308[o002co`00/ol00080/ol01P3Mo`170?oi01X0gOl0402co`0908[o00D0H?l00`0go`00
100=o`000?lK003oKP3o00020?l0n@030=d0o`3o0?T0o`0004P0o`00103oool00`000000oooo0?oo
o`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`80/`3o0P3M0?l<0?l00003002Ho`3o0000
3Ol00080H?l000<0R_l00;?o002co`000P2co`070=go04H0ooT06P3Mo`0@0;?o00T0R_l01@1Po`03
03Oo00803Ol000H00?m^0?l0003o05<0o`1C0?l0YP3o05=90?l000@0oooo00<000000?ooo`3oool0
1P3oool001/0oooo00<000000?ooo`3oool00P3oool0102c0?l0g@3o0?l0n@3o0?T=0?l0000300go
001Po`00R_l00080R_l0102co`080=go04@0ooT06`3Mo`0A0;?o00P0R_l01P1Po`0303Oo000300go
0000odD0o`0004d0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?oo
o`020?ooo`030=d0o`3o0<l0o`0000h0o`0000<03Ol0063o002:o`000P2:o`040;?o00P0gOl0@`3o
n@0L0=go0140/ol02P2:o`04063o00<0=ol000<03Ol0003o6`3o05<0C@3o00040?ooo`030000003o
ool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo4@3o00000`0go`00H?l008[o0002
08[o00@0/ol02@3Mo`110?oi01`0gOl04P2co`0:08[o00@0H?l0100go`000`0=o`000?m^0?l0001<
0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3oool<0?l0
00060?l0O03o0000o`000?l00000odD0H?l00`2:o`050;?o00X0gOl0?P3on@0N0=go0180/ol02P2:
o`06063o0080=ol000@03Ol0003o6`00oiP00?nH0`3o00020?l0cdH0o`00103oool00`000000oooo
0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo``0o`0000H0o`1l0?l0003o0000o`00
003oA@1Po`0308[o00D0/ol02P3Mo`0n0?oi01h0gOl04P2co`0:08[o00H0H?l00P0go`00100=o`00
0?lK003oV000oiP30?l00080o`3?AP3o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`03
0000003oool0oooo0080oooo2`3o00000`0g0?l0/`3o0?l000020?l0000303Oo001Po`00R_l00080
R_l01@2co`0<0=go03/0ooT07`3Mo`0B0;?o00/0R_l01@1Po`0303Oo000600go0000oa/00?lK003o
A@00oiP0o`000P3M0?l00`3o0<l0o`000?l000130?l000@0oooo00<000000?ooo`3oool01P3oool0
01/0oooo0P0000030?ooo``0o`0000D00?m^003oA@00odD0=ol0063o000408[o00H0/ol0303Mo`0i
0?oi0200gOl04P2co`0;08[o00H0H?l00`0go`0200go0003003o6`00odD0o`0004P0o`000`3oool2
000000P0oooo000K0?ooo`030000003oool0oooo0080oooo303o00000`0=o`00=ol003Oo0002063o
00@0R_l01P2co`0=0=go03L0ooT07`3Mo`0D0;?o00/0R_l01P1Po`0303Oo00<03Ol000<00?lK0031
o`3o0000A`3o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080
oooo2`3o00000`00oa/0=ol0063o0002063o00<0R_l0202co`0@0=go0340ooT08P3Mo`0D0;?o00`0
R_l01P1Po`0403Oo00803Ol000<00?lK0?l0003o0000AP3o00040?ooo`030000003oool0oooo00H0
oooo000K0?ooo`030000003oool0oooo0080oooo2`3o00000`00oa/0=ol0063o0002063o00<0R_l0
202co`0@0=go0340ooT08P3Mo`0D0;?o00`0R_l01P1Po`0403Oo00803Ol000<00?lK0?l0003o0000
AP3o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo1@3o
00000`2:0?l0o`2V0?l000020?l00003003o6`0go`00H?l00080H?l0102:o`080;?o0140gOl0;`3o
n@0R0=go01D0/ol0302:o`07063o00@0=ol00P0=o`02003o6`04003oKP00ol40o`0Y0?l0YT80o`00
103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`T0o`0000<0
3Ol003Oo001Po`000`1Po`0408[o00P0/ol04`3Mo`0[0?oi02@0gOl05@2co`0<08[o00L0H?l01@0g
o`0300go0003003o6`00odD0o`0004<0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool0
0`000000oooo0?ooo`020?ooo`@0o`0000<00?m5003o6`0=o`000`0go`03063o00D0R_l02@2co`0F
0=go02D0ooT09`3Mo`0E0;?o00`0R_l0201Po`0403Oo00@03Ol000<00?lK003oA@3o00000P3o0000
0`0=0?l0o`2V0?l0000m0?l000@0oooo00<000000?ooo`3oool01P3oool000P0oooo0P0000040?oo
o`8000000`3oool4000000@0oooo00<000000?ooo`3oool00P3oool01@3o00000?m^003o6`00oa/0
3Ol000@0=ol00`1Po`0608[o00T0/ol0603Mo`0Q0?oi02P0gOl05P2co`0=08[o00L0H?l01@0go`04
00go00800?lK0P00odD00`00oiP0o`000?l0000U0?l000030?l0O03o0000o`0000T0o`000P3o07`:
0?l000@0oooo00<000000?ooo`3oool01P3oool000L0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P0=o`0403Oo00D0H?l01P2:o`0;
0;?o01/0gOl0603on@0]0=go01H0/ol03@2:o`09063o00D0=ol00`0=o`03003o6`04003oA@00ofh0
0?nH003[o`<0o`0000<0o`0Y0?l0003o00005P3o00030;<0o`030?l0n@3o0000g@3o00<0RP3o00@0
/`3o0=d0o`3o0?T0o`3i103o00020?l0D`<0o`3i00<0o`1C0?l0003o00001`3o00040?ooo`030000
003oool0oooo00H0oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
103oool2000000<0oooo0P0=o`0403Oo00D0H?l01P2:o`0;0;?o01/0gOl0603on@0]0=go01H0/ol0
3@2:o`09063o00D0=ol00`0=o`03003o6`04003oA@00ofh00?nH003[o`<0o`0000<0o`0Y0?l0003o
00005P3o00030;<0o`030?l0n@3o0000g@3o00<0RP3o00@0/`3o0=d0o`3o0?T0o`3i103o00020?l0
D`<0o`3i00<0o`1C0?l0003o00001`3o00030?ooo`800000203oool000L0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo100go`06063o
00L0R_l02`2co`0R0=go00/0ooT0<P3Mo`0G0;?o00d0R_l02@1Po`0603Oo00<03Ol00`00oa/2003o
A@05003oKP00oiP00?nH003o`@00`Ol0103o00000`3o05<0o`000?l0000:0?l000H03@3o1P0g0?l5
0600o`@0RP3o1@2c0?l30=d0o`030?l0n@3o0:H0o`2V00L0o`00103oool00`000000oooo0?ooo`06
0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool203Oo00L0H?l0202:o`0;0;?o05d0gOl0602co`0>08[o00X0H?l01P0g
o`0400go00<00?lK0`00odD2003oKP05003oV000ol400?o1003o`@00on/00P00jol40031o`@009So
0P00K_l40015o`<001_o1@0=0?l403L0o`D0H03o1@2:0?l30;<0o`<0g@3o00<0o`3?0?l0003o0000
103o00040?ooo`030000003oool0oooo00H0oooo00080?ooo`8000002P3oool2000000D0oooo00<0
00000?ooo`3oool00P3oool7063o00T0R_l03@2co`1L0=go01P0/ol03P2:o`0:063o00H0=ol01@0=
o`03003o6`@00?m50`00ofh2003oV0800?o10`00on/2003[o`<00<7o0P00V?l3001^o`<004Go1000
6ol300d0o`D0=`3o1@1P0?l508X0o`80/`3o0`3M0?l00`3o0<l0o`000?l000030?l000@0oooo00<0
00000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3oool6063o00X0R_l03@2co`1K
0=go01T0/ol03P2:o`0:063o00L0=ol01@0=o`04003o6`<00?m50`00ofh2003oV0<00?o10P00on/2
003[o`<00<7o0P00V?l3001^o`<004Go10006ol400d0o`D0=`3o1P1P0?l308X0o`@0/`3o00@0g@3o
0?l0n@3o07`0o`1l0P3o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0
oooo0080oooo1@1Po`0:08[o00h0/ol0FP3Mo`0J0;?o00h0R_l02P1Po`0703Oo00D03Ol01@00oa/2
003oA@@00?m^0P00oiP3003o`@03003oj`00jol00>_o00<00<7o0P00V?l3001^o`<004Go10006ol5
00d0o`D0=`3o1P1P0?l308X0o`@0/`3o00D0g@3o0?l0n@3o0?T0o`3?0?l000040?ooo`030000003o
ool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo1@1Po`0:08[o00h0/ol0FP3Mo`0J
0;?o00h0R_l02P1Po`0703Oo00D03Ol01@00oa/2003oA@@00?m^0P00oiP3003o`@03003oj`00jol0
0>_o00<00<7o0P00V?l3001^o`<004Go10006ol500d0o`D0=`3o1P1P0?l308X0o`@0/`3o00D0g@3o
0?l0n@3o0?T0o`3?0?l000040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0
oooo0080oooo101Po`0;08[o00l0/ol0F@3Mo`0J0;?o00h0R_l02`1Po`0603Oo00H03Ol01000oa/4
003oA@800?m^0P00oiP2003o`@800?o[00@00>_o0031o`00`Ol00<7o0P00V?l4001^o`<004Go1000
6ol500d0o`H0=`3o1P1P0?l408X0o`<0/`3o0P3M0?l00`3o0?T0o`000?ooo`030?ooo`030000003o
ool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo0P1Po`0=08[o0140/ol0EP3Mo`0I
0;?o0100R_l02`1Po`0603Oo00H03Ol01000oa/4003oA@800?m^00L00?nH003o`@00ol400?o1003o
j`00jol00<7o00<009So0`00K_l50015o`D001_o1P0=0?l503L0o`H0H03o1@2:0?l20;<0o`<0g@3o
00<0o`3?0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?oo
o`020?ooo`03063o002:o`00R_l000`0R_l04@2co`1E0=go01X0/ol0402:o`0;063o00L0=ol01@0=
o`04003o6`800?m50`00ofh00`00oiP00?o1003oj`02003[o`L0o`0000<0H03o000Ko`006ol02000
6ol600d0o`L0=`3o1P1P0?l508X0o`<0/`3o00<0g@3o0?l0n@3oool00`3oool00`000000oooo0?oo
o`060?ooo`006`3oool2000000<0oooo3@2:o`0D0;?o0580gOl0702co`0@08[o00/0H?l01P0go`06
00go00@00?lK0P00odD2003oKP03003oV000ol40o`0000`0o`000P3M0?l200d0o`03000Ko`0=0?l0
3@3o00P03@3o1`0g0?l60600o`D0RP3o102c0?l0103M0?l0oooo0?ooo`3oool2000000P0oooo000K
0?ooo`030000003oool0oooo0080oooo3@2:o`0D0;?o0580gOl0702co`0@08[o00/0H?l01P0go`06
00go00@00?lK0P00odD2003oKP03003oV000ol40o`0000`0o`000P3M0?l200d0o`03000Ko`0=0?l0
3@3o00P03@3o1`0g0?l60600o`D0RP3o102c0?l00`3M0?l0oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo3@2:o`0E0;?o0500gOl0702co`0A08[o
00X0H?l01`0go`0500go00@00?lK0P00odD00`00ofh00?nH003oV00A0?l000030;<0o`0g0?l03@3o
00T03@3o200g0?l60600o`H0RP3o0`2c0?l00`3M0?l0oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo000K0?ooo`030000003oool0oooo0080oooo3@2:o`0E0;?o04l0gOl07@2co`0A08[o00X0
H?l01`0go`0500go00800?lK0`00odD00`00ofh00?o10?l0000C0?l000030600o`0g0?l0=`3o00D0
3@3o2P0g0?l70600o`H0RP3o102c0?l40?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000
003oool0oooo0080oooo3@2:o`0F0;?o04d0gOl07@2co`0A08[o00/0H?l01`0go`0400go00<00?lK
0P00odD00`00ofh0o`000?l000060?l000@0o`1C00<0o`0Y0?l0003o00001`3o00000`2:0?l0H03o
03L0o`0?03L0o`L0H03o1P2:0?l40;<0o`@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<0
00000?ooo`3oool00P3oool=08[o01L0/ol0B`3Mo`0N0;?o0140R_l02`1Po`0603Oo00D03Ol00P00
oa/00`00odD00?nH003oV0080?l000030?l0D`3o07`0o`1l0080o`1l00<0o`1C0?l0003o00001`3o
00000`2:0?l0H03o0600o`0>03L0o`P0H03o1P2:0?l40;<0o`@0oooo00<000000?ooo`3oool01P3o
ool001/0oooo00<000000?ooo`3oool00P3oool=08[o01T0/ol0AP3Mo`0P0;?o0180R_l02P1Po`07
03Oo00@03Ol00P00oa/01000odD00?m^0?l0c`3o0<l70?l000030?l0D`3o07`0o`2V00@0o`2V00<0
o`0Y0?l0003o00001@3o00000`3M0?l0RP3o0600o`030600o`/0=`3o2@1P0?l608X0o`@0/`3o103o
ool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`d0R_l06@2co`16
0=go0200/ol04P2:o`0:063o00L0=ol0100=o`02003o6`04003oA@00ofh0o`3?0?l0c`L0o`0000<0
o`1C0?l0O03o0:H0103o0:H00`3o02T0o`000?l000050?l000030=d0o`2:0?l0H03o00<0H03o2`0g
0?l90600o`H0RP3o102c0?l40?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0
oooo0080oooo3@2:o`0J0;?o04@0gOl08@2co`0A08[o00/0H?l01P0go`0300go00<00?lK00<00?m5
003oKP00jol0203o00000`3o02T0o`1l0?l0YP020?l0YP@0o`3?0P3o0:H00`3o05<0o`1l0?l0c`02
0=d0o`030;<0o`2:0?l0H03o00D0H03o1@0g0?l<0600o`L0RP3o102c0?l40?ooo`030000003oool0
oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo3@2:o`0L0;?o03l0gOl08`2co`0B08[o
00/0H?l01P0go`0300go00800?lK00@00?m5003oV03o0000/`3o203o00000`3o05<0o`2V0?l0YP04
0?l0c`D0o`3i0P3M0?l20;<0o`<0RP3o5P1P0?l708X0o`@0/`3o103oool00`000000oooo0?ooo`06
0?ooo`006`3oool2000000<0oooo3@2:o`0N0;?o03`0gOl0902co`0B08[o00T0H?l01`0go`0300go
00<00?lK00<00?m^0?l0003o00002@3o00000`3o07`0o`2V0?l0c`020?l0c`@0o`3i103M0?l30;<0
o`<0RP3o5@1P0?l808X0o`@0/`3o0`3oool2000000P0oooo000K0?ooo`030000003oool0oooo0080
oooo3@2:o`0P0;?o03P0gOl0902co`0C08[o00X0H?l01`0go`0200go00800?lK0P00odD<0?l00003
0?l0O03o0:H0o`3?0080o`3?0P3o0?T50=d0o`@0/`3o102:0?lC0600o`P0RP3o1@2c0?l40?ooo`03
0000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo3@2:o`0Q0;?o03@0gOl0
9P2co`0D08[o00T0H?l01P0go`0400go0004003o6`00odD00?m^003oKP`0o`0000<0o`1l0?l0c`3o
0<l0103o0?T40=d0o`D0/`3o1P2:0?l>0600o`/0RP3o1@2c0?l40?ooo`030000003oool0oooo00H0
oooo000K0?ooo`030000003oool0oooo0080oooo3@2:o`0Q0;?o03@0gOl09P2co`0D08[o00T0H?l0
1P0go`0400go0004003o6`00odD00?m^003oKP`0o`0000<0o`1l0?l0c`3o0<l0103o0?T40=d0o`D0
/`3o1P2:0?l>0600o`/0RP3o1@2c0?l40?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000
003oool0oooo0080oooo3@2:o`0T0;?o02l0gOl09`2co`0C08[o00/0H?l01@0go`0400go0003003o
6`00odD00?o[0080o`0000<004Go0?l0003o00002@3o00000`3o0:H0o`3?0?l0c`030?l0n@D0g@3o
1@2c0?l808X0o`X0H03o302:0?l60;<0o`@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<0
00000?ooo`3oool00P3oool?08[o02D0/ol0:03Mo`0[0;?o0180R_l02`1Po`0603Oo00<03Ol000@0
0?lK003oA@3o0000o`000P3o0:H00`3M0?l0o`000?l000080?l000040?l0:@3o0:H0o`3?0?l0c`<0
o`3i1@3M0?l50;<0oad0RP3o1`2c0?l40?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000
003oool0oooo0080oooo3`2:o`0Y0;?o0240gOl0;@2co`0C08[o00X0H?l01P0go`0200go00<00?lK
00<00?m^0?l0003o00003P3o00000`3o07`0o`2V0?l0c`030?l0n@D0g@3o1P2c0?lJ08X0o`P0/`3o
00<0g@3o0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?oo
o`020?ooo`l0R_l0;P2co`0F0=go0340/ol0502:o`0;063o00H0=ol00P0=o`02003o6`03003oA@3o
0000o`1C0100o`0000<0o`2V0?l0c`3o0?T00`3o0?T40=d0o`L0/`3o602:0?l80;<0o`80g@3o103o
ool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`l0R_l0;P2co`0F
0=go0340/ol0502:o`0;063o00H0=ol00P0=o`02003o6`03003oA@3o0000o`1C0100o`0000<0o`2V
0?l0c`3o0?T00`3o0?T40=d0o`L0/`3o602:0?l80;<0o`80g@3o103oool00`000000oooo0?ooo`06
0?ooo`006`3oool00`000000oooo0?ooo`020?oooa00R_l0L`2co`0E08[o00X0H?l01P0go`0200go
00<00?lK00<00?m^0?l0003o0000403o00000`3o0:H0o`3?0?l0n@030?l0n@D0g@3o1`2c0?lF08X0
o`T0/`3o0P3M0?l40?ooo`030000003oool0oooo00H0oooo000K0?ooo`8000000`3oool@08[o0780
/ol05@2:o`0;063o00@0=ol0100=o`001000oa/00?m5003oA@00oiPB0?l000040?l0O03o0<l0o`3?
0?l0c`80o`3i1@3M0?l:0;<0o`l0RP3o2P2c0?l50=d0o`<0oooo0P0000080?ooo`006`3oool00`00
0000oooo0?ooo`020?oooa40R_l0L02co`0D08[o00/0H?l01@0go`0400go00800?lK0P00odD00`00
oiP0o`000?l0000@0?l000030?l0O03o0:H0o`3?0080o`3?0P3o0?T50=d0o``0/`3o2@2:0?l<0;<0
o`D0g@3o00<0o`3i0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000
oooo0?ooo`020?oooa40R_l0K`2co`0E08[o00X0H?l01P0go`0300go0003003o6`00odD00?m^0080
0?nH00<00?o[0015o`3o00004@3o0000103o07`0o`2V0?l0YP3o0<l30?l0n@L0g@3o7@2c0?l50=d0
o`80o`3i103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?oooa80
R_l0K02co`0F08[o00/0H?l01@0go`0200go00800?lK00<00?m5003o`@3o00000P3o02T00`3o0000
=`3o0?l0n@0D0?l000030?l0YP3o0<l0o`3i00<0o`3i1P3M0?lI0;<0o`H0g@3o0`3o0?T00`3o0<l0
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo
4P2:o`1/0;?o01H0R_l02`1Po`0503Oo00803Ol00P00oa/00`00odD00?o10?l000020?l0:@030?l0
000g0?l0o`3i01@0o`0000<0o`2V0?l0c`3o0?T00`3o0?T60=d0oaT0/`3o1P3M0?l30?l0n@030?l0
c`3oool0oooo0080oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3o
oolC08[o06X0/ol05P2:o`0;063o00D0=ol00P0=o`001000oa/00?m5003oA@00ol420?l00080o`2V
00<0o`3i0;<0o`3M0?l05@3o00000`3o0:H0o`3?0?l0n@030?l0n@L0g@3o5@2c0?l60=d0o`@0o`3i
00<0o`3?0?l0YP3oool00`3oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?oo
o`020?oooa<0R_l0J@2co`0F08[o00/0H?l01P0go`0200go0003003o6`00ol400?o100D0o`000P3o
0<lF0?l000030?l0O03o0:H0o`3?00@0o`3i2P3M0?l>0;<0o`P0g@3o0P3o0?T00`3o0<l0o`2V0?l0
YP020?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3ooolE
08[o06H0/ol05P2:o`0<063o00D0=ol00P0=o`000`00oa/00?m50?l0000O0?l000040?l0D`3o0:H0
o`3?0?l0c`D0o`3i6P3M0?l40?l0n@030?l0c`3o0:H0o`0000<0o`00103oool00`000000oooo0?oo
o`060?ooo`006`3oool00`000000oooo0?ooo`020?oooaH0R_l0HP2co`0I08[o00/0H?l01P0go`02
00go0004003o6`00odD00?o[003ojal0o`0000<0o`1l0?l0c`3o0<l00P3o0<l50?l0nAL0g@3o103o
0?T00`3o0<l0o`2V0?l0:@040?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo0P000003
0?oooaL0R_l0H02co`0H08[o00/0H?l01P0go`0300go0003003o6`00odD0o`000080o`1l00<0o`3?
0?l0003o0000703o0000103o02T0o`2V0?l0YP3o0:H40?l0c`L0o`3i403M0?l30?l0n@<0o`3?00<0
o`1C0?l0003o0000103o00030?ooo`800000203oool001/0oooo00<000000?ooo`3oool00P3ooolG
08[o0600/ol0602:o`0;063o00H0=ol00`0=o`000`00oa/00?m50?l000020?l0O0030?l0c`3o0000
o`0001`0o`0000@0o`0Y0?l0YP3o0:H0o`2V103o0<l70?l0nA00g@3o0`3o0?T30?l0c`030?l0D`3o
0000o`0000@0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`02
0?oooaP0R_l0G@2co`0I08[o00`0H?l01P0go`0300go0003003o6`00ofh0o`000280o`000P3o05<0
0`3o07`0o`2V0?l0YP030?l0YP<0o`3?2P3o0?T30=d0o`P0o`3i00@0o`3?0?l0YP3o05<0o`1C1`3o
00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo6P2:o`1I
0;?o01X0R_l0301Po`0603Oo00@03Ol000<00?lK003oKP2:0?l0:P3o00000`3o02T0o`1C0?l0YP05
0?l0c`h0o`3i0P3o0<l00`3o0:H0o`1C0?l000080?l000@0oooo00<000000?ooo`3oool01P3oool0
01/0oooo00<000000?ooo`3oool00P3ooolK08[o05H0/ol06`2:o`0<063o00L0=ol00`0=o`000`00
oa/00?m50?l0000`0?l000040?l0O03o0:H0o`2V0?l0YPD0o`3?103o0?T50?l0c`030?l0YP3o07`0
o`0000T0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?oo
oa`0R_l0D`2co`0L08[o00d0H?l01P0go`0400go0003003o6`00odD00?o103@0o`000P3o02T00`3o
07`0o`2V0?l0YP080?l0c`030?l0YP3o07`0o`0000X0o`00103oool00`000000oooo0?ooo`060?oo
o`006`3oool00`000000oooo0?ooo`020?oooa`0R_l0D`2co`0L08[o00d0H?l01P0go`0400go0003
003o6`00odD00?o103@0o`000P3o02T00`3o07`0o`2V0?l0YP080?l0c`030?l0YP3o07`0o`0000X0
o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?oooah0R_l0
C`2co`0L08[o00h0H?l01P0go`0300go00<00?lK00<00?m5003o`@3o0000>03o00020?l0O0H0o`2V
00<0o`1l0?l0:@3o00002P3o00040?ooo`030000003oool0oooo00H0oooo00080?ooo`800000103o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo0080oooo802:o`1;0;?o01d0R_l03@1P
o`0703Oo00@03Ol00`00oa/00`00odD00?nH0?l0000k0?l000030?l0D`3o07`0o`1l0080o`1l00<0
o`1C0?l0003o00002P3o00040?ooo`030000003oool0oooo00H0oooo00070?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooob80R_l0
A@2co`0P08[o00d0H?l01P0go`0500go00<00?lK00@00?m5003oKP00oiP00<7o?@3o00030?l0D`03
0?l0:@3o0000o`0000X0o`00103oool00`000000oooo0?ooo`060?ooo`001`3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo0P0000030?ooob@0R_l0@@2co`0Q08[o00d0
H?l01P0go`0500go00800?lK0P00odD2003oKP03003oV000on/0o`0004`0o`000`3oool2000000P0
oooo00070?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooobL0R_l0>P2co`0S08[o00h0H?l01P0go`0400go00800?lK00P00?m5003oKP00
oiP00?nH003[o`00K_l00<7o003[o`8009So00<03@3o0?l0003o0000B03o00040?ooo`030000003o
ool0oooo00H0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`020?ooobL0R_l0>P2co`0S08[o00h0H?l01P0go`0400go00800?lK
00P00?m5003oKP00oiP00?nH003[o`00K_l00<7o003[o`8009So00<03@3o0?l0003o0000B03o0004
0?ooo`030000003oool0oooo00H0oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?oo
o`3oool00P3oool[08[o03<0/ol09@2:o`0>063o00H0=ol00`0=o`03003o6`03003oKP3o0000o`00
00H0o`000`006ol00`1P0?l0o`000?l000170?l000@0oooo00<000000?ooo`3oool01P3oool001/0
oooo00<000000?ooo`3oool00P3oool^08[o02`0/ol0:02:o`0=063o00H0=ol0100=o`001000oa/0
0?m5003oA@00ol450?l000040?l0O03o0:H0o`000?l00080H03o00<0=`3o0600o`3M0?l0B03o0004
0?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo<`2:o`0Q0;?o
02d0R_l03@1Po`0703Oo00<03Ol000<00?lK003oA@3o00001`3o0000103o0:H0o`3i0?l0n@2c0?l2
08X0o`030600o`2:0?l0/`3o04P0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`00
0000oooo0?ooo`020?ooocX0R_l04`2co`0c08[o00h0H?l01P0go`0300go0003003o6`00odD00?m^
00P0o`0000<0o`3?0?l0n@3M0?l00`2c0?l00`2:0?l0/`3o0=d0o`020?l0cdH0o`00103oool00`00
0000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`03063o002:o`00R_l007/0
R_l03`1Po`0603Oo00803Ol00P00oa/00`00odD0o`000?l000080?l000040?l0YP3o0?T0g@3o0=d0
o`<0/`3o00<0g@3o0?l0n@3o0000A`3o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`03
0000003oool0oooo0080oooo00<0H?l008[o002:o`00N`2:o`0?063o00H0=ol00P0=o`02003o6`03
003oA@3o0000o`0000P0o`0000@0o`2V0?l0n@3M0?l0g@3o0`2c0?l00`3M0?l0o`3i0?l000170?l0
00@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3oool2063o07/0
R_l03`1Po`0603Oo00803Ol000<00?lK003oA@00odD00P3o00000`3o07`0o`000?l000070?l00003
0?l0c`3o0?T0o`3i00@0o`3i00<0o`1l0?l0003o0000AP3o00040?ooo`030000003oool0oooo00H0
oooo000K0?ooo`8000000`3oool4063o07L0R_l0401Po`0603Oo00<03Ol000<00?lK003oKP00ofh0
3@3o00000`3o07`0o`2V0?l0YP030?l0YTT0o`000`3oool2000000P0oooo000K0?ooo`030000003o
ool0oooo0080oooo1@1Po`1d08[o0100H?l0200go`0200go0003003o6`00odD0o`0005d0o`00103o
ool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`H0H?l0L@2:o`0A
063o00L0=ol0100=o`000`00oa/00?m50?l0001M0?l000@0oooo00<000000?ooo`3oool01P3oool0
01/0oooo00<000000?ooo`3oool00P3oool6063o0740R_l04@1Po`0703Oo00@03Ol000<00?lK003o
A@3o0000G@3o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080
oooo1`1Po`1_08[o0140H?l01`0go`0400go00800?lK00<00?m5003o`@00ol40G03o00040?ooo`03
0000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo2P1Po`1Y08[o01<0H?l0
200go`0400go0003003o6`00odD00?m^00800?nHG03o00040?ooo`030000003oool0oooo00H0oooo
000K0?ooo`030000003oool0oooo0080oooo2`1Po`1W08[o01@0H?l01`0go`0400go0003003o6`00
odD00?m^00<0o`0000<03@3o03L0o`3o0000F@3o00040?ooo`030000003oool0oooo00H0oooo000K
0?ooo`030000003oool0oooo0080oooo3@1Po`1S08[o01@0H?l0200go`0300go00800?lK00@00?m5
003oV03o0000o`000P3o0:H00`3o0<l0RP3o0=d0o`1I0?l000@0oooo00<000000?ooo`3oool01P3o
ool001/0oooo00<000000?ooo`3oool00P3oool@063o05d0R_l05P1Po`0803Oo00<03Ol000@00?lK
003oA@00odD00?nH0`3o00020?l0YP030?l0n@3M0?l0o`3i05T0o`00103oool00`000000oooo0?oo
o`060?ooo`006`3oool2000000<0oooo401Po`1M08[o01H0H?l0200go`0300go0004003o6`00odD0
0?m5003oV0<0o`000P3o0:H00`3o0?T0g@3o0?l0n@1I0?l000<0oooo0P0000080?ooo`006`3oool0
0`000000oooo0?ooo`020?oooa80H?l0F@2:o`0G063o00T0=ol00P0=o`02003o6`800?m^1P3o0002
0?l0YP030?l0D`3o0000o`0005L0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`00
0000oooo0?ooo`020?oooaD0H?l0D`2:o`0I063o00P0=ol0100=o`000`00oa/00?m50?l0001S0?l0
00@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3ooolH063o04d0
R_l06`1Po`0803Oo00@03Ol00P00oa/00`00odD0o`000?l0001R0?l000@0oooo00<000000?ooo`3o
ool01P3oool001/0oooo00<000000?ooo`3oool00P3ooolK063o04H0R_l07@1Po`0:03Oo00@03Ol0
0P00oa/00`00ofh0o`000?l0001R0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<0
00000?ooo`3oool00P3ooolN063o0400R_l07`1Po`0:03Oo00@03Ol00P00oa/01@00odD00?m^003o
`@00ol4001_o0640o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?oo
o`020?oooah0H?l0@02:o`0O063o00X0=ol0100=o`02003o6`05003oA@00ofh00?o1003o`@006ol0
H@3o00040?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo8`1P
o`0g08[o0240H?l02`0go`0500go00800?lK00H00?m50?l0003o0000o`000?l0c`3M0?mP0?l000@0
oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3ooolY063o02/0R_l0
9@1Po`0=03Oo00<03Ol00`00oa/00`00odD00?nH0?l000020?l00080o`2VH03o00040?ooo`030000
003oool0oooo00H0oooo000K0?ooo`030000003oool0oooo0080oooo<@1Po`0J08[o02d0H?l0300g
o`0500go00<00?lK00<00?m50?l0003o0000I03o00040?ooo`030000003oool0oooo00H0oooo000K
0?ooo`8000000`3ooomf063o00d0=ol01P0=o`02003o6`03003oA@00ofh0o`0006D0o`000`3oool2
000000P0oooo000K0?ooo`030000003oool0oooo0080ooooMP1Po`0=03Oo00H03Ol00P00oa/00`00
odD00?m^0?l0001U0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3o
ool00P3ooome063o00d0=ol01P0=o`03003o6`03003oA@00ofh00<7o06D0o`00103oool00`000000
oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooog80H?l0400go`0600go00<00?lK
00@00?m5003oKP3o0000o`000P3o0:IR0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo
00<000000?ooo`3oool00P3oool00`0go`00H?l0063o001]063o0140=ol01P0=o`04003o6`03003o
A@00oiP0o`0006D0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?oo
o`020?ooo`D0=ol0I`1Po`0D03Oo00L03Ol00P00oa/3003oA@03003oj`3o0000o`0006@0o`00103o
ool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`L0=ol0H`1Po`0C
03Oo00T03Ol00`00oa/2003oA@03003oKP00oiP0o`0006D0o`00103oool00`000000oooo0?ooo`06
0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`L0=ol0H`1Po`0C03Oo00T03Ol00`00oa/2003o
A@03003oKP00oiP0o`0006D0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`X0=ol0F`1Po`0G03Oo00X03Ol00`00oa/2003oA@04003oKP00oiP0o`000?l0
YV@0o`00103oool00`000000oooo0?ooo`060?ooo`006`3oool00`000000oooo0?ooo`020?ooo`d0
=ol0E01Po`0H03Oo00/03Ol01@00oa/2003oA@03003oKP00oiP0o`0006D0o`00103oool00`000000
oooo0?ooo`060?ooo`006`3oool2000000<0oooo4@0go`1:063o01d0=ol02`0=o`05003o6`<00?m5
00<00?m^003oV03o0000I@3o00030?ooo`800000203oool001/0oooo00<000000?ooo`3oool00P3o
oolE03Oo0400H?l0800go`0=00go00H00?lK0`00odD01000ofh00?nH0031o`3o05=T0?l000@0oooo
00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3ooolJ03Oo03<0H?l0900g
o`0@00go00H00?lK1000odD00`00ofh00?nH0031o`1U0?l000@0oooo00<000000?ooo`3oool01P3o
ool001/0oooo00<000000?ooo`3oool00P3ooolJ03Oo03<0H?l0900go`0@00go00H00?lK1000odD0
0`00ofh00?nH0031o`1U0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?oo
o`3oool00P3ooolQ03Oo0280H?l0:P0go`0A00go00T00?lK1000odD01000ofh00?nH003o`@0g0?mT
0?l000@0oooo00<000000?ooo`3oool01P3oool001/0oooo00<000000?ooo`3oool00P3ooomW03Oo
01D03Ol02000oa/5003oA@<00?m^00<00?nH003o`@2:0?l0I03o00040?ooo`030000003oool0oooo
00H0oooo000K0?ooo`030000003oool0oooo0080oooo00<03Ol003Oo000go`00G`0go`0E00go00`0
0?lK1P00odD3003oKP03003oV000ol400?o[06@0o`00103oool00`000000oooo0?ooo`060?ooo`00
6`3oool00`000000oooo0?ooo`020?ooo`D03Ol0E`0go`0E00go01000?lK1`00odD4003oKP03003o
V000ol400?o[06@0o`00103oool00`000000oooo0?ooo`060?ooo`00203oool2000000@0oooo0P00
00050?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`D03Ol0E`0go`0E00go01000?lK1`00
odD4003oKP03003oV000ol400?o[06@0o`00103oool00`000000oooo0?ooo`060?ooo`001`3oool0
10000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool700go04l0=ol05@0=o`0>003o6`d00?m51@00ofh2003oV0800?o10P00jomR0?l000@0oooo00<0
00000?ooo`3oool01P3oool000L0oooo00@000000?ooo`3oool00000203oool5000000<0oooo0P00
00030?ooo`/03Ol0A00go`0E00go00`00?lK4@00odD8003oKP@00?nH0P00ol42003oj`030031o`3o
0000o`0005l0o`000`3oool2000000P0oooo00070?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`3i0?ooo`030000003oool0oooo00H0oooo
00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`3i0?ooo`030000003oool0oooo00H0oooo00080?ooo`8000002`3oool2000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00D0
00000?ooo`3oool0oooo000000080?ooo`006`3oooom000000P0oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.552709, -0.157803, \
0.00164623, 0.00205779}}]
}, Open  ]],

Cell[BoxData[
    \(TraditionalForm\`\(juliaC1 = 
        Compile[{x, y, lim, cx, 
            cy}, \[IndentingNewLine]Module[{z, 
              ct = 0}, \[IndentingNewLine]z = 
              x + I\ y; \[IndentingNewLine]While[
              Abs[z] < 90.0 && ct < lim, \[IndentingNewLine]z = 
                Cos[z]\ \((cx + 
                      I\ cy)\); \[IndentingNewLine]\(++ct\)]; \
\[IndentingNewLine]ct]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(gr11 = 
        DensityPlot[\(-juliaC1[x, y, 90, 
              3.96,  .01]\), \[IndentingNewLine]{x, \(-3.5\), 
            3.5}, {y, \(-3.5\), 3.5}, PlotPoints \[Rule] 200, Mesh -> False, 
          ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.137363 0.5 0.137363 [
[.08791 -0.0125 -6 -9 ]
[.08791 -0.0125 6 0 ]
[.22527 -0.0125 -6 -9 ]
[.22527 -0.0125 6 0 ]
[.36264 -0.0125 -6 -9 ]
[.36264 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.63736 -0.0125 -3 -9 ]
[.63736 -0.0125 3 0 ]
[.77473 -0.0125 -3 -9 ]
[.77473 -0.0125 3 0 ]
[.91209 -0.0125 -3 -9 ]
[.91209 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08791 -12 -4.5 ]
[-0.0125 .08791 0 4.5 ]
[-0.0125 .22527 -12 -4.5 ]
[-0.0125 .22527 0 4.5 ]
[-0.0125 .36264 -12 -4.5 ]
[-0.0125 .36264 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .63736 -6 -4.5 ]
[-0.0125 .63736 0 4.5 ]
[-0.0125 .77473 -6 -4.5 ]
[-0.0125 .77473 0 4.5 ]
[-0.0125 .91209 -6 -4.5 ]
[-0.0125 .91209 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08791 0 m
.08791 .00625 L
s
[(-3)] .08791 -0.0125 0 1 Mshowa
.22527 0 m
.22527 .00625 L
s
[(-2)] .22527 -0.0125 0 1 Mshowa
.36264 0 m
.36264 .00625 L
s
[(-1)] .36264 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.63736 0 m
.63736 .00625 L
s
[(1)] .63736 -0.0125 0 1 Mshowa
.77473 0 m
.77473 .00625 L
s
[(2)] .77473 -0.0125 0 1 Mshowa
.91209 0 m
.91209 .00625 L
s
[(3)] .91209 -0.0125 0 1 Mshowa
.125 Mabswid
.11538 0 m
.11538 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.17033 0 m
.17033 .00375 L
s
.1978 0 m
.1978 .00375 L
s
.25275 0 m
.25275 .00375 L
s
.28022 0 m
.28022 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.33516 0 m
.33516 .00375 L
s
.39011 0 m
.39011 .00375 L
s
.41758 0 m
.41758 .00375 L
s
.44505 0 m
.44505 .00375 L
s
.47253 0 m
.47253 .00375 L
s
.52747 0 m
.52747 .00375 L
s
.55495 0 m
.55495 .00375 L
s
.58242 0 m
.58242 .00375 L
s
.60989 0 m
.60989 .00375 L
s
.66484 0 m
.66484 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.71978 0 m
.71978 .00375 L
s
.74725 0 m
.74725 .00375 L
s
.8022 0 m
.8022 .00375 L
s
.82967 0 m
.82967 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.06044 0 m
.06044 .00375 L
s
.03297 0 m
.03297 .00375 L
s
.00549 0 m
.00549 .00375 L
s
.93956 0 m
.93956 .00375 L
s
.96703 0 m
.96703 .00375 L
s
.99451 0 m
.99451 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08791 m
.00625 .08791 L
s
[(-3)] -0.0125 .08791 1 0 Mshowa
0 .22527 m
.00625 .22527 L
s
[(-2)] -0.0125 .22527 1 0 Mshowa
0 .36264 m
.00625 .36264 L
s
[(-1)] -0.0125 .36264 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .63736 m
.00625 .63736 L
s
[(1)] -0.0125 .63736 1 0 Mshowa
0 .77473 m
.00625 .77473 L
s
[(2)] -0.0125 .77473 1 0 Mshowa
0 .91209 m
.00625 .91209 L
s
[(3)] -0.0125 .91209 1 0 Mshowa
.125 Mabswid
0 .11538 m
.00375 .11538 L
s
0 .14286 m
.00375 .14286 L
s
0 .17033 m
.00375 .17033 L
s
0 .1978 m
.00375 .1978 L
s
0 .25275 m
.00375 .25275 L
s
0 .28022 m
.00375 .28022 L
s
0 .30769 m
.00375 .30769 L
s
0 .33516 m
.00375 .33516 L
s
0 .39011 m
.00375 .39011 L
s
0 .41758 m
.00375 .41758 L
s
0 .44505 m
.00375 .44505 L
s
0 .47253 m
.00375 .47253 L
s
0 .52747 m
.00375 .52747 L
s
0 .55495 m
.00375 .55495 L
s
0 .58242 m
.00375 .58242 L
s
0 .60989 m
.00375 .60989 L
s
0 .66484 m
.00375 .66484 L
s
0 .69231 m
.00375 .69231 L
s
0 .71978 m
.00375 .71978 L
s
0 .74725 m
.00375 .74725 L
s
0 .8022 m
.00375 .8022 L
s
0 .82967 m
.00375 .82967 L
s
0 .85714 m
.00375 .85714 L
s
0 .88462 m
.00375 .88462 L
s
0 .06044 m
.00375 .06044 L
s
0 .03297 m
.00375 .03297 L
s
0 .00549 m
.00375 .00549 L
s
0 .93956 m
.00375 .93956 L
s
0 .96703 m
.00375 .96703 L
s
0 .99451 m
.00375 .99451 L
s
.25 Mabswid
0 0 m
0 1 L
s
.08791 .99375 m
.08791 1 L
s
.22527 .99375 m
.22527 1 L
s
.36264 .99375 m
.36264 1 L
s
.5 .99375 m
.5 1 L
s
.63736 .99375 m
.63736 1 L
s
.77473 .99375 m
.77473 1 L
s
.91209 .99375 m
.91209 1 L
s
.125 Mabswid
.11538 .99625 m
.11538 1 L
s
.14286 .99625 m
.14286 1 L
s
.17033 .99625 m
.17033 1 L
s
.1978 .99625 m
.1978 1 L
s
.25275 .99625 m
.25275 1 L
s
.28022 .99625 m
.28022 1 L
s
.30769 .99625 m
.30769 1 L
s
.33516 .99625 m
.33516 1 L
s
.39011 .99625 m
.39011 1 L
s
.41758 .99625 m
.41758 1 L
s
.44505 .99625 m
.44505 1 L
s
.47253 .99625 m
.47253 1 L
s
.52747 .99625 m
.52747 1 L
s
.55495 .99625 m
.55495 1 L
s
.58242 .99625 m
.58242 1 L
s
.60989 .99625 m
.60989 1 L
s
.66484 .99625 m
.66484 1 L
s
.69231 .99625 m
.69231 1 L
s
.71978 .99625 m
.71978 1 L
s
.74725 .99625 m
.74725 1 L
s
.8022 .99625 m
.8022 1 L
s
.82967 .99625 m
.82967 1 L
s
.85714 .99625 m
.85714 1 L
s
.88462 .99625 m
.88462 1 L
s
.06044 .99625 m
.06044 1 L
s
.03297 .99625 m
.03297 1 L
s
.00549 .99625 m
.00549 1 L
s
.93956 .99625 m
.93956 1 L
s
.96703 .99625 m
.96703 1 L
s
.99451 .99625 m
.99451 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08791 m
1 .08791 L
s
.99375 .22527 m
1 .22527 L
s
.99375 .36264 m
1 .36264 L
s
.99375 .5 m
1 .5 L
s
.99375 .63736 m
1 .63736 L
s
.99375 .77473 m
1 .77473 L
s
.99375 .91209 m
1 .91209 L
s
.125 Mabswid
.99625 .11538 m
1 .11538 L
s
.99625 .14286 m
1 .14286 L
s
.99625 .17033 m
1 .17033 L
s
.99625 .1978 m
1 .1978 L
s
.99625 .25275 m
1 .25275 L
s
.99625 .28022 m
1 .28022 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .33516 m
1 .33516 L
s
.99625 .39011 m
1 .39011 L
s
.99625 .41758 m
1 .41758 L
s
.99625 .44505 m
1 .44505 L
s
.99625 .47253 m
1 .47253 L
s
.99625 .52747 m
1 .52747 L
s
.99625 .55495 m
1 .55495 L
s
.99625 .58242 m
1 .58242 L
s
.99625 .60989 m
1 .60989 L
s
.99625 .66484 m
1 .66484 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .71978 m
1 .71978 L
s
.99625 .74725 m
1 .74725 L
s
.99625 .8022 m
1 .8022 L
s
.99625 .82967 m
1 .82967 L
s
.99625 .85714 m
1 .85714 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .06044 m
1 .06044 L
s
.99625 .03297 m
1 .03297 L
s
.99625 .00549 m
1 .00549 L
s
.99625 .93956 m
1 .93956 L
s
.99625 .96703 m
1 .96703 L
s
.99625 .99451 m
1 .99451 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFF0000CC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FF00FF66CC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCCFF00CC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF00FF66CC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCCFF00CC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCCFF00CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FF00FF66CC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF00FF66CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFF00000066FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF00FF66CCFF00CC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FF00FF66CC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFFF0000CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCCFF00CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFFF0000CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF00FF660066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFFF0000CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF0066FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FF00FF66CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCCFF00CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF00FF660066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCCFF00CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF00FF660066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FFFF0000CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFFF0000CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF0066FF0066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FFCCFF00CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF0066FF0066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FFFF000000FF66
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FF00FF6600FF6600FF66CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CCFF000066FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCCFF00CC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF00FF660066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF00FF66CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FFFF000000FF66
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FF0066FF00FF660066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FFFF00000066FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCCFF000066FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFFF000000FF66CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FF00FF66CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCCFF00CC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF0066FF0066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FF0066FFCC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FFCCFF00FF0000FF0000
FF0000CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FF00FF66FF0000CCFF00FF0000CCFF000066FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FF00FF66FF0000FF0000FF00000066FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF00FF660066FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FF0066FFCC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF00FF660066FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF00FF66CC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCCFF00FF0000FF0000FF0000
FF00000066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFFF0000FF0000FF0000FF0000FF0000CCFF00CC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FF0066FFFF0000CCFF00FF0000FF0000CCFF00
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFFF00000066FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FF00FF660066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCCFF0000FF66CC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF00FF660066FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF00FF66CC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FFFF00000066FF
0066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FF0066FFCCFF0000FF660066FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FF0066FFFF0000FF0000CC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FFFF00000066FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FF00FF6600FF6600FF660066FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FFCCFF000066FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF00FF660066FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF00FF66CC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF00FF6600FF660066FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FF00FF66CC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF660066FF00FF66FF000000FF66
0066FF0066FF00FF66CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FF
0066FF0066FFFF0000CCFF0000FF660066FF0066FF0066FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCCFF000066FF0066FF00FF66FF000000FF660066FF
0066FF0066FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FFFF00000066FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FF0066FF00FF6600FF660066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF0066FFCCFF000066FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FF00FF660066FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FF00FF66CC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FFFF00000066FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FFCCFF000066FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF0066FFFF00000066FF
0066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FFCC00FF0066FF00FF6600FF660066FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCCFF0000FF66FF00000066FF0066FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FF0066FF00FF66FF000000FF66
0066FF00FF66CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FF00FF6600FF66FF0000CCFF00CCFF000066FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FFCCFF0000FF66FF000000FF660066FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF0000CCFF00
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FFCC00FF0066FFCCFF00FF00000066FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FFCCFF00CCFF000066FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF00000066FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
CC00FFCC00FF0066FF00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF660066FFCC00FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF00000066FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FFCCFF000066FFCC00FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FF0066FFFF000000FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
CC00FF0066FF0066FFCCFF0000FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF00000066FF0066FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF00FF66FF0000FF0000FF0000CCFF00
FF0000FF000000FF66CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FF
CCFF00FF0000CCFF00FF0000FF0000FF0000CCFF000066FF0066FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FF0066FFFF0000FF0000FF0000FF0000FF0000FF0000
CCFF000066FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFFF000000FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FFCCFF0000FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF00000066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF00000066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FFCCFF0000FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF660066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF00000066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF00FF66FF00000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66CCFF000066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCCFF000066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF00FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF660066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF0000FF0000
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FFCCFF00FF00000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF0000FF000000FF660066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000CC00FFCC00FFFF00000066FF0066FF0066FF00FF6600FF66FF000000FF66
0066FF0066FF0066FF0066FFCCFF000066FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF660066FF0066FF
0066FF00FF6600FF66FF0000FF0000CCFF0000FF66FF00000066FFCCFF000066FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FF0066FF00FF660066FF0066FF00FF660066FFFF0000FF000000FF6600FF66
0066FFFF000000FF66CCFF00CC00FFCC00FFFF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF0000FF66FF0000CCFF00
00FF6600FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FF
0066FFCCFF00CCFF00FF0000FF0000CCFF00FF00000066FF0066FFCC00FFCC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FFCC00FFCC00FFFF000000FF6600FF66FF0000FF000000FF6600FF66
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF000000FF66
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FFFF0000CCFF000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF000000FF660066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF00FF660066FFFF000000FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FFCCFF0000FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF00000066FF00FF66
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF000066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF00FF6600FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF660066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFFF000000FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF00FF6600FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF00000066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF000066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF00FF6600FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF660066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFFF0000FF0000CCFF00
00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CCFF00CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FFFF0000CCFF00CCFF00FF00000066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66CCFF00FF0000FF00000066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF00FF66FF0000CCFF00
0066FF0066FF0066FF0066FF0066FF0066FF0066FFFF0000CC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FF00FF6600FF660066FF0066FF0066FF0066FF
00FF660066FF00FF66FF0000CCFF0000FF660066FFFF00000066FF0066FF00FF660066FF
00FF660066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
FF00000066FF0066FF0066FF0066FF0066FF0066FF0066FFCCFF00FF000000FF660066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FFCC00FF
CC00FFCC00FFCC00FF0066FF00FF66FF000000FF66CCFF00CCFF00CCFF00FF0000FF0000
CCFF00FF0000FF0000FF000000FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF0000FF66
FF000000FF6600FF66FF0000FF000000FF6600FF66CCFF00FF000000FF660066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF00FF66CCFF00FF0000CCFF00CCFF0000FF66FF0000FF0000CCFF0000FF66
CCFF00FF0000FF00000066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF0000FF0000FF0000FF0000
00FF66FF000000FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF
CCFF0000FF6600FF66FF0000FF000000FF6600FF66FF00000066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FFCCFF0000FF6600FF66FF0000FF0000CCFF0000FF66
00FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FFCCFF00FF0000CCFF00
00FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
0066FF0066FF00FF66FF0000FF000000FF660066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66CCFF00FF000000FF660066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF0000FF0000FF0000
00FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FFFF0000FF0000FF0000FF00000066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF0000FF0000FF000000FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF0000CCFF00
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF0066FFCCFF0000FF660066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66CCFF000066FF0066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FFCCFF0000FF66
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF0066FF00FF6600FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF6600FF660066FF0066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFFF0000FF000000FF66
00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF00FF66CCFF00CCFF00CCFF000066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF6600FF66FF000000FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF000000FF66
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF66CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF0066FFCCFF00CCFF000066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66FF000000FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FFFF000000FF66
0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCCFF00
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF0066FFCCFF0000FF660066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66CCFF000066FF0066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66FF0000FF0000
0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFFF0000CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
0066FF00FF66CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
00FF660066FF00FF66CCFF00CCFF0000FF660066FFCCFF000066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FF00FF66CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FF0066FF00FF660066FF0066FFCCFF00CCFF0000FF660066FF
00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FFFF0000FF0000FF0000CCFF00
FF000000FF660066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFFF00000066FF0066FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF
0066FF00FF66CCFF00FF0000FF0000FF000000FF660066FF0066FF0066FF0066FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF00FF66CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF660066FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FFCCFF00FF0000CCFF00FF0000CCFF00CCFF00
0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FFCCFF000066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000FF0000
00FF660066FF0066FF0066FFFF00000066FF0066FF0066FF0066FF00FF6600FF660066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF00FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF00FF66CCFF00FF0000FF000000FF6600FF660066FF0066FF0066FF0066FF0066FF
0066FF00FF6600FF66FF00000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF0000FF00000066FF
0066FF0066FF0066FF00FF660066FF0066FF00FF6600FF66FF0000FF0000CCFF0000FF66
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
00FF66FF0000FF00000066FF00FF6600FF660066FF00FF66CCFF00FF0000FF0000FF0000
FF000000FF660066FF00FF66CCFF000066FF00FF6600FF66FF00000066FF0066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FF0066FF0066FFFF000000FF660066FF00FF66CCFF000066FF
00FF6600FF66FF0000FF0000FF0000FF000000FF660066FF0066FFCCFF000066FF00FF66
00FF66FF00000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFFF0000
CCFF0000FF660066FFFF00000066FF0066FF00FF66FF0000FF0000FF0000FF000000FF66
00FF660066FFCCFF0000FF660066FFCCFF00CCFF0000FF66
0066FF0066FF00FF66CCFF00FF0000CCFF0000FF6600FF66CCFF00FF0000FF0000FF0000
FF000000FF6600FF66FF0000FF0000FF0000CCFF0000FF660066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF00FF0000FF0000FF000000FF66
FF000000FF66CCFF00FF0000FF0000CCFF0000FF66CCFF00CCFF00FF0000FF000000FF66
FF00000066FF00FF66CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF
FF000000FF66FF0000FF0000FF000000FF6600FF66CCFF00FF0000FF0000FF000000FF66
CCFF0000FF66FF0000FF0000CCFF0000FF660066FF0066FF
CC00FF0066FF0066FF0066FFFF0000FF0000CCFF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CCFF00CCFF00CCFF0000FF660066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FFCCFF00CCFF00CCFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FF000000FF660066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
0066FF0066FF00FF66CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CCFF00CCFF00CCFF000066FF0066FF00FF66CC00FF
CC00FF0066FF0066FF00FF6600FF6600FF6600FF6600FF66FF0000FF0000FF0000FF0000
CCFF0000FF66CCFF0000FF6600FF66FF00000066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF660066FF00FF66
00FF6600FF66FF0000FF0000FF0000CCFF0000FF6600FF6600FF660066FF00FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FFCCFF0000FF6600FF6600FF6600FF66CCFF00FF0000FF0000FF0000FF0000
00FF6600FF660066FF00FF660066FF0066FFCC00FFCC00FF
CC00FFCC00FF00FF660066FF0066FF0066FF0066FF00FF66FF0000FF0000FF0000FF0000
FF000000FF660066FF0066FF0066FF0066FF00FF66CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF
00FF66CCFF00FF0000FF0000FF0000FF0000FF000000FF660066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF0000FF0000FF0000FF0000
00FF660066FF0066FF0066FF0066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF0000FF0000
00FF6600FF660066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFFF0000
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
00FF6600FF66CCFF00FF0000FF0000CCFF0000FF660066FF0066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000FF0000CCFF0000FF66
00FF660066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FFFF0000CCFF00FF0000FF0000FF0000
FF0000CCFF0000FF660066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCCFF00CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
00FF66CCFF00CCFF00FF0000FF0000CCFF00CCFF0000FF660066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCCFF00CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF0066FF0066FF00FF66CCFF00CCFF00FF0000FF0000FF0000CCFF00
00FF660066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF00FF66FF0000FF0000CCFF00CCFF00FF0000FF0000
CCFF00CCFF00FF000000FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF0000
CCFF00CCFF00CCFF00FF0000FF0000CCFF00FF0000FF0000CCFF000066FF0066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF00FF66CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF00FF66FF0000FF0000FF0000FF0000FF0000CCFF00CCFF00
CCFF00FF000000FF660066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF0000FF0000
00FF6600FF660066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF00FF66CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
0066FF00FF66CCFF00FF0000FF000000FF6600FF660066FF0066FF0066FF0066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCCFF000066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF00FF66CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF0000CCFF0000FF66
0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66FF000000FF66
00FF660066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFFF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
0066FF0066FF00FF66CCFF00CCFF0000FF660066FF0066FF0066FF0066FF0066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF00FF66CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF0000FF660066FF
0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66FF0000CCFF00
00FF660066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
0066FF0066FF00FF66CCFF00CCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CCFF00CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF0066FF0066FF00FF66FF0000FF000000FF660066FF
0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66FF000000FF66
00FF660066FF0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF00FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FFFF00000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
0066FF0066FF00FF66CCFF0000FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FF0066FFCCFF000066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
00FF66CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF00FF660066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF0000FF660066FF
0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000FF0000
00FF660066FF0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF0000
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF00FF66CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF00FF6600FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCCFF000066FF0066FF0066FF0066FF
0066FF00FF66FF0000FF0000CCFF00CCFF0000FF660066FF0066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FFFF00000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
00FF66CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF00000066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF0066FF0066FF0066FF00FF66CCFF00CCFF00FF0000CCFF0000FF66
0066FF0066FF0066FF0066FF0066FF0066FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FFCCFF0000FF6600FF6600FF6600FF66CCFF00FF0000CCFF00
00FF66FF000000FF6600FF66FF00000066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCCFF0000FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FFFF00000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF0000FF6600FF66
00FF6600FF66CCFF00FF0000FF000000FF6600FF6600FF6600FF66CCFF0000FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF00FF66FF00000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF000000FF660066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF00FF6600FF66CCFF0000FF6600FF6600FF66FF0000FF0000CCFF0000FF66
00FF6600FF6600FF66FF00000066FF0066FFCC00FFCC00FF
CC00FF0066FF0066FF0066FF0066FF00FF66FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CCFF00CCFF000066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF000066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF00FF6600FF6600FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF00FF66
CCFF00FF0000FF0000FF0000FF0000FF0000FF0000CCFF0000FF660066FF0066FF0066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF00FF6600FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CCFF00CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF6600FF660066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
0066FF0066FF0066FF0066FF00FF66CCFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FF6600FF660066FF0066FF0066FF0066FFCC00FF
0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF6600FF66FF0000FF0000FF0000
00FF6600FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66CCFF000066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FFCCFF00FF00000066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
FF000000FF66CCFF00FF0000FF0000CCFF0000FF6600FF660066FF0066FF0066FF0066FF
0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF0066FFFF000000FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF00000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF00000066FF0066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000FF0000CCFF0000FF66
FF00000066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000FF0000
00FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF6600FF66CCFF000066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF660066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF00FF6600FF6600FF660066FF0066FF0066FF0066FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
00FF6600FF66CCFF00FF0000FF0000CCFF0000FF660066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF
0066FF00FF6600FF6600FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
CCFF000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF6600FF6600FF66
0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000FF0000CCFF0000FF66
00FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000CCFF00
00FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF660066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66FF000000FF660066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF00000066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FFFF0000FF000000FF660066FF0066FF0066FF00FF660066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
00FF6600FF66CCFF00FF0000CCFF0000FF6600FF660066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF00FF66FF000000FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
CCFF000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF000000FF66
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF660066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000FF000000FF66
00FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF6600FF66FF000000FF66
00FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FFFF00000066FF0066FF0066FFCCFF00FF00000066FF0066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF000066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF00FF66CCFF0000FF660066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FFCCFF000066FF0066FF0066FF0066FF0066FF0066FF0066FF
00FF6600FF6600FF66FF0000FF000000FF6600FF660066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF00FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF00FF66CCFF000066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
CCFF000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF6600FF66
0066FF0066FF0066FF00FF660066FF0066FF0066FF0066FF0066FF00FF660066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF000000FF6600FF66
00FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000CCFF00
00FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF0066FFFF00000066FF0066FF
0066FF0066FF0066FF0066FF00FF66FF000000FF6600FF66CCFF0000FF660066FF0066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF00000066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF00FF66CCFF0000FF6600FF6600FF660066FF0066FF
0066FF0066FF0066FF0066FF00FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF
00FF6600FF66FF0000FF0000CCFF0000FF6600FF66CCFF000066FF0066FF0066FF0066FF
0066FF0066FF00FF6600FF660066FF0066FF0066FF0066FF0066FF0066FFFF000000FF66
00FF66FF000000FF660066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF
FF000000FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66FF0000
FF000000FF66FF00000066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF660066FF
0066FF0066FF0066FF0066FF0066FF00FF6600FF6600FF66CCFF00FF0000FF000000FF66
00FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF
CCFF000066FF0066FF0066FF0066FF0066FF00FF6600FF6600FF66CCFF00FF0000CCFF00
00FF6600FF6600FF660066FF0066FF0066FF0066FF0066FF00FF66CCFF000066FF0066FF
0066FF0066FF0066FF0066FF0066FFCCFF00CCFF00FF0000CCFF0000FF660066FF0066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF660066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF0066FF0066FF00FF66FF0000CCFF00FF000000FF660066FF0066FF
0066FF0066FF0066FF0066FF00FF66CCFF000066FF0066FF0066FF0066FF0066FF0066FF
00FF6600FF66FF0000FF0000FF0000CCFF0000FF6600FF660066FF0066FF0066FF0066FF
0066FF00FF66CCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF00FF66FF0000
CCFF00FF000000FF660066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF
CCFF000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66FF0000
FF0000FF0000CCFF000066FF0066FF0066FF0066FF0066FF0066FF0066FFFF000000FF66
0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000FF0000FF000000FF66
00FF660066FF0066FF0066FF0066FF0066FF0066FF00FF66
CCFF0000FF6600FF660066FF0066FF00FF6600FF6600FF6600FF66CCFF00FF0000CCFF00
00FF6600FF6600FF6600FF660066FF0066FF0066FF00FF66FF000000FF660066FF0066FF
0066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000FF0000FF000000FF66FF0000
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF00FF000000FF660066FF0066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FFFF0000CCFF00FF0000FF0000FF000000FF6600FF660066FF0066FF
0066FF0066FF0066FF0066FF00FF66FF000000FF6600FF660066FF0066FF00FF6600FF66
00FF6600FF6600FF66FF0000CCFF0000FF6600FF6600FF6600FF6600FF660066FF0066FF
00FF66FF0000CCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF00FF66CCFF00
FF0000FF0000FF0000CCFF00CCFF000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66
FF0000CCFF000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFFF0000FF0000FF0000FF0000
FF0000CCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000
00FF660066FF0066FF00FF6600FF6600FF6600FF6600FF66CCFF00FF000000FF6600FF66
00FF6600FF6600FF660066FF0066FF00FF6600FF66CCFF00
FF000000FF66CCFF0000FF6600FF6600FF6600FF6600FF6600FF66CCFF00FF0000CCFF00
00FF6600FF6600FF6600FF6600FF6600FF66CCFF0000FF66CCFF0000FF6600FF660066FF
0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF000000FF6600FF660066FF0066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66CCFF000066FF0066FF0066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000FF000000FF660066FF0066FF
0066FF0066FF0066FF0066FF00FF66CCFF0000FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF66CCFF00FF0000CCFF0000FF6600FF6600FF66FF000000FF6600FF6600FF66
00FF66CCFF00CCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF00FF66FF0000
FF0000CCFF0000FF6600FF660066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF
CCFF000066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF00FF66CCFF00
FF0000FF000000FF6600FF660066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000
00FF6600FF6600FF6600FF66FF000000FF6600FF6600FF66FF0000FF0000CCFF0000FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FF66FF0000
FF0000FF000000FF6600FF6600FF6600FF66FF0000CCFF00CCFF00FF0000FF0000CCFF00
CCFF00CCFF00FF000000FF6600FF6600FF6600FF66FF0000FF000000FF6600FF6600FF66
0066FF0066FF0066FFCCFF0000FF6600FF66CCFF00CCFF00CCFF000066FF0066FF0066FF
0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF0066FFFF0000FF000000FF660066FFCCFF000066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
0066FF0066FF0066FF0066FF0066FFFF000000FF66CCFF00CCFF0000FF6600FF660066FF
0066FF0066FF0066FF00FF6600FF66CCFF00FF0000CCFF0000FF6600FF6600FF66CCFF00
CCFF00CCFF00FF0000FF0000FF0000CCFF00CCFF00CCFF00CCFF0000FF6600FF6600FF66
FF0000FF0000CCFF0000FF6600FF660066FF0066FF0066FF0066FF00FF6600FF66CCFF00
CCFF0000FF6600FF660066FF0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF660066FF00FF66
FF000000FF660066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66
CCFF00CCFF0000FF6600FF6600FF660066FF0066FF0066FF00FF6600FF66CCFF00FF0000
FF000000FF6600FF6600FF66CCFF00FF0000CCFF00CCFF00FF0000FF0000FF0000CCFF00
CCFF00FF000000FF6600FF6600FF66CCFF00FF0000FF0000
FF0000FF0000CCFF0000FF6600FF6600FF66CCFF00FF0000CCFF00FF0000FF0000FF0000
CCFF00FF0000CCFF0000FF6600FF6600FF66CCFF00FF0000FF0000FF000000FF6600FF66
00FF6600FF6600FF6600FF66FF0000CCFF00FF000000FF6600FF660066FF0066FF0066FF
0066FF0066FF0066FF00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF0066FF0066FFCCFF00FF0000FF0000FF0000FF00000066FF0066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF0000FF000000FF6600FF66
00FF6600FF6600FF6600FF6600FF66CCFF00FF0000FF000000FF6600FF6600FF66CCFF00
FF0000CCFF00FF0000FF0000FF0000CCFF00FF0000FF0000CCFF0000FF6600FF6600FF66
CCFF00FF0000CCFF0000FF6600FF6600FF6600FF6600FF6600FF6600FF66CCFF00FF0000
CCFF0000FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FFCCFF00FF0000
FF0000FF000000FF660066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF00FF660066FF0066FF0066FF0066FF0066FF0066FF00FF66
00FF66FF0000FF000000FF6600FF6600FF66FF000000FF6600FF6600FF66CCFF00FF0000
FF000000FF6600FF6600FF66CCFF00FF0000FF0000CCFF00FF0000FF0000FF0000CCFF00
FF0000CCFF0000FF6600FF6600FF66CCFF00FF0000FF0000
CCFF00FF0000CCFF00CCFF00CCFF00CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CCFF00CCFF0000FF6600FF66CCFF00FF0000CCFF00CCFF0000FF6600FF66
00FF6600FF6600FF6600FF6600FF66FF0000FF0000FF0000CCFF000066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
00FF660066FF0066FF0066FF0066FF00FF66CCFF00FF000000FF660066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000FF0000CCFF0000FF6600FF66
00FF66CCFF0000FF6600FF6600FF66CCFF00FF0000CCFF00CCFF00CCFF00CCFF00CCFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00CCFF0000FF6600FF66CCFF00
CCFF00FF0000CCFF0000FF6600FF6600FF66FF000000FF6600FF6600FF66CCFF00FF0000
FF0000CCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66
FF0000CCFF0000FF660066FF0066FF0066FF0066FFFF00000066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66
FF0000FF0000CCFF0000FF6600FF6600FF66CCFF0000FF6600FF6600FF66CCFF00FF0000
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CCFF00CCFF0000FF66FF0000CCFF00FF0000CCFF00
FF0000FF0000FF0000CCFF00CCFF00CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CCFF00CCFF00CCFF00CCFF00FF0000FF0000FF0000FF000000FF6600FF66
00FF66CCFF0000FF6600FF66CCFF00CCFF00CCFF0000FF6600FF6600FF660066FF0066FF
0066FF00FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF0000FF660066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
FF00000066FF0066FF0066FF00FF6600FF6600FF66CCFF00FF0000CCFF0000FF6600FF66
00FF66CCFF0000FF6600FF6600FF66FF0000FF0000FF0000CCFF00CCFF00CCFF00CCFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00CCFF00FF0000CCFF00CCFF00
FF0000FF0000CCFF0000FF6600FF6600FF66FF000000FF6600FF6600FF66CCFF00FF0000
CCFF0000FF6600FF660066FF0066FF0066FF0066FFFF00000066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66
FF000000FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FFCCFF0000FF660066FF0066FF0066FF00FF6600FF66
00FF66CCFF00CCFF0000FF6600FF6600FF66FF000000FF6600FF6600FF66CCFF00FF0000
FF0000CCFF00CCFF00FF0000CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CCFF00CCFF00CCFF00CCFF00FF0000FF0000CCFF00
CCFF00FF0000FF0000CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CCFF00FF0000FF0000CCFF00CCFF00CCFF00CCFF00
CCFF00FF0000CCFF00CCFF00CCFF00FF0000FF000000FF6600FF6600FF6600FF6600FF66
00FF66FF000000FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF00FF660066FF0066FF0066FF00FF66FF0000FF0000FF000000FF660066FF0066FF
0066FF00FF660066FF0066FF0066FF0066FF00FF660066FF0066FF0066FF0066FF0066FF
00FF6600FF66CCFF0000FF6600FF6600FF6600FF66CCFF00FF0000CCFF00CCFF00CCFF00
FF0000FF0000CCFF00CCFF00CCFF00CCFF00FF0000FF0000CCFF00CCFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00CCFF00
FF0000FF0000CCFF00CCFF00CCFF00FF0000FF0000FF0000CCFF00CCFF00FF0000FF0000
CCFF0000FF6600FF6600FF6600FF6600FF66CCFF0000FF660066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FFCCFF000066FF0066FF0066FF00FF66FF0000
FF0000FF000000FF660066FF0066FF0066FFCCFF000066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF00FF66FF000000FF6600FF6600FF6600FF6600FF66
00FF66CCFF00FF0000CCFF00CCFF00CCFF00FF0000FF0000CCFF00CCFF00CCFF00FF0000
FF0000FF0000CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CCFF00CCFF00FF0000FF0000CCFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FF0000CCFF00
FF0000FF0000CCFF00FF0000FF0000FF0000CCFF00CCFF00FF0000FF000000FF6600FF66
FF0000CCFF0000FF660066FF0066FF0066FF0066FFCCFF000066FF0066FF0066FF0066FF
0066FFCCFF0000FF6600FF6600FF6600FF66CCFF00FF000000FF6600FF6600FF6600FF66
00FF6600FF660066FF0066FF0066FF0066FFCCFF000066FF0066FF0066FF0066FF0066FF
00FF66FF0000CCFF0000FF6600FF66CCFF00CCFF00FF0000FF0000FF0000FF0000CCFF00
FF0000FF0000CCFF00CCFF00FF0000CCFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CCFF00FF0000CCFF00CCFF00FF0000CCFF00CCFF00FF0000FF0000FF0000
FF0000CCFF00FF000000FF6600FF66CCFF00FF000000FF660066FF0066FF0066FF0066FF
0066FF00FF660066FF0066FF0066FF0066FF00FF6600FF6600FF6600FF6600FF6600FF66
FF000000FF6600FF66CCFF0000FF6600FF66CCFF000066FF0066FF0066FF0066FF0066FF
00FF660066FF0066FF0066FF0066FF00FF66CCFF00CCFF0000FF6600FF66FF0000CCFF00
CCFF00FF0000FF0000FF0000CCFF00CCFF00FF0000CCFF00CCFF00FF0000CCFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FF0000FF0000CCFF00CCFF00
FF000000FF6600FF660066FF0066FF0066FF0066FF00FF6600FF660066FF0066FF0066FF
00FF66FF0000FF000000FF66CCFF00CCFF00CCFF00FF0000FF0000CCFF0000FF6600FF66
FF000000FF660066FF0066FF0066FF0066FF00FF6600FF660066FF0066FF0066FF00FF66
00FF66CCFF00FF0000CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CCFF00FF0000CCFF00CCFF00CCFF00CCFF0000FF6600FF660066FF0066FF0066FF
00FF6600FF660066FF0066FF0066FF0066FF00FF66FF000000FF6600FF66CCFF00CCFF00
FF0000CCFF00CCFF00CCFF0000FF66FF0000CCFF0000FF660066FF0066FF0066FF00FF66
00FF660066FF0066FF0066FF0066FF00FF6600FF66FF0000CCFF00CCFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CCFF00CCFF0000FF66CCFF0000FF6600FF66CCFF0000FF66CCFF0000FF6600FF66
00FF66CCFF00FF0000FF0000CCFF00FF0000FF0000FF0000FF0000FF0000CCFF00CCFF00
FF000000FF66CCFF0000FF6600FF6600FF66CCFF0000FF6600FF6600FF6600FF6600FF66
FF0000CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CCFF0000FF6600FF6600FF6600FF6600FF66
00FF66CCFF0000FF6600FF6600FF66CCFF0000FF66FF0000CCFF00CCFF00FF0000FF0000
FF0000FF0000FF0000CCFF00CCFF00FF0000CCFF0000FF6600FF6600FF66FF000000FF66
CCFF0000FF6600FF66CCFF0000FF66CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CCFF00FF000000FF66FF0000FF0000FF0000CCFF00CCFF0000FF66
CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CCFF00CCFF0000FF66FF0000FF0000FF0000FF0000CCFF00CCFF00CCFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00CCFF0000FF66FF0000
FF0000FF0000FF000000FF66CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00CCFF00CCFF00CCFF00FF0000
FF0000FF0000CCFF00FF0000CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CCFF00FF0000CCFF00FF0000FF0000FF0000CCFF00CCFF00CCFF00
CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CCFF00CCFF0000FF66FF0000FF0000FF0000FF000000FF66CCFF00CCFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00CCFF00CCFF00FF0000
FF0000FF0000FF000000FF66CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF0000FF66CCFF00CCFF00FF0000
FF0000FF000000FF66FF0000CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CCFF00CCFF0000FF66CCFF0000FF6600FF66CCFF0000FF66FF000000FF6600FF66
00FF66CCFF00FF0000CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000CCFF00CCFF00
FF000000FF66CCFF0000FF6600FF6600FF66CCFF0000FF6600FF6600FF6600FF6600FF66
00FF66CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FF000000FF6600FF6600FF6600FF66
00FF66CCFF0000FF6600FF6600FF66CCFF0000FF66FF0000CCFF00CCFF00FF0000FF0000
FF0000FF0000FF0000CCFF00FF0000FF0000CCFF0000FF6600FF6600FF66CCFF0000FF66
CCFF0000FF6600FF66CCFF0000FF66CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00CCFF00
FF000000FF6600FF660066FF0066FF0066FF0066FF00FF6600FF660066FF0066FF0066FF
00FF66CCFF00FF000000FF66CCFF00CCFF00CCFF00FF0000CCFF00CCFF0000FF6600FF66
FF000000FF660066FF0066FF0066FF0066FF00FF6600FF660066FF0066FF0066FF00FF66
00FF66CCFF00CCFF00CCFF00CCFF00FF0000CCFF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CCFF00CCFF00FF0000CCFF0000FF6600FF660066FF0066FF0066FF
00FF6600FF660066FF0066FF0066FF0066FF00FF66FF000000FF6600FF66CCFF00FF0000
FF0000CCFF00CCFF00CCFF0000FF66FF0000FF000000FF660066FF0066FF0066FF00FF66
00FF660066FF0066FF0066FF0066FF00FF6600FF66FF0000CCFF00CCFF00FF0000FF0000
CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FF0000CCFF00
CCFF00FF0000CCFF00CCFF00FF0000FF0000FF0000CCFF00CCFF00FF000000FF6600FF66
CCFF00CCFF0000FF660066FF0066FF0066FF0066FF00FF660066FF0066FF0066FF0066FF
0066FFCCFF0000FF6600FF66CCFF0000FF6600FF66FF000000FF6600FF6600FF6600FF66
00FF6600FF660066FF0066FF0066FF0066FF00FF660066FF0066FF0066FF0066FF0066FF
00FF66FF0000CCFF0000FF6600FF66FF0000CCFF00FF0000FF0000FF0000FF0000CCFF00
CCFF00FF0000CCFF00CCFF00FF0000CCFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CCFF00FF0000CCFF00CCFF00FF0000FF0000CCFF00FF0000FF0000FF0000
FF0000CCFF00CCFF0000FF6600FF66CCFF00FF000000FF660066FF0066FF0066FF0066FF
0066FFCCFF000066FF0066FF0066FF0066FF00FF6600FF6600FF6600FF6600FF6600FF66
FF0000CCFF0000FF6600FF6600FF6600FF66CCFF000066FF0066FF0066FF0066FF0066FF
CCFF000066FF0066FF0066FF0066FF00FF66CCFF00FF000000FF6600FF66FF0000FF0000
CCFF00CCFF00FF0000FF0000FF0000CCFF00FF0000FF0000CCFF00FF0000CCFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CCFF00FF0000FF0000CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CCFF00FF0000FF0000FF0000CCFF00CCFF00CCFF00
FF0000FF0000CCFF00CCFF00CCFF00FF0000CCFF0000FF6600FF6600FF6600FF6600FF66
00FF66FF000000FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FFCCFF000066FF0066FF0066FF00FF66FF0000FF0000FF000000FF660066FF0066FF
0066FFCCFF000066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
00FF66CCFF0000FF6600FF6600FF6600FF6600FF66CCFF00FF0000FF0000CCFF00CCFF00
FF0000FF0000FF0000CCFF00CCFF00CCFF00FF0000FF0000CCFF00CCFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00CCFF00
FF0000FF0000CCFF00CCFF00CCFF00CCFF00FF0000FF0000CCFF00CCFF00CCFF00FF0000
CCFF0000FF6600FF6600FF6600FF66CCFF0000FF6600FF660066FF0066FF0066FF0066FF
0066FF00FF660066FF0066FF0066FF0066FF00FF660066FF0066FF0066FF00FF66FF0000
FF0000FF000000FF660066FF0066FF0066FF00FF660066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF00FF66FF000000FF6600FF6600FF6600FF6600FF66
00FF66FF0000FF0000CCFF00CCFF00CCFF00FF0000CCFF00CCFF00CCFF00CCFF00CCFF00
FF0000FF0000CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CCFF00FF0000FF0000CCFF00
CCFF00FF0000FF0000CCFF00CCFF00CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CCFF00CCFF00FF0000CCFF00CCFF00FF0000FF0000CCFF0000FF6600FF66
00FF66FF000000FF6600FF6600FF66CCFF00CCFF0000FF6600FF6600FF660066FF0066FF
0066FF00FF66CCFF000066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF00FF66FF000000FF660066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
FF00000066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000CCFF0000FF6600FF66
00FF66FF000000FF6600FF6600FF66CCFF00FF0000FF0000CCFF00CCFF00FF0000CCFF00
CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00CCFF00CCFF00CCFF00
FF0000FF0000FF000000FF6600FF6600FF66CCFF0000FF6600FF6600FF66CCFF00FF0000
CCFF0000FF6600FF6600FF660066FF0066FF0066FFFF00000066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66
CCFF0000FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF00FF6600FF660066FF0066FF0066FF00FF6600FF66
00FF66CCFF00CCFF00CCFF0000FF6600FF66CCFF0000FF6600FF6600FF66FF0000FF0000
FF0000FF0000CCFF00CCFF00CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CCFF00CCFF00CCFF00CCFF00FF0000FF0000FF0000
CCFF00FF0000CCFF00FF000000FF66CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00FF0000CCFF0000FF6600FF66
00FF66CCFF0000FF6600FF6600FF66CCFF00FF0000FF000000FF6600FF660066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
FF00000066FF0066FF0066FF0066FF00FF66CCFF00FF000000FF660066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000FF0000CCFF0000FF6600FF66
00FF66FF000000FF6600FF6600FF66CCFF00FF0000CCFF00CCFF0000FF6600FF66CCFF00
CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00CCFF00CCFF00CCFF00
CCFF00FF0000CCFF0000FF6600FF6600FF66CCFF0000FF6600FF6600FF66CCFF00FF0000
FF0000CCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66
FF0000CCFF0000FF660066FF0066FF0066FF0066FF00FF660066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FFCCFF00
FF0000FF0000FF000000FF6600FF6600FF6600FF6600FF6600FF6600FF66CCFF00CCFF00
FF0000CCFF0000FF6600FF66CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CCFF00CCFF00CCFF00CCFF00CCFF00FF0000CCFF00
FF0000FF0000CCFF0000FF6600FF6600FF66CCFF00FF0000CCFF00FF0000FF0000FF0000
CCFF00FF0000FF0000CCFF0000FF6600FF6600FF66FF0000FF0000CCFF0000FF6600FF66
00FF66FF000000FF6600FF6600FF66FF0000FF000000FF6600FF660066FF0066FF0066FF
0066FF0066FF0066FF00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF0066FF0066FF00FF66FF0000FF0000FF0000CCFF000066FF0066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000CCFF0000FF6600FF66
00FF6600FF6600FF6600FF6600FF66CCFF00FF0000CCFF0000FF6600FF6600FF66CCFF00
FF0000FF0000CCFF00FF0000FF0000FF0000CCFF00FF0000CCFF0000FF6600FF6600FF66
FF0000FF0000CCFF0000FF6600FF6600FF6600FF6600FF6600FF6600FF66FF0000FF0000
FF000000FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FFFF0000FF0000
FF0000FF0000CCFF000066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF00FF660066FF0066FF0066FF0066FF0066FF0066FF00FF66
00FF66FF0000CCFF00FF000000FF6600FF6600FF6600FF6600FF6600FF66FF0000FF0000
FF0000CCFF0000FF6600FF6600FF66CCFF00FF0000CCFF00FF0000FF0000FF0000CCFF00
FF0000CCFF0000FF6600FF6600FF66CCFF00FF0000FF0000
FF0000FF0000CCFF0000FF6600FF6600FF66FF0000CCFF00CCFF00FF0000FF0000FF0000
CCFF00CCFF00FF0000CCFF0000FF6600FF6600FF66FF0000FF0000CCFF0000FF6600FF66
0066FF0066FF0066FF00FF6600FF6600FF66CCFF00CCFF0000FF6600FF660066FF0066FF
0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF0066FF00FF66FF000000FF660066FF00FF660066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF00CCFF0000FF6600FF660066FF
0066FF0066FF0066FF00FF6600FF66CCFF00FF0000FF000000FF6600FF6600FF66CCFF00
CCFF00CCFF00CCFF00FF0000FF0000FF0000CCFF00CCFF00CCFF0000FF6600FF6600FF66
CCFF00FF0000CCFF0000FF6600FF660066FF0066FF0066FF0066FF00FF6600FF66CCFF00
CCFF0000FF66FF00000066FF0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCCFF000066FF00FF66
FF0000FF00000066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF0066FFCCFF00
CCFF00CCFF0000FF6600FF66CCFF000066FF0066FF0066FF00FF6600FF6600FF66FF0000
FF000000FF6600FF6600FF6600FF66FF0000CCFF00CCFF00CCFF00FF0000FF0000CCFF00
CCFF00FF000000FF6600FF6600FF6600FF66FF0000FF0000
FF000000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66CCFF00FF0000FF0000
00FF6600FF6600FF66FF000000FF6600FF6600FF6600FF66FF0000CCFF0000FF660066FF
0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF0000CCFF0000FF660066FF0066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FFCCFF000066FF0066FF0066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000FF000000FF660066FF0066FF
0066FF0066FF0066FF0066FF00FF66CCFF00CCFF0000FF6600FF6600FF6600FF66FF0000
00FF6600FF6600FF66CCFF00FF0000CCFF0000FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FF66CCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF00FF66FF0000
FF0000CCFF0000FF6600FF660066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF
CCFF0000FF660066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF00FF6600FF66
FF0000FF000000FF6600FF660066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF00
00FF66CCFF0000FF6600FF6600FF6600FF6600FF6600FF66CCFF00FF0000CCFF0000FF66
00FF6600FF6600FF6600FF6600FF66CCFF0000FF66FF0000
CCFF0000FF6600FF660066FF0066FF00FF6600FF6600FF6600FF6600FF66FF0000CCFF00
00FF6600FF6600FF6600FF6600FF660066FF0066FF00FF66FF0000CCFF0000FF660066FF
0066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000FF0000FF0000FF0000FF0000
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF00FF000000FF660066FF0066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FFCCFF00CCFF00FF0000FF0000FF0000CCFF0000FF660066FF0066FF
0066FF0066FF0066FF0066FF00FF66CCFF00FF000000FF660066FF0066FF00FF6600FF66
00FF6600FF6600FF66CCFF00FF000000FF6600FF6600FF6600FF6600FF660066FF0066FF
00FF6600FF66FF000000FF660066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66
FF0000FF0000FF0000CCFF00FF00000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66
FF0000CCFF000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFFF000000FF66FF0000FF0000
FF0000CCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66FF0000
00FF660066FF0066FF0066FF00FF6600FF6600FF6600FF66CCFF00FF0000CCFF0000FF66
00FF6600FF6600FF660066FF0066FF00FF6600FF66CCFF00
00FF660066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF0000FF0000
CCFF0000FF6600FF660066FF0066FF0066FF0066FF0066FF00FF66FF00000066FF0066FF
0066FF0066FF0066FF0066FF0066FFCCFF00FF0000FF0000FF000000FF660066FF0066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF000066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF00FF66FF0000CCFF00FF000000FF660066FF0066FF
0066FF0066FF0066FF0066FF00FF66CCFF0000FF660066FF0066FF0066FF0066FF0066FF
00FF6600FF66CCFF00FF0000FF0000FF000000FF6600FF660066FF0066FF0066FF0066FF
0066FF0066FFCCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF00FF66FF0000
CCFF00FF000000FF660066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF
00FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66CCFF00
FF0000CCFF00CCFF000066FF0066FF0066FF0066FF0066FF0066FF0066FFCCFF0000FF66
0066FF0066FF0066FF0066FF0066FF00FF6600FF6600FF66CCFF00FF0000CCFF0000FF66
00FF6600FF660066FF0066FF0066FF0066FF0066FFCCFF00
0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF0000CCFF00
00FF6600FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF00FF660066FF0066FF
0066FF0066FF0066FF0066FF0066FFFF000000FF66FF0000FF000000FF660066FF0066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF00000066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF00FF66FF000000FF6600FF66FF00000066FF0066FF
0066FF0066FF0066FF0066FF00FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF
CCFF0000FF6600FF66CCFF00FF0000FF000000FF6600FF660066FF0066FF0066FF0066FF
0066FF0066FF00FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66
00FF66CCFF0000FF660066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF
FF000000FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66CCFF00
00FF6600FF66FF000000FF660066FF0066FF0066FF0066FF0066FF0066FFFF00000066FF
0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000CCFF0000FF66
00FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF6600FF66FF0000FF0000
00FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF660066FF
0066FF0066FF0066FF0066FF00FF660066FF0066FF0066FF00FF6600FF660066FF0066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCCFF000066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FFCCFF0000FF660066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF00FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF00FF6600FF66FF0000FF000000FF6600FF6600FF660066FF0066FF0066FF0066FF
0066FF0066FF0066FFCCFF000066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF00FF66CCFF0000FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
CCFF000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FFFF0000CCFF00
0066FF0066FF0066FFFF00000066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF6600FF66FF000000FF6600FF66
00FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF0000CCFF00
00FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF660066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66FF000000FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCCFF000066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF00FF66FF000000FF660066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF00FF6600FF66CCFF00FF0000CCFF0000FF6600FF660066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF660066FF0066FF
0066FF00FF66FF0000FF00000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
FF00000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF000000FF66
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF660066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000CCFF0000FF66
00FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000FF0000
CCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF00FF6600FF6600FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCCFF000066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF00FF6600FF6600FF660066FF0066FF0066FF0066FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF00FF66CCFF00FF0000FF0000CCFF0000FF6600FF660066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF
0066FF00FF6600FF6600FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF0000FF66
00FF660066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF0000CCFF0000FF66
00FF660066FF0066FF0066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF0066FF0066FFFF000000FF66CCFF00FF0000FF0000
CCFF0000FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FFFF000000FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF00FF66FF00000066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF
00FF6600FF66CCFF00FF0000FF0000CCFF0000FF66FF00000066FF0066FF0066FF0066FF
0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF0066FFFF0000CCFF000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF0000FF660066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF
0066FF0066FF0066FF0066FF0066FF00FF6600FF6600FF66FF0000FF0000FF000000FF66
00FF6600FF660066FF0066FF0066FF0066FF0066FF0066FF
CC00FF0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CCFF0000FF660066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF6600FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCCFF00CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF00FF6600FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF00FF66
CCFF00FF0000FF0000FF0000FF0000FF0000FF0000CCFF0000FF660066FF0066FF0066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF00FF6600FF6600FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF000066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF0066FF0066FFCCFF00CCFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF660066FF0066FF0066FF0066FFCC00FF
CC00FFCC00FF0066FF0066FFFF000000FF6600FF6600FF6600FF66CCFF00FF0000FF0000
00FF6600FF6600FF66CCFF0000FF6600FF660066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF0000
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FFFF000000FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66CCFF0000FF66
00FF6600FF6600FF66FF0000FF0000CCFF0000FF6600FF6600FF6600FF66CCFF000066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FFFF00000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66CCFF000066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF0066FFFF000000FF6600FF66FF000000FF66CCFF00FF0000CCFF0000FF66
00FF6600FF6600FF66CCFF000066FF0066FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000CCFF00
CCFF0000FF660066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF0000
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF00FF66CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FFFF00000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
0066FF00FF66CCFF00CCFF00FF0000FF000000FF660066FF0066FF0066FF0066FF0066FF
CCFF00CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF00FF6600FF66CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
00FF66CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF00000066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66FF0000FF0000CCFF0000FF66
0066FF0066FF0066FF0066FF0066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66CCFF0000FF66
00FF660066FF0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
00FF66CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF00FF66CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FFCCFF000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
0066FF0066FF00FF6600FF66CCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FF0066FFFF00000066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66CC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66FF000000FF6600FF66
0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66FF0000FF0000
00FF660066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCCFF00CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
0066FF0066FF00FF66CCFF00CCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF000000FF660066FF
0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66CCFF0000FF66
00FF660066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF00FF66CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF
0066FF0066FF00FF66CCFF00CCFF0000FF660066FF0066FF0066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66FF000000FF6600FF66
0066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000FF0000
00FF6600FF660066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF00FF66CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FFCCFF00CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF
0066FF00FF6600FF66FF0000FF0000CCFF0000FF660066FF0066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF00FF66CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF0000FF000000FF66
00FF660066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF00FF66FF0000CCFF00CCFF00CCFF00FF0000FF0000
FF0000FF0000FF000000FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
00FF66CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF00
FF0000FF0000CCFF00FF0000FF0000CCFF00CCFF00CCFF00FF000000FF660066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF00FF66FF0000CCFF00CCFF00FF0000FF0000CCFF00CCFF00
FF0000FF000000FF660066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000FF0000FF0000
CCFF00CCFF0000FF660066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCCFF00CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
00FF66CCFF00CCFF00FF0000FF0000CCFF00CCFF0000FF660066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCCFF00CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF00FF66CCFF00FF0000FF0000FF0000FF0000CCFF00
FF00000066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF00FF6600FF66CCFF00FF0000FF0000
CCFF0000FF660066FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
0066FF00FF66CCFF00FF0000FF0000CCFF0000FF6600FF660066FF0066FF0066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000CC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF0066FF0066FF0066FF00FF6600FF66FF0000FF0000FF000000FF66
00FF660066FF0066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF0066FF0066FF00FF66FF0000FF0000FF0000FF0000
FF000000FF6600FF660066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FF
00FF66FF0000FF0000FF0000FF0000FF0000CCFF0000FF660066FF0066FF0066FF0066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF00FF660066FF0066FF0066FF0066FF00FF66FF0000FF0000FF0000FF0000FF0000
00FF660066FF0066FF0066FF0066FF00FF66CC00FFCC00FF
CC00FFCC00FF0066FF0066FF00FF660066FF00FF6600FF66FF0000FF0000FF0000FF0000
CCFF0000FF6600FF6600FF6600FF66CCFF000066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF660066FF00FF66
00FF6600FF66CCFF00FF0000FF0000FF000000FF6600FF6600FF660066FF00FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FFFF000000FF6600FF66CCFF0000FF66CCFF00FF0000FF0000FF0000FF0000
00FF6600FF6600FF6600FF6600FF660066FF0066FFCC00FF
CC00FF00FF660066FF0066FFCCFF00CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CCFF00CCFF0000FF660066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66FF0000CCFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CCFF00CCFF00CCFF000066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
0066FF0066FF00FF66CCFF00CCFF00CCFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CCFF00FF0000FF00000066FF0066FF0066FFCC00FF
0066FF0066FF00FF66CCFF00FF0000FF000000FF66CCFF0000FF66FF0000FF0000FF0000
CCFF0000FF6600FF66FF0000FF0000FF000000FF66FF00000066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF00FF660066FFFF000000FF66FF0000FF0000CCFF00
CCFF0000FF66CCFF00FF0000FF0000CCFF0000FF66FF000000FF66FF0000FF0000FF0000
CCFF000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF
00FF66CCFF00FF0000FF0000FF000000FF6600FF66FF0000FF0000FF0000FF0000CCFF00
00FF6600FF66CCFF00FF0000CCFF0000FF660066FF0066FF
00FF66CCFF00CCFF000066FF00FF66CCFF000066FF00FF6600FF66FF0000FF0000FF0000
FF000000FF660066FF0066FFFF00000066FF00FF66CCFF00FF00000066FF0066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FF0066FF0066FFFF000000FF6600FF660066FFCCFF000066FF
0066FF00FF66FF0000FF0000FF0000FF000000FF6600FF660066FFCCFF0000FF660066FF
00FF66FF00000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFFF0000
00FF6600FF660066FFCCFF0000FF660066FF00FF66FF0000FF0000FF0000FF0000CCFF00
00FF660066FF00FF6600FF660066FFFF0000FF000000FF66
0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66CCFF00FF0000FF0000
00FF6600FF660066FF0066FF00FF660066FF0066FF0066FF0066FFFF0000FF00000066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FFFF000000FF6600FF660066FF0066FF0066FF0066FF0066FF
0066FF00FF6600FF66FF0000FF0000CCFF0000FF660066FF0066FF0066FF0066FF0066FF
0066FF0066FF0066FF00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF6600FF660066FF
0066FF0066FF0066FFFF00000066FF0066FF0066FF00FF66FF0000FF0000CCFF0000FF66
0066FF0066FF0066FF0066FF0066FFCCFF000066FF0066FF
CC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FFCCFF00CCFF00FF0000CCFF00
FF0000CCFF000066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF00FF660066FF0066FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF
0066FF00FF66FF0000FF0000FF0000CCFF0000FF660066FF0066FF0066FF0066FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FFFF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF660066FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66FF0000CCFF00FF0000FF0000FF0000
0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF660066FF00FF66CCFF00CCFF00
0066FF0066FF00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF00FF66CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
CC00FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
CCFF000066FF00FF66CCFF00CCFF0000FF660066FF00FF660066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF00FF660066FFCC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFFF0000CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF0066FFFF0000FF000000FF660066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FFCCFF0000FF66
0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF0066FF00FF66CCFF000066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCCFF00CC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66FF00000066FF0066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF000000FF66
0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF0066FFCCFF00CCFF000066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF00FF66FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF000000FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF000000FF66
00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FFCCFF00CCFF00CCFF0000FF660066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF6600FF66FF0000FF00000066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF6600FF66
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF00FF6600FF660066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66CCFF000066FF0066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FFCCFF0000FF66
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FF0066FF00FF66CCFF000066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF00FF000000FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF0000FF0000FF0000
00FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FFFF0000FF0000FF0000FF00000066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF0000FF0000FF000000FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF0066FF00FF66FF0000CCFF00
00FF660066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF
0066FF0066FF00FF66FF0000FF000000FF660066FF0066FF0066FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66CCFF00FF0000CCFF000066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF6600FF66CCFF00FF0000FF0000
00FF6600FF66CCFF000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF
FF000000FF6600FF66FF0000FF000000FF6600FF66CCFF000066FF0066FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FF00FF66FF000000FF66FF0000FF0000FF0000FF0000
00FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FF0066FF0066FFFF0000FF0000CCFF0000FF66CCFF00FF0000FF0000
00FF66CCFF00CCFF00FF0000CCFF0000FF66CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF0000
CCFF0000FF6600FF66FF0000FF000000FF6600FF66FF000000FF66CCFF000066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
CC00FFCC00FF0066FF00FF66FF0000FF0000FF0000CCFF00FF0000FF0000CCFF00CCFF00
CCFF0000FF66FF000000FF660066FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00FF66FF0000CCFF00
0066FF0066FF0066FF0066FF0066FF0066FF0066FFFF0000CC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FF0066FF00FF660066FF00FF660066FF0066FF
FF00000066FF00FF66CCFF00FF000000FF660066FF00FF660066FF0066FF0066FF0066FF
00FF6600FF66CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
FF00000066FF0066FF0066FF0066FF0066FF0066FF0066FFCCFF00FF000000FF660066FF
0066FF0066FF0066FF0066FF0066FF00FF66CCFF00CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFFF0000FF0000CCFF00
00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
0066FF0066FFFF0000CCFF00CCFF00FF00000066FF0066FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66CCFF00FF0000FF00000066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF660066FF
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF00FF6600FF660066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF000066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFFF000000FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF00FF6600FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF00000066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF00FF6600FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF000066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF00FF660066FFFF000000FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FF00FF66CCFF000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF00000066FF00FF66
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF000000FF66
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FFCCFF00FF00000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF66FF000000FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FF00FF6600FF66FF0000FF0000
00FF6600FF66FF0000CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FF
0066FFFF0000CCFF00FF0000FF0000CCFF00CCFF000066FF0066FFCC00FFCC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF6600FF66CCFF00FF000000FF66CCFF00
0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000FF0000CC00FFCC00FFCCFF0000FF66FF00000066FF00FF6600FF66FF0000FF0000
0066FF00FF660066FF0066FF00FF660066FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FFCCFF000066FF
FF000000FF66CCFF00FF0000FF000000FF6600FF660066FF0066FF0066FF00FF66CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FF0066FFCCFF000066FF0066FF0066FF0066FF00FF66FF000000FF6600FF66
0066FF0066FF0066FFFF0000CC00FFCC00FFFF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF0000FF0000
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF
CC00FF0066FF0066FFFF0000CCFF000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF0000FF000000FF660066FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFCCFF000066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFCCFF0000FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FFFF000000FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF00000066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF660066FF
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF
CC00FFCC00FF0066FF00FF66CCFF000066FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFFF00000066FFCC00FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FF0066FFFF000000FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
CC00FF0066FF0066FF00FF66CCFF000066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF00000066FF0066FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FF0066FFCCFF00FF0000FF0000FF0000FF0000
FF0000FF00000066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FF
0066FFCCFF00FF0000FF0000FF0000CCFF00FF0000CCFF000066FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FF00FF66FF0000FF0000CCFF00FF0000FF0000FF0000
00FF660066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FF0066FFFF000000FF66
0066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
CC00FFCC00FF0066FF00FF66CCFF000066FF0066FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF66FF00000066FF0066FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FFCCFF000066FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF
CC00FFCC00FF0066FF0066FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF00000066FFCC00FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FF00FF660066FF
CC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FFCC00FFCC00FF0066FF00FF660066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF0066FFFF00000066FFCC00FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FFCCFF00CCFF00
0066FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FFCC00FF0066FFFF0000CCFF000066FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FFCCFF00FF00000066FFCC00FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF00FF66FF000000FF66
CCFF000066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FF0066FFCCFF00CCFF00FF000000FF6600FF66CC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFCC00FFCC00FF00FF660066FF00FF66FF000000FF660066FF
0066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF0066FFFF000000FF66
CCFF00CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF
CC00FFCC00FF0066FF00FF6600FF660066FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF0066FFFF00000066FF0066FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FFCCFF000066FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FFFF00000066FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FFCC00FF00FF660066FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FF00FF660066FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FFCCFF000066FF
0066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FF0066FF00FF6600FF660066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF0066FFFF00000066FFCC00FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000066FF0066FF0066FF00FF66FF000000FF66
0066FF0066FFCCFF00CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
0066FF0066FF0066FF00FF66CCFF00FF00000066FF0066FF0066FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CC00FF00FF660066FF0066FF00FF66FF000000FF660066FF
00FF66FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF00FF660066FF
CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF00FF6600FF66CC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCC00FF00FF660066FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF00FF66CC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FFCCFF000066FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FF0066FF00FF6600FF6600FF66CC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FFFF00000066FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFFF0000FF00000066FF
0066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FF0066FF00FF66CCFF000066FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FF0066FFFF00000066FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF00FF660066FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF00FF66CC00FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF00FF66CCFF00
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FF0066FF00FF66CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FFFF0000CC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCCFF00FF0000FF0000CCFF00
FF00000066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCCFF00FF0000FF0000FF0000FF0000FF0000CC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000066FFFF0000FF0000FF0000FF0000CCFF00
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF00FF660066FF
CC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FF00FF66CC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF0066FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
CC00FFCC00FFCC00FF0066FF0066FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FF00FF66CC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FFFF0000FF0000FF0000
00FF66CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000066FFCCFF00FF0000CCFF00FF000000FF66CC00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFF0000FF0000FF0000CCFF000066FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FF0066FF0066FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF0066FF0066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCCFF00CC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF660066FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF00FF66FF0000CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FFCCFF00CC00FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FFFF00000066FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF0066FF00FF660066FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66FF00000066FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF0066FF00FF66CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCC00FFCCFF00CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FFCCFF0000FF66
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF00FF6600FF6600FF66CC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66FF00000066FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF0066FFCC00FF
CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF0066FF0066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCCFF000066FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF0066FF0066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFFF0000CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFFF00000066FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000CC00FFCC00FF0066FF00FF66CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCCFF00CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF00FF66CC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCCFF00CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF660066FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF0066FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFFF0000CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF00FF66CC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFFF0000CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCCFF00CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF00FF66CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFFF0000CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF00FF660066FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCCFF0000FF66CC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FFFF0000CC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FF00FF66CC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF00FF660066FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCC00FFCCFF00CC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF00FF66CC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCCFF00CC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FFCC00FF
CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF00FF66CC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF0066FFCC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFCCFF00CC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF00FF660066FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0066FF0066FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFF0000CC00FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00:@3oool200000280oooo1000000Q0?ooo`D00000
7`3oool200000280oooo1@00000P0?ooo`@000008`3oool2000001P0oooo000X0?ooo`040000003o
ool0oooo00000240oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0N0?ooo`040000
003oool0oooo000002<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0S0?ooo`04
0000003oool0oooo000001L0oooo000Z0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo000002<0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01H0oooo000R0?ooo`@0
00001@3oool00`000000oooo0?ooo`0I0?ooo`@00000103oool00`000000oooo0?ooo`0J0?ooo`@0
0000103oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo000002<0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01D0oooo000X0?ooo`04
0000003oool0oooo00000240oooo00@000000?ooo`3oool000008`3oool00`000000oooo0?ooo`0N
0?ooo`040000003oool0oooo000002<0oooo00<000000?ooo`3oool0803oool010000000oooo0?oo
o`00000R0?ooo`040000003oool0oooo000001L0oooo000Y0?ooo`8000008`3oool2000002<0oooo
0P00000Q0?ooo`8000008`3oool2000002<0oooo0P00000T0?ooo`800000603oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool000l0ooooo`00
000A00000040oooo000?0?ooo`8000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo0P0000010?ooo`003`3oool2000001H0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04`3oool20000
0040oooo000?0?ooo`030000003oool0oooo0?l0oooo3@3oool100000040oooo000?0?ooo`030000
003oool0oooo0?l0oooo3@3oool100000040oooo000?0?ooo`030000003oool0oooo0?l0oooo3@3o
ool100000040oooo000?0?ooo`030000003oool0oooo0?l0oooo3@3oool100000040oooo000?0?oo
o`030000003oool0oooo0080oooo303o0000103<0?l0o`000<`0o`3<0?m`0?l000050<`0o`00I_l0
06Ko001Vo`3<0?l0L03o0002001Vo`03003oIP3<0?l0o`0000/0o`001@3oool100000040oooo000?
0?ooo`030000003oool0oooo0080oooo303o0000103<0?l0c?l00<`0o`3<0?m`0?l000050<`0o`00
I_l006Ko001Vo`3<0?l0L03o00020<`0o`03001Vo`3<0?l0o`0000/0o`001@3oool100000040oooo
000?0?ooo`8000000`3oool<0?l000040<`0o`3<o`00c03o0<`0og00o`0000D0c03o001Vo`00I_l0
06Ko0<`0o`1`0?l00080c03o00<006Ko0<`0o`3o00002`3o00040?ooo`8000000@3oool000l0oooo
00<000000?ooo`3oool00P3oool<0?l000040<`0o`00ofH0c03o0<`0og00o`001@3<0?m_0?l000<0
c03o00<006Ko0<`0o`3o00002`3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0
0P3oool<0?l000040<`0o`3<o`00c03o0<`0og00o`0000D0c03o001Vo`00I_l006Ko0<`0o`1_0?l0
00<0c03o00<00?mV0<`0o`3o00002`3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3o
ool00P3oool<0?l000030<`0o`3<o`00c03o0080c03oK`3o00001@3<0?l006Ko001Vo`00I_l0c03o
06l0o`0000D0c03o001Vo`00I_l00?mV0<`0o`0<0?l000D0oooo0@0000010?ooo`003`3oool00`00
0000oooo0?ooo`020?ooo``0o`0000<0c03o0<co003<0?l00P3<0?m_0?l000050<`0o`00I_l006Ko
001Vo`3<0?l0K`3o00001@3<0?l006Ko001Vo`00ofH0c03o00`0o`001@3oool100000040oooo000?
0?ooo`030000003oool0oooo0080oooo303o00000`3<0?l00?mV0<`0o`020<`0ofl0o`0000<0c03o
001Vo`3<0?l00P3<0?m_0?l000<0c03o00<006Ko0<`0o`3o00002`3o00050?ooo`4000000@3oool0
00l0oooo00<000000?ooo`3oool00P3oool<0?l000050<`0o`3o000006Ko001Vo`3<0?l0K`3o0000
1@3<0?l00?mV0<co003<o`00c03o06l0o`0000D0c03o001Vo`00I_l00?mV0<`0o`0<0?l000D0oooo
0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`X0o`000`3<0?l01000ofH0c03o0<`0
o`3<0?m_0?l000030<`0o`00I_l0c03o0080c03oK`3o00030<`0o`03001Vo`3<0?l0o`0000/0o`00
1@3oool100000040oooo000?0?ooo`8000000`3oool:0?l000<0c03o00@0o`000<`0o`3<0?l0c03o
K`3o00001@3<0?l006Ko001Vo`00I_l0c03o06l0o`000`3<0?l00`00ofH0c03o0?l0000;0?l000@0
oooo0P0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`X0o`000`3<0?l0103o0000c03o
0<`0o`3<0?m_0?l000050<`0o`00I_l006Ko001Vo`3<0?l0K`3o00030<`0o`03003oIP3<0?l0o`00
00/0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo2P3o00030<`0o`04
0<co003<0?l0c03o0<`0ofl0o`0000D0c03o001Vo`00I_l006Ko0<`0o`1_0?l000<0c03o00@0o`00
0<`0o`3<0?l0c03o2P3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool:
0?l000<0c03o00@00?mV0<`0o`3<0?l0c03oK`3o00001@3<0?l00?mV001Vo`00I_l0c03o06l0o`00
0`3<0?l01000ofH0c03o0<`0o`3<0?l:0?l000D0oooo0@0000010?ooo`003`3oool00`000000oooo
0?ooo`020?ooo`X0o`000`3<0?l0103o0000c03o0<`0o`3<0?m^0?l00080c03o0`00I_l00`3<0?l0
o`000?l0001]0?l000040<`0o`00I_l006Ko003oIP<0c03o2P3o00050?ooo`4000000@3oool000P0
oooo0P0000050?ooo`030000003oool0oooo0080oooo2P3o00030<`0o`040?l0003<0?l0c03o0<`0
ofh0o`000P3<0?l3001Vo`030<`0o`3o0000o`0006d0o`0000@0c03o001Vo`00I_l00?mV0`3<0?l:
0?l000D0oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0080oooo2P3o00030<`0o`040<co003<0?l0c03o0<`0ofh0o`000P3<0?l01000ofH006Ko001V
o`3<0?m_0?l000<0c03o00@00?mV0<`0o`3<0?l0c03o2P3o00050?ooo`4000000@3oool000T0oooo
00<000000?ooo`3oool00`3oool300000080oooo2P3o00030<`0o`040<co003<0?l0c03o0<`0ofh0
o`000P3<0?l00`00ofH006Ko001Vo`020<`0ofh0o`0000@0c03o001Vo`00I_l0o`000`3<0?l:0?l0
00@0oooo0P0000010?ooo`0000<0oooo0000000000000P0000050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool:0?l000<0c03o00@0o`000<`0o`3<0?l0c03oKP3o00020<`0
o`<006Ko0P3<0?m^0?l000040<`0o`00I_l006Ko0<co00<0c03o2P3o00050?ooo`4000000@3oool0
00L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`X0o`000`3<0?l0
103o0000c03o0<`0o`3<0?m^0?l00080c03o0`00I_l20<`0ofh0o`0000@0c03o001Vo`00I_l0c?l0
0`3<0?l:0?l000D0oooo0@0000010?ooo`00203oool2000000D0oooo00<000000?ooo`3oool00P3o
ool:0?l000<0c03o00@00?mV0<`0o`3<0?l0c03oKP3o00020<`0o`<006Ko0P3<0?m]0?l000@0c03o
00@006Ko0<`0o`3<0?l0c03o2P3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0
0P3oool:0?l00080c03o00@006Ko0?l00000ofH00?mV0P3<0?m]0?l000030<`0o`00ofH00?mV0080
0?mV0P3<0?m]0?l00080c03o0P00ofH0103<o`0006Ko0<`0o`3<0?l:0?l000D0oooo0@0000010?oo
o`003`3oool00`000000oooo0?ooo`020?ooo`X0o`000`3<0?l00`3<o`00c03o0<`0o`020<`0ofd0
o`000P3<0?l00`00ofH006Ko001Vo`020<`0ofd0o`00103<0?l01000ofH0c03o0<`0o`3<0?l:0?l0
00D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`T0o`000`3<0?l01000I_l0
o`00003oIP00ofH20<`0ofd0o`0000<0c03o001Vo`00ofH00P00I_l20<`0ofd0o`000P3<0?l2001V
o`040?l00000I_l0c03o0<`0o`X0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo
0080oooo2@3o00030<`0o`04001Vo`3o00000?mV003oIP80c03oK@3o00000`3<0?l006Ko003oIP02
001Vo`80c03oK@3o00020<`0o`8006Ko00@0o`00001Vo`3<0?l0c03o2P3o00050?ooo`4000000@3o
ool000l0oooo0P0000030?ooo`T0o`00103<0?l00`3<o`0006Ko001Vo`020<`0ofd0o`000P3<0?l0
0`3o00000?mV003oIP020<`0ofd0o`000P3<0?l2001Vo`04003oIP3<0?l0c03o0<`0o`X0o`00103o
ool200000040oooo000?0?ooo`030000003oool0oooo0080oooo2@3o00040<`0o`030<co003<0?l0
c03o0080c03oK@3o00020<`0o`<006Ko0P3<0?m]0?l00080c03o0`00I_l40<`0o`T0o`001@3oool1
00000040oooo000?0?ooo`030000003oool0oooo0080oooo2@3o0000103<0?l006Ko001Vo`3<o`04
0?l000030<`0o`3o0000o`0006T0o`000P3<0?l00`00ofH0o`000<co00020?l000030<co0000I_l0
o`0006`0o`0000<0c03o003oIP3o00000`3o0002001Vo`030<`0o`3o0000o`0000L0o`001@3oool1
00000040oooo000?0?ooo`030000003oool0oooo0080oooo2@3o0000103<0?l006Ko001Vo`3<o`04
0?l000030<`0o`3o0000o`0006T0o`000P3<0?l00`00ofH0o`000<co00020?l000030<co0000I_l0
o`0006`0o`0000<0c03o003oIP3o00000`3o0002001Vo`030<`0o`3o0000o`0000L0o`001@3oool1
00000040oooo000?0?ooo`030000003oool0oooo0080oooo2@3o00040<`0o`03003oIP00I_l006Ko
0080c03oJ`3o00040<`0o`<006Ko103<0?m[0?l00080c03o0`00I_l40<`0o`T0o`001@3oool10000
0040oooo000?0?ooo`030000003oool0oooo0080oooo2@3o00040<`0o`03003oIP00I_l006Ko0080
c03oJ`3o00040<`0o`<006Ko103<0?mY0?l000@0c03o0P00I_l00`00ofH0c03o0<`0o`020<`0o`T0
o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo2@3o00000`3<0?l0c?l0
0<co00050?l00003001Vo`3o0000o`0006T0o`000P3<0?l60?l000030<co003<0?l0c03o06T0o`00
0P3<0?l01000I_l0o`000<co003<o`020?l00080c?l000<0c03o0?l0003o00001`3o00050?ooo`40
00000@3oool000l0oooo0P0000030?ooo`T0o`0000<0c03o0<co003<o`001@3o00000`00I_l0o`00
0?l0001Y0?l00080c03o1P3o00000`3<o`00c03o0<`0o`1Y0?l00080c03o00@006Ko0?l0003<o`00
c?l00P3o00020<co00030<`0o`3o0000o`0000L0o`00103oool200000040oooo000?0?ooo`030000
003oool0oooo0080oooo2@3o00040<`0o`030?l00000I_l006Ko00@0c03oJ@3o00040<`0o`03003o
IP00I_l006Ko00@0c03oJ@3o00040<`0o`80c?l000<00?mV0<`0o`3<0?l00P3<0?l90?l000D0oooo
0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`P0o`001@3<0?l00`00ofH006Ko001V
o`040<`0ofT0o`00103<0?l3001Vo`@0c03oJ@3o00040<`0o`8006Ko00<00?mV0<`0o`3<0?l00P3<
0?l90?l000D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`P0o`00103<0?l0
0`00I_l0o`00001Vo`02001Vo`<0c03oJ@3o00030<`0o`05001Vo`3<o`000?mV003oIP00I_l00`3<
0?mY0?l000<0c03o0`00I_l20?l000@0c03o203o00050?ooo`4000000@3oool000l0oooo00<00000
0?ooo`3oool00P3oool80?l000@0c03o00<006Ko0?l00000I_l00P00I_l30<`0ofT0o`000`3<0?l0
1@00I_l0c?l0003oIP00ofH006Ko00<0c03oJ@3o00030<`0o`<006Ko0P3o00040<`0o`P0o`001@3o
ool100000040oooo000?0?ooo`030000003oool0oooo0080oooo203o00040<`0o`04001Vo`3o0000
06Ko001Vo`@0c03oJ03o00040<`0o`@00?mV00@006Ko0<`0o`3<0?l0c03oJ@3o00040<`0o`8006Ko
00<0c?l0001Vo`3<0?l00`3<0?l80?l000D0oooo0@0000010?ooo`003`3oool00`000000oooo0?oo
o`020?ooo`P0o`001@3<0?l00`00ofH006Ko001Vo`040<`0ofP0o`001@3<0?l3001Vo`D0c03oJ03o
00040<`0o`8006Ko00<00?mV0<`0o`3<0?l00`3<0?l80?l000D0oooo0@0000010?ooo`003`3oool0
0`000000oooo0?ooo`020?ooo`P0o`00103<0?l2003oIP8006Ko103<0?mX0?l000D0c03o0`00I_l5
0<`0ofL0o`001@3<0?l2001Vo`03003oIP3<0?l0c03o00<0c03o203o00050?ooo`4000000@3oool0
00l0oooo0P0000030?ooo`T0o`0000D00?mV001Vo`00I_l00?mV0?l00002003oIP8006Ko0P00ofH0
0`3<0?l0o`000?l0001U0?l000@006Ko00@0o`000<co0000ofH00?mV1000I_l00`3<0?l0o`000?l0
001U0?l000030<`0o`3<o`00c?l0008006Ko0P00ofH00`3o00000?mV001Vo`03001Vo`P0o`00103o
ool200000040oooo000?0?ooo`030000003oool0oooo0080oooo2@3o00001@00ofH006Ko001Vo`00
ofH0o`0000800?mV0P00I_l2003oIP030<`0o`3o0000o`0006D0o`001000I_l0103o0000c?l0003o
IP00ofH4001Vo`030<`0o`3o0000o`0006D0o`0000<0c03o0<co003<o`000P00I_l2003oIP030?l0
0000ofH006Ko00<006Ko203o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3o
ool70?l000D0c03o00@006Ko0?l00000I_l006Ko1@3<0?mW0?l000@0c03o00D006Ko003oIP00ofH0
0?mV001Vo`040<`0ofL0o`00103<0?l3001Vo`030<co0000I_l0c03o00<0c03o203o00050?ooo`40
00000@3oool000l0oooo00<000000?ooo`3oool00P3oool70?l000D0c03o00@006Ko003oIP00I_l0
06Ko1@3<0?mW0?l000D0c03o0`00I_l50<`0ofL0o`001@3<0?l2001Vo`03003oIP3<0?l0c03o00@0
c03o1`3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool70?l000D0c03o
00@006Ko0?l00000I_l006Ko1@3<0?mV0?l000H0c03o0`00I_l50<`0ofL0o`001@3<0?l2001Vo`03
0<co0000I_l0c03o00@0c03o1`3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0
0P3oool70?l000D0c03o00@006Ko0?l00000I_l006Ko1@3<0?mV0?l000H0c03o0`00I_l50<`0ofL0
o`001@3<0?l2001Vo`030<co0000I_l0c03o00@0c03o1`3o00050?ooo`4000000@3oool000l0oooo
00<000000?ooo`3oool00P3oool70?l000<0c03o0`00I_l0103o000006Ko001Vo`00I_l40<`0ofH0
o`001@3<0?l01@00I_l00?mV003oIP00ofH006Ko00D0c03oI@3o00050<`0o`040<co0000ofH00?mV
0?l000<006Ko0`3<0?l70?l000D0oooo0@0000010?ooo`003`3oool2000000<0oooo1`3o00020<`0
o`<006Ko00H00?mV0?l00000ofH00?mV001Vo`00ofH40<`0ofD0o`00103<0?l2003oIP050?l0003<
o`00c?l00<co0000I_l0103<0?mU0?l000@0c03o00H006Ko0<co0000ofH00?mV0?l00000ofH2001V
o`<0c03o1`3o00040?ooo`8000000@3oool000l0oooo00<000000?ooo`3oool00P3oool50?l000L0
c03o00@006Ko0?l0003<o`00c?l01P3<0?mU0?l000D0c03o00D006Ko0<co003o0000o`00001Vo`05
0<`0ofD0o`001@3<0?l01@00I_l0c?l00<co003<o`0006Ko00D0c03o1`3o00050?ooo`4000000@3o
ool000l0oooo00<000000?ooo`3oool00P3oool50?l000L0c03o00@006Ko0?l0003<o`00c?l01P3<
0?mU0?l000D0c03o00D006Ko0<co003o0000o`00001Vo`050<`0ofD0o`001@3<0?l01@00I_l0c?l0
0<co003<o`0006Ko00D0c03o1`3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0
0P3oool50?l000L0c03o00@006Ko0?l00000I_l006Ko1P3<0?mS0?l000L0c03o00@006Ko003oIP00
I_l006Ko1P3<0?mU0?l000H0c03o0P00I_l00`00ofH006Ko0<`0o`060<`0o`D0o`001@3oool10000
0040oooo000?0?ooo`030000003oool0oooo0080oooo1@3o00070<`0o`04001Vo`3o000006Ko001V
o`H0c03oH`3o00070<`0o`D006Ko1`3<0?mS0?l000H0c03o0P00I_l00`3<o`0006Ko0<`0o`060<`0
o`D0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo1@3o00050<`0o`<0
06Ko00@0o`00003oIP00ofH006Ko1P3<0?mR0?l000H0c03o0P00I_l0103<o`000?mV003oIP00I_l7
0<`0of80o`001P3<0?l01000I_l00?mV003oIP3o0003001Vo`D0c03o1@3o00050?ooo`4000000@3o
ool000L0oooo100000040?ooo`030000003oool0oooo0080oooo1@3o00050<`0o`<006Ko00@0o`00
003oIP00ofH006Ko1P3<0?mR0?l000H0c03o0P00I_l0103<o`000?mV003oIP00I_l70<`0of80o`00
1P3<0?l01000I_l00?mV003oIP3o0003001Vo`D0c03o1@3o00050?ooo`4000000@3oool000L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`@0o`00103<0?l00`00I_l00?mV
0?l000030?l00080c?l00P3o0002003oIP<0c03oHP3o00030<`0o`05001Vo`3<o`00c?l00?l0003<
o`00103o0000103<o`0006Ko001Vo`00I_l30<`0of80o`000`3<0?l2001Vo`P0o`0000<0c?l0001V
o`3<0?l00P3<0?l50?l000D0oooo0@0000010?ooo`00203oool00`000000oooo0?ooo`040?ooo`<0
00000P3oool40?l000H0c03o0`00I_l0103o00000?mV003oIP00I_l60<`0of40o`001`3<0?l2001V
o`030<co0000ofH00?mV008006Ko1P3<0?mR0?l000H0c03o00@006Ko003oIP00ofH0o`000`00I_l6
0<`0o`@0o`00103oool200000040oooo00000`3oool0000000000002000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`@0o`00203<0?l00`00I_l0o`00001Vo`02001V
o`H0c03oH@3o00080<`0o`05001Vo`3<o`000?mV003oIP00I_l0203<0?mO0?l000P0c03o0`00I_l0
0`00ofH006Ko0<`0o`070<`0o`@0o`001@3oool100000040oooo00070?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool40?l000P0c03o00@006Ko0?l00000I_l006Ko2@3<
0?mO0?l000P0c03o00D006Ko003oIP3o0000o`00001Vo`080<`0oel0o`00203<0?l01@00I_l00?mV
003oIP3<o`0006Ko00P0c03o103o00050?ooo`4000000@3oool000P0oooo0P0000050?ooo`030000
003oool0oooo0080oooo103o00080<`0o`04001Vo`3o000006Ko001Vo`T0c03oG`3o00080<`0o`05
001Vo`00ofH0o`000?l00000I_l0203<0?mO0?l000P0c03o00D006Ko003oIP00ofH0c?l0001Vo`08
0<`0o`@0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo0`3o00090<`0
o`03001Vo`3<o`0006Ko008006Ko203<0?mO0?l000P0c03o00<006Ko003oIP00I_l00P00I_l80<`0
oel0o`00203<0?l3001Vo`03003oIP00I_l0c03o00P0c03o0`3o00050?ooo`4000000@3oool000l0
oooo00<000000?ooo`3oool00P3oool30?l000L0c03o0P00I_l01@00ofH0o`000?l0003o000006Ko
00P0c03oGP3o00080<`0o`8006Ko00<0c?l00?l0003o00000P00I_l80<`0oeh0o`00203<0?l01@00
I_l0o`000?l0003o00000?mV008006Ko1`3<0?l30?l000D0oooo0@0000010?ooo`003`3oool00`00
0000oooo0?ooo`020?ooo`<0o`000P3<0?l20?l000<006Ko0`00ofH00`3o00000?mV003oIP05001V
o`030<co0000I_l0c03o0080c03oG@3o00020<`0o`800?mV1000I_l2003oIP<0o`0000H0c?l0003o
IP3o0000o`00001Vo`3<o`02001Vo`80c03oG@3o00030<`0o`03001Vo`00ofH006Ko008006Ko00<0
0?mV001Vo`3o00000P3o0003003oIP03001Vo`3o00000?mV0080c?l00P3<0?l30?l000D0oooo0@00
00010?ooo`003`3oool2000000<0oooo0`3o00020<`0o`80o`000`00I_l3003oIP030?l00000ofH0
0?mV00D006Ko00<0c?l0001Vo`3<0?l00P3<0?mM0?l00080c03o0P00ofH4001Vo`800?mV0`3o0000
1P3<o`000?mV0?l0003o000006Ko0<co008006Ko0P3<0?mM0?l000<0c03o00<006Ko003oIP00I_l0
0P00I_l00`00ofH006Ko0?l000020?l000<00?mV00<006Ko0?l00000ofH00P3<o`020<`0o`<0o`00
103oool200000040oooo000?0?ooo`030000003oool0oooo0080oooo00<0o`000<`0o`3<0?l01@3<
0?l2001Vo`80c?l000@00?mV0?l0003<o`00c?l00P00ofH2001Vo`H0c03oG@3o00050<`0o`<006Ko
0P3<o`030?l000030<co003o000006Ko008006Ko1@3<0?mM0?l000H0c03o0P3o0002003oIP<0o`00
0`00ofH2001Vo`L0c03o00<0o`000?ooo`3oool00`3oool100000040oooo000?0?ooo`030000003o
ool0oooo0080oooo00<0o`000<`0o`3<0?l01P3<0?l3001Vo`04003oIP3o00000?mV003oIP8006Ko
203<0?mK0?l000X0c03o0P00I_l00`3o0000c?l00<co0002001Vo`X0c03oFP3o00090<`0o`8006Ko
0P00ofH0103o00000?mV001Vo`00I_l90<`0o`030?l0003oool0oooo00<0oooo0@0000010?ooo`00
3`3oool00`000000oooo0?ooo`020?ooo`X0c03o0P00ofH01@00I_l0o`00003oIP00ofH006Ko00X0
c03oFP3o000:0<`0o`8006Ko00<0c?l0003oIP00ofH00P00I_l:0<`0oeX0o`002P3<0?l01@00I_l0
0?mV003oIP3o000006Ko00800?mV2@3<0?l00`3o0000oooo0?ooo`030?ooo`4000000@3oool000l0
oooo00<000000?ooo`3oool00P3oool:0<`0o`800?mV00D006Ko0?l00000ofH00?mV001Vo`0:0<`0
oeX0o`002P3<0?l2001Vo`030<co0000ofH00?mV008006Ko2P3<0?mJ0?l000X0c03o00D006Ko003o
IP00ofH0o`00001Vo`02003oIPT0c03o00<0o`000?ooo`3oool00`3oool100000040oooo000?0?oo
o`030000003oool0oooo0080oooo2P3<0?l3001Vo`040<co0000I_l006Ko001Vo`X0c03oF@3o000<
0<`0o`05001Vo`00ofH00?mV003oIP00I_l02`3<0?mJ0?l000X0c03o0`00I_l01000ofH006Ko001V
o`00I_l:0<`0o`D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`X0c03o0`00
I_l0103o00000?mV003oIP00I_l<0<`0oeL0o`00303<0?l01@00I_l00?mV003oIP00ofH006Ko00`0
c03oE`3o000<0<`0o`04001Vo`00ofH00?mV0?l000<006Ko2P3<0?l50?ooo`4000000@3oool000l0
oooo00<000000?ooo`3oool00P3oool:0<`0o`<006Ko00@0c?l0001Vo`00I_l006Ko303<0?mG0?l0
00/0c03o0P00I_l3003oIP8006Ko2`3<0?mG0?l000/0c03o1000I_l01000ofH006Ko001Vo`00I_l:
0<`0o`D0oooo0@0000010?ooo`003`3oool2000000<0oooo2@3<0?l3001Vo`80o`000P3<o`000`00
ofH006Ko0<`0o`080<`0o`8006KoEP3o00000`3<o`00c03o0<`0o`070<`0o`<006Ko00D0o`000<co
003<o`00c?l00?l00003001Vo`X0c03oE@3o000<0<`0o`04001Vo`00ofH0c?l00<co0080o`000`00
I_l90<`0o`@0oooo0P0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`T0c03o0`00I_l2
0?l00080c?l000<00?mV001Vo`3<0?l0203<0?l2001VoeH0o`0000<0c?l00<`0o`3<0?l01`3<0?l3
001Vo`050?l0003<o`00c?l00<co003o00000`00I_l:0<`0oeD0o`00303<0?l01000I_l00?mV0<co
003<o`020?l000<006Ko2@3<0?l50?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3o
ool0103<0?l0c?l00<co0000ofH8001Vo`04003oIP3o0000c?l00<co00T006Ko00<0o`000<`0o`3<
0?l00P3<0?mE0?l00080c03o0`00ofH5001Vo`800?mV00<006Ko003oIP3o00000P3<o`001000ofH0
06Ko0?l0003o0002001Vo`800?mV00@006Ko003oIP00I_l006Ko0P3<0?mE0?l000@0c03o00<0o`00
001Vo`00I_l01`00I_l20<co00030?l00000ofH006Ko00X006Ko00<0c03o0?ooo`3oool00`3oool1
00000040oooo000?0?ooo`030000003oool0oooo0080oooo103<0?l01@00I_l00?mV003oIP3o0000
0?mV00@0c?l00`3o00000`3<o`00o`000?l000020?l00003003oIP00I_l0c03o00H0c03oE03o0006
0<`0o`<006Ko00@0c?l0003oIP3o0000o`000P00ofH30?l000800?mV0P3<o`000`3o00000?mV001V
o`02001Vo`H0c03oD`3o00080<`0o`03003oIP3<o`00o`0000<0c?l000D00?mV0?l0003o0000o`00
0<co0002003oIP030<co003o0000o`0000<006Ko103<0?l50?ooo`4000000@3oool000l0oooo00<0
00000?ooo`3oool00P3oool70<`0o`8006Ko00<00?mV0?l0003o0000103o00001000ofH0o`00003o
IP00ofH2001Vo`T0c03oD@3o000;0<`0o`8006Ko0P3<o`02003oIP<0o`000P00ofH20?l0008006Ko
2@3<0?mC0?l000T0c03o0P00I_l20<co00800?mV0`3o0000103<o`000?mV003oIP00ofH2001Vo`L0
c03o1@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo1`3<0?l2001Vo`03003o
IP3o0000o`0000@0o`0000@00?mV0?l00000ofH00?mV0P00I_l90<`0oe40o`002`3<0?l2001Vo`80
c?l00P00ofH30?l000800?mV0P3o0002001Vo`T0c03oD`3o00090<`0o`8006Ko0P3<o`02003oIP<0
o`0000@0c?l0003oIP00ofH00?mV0P00I_l70<`0o`D0oooo0@0000010?ooo`003`3oool00`000000
oooo0?ooo`020?ooo`P0c03o1000I_l01@3<o`00o`000<co003<o`000?mV00<006Ko3@3<0?m?0?l0
00`0c03o1000I_l01@00ofH0o`000?l0003o00000?mV00@006Ko303<0?m?0?l000`0c03o1000I_l0
1@00ofH0c?l00<co003o00000?mV00@006Ko203<0?l50?ooo`4000000@3oool000l0oooo0P000003
0?ooo`T0c03o00<006Ko003oIP00ofH0103o00001000ofH006Ko001Vo`00I_l=0<`0odh0o`003P3<
0?l3001Vo`D0o`000`00I_l>0<`0odh0o`003@3<0?l3001Vo`03003oIP3o0000o`000080o`000P00
ofH00`00I_l0c03o0<`0o`070<`0o`@0oooo0P0000010?ooo`003`3oool00`000000oooo0?ooo`02
0?ooo`T0c03o0`00I_l01000ofH0o`000<co003<o`02001Voa00c03oC@3o000>0<`0o`@006Ko00<0
c?l0003oIP00ofH01000I_l>0<`0odd0o`00403<0?l2001Vo`800?mV00<0c?l0001Vo`00I_l00P00
I_l90<`0o`D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`T0c03o0`00I_l0
1000ofH0o`000<co003<o`02001Voa00c03oC@3o000>0<`0o`@006Ko00<0c?l0003oIP00ofH01000
I_l>0<`0odd0o`00403<0?l2001Vo`800?mV00<0c?l0001Vo`00I_l00P00I_l90<`0o`D0oooo0@00
00010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`T0c03o1000I_l00`3<o`000?mV003oIP02
001Voa40c03oB`3o000?0<`0o`@006Ko0`00ofH2001Voa40c03oB`3o000A0<`0o`8006Ko0`00ofH4
001Vo`T0c03o1@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo2@3<0?l3001V
o`80o`000`00ofH00`00I_l0c03o0<`0o`0?0<`0odT0o`004@3<0?l3001Vo`03003oIP3<o`00c?l0
0080c?l000<006Ko0<`0o`3<0?l04@3<0?m90?l00140c03o00H006Ko003oIP00ofH00?mV0?l00000
ofH3001Vo`T0c03o1@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo2@3<0?l3
001Vo`04003oIP3o00000?mV003oIP8006Ko4`3<0?m60?l00003003oIP3<0?l0c03o00l0c03o1000
I_l30<co00@006Ko4@3<0?m70?l00140c03o1000I_l2003oIP030?l00000ofH006Ko008006Ko2@3<
0?l50?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool90<`0o`<006Ko00@00?mV
0?l00000ofH00?mV0P00I_lC0<`0odH0o`0000<00?mV0<`0o`3<0?l03`3<0?l4001Vo`<0c?l01000
I_lA0<`0odL0o`004@3<0?l4001Vo`800?mV00<0o`00003oIP00I_l00P00I_l90<`0o`D0oooo0@00
00010?ooo`003`3oool2000000<0oooo203<0?l5001Vo`030?l00000ofH00?mV00@006Ko3P3<0?l0
1000I_l0c03o0<`0o`3<0?m50?l000030<`0o`3<o`00c?l000l0c03o1000I_l00`3<o`000?mV003o
IP04001Vo`l0c03o0P00I_l00`3<0?l0o`000?l000130?l00180c03o1000I_l2003oIP030<co0000
I_l006Ko008006Ko2@3<0?l40?ooo`8000000@3oool000l0oooo00<000000?ooo`3oool00P3oool8
0<`0o`@006Ko00@00?mV0?l0003o0000o`001@00I_l<0<`0o`030?l0003<0?l0c03o00<0c03o@`3o
00040<`0o`03001Vo`00ofH0c03o00/0c03o00D006Ko003oIP00ofH006Ko003oIP030<co0005003o
IP00I_l0c?l00<co0000I_l0303<0?l00`00I_l0c03o0<`0o`030<`0od<0o`001@3<0?l00`00ofH0
c03o0<`0o`0:0<`0o`03001Vo`00ofH00?mV008006Ko0`3<o`001@00ofH006Ko001Vo`00ofH006Ko
00P0c03o1@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo1@3<0?l5001Vo`@0
o`000P3<o`000`3o00000?mV001Vo`03001Vo`L0c03o00@006Ko003oIP00I_l006Ko1`3<0?m00?l0
00P0c03o0P3o0002001Vo`D0c03o1P00I_l00`00ofH0c?l00?l000030?l00003003oIP00I_l006Ko
00@006Ko1@3<0?l2001Vo`800?mV203<0?m00?l000L0c03o0P00I_l00`00ofH006Ko0<`0o`060<`0
o`@006Ko00D0c?l00?l0003<o`00c?l00?l000030<co00D006Ko1@3<0?l50?ooo`4000000@3oool0
00l0oooo00<000000?ooo`3oool00P3oool3001Vo`030<co0000I_l006Ko00@006Ko0P00ofH01@3<
o`00o`000?l0003o00000?mV00@006Ko00<0o`00001Vo`00I_l00`00I_l3003oIP03001Vo`3<0?l0
c03o00T0c03o?03o000<0<`0o`03001Vo`00ofH006Ko00X006Ko00<00?mV0<co003o00000P3o0002
003oIPP006Ko0`00ofH00`3o000006Ko0<`0o`0:0<`0ocd0o`002`3<0?l01000I_l0o`000?l0003o
0005001Vo`04003oIP00I_l006Ko001Vo`800?mV0`3o00000`3<o`000?mV003oIP0:001Vo`D0oooo
0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`<006Ko00<0c?l0001Vo`00I_l01000
I_l2003oIP050<co003o0000o`000?l00000ofH01000I_l00`3o000006Ko001Vo`03001Vo`<00?mV
00<006Ko0<`0o`3<0?l02@3<0?ll0?l000`0c03o00<006Ko003oIP00I_l02P00I_l00`00ofH0c?l0
0?l000020?l000800?mV2000I_l3003oIP030?l00000I_l0c03o00X0c03o?@3o000;0<`0o`04001V
o`3o0000o`000?l000D006Ko00@00?mV001Vo`00I_l006Ko0P00ofH30?l000030<co0000ofH00?mV
00X006Ko1@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo00D00?mV0?l0003o
0000o`00001Vo`03003oIP04001Vo`00ofH0c?l00<co00D0o`0000H00?mV001Vo`00I_l00?mV0<co
0000I_l3003oIP040?l00000I_l006Ko001Vo`d0c03o>@3o000?0<`0o`8006Ko0P3o00001P00ofH0
06Ko003oIP00ofH0c?l0001Vo`<00?mV1@3o00001@00ofH006Ko001Vo`00I_l0c?l0008006Ko0P00
ofH20?l0008006Ko3`3<0?li0?l000d0c03o0`00I_l01P3o0000c?l0003oIP00ofH006Ko0?l000<0
06Ko00<00?mV0?l0003o00000`3o0003003oIP05001Vo`3<o`000?mV003oIP00I_l00`3<o`000`00
ofH0oooo0?ooo`030?ooo`4000000@3oool000L0oooo1@0000030?ooo`030000003oool0oooo0080
oooo0`00I_l01@00ofH0c?l00?l0003o0000c?l000800?mV0P3<o`050?l000<00?mV0`3o00020<co
0004003oIP00I_l006Ko001Voa40c03o=@3o000A0<`0o`<006Ko00<0c?l00?l0003o00000P3o0000
1@00ofH0o`000?l00000ofH0c?l000<0o`0000<0c?l0003oIP3<o`000P3<o`030?l00005003oIP3o
000006Ko001Vo`00ofH04@3<0?le0?l00140c03o0`00I_l00`3o00000?mV003oIP030?l000<00?mV
00<0c?l00?l0003o00000P3o0002003oIP030<co0000ofH0o`000080o`0000<0c?l0003oIP00I_l0
0P00I_l50?ooo`4000000@3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030<`0o`00I_l006Ko008006Ko0`3o00000`3<o`00o`000?l000070?l000@0c?l000<0
0?mV001Vo`00I_l00P00I_lD0<`0oc80o`00503<0?l4001Vo`@0c?l02`3o0000103<o`00o`00003o
IP00ofH4001Voa<0c03o<`3o000D0<`0o`@006Ko00<00?mV0<co003<o`002`3o00040<co008006Ko
0P00ofH00`3<0?l0oooo0?ooo`030?ooo`4000000@3oool000T0oooo00<000000?ooo`3oool00`3o
ool300000080oooo00<0c03o001Vo`00I_l00P00I_l30?l000030<co003o0000o`0000L0o`00103<
o`000`00ofH006Ko001Vo`02001Voa@0c03o<P3o000D0<`0o`@006Ko103<o`0;0?l000040<co003o
00000?mV003oIP@006Ko4`3<0?lc0?l001@0c03o1000I_l00`00ofH0c?l00<co000;0?l000@0c?l0
0P00I_l2003oIP030<`0o`3oool0oooo0080oooo0P0000010?ooo`0000<0oooo0000000000000P00
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0103<0?l006Ko001V
o`00I_l6003oIPH0o`0000@0c?l0003oIP3<o`00c?l00P00ofH0103o000006Ko001Vo`00I_lH0<`0
obd0o`00603<0?l2001Vo`800?mV00<006Ko003oIP00ofH00P00ofH40?l000030<co0000ofH00?mV
00800?mV00<006Ko003oIP00ofH00P00I_lH0<`0obd0o`00603<0?l3001Vo`030<co0000ofH00?mV
00<00?mV00<0c?l00?l0003o0000103o0002003oIP03001Vo`00ofH00?mV008006Ko0`3<0?l50?oo
o`4000000@3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<0
c03o00<00?mV001Vo`00I_l00`00I_l00`00ofH0o`000?l000050?l00003003oIP00I_l006Ko00<0
06Ko0P00ofHJ0<`0obX0o`006P3<0?l6001Vo`800?mV00<0c?l00?l0003o0000103o0002003oIPD0
06Ko6`3<0?lY0?l00003001Vo`3<0?l0c03o01P0c03o1@00I_l3003oIPL0o`0000<00?mV001Vo`00
I_l01000I_l30<`0o`D0oooo0@0000010?ooo`00203oool2000000D0oooo00<000000?ooo`3oool0
0P3oool40<`0o`D006Ko0`00ofH40?l000800?mV1`00I_lN0<`0ob80o`00103<0?l00`3o0000c03o
0<`0o`0H0<`0o`D006Ko0`00ofH01P3<o`00o`000?l0003o0000c?l0003oIPL006Ko6P3<0?l00`00
I_l0c03o0<`0o`020<`0ob80o`007P3<0?l7001Vo`03003oIP3<o`00o`000080o`0000@0c?l0003o
IP00ofH00?mV1@00I_l40<`0o`D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?oo
o`@0c03o1@00I_l3003oIP@0o`000P00ofH7001Voah0c03o8P3o00040<`0o`030?l0003<0?l0c03o
01P0c03o1@00I_l3003oIP060<co003o0000o`000?l0003<o`000?mV1`00I_lJ0<`0o`03001Vo`3<
0?l0c03o0080c03o8P3o000N0<`0o`L006Ko00<00?mV0<co003o00000P3o0000103<o`000?mV003o
IP00ofH5001Vo`@0c03o1@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo103<
0?l5001Vo`030?l0003<o`00c?l000D0o`0000<0c?l0003oIP00ofH00`00I_lK0<`0o`030<co003<
0?l0c03o00L0c03o6@3o000S0<`0o`D006Ko0P00ofH20<co00<0o`000P3<o`02003oIPD006Ko6@3<
0?l00`00I_l0c03o0<`0o`070<`0oaT0o`002@3<0?l00`3<o`00c03o0<`0o`0G0<`0o`D006Ko0P00
ofH20<co00@0o`000P3<o`000`00ofH006Ko001Vo`03001Vo`@0c03o1@3oool100000040oooo000?
0?ooo`030000003oool0oooo0080oooo103<0?l3001Vo`03003oIP3o0000o`0000<0c?l00`3o0002
0<co0080o`0000<00?mV001Vo`00I_l06`3<0?l00`00I_l0c03o0<`0o`0>0<`0o`X0o`004@3<0?l0
0`3o0000c03o0<`0o`0G0<`0o`<006Ko00<00?mV0?l0003<o`000`3<o`030?l000050<co003o0000
o`000?l0003<o`000`00I_lJ0<`0o`03003oIP3<0?l0c03o00l0c03o2@3o000A0<`0o`03001Vo`3<
0?l0c03o01T0c03o0P00I_l00`00ofH0o`000?l000050?l000@0c?l000<0o`00003oIP00I_l00P00
I_l40<`0o`D0oooo0@0000010?ooo`003`3oool2000000<0oooo103<0?l5001Vo`<00?mV103o0002
003oIPD006Ko6@3<0?l2003oIQH0c03o00<006Ko0<`0o`3<0?l04`3<0?l3001VoaL0c03o1`00I_l0
0`00ofH0c?l00?l000020?l000800?mV1P00I_lH0<`0o`80c?l000<006Ko0<`0o`3<0?l04`3<0?l0
0`00I_l0c03o0<`0o`0D0<`0o`800?mV6@3<0?l5001Vo`800?mV0`3o00000`3<o`000?mV003oIP06
001Vo`@0c03o103oool200000040oooo000?0?ooo`030000003oool0oooo0080oooo103<0?l6001V
o`<00?mV00@0o`00003oIP00ofH00?mV1P00I_lH0<`0o`<006Ko5P3<0?l00`00I_l0c03o0<`0o`0D
0<`0o`80o`005`3<0?l8001Vo`05003oIP3<o`00c?l00<co0000ofH01`00I_lH0<`0o`800?mV5P3<
0?l00`00I_l0c03o0<`0o`0D0<`0o`<006Ko603<0?l6001Vo`<00?mV00<0c?l0003oIP00I_l01`00
I_l40<`0o`D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`@0c03o1P00I_l3
003oIP040?l00000ofH00?mV003oIPH006Ko603<0?l3001VoaH0c03o00<006Ko0<`0o`3<0?l0503<
0?l20?l001L0c03o2000I_l01@00ofH0c?l00<co003<o`000?mV00L006Ko603<0?l2003oIQH0c03o
00<006Ko0<`0o`3<0?l0503<0?l3001VoaP0c03o1P00I_l3003oIP030<co0000ofH006Ko00L006Ko
103<0?l50?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool40<`0o`P006Ko00D0
0?mV0?l0003<o`00c?l0003oIP06001VoaP0c03o00<00?mV001Vo`00I_l05P3<0?l00`00I_l0c03o
0<`0o`0D0<`0o`<006Ko5P3<0?l8001Vo`05003oIP3<o`00c?l00<co0000ofH02000I_lF0<`0o`<0
06Ko5P3<0?l00`3<o`00c03o0<`0o`0D0<`0o`<006Ko603<0?l6001Vo`05003oIP3o0000o`000?l0
0000ofH02000I_l40<`0o`D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`@0
c03o1P00I_l3003oIP040?l00000ofH00?mV003oIPP006Ko5@3<0?l00`00ofH006Ko0<`0o`0G0<`0
o`03001Vo`3<0?l0c03o01@0c03o0P00I_l00`3o000006Ko0<`0o`0D0<`0o`P006Ko00<00?mV0<co
0000ofH00P00ofH8001VoaD0c03o00@006Ko0<co0000I_l006Ko5P3<0?l00`00ofH0c03o0<`0o`0F
0<`0o`03003oIP00I_l0c03o01@0c03o2000I_l3003oIP030<co0000ofH006Ko00L006Ko103<0?l5
0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool30<`0o`L006Ko0P00ofH01@3<
o`00o`000?l0003o00000?mV00P006Ko4`3<0?l2001Vo`030?l00000I_l0c03o01L0c03o00<00?mV
0<`0o`3<0?l05P3<0?l2003oIP03001Vo`3<0?l0c03o0140c03o00<0c?l0001Vo`00I_l01@00I_l0
0`00ofH0o`000?l000030<co0003003oIP00I_l006Ko00D006Ko503<0?l00`00I_l0o`00001Vo`0H
0<`0o`03003oIP3<0?l0c03o01H0c03o00@006Ko0?l00000I_l006Ko4`3<0?l7001Vo`06003oIP3<
o`00c?l00<co003o0000c?l00P00ofH7001Vo`<0c03o1@3oool100000040oooo000?0?ooo`030000
003oool0oooo0080oooo0`3<0?l7001Vo`800?mV00D0c?l00?l0003o0000o`00003oIP08001Voa<0
c03o0P00I_l00`3o000006Ko0<`0o`0G0<`0o`03003oIP3<0?l0c03o01H0c03o0P00ofH00`00I_l0
c03o0<`0o`0A0<`0o`030<co0000I_l006Ko00D006Ko00<00?mV0?l0003o00000`3<o`000`00ofH0
06Ko001Vo`05001Voa@0c03o00<006Ko0?l00000I_l0603<0?l00`00ofH0c03o0<`0o`0F0<`0o`04
001Vo`3o000006Ko001Voa<0c03o1`00I_l01P00ofH0c?l00<co003<o`00o`000<co00800?mV1`00
I_l30<`0o`D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`<0c03o0P00I_l2
0<co00D00?mV00H0c?l00?l0003<o`00c?l0003oIP3o0003003oIP030?l00000I_l006Ko008006Ko
4@3<0?l01@00I_l0c?l00<co0000ofH006Ko01P0c03o00<0o`000<`0o`3<0?l05P3<0?l00`00I_l0
o`00001Vo`02001Voa40c03o0P00I_l20<co00D00?mV00@0c?l00?l0003o0000o`001@00ofH00`3<
o`000?mV003oIP02001Voa40c03o0P00I_l00`00ofH0o`00001Vo`0H0<`0o`030?l0003<0?l0c03o
01H0c03o00D006Ko0?l00000ofH00?mV001Vo`0A0<`0o`<006Ko0P00ofH00`3<o`000?mV003oIP02
003oIP<0o`0000<0c?l0003oIP00ofH00`00ofH20?l0008006Ko0`3<0?l50?ooo`4000000@3oool0
00l0oooo0P0000030?ooo`030<`0o`00I_l006Ko00@006Ko00<00?mV0?l0003o0000203o00030<co
00D006Ko403<0?l2001Vo`80c?l00P00I_lF0<`0o`<006Ko603<0?l00`00I_l00?mV003oIP02003o
IP03001Vo`3<0?l0c03o00`0c03o1`00I_l00`00ofH0c?l00<co00070?l00080c?l000<00?mV001V
o`00I_l01@00I_l>0<`0o`04001Vo`00ofH00?mV003oIP8006Ko603<0?l00`3<o`00c03o0<`0o`0F
0<`0o`8006Ko0`00ofH00`00I_l0c03o0<`0o`0=0<`0o`H006Ko00<00?mV0<co003<o`002@3o0002
003oIPH006Ko00<0c03o0?ooo`3oool00P3oool200000040oooo000?0?ooo`030000003oool0oooo
0080oooo2000I_l4003oIP@0o`001000ofH9001Vo`X0c03o1000I_l00`00ofH0c?l00<co0002001V
oaH0c03o0P00I_l00`00ofH0c03o0<`0o`0F0<`0o`03001Vo`3<o`00o`0000@006Ko303<0?l9001V
o`80o`0000<00?mV0<co003o00000P3o0000103<o`000?mV003oIP00ofH9001Vo``0c03o1000I_l0
0`3o00000?mV001Vo`0H0<`0o`030?l00000I_l006Ko01H0c03o00@006Ko003oIP3o0000o`001@00
I_l:0<`0o`T006Ko0`00ofH01@3<o`00o`000?l0003o0000c?l000800?mV00<0o`00001Vo`00I_l0
1`00I_l50?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool8001Vo`@00?mV103o
0004003oIPT006Ko2P3<0?l4001Vo`03003oIP3<o`00c?l0008006Ko5P3<0?l2001Vo`03003oIP3<
0?l0c03o01H0c03o00<006Ko0<co003o00001000I_l<0<`0o`T006Ko0P3o00000`00ofH0c?l00?l0
00020?l000040<co0000ofH00?mV003oIPT006Ko303<0?l4001Vo`030?l00000ofH006Ko01P0c03o
00<0o`00001Vo`00I_l05P3<0?l01000I_l00?mV0?l0003o0005001Vo`X0c03o2@00I_l3003oIP05
0<co003o0000o`000?l0003<o`000P00ofH00`3o000006Ko001Vo`07001Vo`D0oooo0@0000010?oo
o`003`3oool00`000000oooo0?ooo`020?ooo`T006Ko0`00ofH0103<o`00o`000?l0003o0002003o
IPd006Ko1P3<0?l3001Vo`<00?mV00@0c?l0001Vo`00I_l006Ko5`3<0?l2001Vo`03003oIP00I_l0
c03o01H0c03o0P00I_l4003oIPD006Ko1P3<0?l;001Vo`<00?mV00H0c?l00?l0003o0000o`000<co
0000ofH=001Vo`H0c03o1@00I_l4003oIP8006Ko5`3<0?l01000I_l0c?l0001Vo`00I_lF0<`0o`80
06Ko1000ofH5001Vo`H0c03o3@00I_l00`00ofH0c?l00?l000020?l000040<co0000ofH00?mV003o
IPT006Ko1@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo2@00I_l3003oIP04
0<co003o0000c?l00<co00800?mV2`00I_l00`00ofH006Ko001Vo`0:001Vo`05003oIP3o00000?mV
003oIP00I_l05`3<0?l2001Vo`030?l00000I_l0c03o01H0c03o0P00I_l30?l00003003oIP00I_l0
06Ko008006Ko00<00?mV001Vo`00I_l03`00I_l3003oIP040<co003o0000c?l00<co00800?mV6000
I_l01000ofH0o`000?l00000ofH2001VoaL0c03o00@006Ko0<co0000I_l006Ko5P3<0?l2001Vo`80
0?mV00<0o`00003oIP00I_l02`00I_l00`00ofH006Ko001Vo`09001Vo`800?mV0P3<o`020?l000<0
0?mV2@00I_l50?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool9001Vo`@00?mV
00<0o`00003oIP00ofH00P00ofHC001Vo`030?l00000I_l006Ko008006Ko00<0c?l00?l00000I_l0
0`00I_lE0<`0o`<006Ko00<0c?l0001Vo`3<0?l05P3<0?l2001Vo`04003oIP3<o`00c?l0003oIP`0
06Ko00<0c?l0001Vo`00I_l01`00I_l4003oIP<0o`000P00ofH;001Vo`03003oIP00I_l006Ko00X0
06Ko00<00?mV0<co003<o`000`00I_lG0<`0o`04001Vo`3<o`0006Ko001VoaH0c03o1000I_l2003o
IP@006Ko00<00?mV001Vo`00I_l01@00I_l00`00ofH006Ko001Vo`09001Vo`800?mV0`3o0004003o
IPT006Ko1@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo2@00I_l4003oIP03
0?l00000ofH00?mV00800?mV4`00I_l00`3o000006Ko001Vo`02001Vo`030<co003o000006Ko00<0
06Ko5@3<0?l3001Vo`030<co0000I_l0c03o01H0c03o0P00I_l01000ofH0c?l00<co0000ofH<001V
o`030<co0000I_l006Ko00L006Ko1000ofH30?l000800?mV2`00I_l00`00ofH006Ko001Vo`0:001V
o`03003oIP3<o`00c?l000<006Ko5`3<0?l01000I_l0c?l0001Vo`00I_lF0<`0o`@006Ko0P00ofH4
001Vo`03003oIP00I_l006Ko00D006Ko00<00?mV001Vo`00I_l02@00I_l2003oIP<0o`001000ofH9
001Vo`D0oooo0@0000010?ooo`003`3oool2000000<0oooo2@00I_l3003oIP040<co003o0000c?l0
0<co00800?mV2@00I_l20?l000P006Ko00<00?mV0?l00000ofH00P00ofH00`3<o`000?mV001Vo`03
001VoaD0c03o00@006Ko003oIP00ofH0o`000`00I_lE0<`0o`<006Ko0P00ofH00`3<o`000?mV003o
IP02003oIPP006Ko0P00ofH8001Vo`<00?mV0P3o00020<co00800?mV0P3<o`08001Vo`800?mV2000
I_l01@3o00000?mV003oIP00ofH0o`0000800?mV0`00I_lE0<`0o`<006Ko00@0o`00003oIP00ofH0
06Ko5@3<0?l4001Vo`06003oIP3o0000o`000?l00000ofH0o`002@00I_l2003oIPL006Ko1000ofH2
0<co0080o`000`00ofH9001Vo`@0oooo0P0000010?ooo`003`3oool00`000000oooo0?ooo`020?oo
o`030<co0000I_l006Ko00D006Ko1000ofH0103<o`00o`000<co003<o`04003oIPH006Ko00<00?mV
0<co003<o`002@00I_l20<co0080o`0000<0c?l0003oIP00I_l00`00I_lE0<`0o`<006Ko00@00?mV
001Vo`00I_l006Ko4`3<0?l5001Vo`800?mV00D0o`000<co003o0000o`00003oIP08001Vo`03003o
IP3<o`0006Ko00L006Ko0`00ofH40?l000040<co0000ofH00?mV003oIPH006Ko0P00ofH00`3<o`00
0?mV001Vo`07001Vo`05003oIP3o0000o`000<co003o00000P00ofH3001VoaD0c03o0`00I_l0103<
o`0006Ko001Vo`00I_lE0<`0o`@006Ko00<00?mV0?l0003o00000P3o00000`3<o`0006Ko001Vo`07
001Vo`80o`0000<00?mV001Vo`00I_l01000I_l3003oIP030<co003o0000o`000080o`000`00ofH8
001Vo`03003oIP3oool0oooo00<0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?oo
o`040<co0000ofH00?mV003oIP<006Ko1@00ofH0103<o`00o`000<co003<o`05003oIP@006Ko00@0
0?mV0?l00000ofH00?mV2@00I_l00`00ofH0c?l00?l000030?l000800?mV00@0o`00001Vo`00I_l0
06Ko4P3<0?l2001Vo`80c?l000<0o`00003oIP00I_l00P00I_lB0<`0o`<006Ko00<0o`000<co003o
00000`3o0003003oIPP006Ko00<00?mV0?l00000ofH00P00ofH3001Vo`H00?mV00<0o`000<co003<
o`001P00ofH3001Vo`05003oIP3o0000o`000<co0000ofH02000I_l00`00ofH0c?l00<co00040?l0
0080c?l00`00I_lB0<`0o`<006Ko00@00?mV0?l0003<o`00c?l00P00I_lB0<`0o`<006Ko1`3o0000
0`3<o`000?mV001Vo`07001Vo`05003oIP3<o`00c?l00?l00000ofH00`00I_l6003oIP80c?l000<0
o`00003oIP00ofH01000ofH3001Vo`<00?mV00<0c?l00?ooo`3oool00`3oool100000040oooo000?
0?ooo`030000003oool0oooo0080oooo00@0o`00003oIP00ofH0c?l02000ofH0103<o`00o`000<co
003<o`07003oIP80c?l000<00?mV0<co0000ofH00P00ofH7001Vo`800?mV0`3o0002003oIPH006Ko
4@3<0?l3001Vo`800?mV00<0c?l0001Vo`00I_l00P00I_lA0<`0o`D006Ko0`00ofH01@3<o`00o`00
0?l0003o00000?mV00P006Ko00<00?mV0<co0000ofH02P00ofH0103<o`00o`000<co003<o`04003o
IP030?l00000ofH00?mV00<00?mV0`3<o`000`00ofH006Ko001Vo`06001Vo`05003oIP3o0000o`00
0?l0003<o`000`00ofH5001Voa40c03o1000I_l00`3<o`0006Ko001Vo`03001Voa40c03o1P00I_l0
0`00ofH0c?l00?l000020?l000800?mV1`00I_l01000ofH0c?l00<co003o0005003oIP030?l00000
ofH00?mV00800?mV0`3o00000`3<o`000?mV003oIP09003oIP030?l0003oool0oooo00<0oooo0@00
00010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`040?l00000ofH00?mV0<co00P00?mV00@0
c?l00?l0003<o`00c?l01`00ofH20<co0003003oIP3<o`000?mV00800?mV1`00I_l2003oIP<0o`00
0P00ofH6001Voa40c03o0`00I_l2003oIP030<co0000I_l006Ko008006Ko4@3<0?l5001Vo`<00?mV
00D0c?l00?l0003o0000o`00003oIP08001Vo`03003oIP3<o`000?mV00X00?mV00@0c?l00?l0003<
o`00c?l01000ofH00`3o00000?mV003oIP03003oIP<0c?l000<00?mV001Vo`00I_l01P00I_l01@00
ofH0o`000?l0003o0000c?l000<00?mV1@00I_lA0<`0o`@006Ko00<0c?l0001Vo`00I_l00`00I_lA
0<`0o`H006Ko00<00?mV0<co003o00000P3o0002003oIPL006Ko00@00?mV0<co003<o`00o`001@00
ofH00`3o00000?mV003oIP02003oIP<0o`0000<0c?l0003oIP00ofH02@00ofH00`3o0000oooo0?oo
o`030?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool30?l000D00?mV00@0o`00
0<co003<o`00c?l00P3o00040<co0080o`001@00ofH20?l000@00?mV1000I_l20<co00800?mV103<
o`08001Vo`h0c03o1@00I_l30?l00005003oIP00I_l006Ko0<co0000I_l03`3<0?l7001Vo`80o`00
00@00?mV0<co003<o`00c?l00P00ofH6001Vo`800?mV00@0c?l00?l0003o0000c?l01000ofH40<co
00@0o`001@3<o`04003oIP<0o`0000<0c?l0003oIP00ofH01P00I_l2003oIP<0c?l00`00ofH7001V
o`l0c03o00H006Ko003oIP00I_l006Ko003oIP3o0002003oIPD006Ko3P3<0?l7001Vo`800?mV0`3<
o`04003oIP@006Ko0P00ofH20<co0080o`001000ofH00`3<o`00o`000?l000020<co00@0o`000`3<
o`000`3o00000?mV003oIP02003oIP040<co003o0000o`000?l000D0oooo0@0000010?ooo`003`3o
ool00`000000oooo0?ooo`020?ooo`<0o`0000<0c?l0003oIP00ofH00P00ofH0103<o`00o`000<co
003<o`040?l000040<co003o0000c?l00<co00<00?mV0P3<o`040?l000P00?mV00<0o`000<co003o
00000`00ofH8001Vo`03003oIP00I_l006Ko00X0c03o1@00I_l00`3<o`00o`000?l000040?l000D0
06Ko2P3<0?l9001Vo`<00?mV103o0009003oIP040<co003o0000o`000?l000@00?mV00@0c?l00?l0
003o0000c?l0103o00001@3<o`00o`000?l0003o0000c?l000@00?mV00@0c?l00?l0003o0000c?l0
2@00ofH0103<o`00o`000?l0003<o`03003oIPT006Ko2P3<0?l5001Vo`80c?l0103o00000`00ofH0
06Ko001Vo`03001Vo`X0c03o0P00I_l00`00ofH006Ko001Vo`06001Vo`<00?mV0P3o0004003oIP03
0?l00000ofH00?mV00800?mV0P3<o`020?l000@00?mV00D0c?l00?l0003o0000o`000<co00040?l0
0080c?l000<0o`000<co0000ofH00`00ofH0103<o`00o`000?l0003o00050?ooo`4000000@3oool0
00l0oooo00<000000?ooo`3oool00P3oool00`3<o`00o`000?l000060<co00T0o`000`3<o`02003o
IP80c?l000@0o`000<co003<o`00c?l02@00ofH40?l000030<co0000I_l006Ko018006Ko00<00?mV
001Vo`00I_l00`00I_l01@00ofH0c?l00<co003o00000?mV01X006Ko0P00ofH01@3<o`00o`000?l0
003o0000c?l000@00?mV00<0c?l0003oIP00ofH00P00ofH00`3<o`00o`000?l000060<co00T0o`00
0`3<o`03003oIP80c?l00P3o00000`3<o`000?mV003oIP02003oIP030?l00000ofH00?mV00800?mV
00D0c?l00?l0003o0000o`000<co0002003oIQX006Ko00D00?mV0?l0003<o`00c?l0003oIP05001V
o`030?l00000I_l006Ko014006Ko0P00ofH30?l000030<co0000ofH00?mV00800?mV00<0c?l0003o
IP00ofH00P00ofH20<co00030?l0003<o`00c?l000H0c?l02@3o00020<co00800?mV00D0o`000<co
003o0000o`000<co00050?ooo`4000000@3oool000l0oooo0P0000030?ooo`030<co003o0000o`00
00H0c?l02@3o00030<co00800?mV0P3<o`00103o0000c?l00<co003<o`09003oIP@0o`0000<0c?l0
001Vo`00I_l04P00I_l00`00ofH006Ko001Vo`03001Vo`05003oIP3<o`00c?l00?l00000ofH06P00
I_l2003oIP050<co003o0000o`000?l0003<o`001000ofH00`3<o`000?mV003oIP02003oIP030<co
003o0000o`0000H0c?l02@3o00030<co00<00?mV0P3<o`020?l000030<co0000ofH00?mV00800?mV
00<0o`00003oIP00ofH00P00ofH01@3<o`00o`000?l0003o0000c?l000800?mV6P00I_l01@00ofH0
o`000<co003<o`000?mV00D006Ko00<0o`00001Vo`00I_l04@00I_l2003oIP<0o`0000<0c?l0003o
IP00ofH00P00ofH00`3<o`000?mV003oIP02003oIP80c?l000<0o`000<co003<o`001P3<o`090?l0
0080c?l00P00ofH01@3o0000c?l00?l0003o0000c?l000@0oooo0P0000010?ooo`003`3oool00`00
0000oooo0?ooo`020?ooo`@0o`001@3<o`090?l000D0c?l01P3o0004003oIP040<co0000ofH00?mV
003oIP<0c?l01000ofH4001Vo`<00?mV4P00I_l3003oIP030<co0000ofH006Ko01<006Ko00<0o`00
001Vo`00I_l00P00I_l4003oIP040<co003o0000o`000<co00@00?mV00<0c?l0003oIP00ofH00P00
ofH40?l000D0c?l02@3o00030<co00040?l0003<o`00c?l00<co00<0o`0000<0c?l0003oIP00ofH0
0P00ofH00`3o00000?mV003oIP02003oIP040<co003o0000o`000<co00<00?mV1@00I_l00`3o0000
06Ko001Vo`0B001Vo`04003oIP3o00000?mV003oIQ<006Ko00<0c?l0003oIP00ofH01000I_l4003o
IP80c?l01000ofH00`3o00000?mV003oIP02003oIP80c?l00P3o00030<co00040?l0003<o`00c?l0
0<co00T0o`001@3<o`030?l000030<co003oool0oooo00<0oooo0@0000010?ooo`003`3oool00`00
0000oooo0?ooo`020?ooo`050<co003o0000o`000?l0003<o`004@3o0000103<o`00o`000?l0003o
00070<co00030?l0003<o`00c?l00080c?l00P3o0008003oIP80o`0000<00?mV001Vo`00I_l02`00
I_l00`00ofH006Ko001Vo`02001Vo`03003oIP3o0000o`000080o`000P00ofH4001Vo`03003oIP00
I_l006Ko00<006Ko00<00?mV001Vo`00I_l01@00I_l3003oIP030<co0000ofH00?mV00<00?mV00<0
c?l00?l0003o0000103<o`020?l000D0c?l00`3o00030<co00l0o`000`3<o`030?l000<0c?l0103o
00030<co00<0o`0000<0c?l0003oIP00ofH01000ofH20<co0003003oIP00I_l006Ko00/006Ko00<0
c?l0001Vo`00I_l00P00I_l2003oIP@0o`0000<00?mV001Vo`00I_l00P00I_l00`3<o`0006Ko001V
o`0;001Vo`03003oIP3o0000o`0000P00?mV00<0c?l00?l0003<o`000`3<o`030?l000@0c?l0103o
00000`3<o`00o`000?l0000=0?l000<0c?l00`3o00000`3<o`00oooo0?ooo`030?ooo`4000000@3o
ool000l0oooo00<000000?ooo`3oool00P3ooolK0?l00080c?l000<0o`000<co003o00000P3o0000
0`3<o`00o`000?l000020?l000<0c?l00P3o0003003oIP040?l0003<o`00c?l0003oIPD006Ko00<0
c?l0001Vo`00I_l01@00I_l00`3<o`000?mV003oIP03003oIP80c?l000<0o`00003oIP00ofH01P00
ofH5001Vo`030<co0000I_l006Ko00D006Ko00@00?mV0?l0003o0000c?l00P00ofH30<co00D0o`00
0P3<o`020?l000<0c?l000<0o`000<co003o00006P3o00000`3<o`00o`000<co00020<co00040?l0
003<o`00c?l00<co00D0o`0000<0c?l00?l0003o00000P00ofH0103<o`00o`000?l00000ofH7001V
o`03003oIP00I_l006Ko00<006Ko2000ofH01@3o00000?mV003oIP00ofH0c?l000<00?mV00<0c?l0
001Vo`00I_l01@00I_l00`00ofH006Ko001Vo`03001Vo`04003oIP3<o`00c?l00<co00<00?mV00@0
o`000<co003<o`00c?l00`3o00030<co00050?l0003<o`00c?l00<co003o00000P3<o`0J0?l00003
0<co003oool0oooo00<0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?oooa/0o`00
0P3<o`000`3o0000c?l00?l000020?l000030<co003o0000o`000080o`000`3<o`020?l000<00?mV
00@0o`000<co003<o`000?mV1@00I_l00`3<o`0006Ko001Vo`05001Vo`030<co0000ofH00?mV00<0
0?mV0P3<o`000`3o00000?mV003oIP06003oIPD006Ko00<0c?l0001Vo`00I_l01@00I_l01000ofH0
o`000?l0003<o`02003oIP<0c?l01@3o00020<co0080o`000`3<o`000`3o0000c?l00?l0000J0?l0
00030<co003o0000c?l00080c?l000@0o`000<co003<o`00c?l01@3o00000`3<o`00o`000?l00002
003oIP040<co003o0000o`00003oIPL006Ko00<00?mV001Vo`00I_l00`00I_l8003oIP050?l00000
ofH00?mV003oIP3<o`000`00ofH00`3<o`0006Ko001Vo`05001Vo`03003oIP00I_l006Ko00<006Ko
00@00?mV0<co003<o`00c?l00`00ofH0103o0000c?l00<co003<o`030?l000<0c?l000D0o`000<co
003<o`00c?l00?l000020<co01X0o`0000<0c?l00?ooo`3oool00`3oool100000040oooo00080?oo
o`8000001@3oool00`000000oooo0?ooo`020?ooobP0o`000P3<o`020?l000<0c?l000@0o`00003o
IP00ofH00?mV1@00I_l3003oIP@006Ko00D00?mV0?l0003o0000o`00003oIP040<co0080o`000P3<
o`02003oIP80o`0000<00?mV001Vo`00I_l00`00I_l3003oIP@006Ko0P00ofH20<co00030?l0003<
o`00c?l003X0o`0000<0c?l00?l0003o00001@3<o`02003oIP@006Ko0`00ofH5001Vo`03003oIP3o
0000o`0000800?mV0`3<o`000`3o0000c?l00<co00020<co0005003oIP3o0000o`000<co0000ofH0
1000I_l3003oIPD006Ko0`00ofH0103o0000c?l00<co003<o`0/0?l000D0oooo0@0000010?ooo`00
1`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo<03o00030<co0003
003oIP3<o`00c?l000800?mV00@0c?l0003oIP00ofH0c?l01000ofH01@3<o`00o`000?l0003o0000
c?l000L0o`000P3<o`020?l00003003oIP3<o`000?mV00<00?mV00<0c?l0003oIP00ofH01@00ofH0
0`3o0000c?l00<co00130?l00080c?l02000ofH00`3<o`000?mV003oIP02003oIP040<co0000ofH0
o`000?l00080c?l01`3o00020<co0080o`0000<0c?l0003oIP00ofH00P00ofH0103o00000?mV003o
IP3<o`02003oIP80c?l000@00?mV0<co003<o`00c?l0<03o00050?ooo`4000000@3oool000L0oooo
00@000000?ooo`3oool00000103oool300000080oooo<`3o0000103<o`00o`000?l00000ofH40?l0
0080c?l00P00ofH00`3<o`00o`000?l0000?0?l000<0c?l000<00?mV0?l0003o00000`3o00040<co
04T0o`000`3<o`000`00ofH0o`000?l000030?l00004003oIP3<o`00c?l00<co0140o`001@3<o`04
0?l000040<co003o0000o`000<co03<0o`00103oool200000040oooo00070?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00P3ooolc0?l000040<co003o0000o`00003oIP@0o`00
0P3<o`02003oIP030<co003o0000o`0000l0o`000`3<o`000`00ofH0o`000?l000030?l000@0c?l0
B@3o00030<co0003003oIP3o0000o`0000<0o`0000@00?mV0<co003<o`00c?l04@3o00050<co00@0
o`0000@0c?l00?l0003o0000c?l0<`3o00050?ooo`4000000@3oool000L0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`020?oooc<0o`0000@0c?l00?l0003o0000c?l0103o0005
0<co0140o`000`3<o`000`00ofH0o`000?l000030?l00004003oIP3<o`00c?l00<co04T0o`00103<
o`050?l00004003oIP3<o`00c?l00<co0140o`0000<0c?l0003oIP00ofH00P3<o`040?l00004003o
IP3o0000o`000<co03<0o`001@3oool100000040oooo00080?ooo`8000001@3oool00`000000oooo
0?ooo`020?oooc00o`000`3<o`000`00ofH0c?l00<co0002003oIP040<co0000ofH00?mV0?l000@0
0?mV00<0c?l00?l0003o00000P3<o`070?l00080c?l00P3o00000`00ofH0c?l0003oIP03003oIP03
0<co0000ofH00?mV00H00?mV0P3<o`130?l00080c?l000<0o`00003oIP00ofH01@00ofH00`3<o`00
0?mV003oIP02003oIP040<co0000ofH0o`000?l00080c?l01`3o00001@3<o`00o`000?l0003o0000
c?l000@00?mV00@0c?l0003oIP00ofH0c?l00P00ofH20<co0004003oIP3<o`00c?l00<co0300o`00
1@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo;03o00030<co00040?l00000
ofH00?mV003oIPD006Ko0`00ofH4001Vo`05003oIP3<o`00o`000?l00000ofH0103<o`00103o0000
c?l00<co003<o`02003oIP80o`0000<00?mV001Vo`00I_l00`00I_l3003oIP@006Ko0P00ofH50<co
0080o`0000<0c?l00?l0003o0000>03o00020<co00030?l0003<o`00c?l000800?mV1000I_l3003o
IPD006Ko00<00?mV0?l0003o00000P00ofH20<co0080o`00103<o`001@00ofH0o`000?l0003o0000
0?mV00@006Ko0`00ofH5001Vo`<00?mV00@0o`000<co003<o`00c?l00P3o00020<co02P0o`001@3o
ool100000040oooo000?0?ooo`030000003oool0oooo0080oooo00<0c?l00?l0003o0000603o0002
0<co00050?l0003<o`00c?l00<co003o00000`3<o`030?l000<0c?l000@0o`00003oIP00ofH00?mV
0`3<o`000`00ofH006Ko001Vo`03001Vo`03003oIP00I_l006Ko00D006Ko00D0c?l0003oIP00ofH0
0?mV0<co0003003oIP030?l00000ofH00?mV00H00?mV1@00I_l00`00ofH006Ko001Vo`05001Vo`04
003oIP3o0000o`000<co00800?mV0P3o00000`3<o`00o`000?l000030?l000<0c?l000H0o`000<co
003<o`00c?l00?l0003<o`0K0?l000030<co003o0000c?l00080c?l00P3o00020<co00D0o`000`3<
o`02003oIP040<co003o0000o`00003oIPL006Ko00<0c?l0001Vo`00I_l00`00I_l8003oIP030?l0
003<o`00c?l000D00?mV00<0c?l0001Vo`00I_l01@00I_l00`3<o`0006Ko001Vo`03001Vo`04003o
IP3<o`00c?l00?l000<00?mV0P3o00030<co00@0o`0000H0c?l00?l0003o0000o`000<co003o0002
0<co01/0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo00<0c?l00?l0
003o0000603o00020<co00050?l0003<o`00c?l00<co003o00000`3<o`030?l000<0c?l000@0o`00
003oIP00ofH00?mV0`3<o`000`00ofH006Ko001Vo`03001Vo`03003oIP00I_l006Ko00D006Ko00D0
c?l0003oIP00ofH00?mV0<co0003003oIP030?l00000ofH00?mV00H00?mV1@00I_l00`00ofH006Ko
001Vo`05001Vo`04003oIP3o0000o`000<co00800?mV0P3o00000`3<o`00o`000?l000030?l000<0
c?l000H0o`000<co003<o`00c?l00?l0003<o`0K0?l000030<co003o0000c?l00080c?l00P3o0002
0<co00D0o`000`3<o`02003oIP040<co003o0000o`00003oIPL006Ko00<0c?l0001Vo`00I_l00`00
I_l8003oIP030?l0003<o`00c?l000D00?mV00<0c?l0001Vo`00I_l01@00I_l00`3<o`0006Ko001V
o`03001Vo`04003oIP3<o`00c?l00?l000<00?mV0P3o00030<co00@0o`0000H0c?l00?l0003o0000
o`000<co003o00020<co01/0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo0080
oooo00@0c?l00?l0003o0000o`000`3<o`0?0?l000030<co003o0000o`000080o`00103<o`030?l0
00@0c?l000<0o`000<co0000ofH01`00ofH20?l00003003oIP00I_l006Ko00/006Ko00<0c?l0001V
o`00I_l00P00I_l00`00ofH0o`000?l000020?l000800?mV1000I_l00`3<o`0006Ko001Vo`0;001V
o`03003oIP3<o`00c?l000H00?mV00@0c?l00?l0003o0000o`000`3<o`040?l000<0c?l00`3o0003
0<co00l0o`000`3<o`030?l000D0c?l00P3o00040<co0080o`0000<0c?l0003oIP00ofH00`00ofH0
103<o`000?mV003oIP00ofH7001Vo`03003oIP00I_l006Ko00<006Ko00<00?mV001Vo`00I_l00P00
I_l2003oIP@0o`0000<00?mV001Vo`00I_l00P00I_l00`00ofH006Ko001Vo`0;001Vo`03003oIP3o
0000o`0000P00?mV0P3o00040<co00030?l0003<o`00c?l000D0c?l00`3o00000`3<o`00o`000?l0
000?0?l000050<co003o0000o`000?l0003<o`001@3oool100000040oooo000?0?ooo`8000000`3o
ool0103<o`00o`000?l0003o00050<co00T0o`000`3<o`00103o0000c?l00<co003<o`020?l00080
c?l01000ofH00`3o00000?mV003oIP02003oIP80c?l01000ofH4001Vo`800?mV00<0c?l0001Vo`00
I_l04@00I_l2003oIP030?l00000ofH006Ko01<006Ko00<0o`00001Vo`00I_l00`00I_l3003oIP04
0<co003o0000o`000<co00@00?mV00<0o`00003oIP00ofH00P00ofH0103<o`00o`000?l0003o0003
0<co00040?l0003<o`00c?l00<co00T0o`001@3<o`040?l000@00?mV00<0c?l0003oIP00ofH00P00
ofH0103<o`00o`000?l0003<o`04003oIP@006Ko00<0o`00001Vo`00I_l04P00I_l00`00ofH0c?l0
003oIP02003oIQ8006Ko0`00ofH4001Vo`@00?mV0`3<o`03003oIP030<co0000ofH00?mV00800?mV
1P3o00050<co00T0o`001@3<o`040?l000@0oooo0P0000010?ooo`003`3oool00`000000oooo0?oo
o`020?ooo`050<co003o0000o`000<co003o00000P00ofH20<co00T0o`00203<o`000`3o0000c?l0
0<co0004003oIP030<co0000ofH00?mV00800?mV00@0c?l00?l0003o0000o`000P00ofHC001Vo`03
0?l00000I_l006Ko00<006Ko00D00?mV0<co003<o`00o`00003oIP0J001Vo`800?mV00D0c?l00?l0
003o0000o`000<co0004003oIP030?l00000ofH00?mV00800?mV00<0c?l00?l0003o00000P3<o`03
003oIP<0c?l02@3o00060<co0080o`0000<0c?l0003oIP00ofH00P00ofH00`3<o`000?mV003oIP02
003oIP050<co003o0000o`000?l0003<o`000P00ofHJ001Vo`05003oIP3o0000c?l00<co0000ofH0
1@00I_l00`00ofH006Ko001Vo`0B001Vo`030<co003o0000o`000080o`002@00ofH30<co00030?l0
003<o`00c?l000800?mV0`3<o`090?l000H0c?l00P3o00000`3<o`00oooo0?ooo`030?ooo`400000
0@3oool000l0oooo00<000000?ooo`3oool00P3oool01@3<o`00o`000?l0003<o`00o`0000800?mV
0P3<o`090?l000P0c?l000<0o`000<co003<o`001000ofH00`3<o`000?mV003oIP02003oIP040<co
003o0000o`000?l000800?mV4`00I_l00`3o000006Ko001Vo`03001Vo`05003oIP3<o`00c?l00?l0
0000ofH06P00I_l2003oIP050<co003o0000o`000?l0003<o`001000ofH00`3o00000?mV003oIP02
003oIP030<co003o0000o`000080c?l00`00ofH30<co00T0o`001P3<o`020?l000030<co0000ofH0
0?mV00800?mV00<0c?l0003oIP00ofH00P00ofH01@3<o`00o`000?l0003o0000c?l000800?mV6P00
I_l01@00ofH0o`000<co003<o`000?mV00D006Ko00<00?mV001Vo`00I_l04P00I_l00`3<o`00o`00
0?l000020?l000T00?mV0`3<o`000`3o0000c?l00<co0002003oIP<0c?l02@3o00060<co0080o`00
00<0c?l00?ooo`3oool00`3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo0`3o
00000`3<o`000?mV003oIP02003oIP040<co003o0000c?l00<co00@0o`0000D0c?l00?l0003o0000
o`000<co0004003oIP80o`000P3<o`04003oIP030?l00000ofH00?mV00800?mV0P3o0003003oIPP0
06Ko00<00?mV001Vo`00I_l02P3<0?l5001Vo`03003oIP3o0000o`000080o`000P3<o`05001Vo`X0
c03o2@00I_l3003oIP040<co003o0000o`000<co00T00?mV00@0c?l00?l0003o0000c?l01000ofH0
1@3<o`00o`000?l0003o0000c?l000@0o`0000@0c?l00?l0003o0000c?l01000ofH30?l000030<co
0000ofH00?mV00L00?mV103o0003003oIPT006Ko2P3<0?l5001Vo`H0o`0000<0c?l0001Vo`00I_l0
0`00I_l:0<`0o`8006Ko00<00?mV001Vo`00I_l01P00I_l3003oIP030?l0003<o`00o`0000P00?mV
103o00020<co00<00?mV0P3<o`000`3o0000c?l00?l000030?l00080c?l000<0o`000<co0000ofH0
0`00ofH0103<o`00o`000?l0003o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0
0P3oool30?l000030<co0000ofH00?mV00800?mV00@0o`000<co003<o`00c?l0103o00020<co0080
o`0000<0c?l0003oIP00ofH00P00ofH20?l00080c?l00P00ofH4001Vo`@00?mV0`3<o`02003oIPL0
06Ko3P3<0?l5001Vo`800?mV00H0o`00003oIP00I_l006Ko003oIP00I_l?0<`0o`L006Ko0`00ofH3
0<co00800?mV1P00I_l2003oIP040<co003o0000o`000?l000@00?mV1@3<o`040?l000@0c?l01000
ofH0103<o`00o`000?l0003<o`02003oIPH006Ko0P00ofH30<co0003003oIP3o0000o`0000L006Ko
3`3<0?l01@00I_l0c?l0001Vo`00I_l00?mV00<0o`001@00I_l>0<`0o`P006Ko103<o`02003oIP80
c?l01000I_l4003oIP80o`001@00ofH20?l000@0c?l00P3o00030<co00030?l00000ofH00?mV00<0
0?mV0`3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool00`3o00000?mV
003oIP09003oIP040<co003o0000o`000?l000@00?mV00<0o`00003oIP00ofH00`00ofH0103o0000
c?l00<co0000ofH7001Vo`800?mV0`3o00000`3<o`000?mV001Vo`05001Voa40c03o1@00I_l00`3<
o`0006Ko001Vo`02001Voa40c03o1@00I_l3003oIP050<co003o0000o`000?l00000ofH02000I_l0
1000ofH0c?l00<co003<o`05003oIP030?l00000ofH00?mV00800?mV00@0c?l00?l0003o0000c?l0
2`00ofH00`3<o`000?mV001Vo`07001Vo`05003oIP3o0000o`000?l0003<o`000`00ofH5001Voa40
c03o1000I_l00`3<o`000?mV003oIP03001Voa40c03o1P00I_l2003oIP<0o`000P00ofH7001Vo`<0
0?mV00@0c?l0003oIP3<o`00c?l01`00ofH20<co00030?l0003<o`000?mV00L00?mV00@0c?l0003o
IP00ofH0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo00<0o`00003o
IP00ofH02@00ofH0103<o`00o`000?l0003o0004003oIP030?l00000ofH00?mV00<00?mV00@0o`00
0<co003<o`000?mV1`00I_l2003oIP<0o`0000<0c?l0003oIP00I_l01@00I_lA0<`0o`D006Ko00<0
c?l0001Vo`00I_l00P00I_lA0<`0o`D006Ko0`00ofH01@3<o`00o`000?l0003o00000?mV00P006Ko
00@00?mV0<co003<o`00c?l01@00ofH00`3o00000?mV003oIP02003oIP040<co003o0000o`000<co
00/00?mV00<0c?l0003oIP00I_l01`00I_l01@00ofH0o`000?l0003o0000c?l000<00?mV1@00I_lA
0<`0o`@006Ko00<0c?l0003oIP00ofH00`00I_lA0<`0o`H006Ko0P00ofH30?l000800?mV1`00I_l3
003oIP040<co0000ofH0c?l00<co00L00?mV0P3<o`000`3o0000c?l0003oIP07003oIP040<co0000
ofH00?mV0?l000D0oooo0@0000010?ooo`003`3oool2000000<0oooo00@0c?l0003oIP00ofH00?mV
0`00I_l6003oIP030?l0003<o`00c?l000H00?mV0`00I_l01@00ofH0o`000<co003<o`000?mV00P0
06Ko00<00?mV0<co003o00001P3o0003001Voa80c03o0P00I_l20<co00030?l00000ofH006Ko0080
06Ko4P3<0?l3001Vo`80c?l0103o00020<co0003003oIP00I_l006Ko00H006Ko00D00?mV0<co003o
0000o`00003oIP03001Vo`H00?mV00<0c?l00?l0003o00001P00ofH3001Vo`<00?mV00<0o`00003o
IP00I_l01`00I_l3003oIP@0o`0000<0c?l00?l00000I_l00P00I_lB0<`0o`<006Ko00@00?mV0?l0
003<o`00c?l00P00I_lB0<`0o`<006Ko00<0o`00003oIP00ofH0103o00000`3<o`000?mV001Vo`08
001Vo`800?mV00<0o`00003oIP00I_l00`00I_l5003oIP80c?l000<0o`000<co0000ofH01000ofH3
001Vo`<00?mV00<0c?l00?ooo`3oool00P3oool200000040oooo000?0?ooo`030000003oool0oooo
0080oooo00<00?mV001Vo`00I_l01P00I_l3003oIP@0o`0000@0c?l0003oIP00ofH00?mV1P00I_l0
0`00ofH0o`000?l00009001Vo`030<co003o0000o`000080o`0000<00?mV001Vo`00I_l00P00I_lE
0<`0o`<006Ko00@0c?l0001Vo`00I_l006Ko5@3<0?l3001Vo`800?mV00D0o`000<co003o0000o`00
003oIP08001Vo`04003oIP3<o`000?mV003oIPH006Ko0`00ofH00`3<o`00o`000?l000020?l000<0
0?mV2000I_l00`3<o`000?mV001Vo`07001Vo`05003oIP3o0000o`000<co003o00000P00ofH5001V
oa<0c03o0`00I_l01000ofH006Ko001Vo`00I_lE0<`0o`@006Ko00@00?mV0<co003o0000o`000P3<
o`09001Vo`80c?l000<00?mV001Vo`00I_l01000I_l4003oIP80c?l000<0o`000<co0000ofH00`00
ofH7001Vo`030<co003oool0oooo00<0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`02
0?ooo`T006Ko0`00ofH20?l00080c?l01000ofH7001Vo`800?mV2@00I_l00`3o00000?mV0?l00002
0?l00003003oIP00I_l006Ko008006Ko5@3<0?l01000I_l00?mV003oIP3o0003001VoaD0c03o0`00
I_l2003oIP050?l00000ofH00?mV003oIP3o00002000I_l2003oIPP006Ko0P3<o`02003oIP040<co
003o0000o`000?l000<00?mV2000I_l2003oIPP006Ko1000ofH00`3<o`000?mV003oIP03001VoaD0
c03o0`00I_l0103o00000?mV003oIP00I_lE0<`0o`@006Ko00<00?mV0<co0000ofH00P00ofH00`3o
00000?mV001Vo`07001Vo`80o`002@00I_l2003oIP80c?l000<0o`000<co0000ofH00P00ofH9001V
o`D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`T006Ko1000ofH30?l00080
0?mV2`00I_l00`00ofH006Ko001Vo`05001Vo`03003oIP00I_l006Ko008006Ko0P00ofH4001VoaH0
c03o0P00I_l00`3<o`0006Ko0<`0o`0F0<`0o`<006Ko0P3<o`000`00ofH006Ko001Vo`0:001Vo`03
003oIP00I_l006Ko00T006Ko0P00ofH30?l000@00?mV2@00I_l00`3<o`0006Ko001Vo`0:001Vo`04
003oIP3<o`00c?l0003oIP8006Ko5`3<0?l00`00I_l0c?l0001Vo`02001VoaD0c03o1000I_l00`3o
0000c?l0001Vo`03001Vo`030?l00000I_l006Ko014006Ko1000ofH00`3o00000?mV003oIP02003o
IPT006Ko1@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo2@00I_l4003oIP<0
o`000P00ofH;001Vo`03003oIP00I_l006Ko00D006Ko00<00?mV001Vo`00I_l00P00I_l2003oIP@0
06Ko5P3<0?l2001Vo`030<co0000I_l0c03o01H0c03o0`00I_l20<co0003003oIP00I_l006Ko00X0
06Ko00<00?mV001Vo`00I_l02@00I_l2003oIP<0o`001000ofH9001Vo`030<co0000I_l006Ko00X0
06Ko00@00?mV0<co003<o`000?mV0P00I_lG0<`0o`03001Vo`3<o`0006Ko008006Ko5@3<0?l4001V
o`030?l0003<o`0006Ko00<006Ko00<0o`00001Vo`00I_l04@00I_l4003oIP030?l00000ofH00?mV
00800?mV2@00I_l50?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool9001Vo`<0
0?mV0P3o00020<co00800?mV2`00I_l00`00ofH006Ko001Vo`0:001Vo`04003oIP3o00000?mV003o
IP8006Ko5P3<0?l2001Vo`030<co0000I_l0c03o01H0c03o0P00I_l01000ofH0o`000?l00000ofHH
001Vo`800?mV00@0c?l00?l0003o0000c?l00`00ofHA001Vo`03003oIP00I_l006Ko008006Ko00@0
0?mV0?l0003o0000o`000P00I_lG0<`0o`04001Vo`3o000006Ko001VoaL0c03o00D006Ko003oIP00
ofH0o`00003oIP0<001Vo`03003oIP00I_l006Ko00T006Ko0P00ofH20<co00030?l0003<o`000?mV
00800?mV2@00I_l50?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool9001Vo`<0
0?mV00H0c?l00?l0003o0000o`000<co0000ofH=001Vo`H0c03o1@00I_l4003oIP8006Ko5P3<0?l2
001Vo`030<co0000I_l0c03o01H0c03o0P00I_l4003oIPD006Ko1P3<0?l=001Vo`03003oIP3<o`00
o`000080o`0000@0c?l0003oIP00ofH00?mV2`00I_l60<`0o`D006Ko1000ofH2001VoaL0c03o00@0
06Ko003oIP00I_l006Ko5`3<0?l3001Vo`040<co0000ofH00?mV003oIP<006Ko1P3<0?l=001Vo`80
0?mV0`3o0000103<o`000?mV003oIP00ofH9001Vo`D0oooo0@0000010?ooo`003`3oool00`000000
oooo0?ooo`020?ooo`T006Ko00@0o`00003oIP00ofH0c?l00`3o0000103<o`000?mV003oIP00ofH9
001Vo`X0c03o1@00I_l20?l00003003oIP00I_l0c03o01D0c03o0P00I_l00`3o0000c03o0<`0o`0F
0<`0o`03001Vo`00ofH0o`0000@006Ko303<0?l9001Vo`<00?mV00H0c?l00?l0003o0000o`000<co
0000ofH20?l000T006Ko303<0?l4001Vo`030?l0003<o`0006Ko01P0c03o00<00?mV001Vo`00I_l0
5P3<0?l2001Vo`80c?l000<00?mV001Vo`00I_l00P00I_l:0<`0o`T006Ko1000ofH40?l000@00?mV
2000I_l50?ooo`4000000@3oool000l0oooo0P0000030?ooo`T006Ko00@0o`00003oIP00ofH0c?l0
0`3o0000103<o`000?mV003oIP00ofH9001Vo`X0c03o1@00I_l20?l00003003oIP00I_l0c03o01D0
c03o0P00I_l00`3o0000c03o0<`0o`0F0<`0o`03001Vo`00ofH0o`0000@006Ko303<0?l9001Vo`<0
0?mV00H0c?l00?l0003o0000o`000<co0000ofH20?l000T006Ko303<0?l4001Vo`030?l0003<o`00
06Ko01P0c03o00<00?mV001Vo`00I_l05P3<0?l2001Vo`80c?l000<00?mV001Vo`00I_l00P00I_l:
0<`0o`T006Ko1000ofH40?l000@00?mV2000I_l40?ooo`8000000@3oool000l0oooo00<000000?oo
o`3oool00P3oool00`3<0?l006Ko001Vo`04001Vo`800?mV2@3o00020<co0003003oIP00I_l006Ko
00@006Ko3`3<0?l01000I_l00?mV003oIP00ofH2001VoaP0c03o00<0c?l00<`0o`3<0?l05P3<0?l2
001Vo`<00?mV00<006Ko0<`0o`3<0?l0303<0?l7001Vo`03003oIP3<o`00c?l000L0o`000P3<o`00
0`00ofH006Ko001Vo`05001Vo`h0c03o00<006Ko003oIP00ofH00P00ofH00`00I_l0c03o0<`0o`0F
0<`0o`<006Ko5P3<0?l2001Vo`80c?l00P00I_l@0<`0o`D006Ko0`3<o`0:0?l00003003oIP00I_l0
06Ko00@006Ko00<0c03o0?ooo`3oool00`3oool100000040oooo000?0?ooo`030000003oool0oooo
0080oooo0`3<0?l2001Vo`80o`001@00ofH0103<o`00o`000?l0003o0004003oIP030<co0000ofH0
0?mV00<006Ko4@3<0?l01@00I_l00?mV003oIP3o000006Ko01P0c03o00<0o`000<`0o`3<0?l05P3<
0?l00`00I_l0o`00003oIP02001Voa40c03o0P00I_l2003oIP030<co0000ofH00?mV00<00?mV0`3o
00000`3<o`000?mV003oIP03003oIP80c?l00P00I_lA0<`0o`<006Ko00<0o`00001Vo`3<0?l05`3<
0?l00`3o0000c03o0<`0o`0F0<`0o`05001Vo`00ofH0c?l00<co0000I_l04@3<0?l4001Vo`060?l0
0000ofH00?mV003oIP3o00000?mV0P3<o`000`3o0000c?l0003oIP04003oIP80c?l00P00I_l30<`0
o`D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`<0c03o1`00I_l2003oIP03
0<co003o0000c?l00080c?l000<00?mV001Vo`00I_l01@00I_lC0<`0o`8006Ko00<0o`00001Vo`3<
0?l05`3<0?l00`00ofH0c03o0<`0o`0F0<`0o`03001Vo`3o000006Ko01@0c03o1`00I_l00`00ofH0
c?l00<co00030?l00003003oIP00I_l006Ko00D006Ko00<0c?l00<`0o`3<0?l04@3<0?l00`00I_l0
0?mV003oIP0H0<`0o`03003oIP3<0?l0c03o01H0c03o00@006Ko0?l00000I_l006Ko4`3<0?l8001V
o`05003oIP3o0000o`000?l0003<o`000P00ofH7001Vo`<0c03o1@3oool100000040oooo000?0?oo
o`030000003oool0oooo0080oooo0`3<0?l7001Vo`800?mV00<0c?l00?l0003<o`000P3<o`000`00
ofH006Ko001Vo`05001Voa<0c03o0P00I_l00`3o000006Ko0<`0o`0G0<`0o`03003oIP3<0?l0c03o
01H0c03o00<006Ko0?l00000I_l0503<0?l7001Vo`03003oIP3<o`00c?l000<0o`0000<00?mV001V
o`00I_l01@00I_l00`3<o`00c03o0<`0o`0A0<`0o`03001Vo`00ofH00?mV01P0c03o00<00?mV0<`0
o`3<0?l05P3<0?l01000I_l0o`00001Vo`00I_lC0<`0o`P006Ko00D00?mV0?l0003o0000o`000<co
0002003oIPL006Ko0`3<0?l50?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool4
0<`0o`P006Ko00<00?mV0<co0000ofH00P00ofH8001VoaD0c03o00<006Ko003oIP3<0?l05`3<0?l0
0`00ofH0c03o0<`0o`0D0<`0o`8006Ko00<0c?l0001Vo`3<0?l0503<0?l8001Vo`800?mV0P3<o`00
0`00ofH006Ko001Vo`06001VoaD0c03o00@006Ko0?l00000I_l006Ko5P3<0?l00`00I_l0c03o0<`0
o`0F0<`0o`03001Vo`00ofH0c03o01@0c03o2000I_l3003oIP040?l00000ofH00?mV003oIPH006Ko
103<0?l50?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool40<`0o`P006Ko00D0
0?mV0?l0003o0000o`00003oIP06001VoaP0c03o0`00I_lF0<`0o`030<co003<0?l0c03o01@0c03o
0`00I_lF0<`0o`P006Ko00D00?mV0<co003<o`00c?l0003oIP08001VoaH0c03o0`00I_lF0<`0o`03
001Vo`3<0?l0c03o01@0c03o0P00I_l00`00ofH0c03o0<`0o`0F0<`0o`H006Ko00D00?mV0<co003<
o`00o`00003oIP08001Vo`@0c03o1@3oool100000040oooo000?0?ooo`8000000`3oool40<`0o`P0
06Ko00<00?mV0<co0000ofH00P00ofH6001VoaP0c03o0`00I_lF0<`0o`03001Vo`3<0?l0c03o01@0
c03o0P00ofHH0<`0o`L006Ko00D00?mV0<co003<o`00c?l0003oIP08001VoaL0c03o0P3o000F0<`0
o`03001Vo`3<0?l0c03o01@0c03o0`00I_lH0<`0o`H006Ko0`00ofH0103o00000?mV003oIP00ofH6
001Vo`@0c03o103oool200000040oooo000?0?ooo`030000003oool0oooo0080oooo103<0?l8001V
o`03003oIP3<o`000?mV00800?mV1P00I_lH0<`0o`<006Ko5P3<0?l00`00I_l0c03o0<`0o`0D0<`0
o`800?mV603<0?l7001Vo`05003oIP3<o`00c?l00<co0000ofH02000I_lG0<`0o`80o`005P3<0?l0
0`00I_l0c03o0<`0o`0D0<`0o`<006Ko603<0?l6001Vo`<00?mV00@0o`00003oIP00ofH00?mV1P00
I_l40<`0o`D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`@0c03o1P00I_l2
003oIP040<co003o0000o`000?l000800?mV1@00I_lI0<`0o`800?mV5P3<0?l00`00I_l0c03o0<`0
o`0C0<`0o`03001Vo`3<o`00c?l001P0c03o1P00I_l2003oIP<0o`0000<0c?l0003oIP00I_l01P00
I_lG0<`0o`<006Ko5@3<0?l00`00I_l0c03o0<`0o`0D0<`0o`800?mV6@3<0?l5001Vo`800?mV103o
0003003oIPD006Ko103<0?l50?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool4
0<`0o`<006Ko00<00?mV0?l0003<o`000`3<o`070?l00003003oIP00I_l006Ko01/0c03o00<006Ko
0<`0o`3<0?l03`3<0?l90?l00140c03o00<00?mV0<`0o`3<0?l0603<0?l3001Vo`050<co003o0000
o`000?l0003<o`000`3o00040<co00030?l00000ofH006Ko008006Ko6@3<0?l00`3o0000c03o0<`0
o`0?0<`0o`X0o`00403<0?l00`00I_l0c03o0<`0o`0I0<`0o`8006Ko00<00?mV0?l0003o00000P3<
o`030?l000<0c?l00P3o00001000ofH006Ko001Vo`00I_l40<`0o`D0oooo0@0000010?ooo`003`3o
ool00`000000oooo0?ooo`020?ooo`@0c03o1@00I_l00`00ofH0c?l00<co00040?l00080c?l00P00
ofH5001VoaT0c03o00<0c?l00<`0o`3<0?l01`3<0?lI0?l000T0c03o00<006Ko0<`0o`3<0?l05`3<
0?l5001Vo`800?mV0P3<o`030?l00080c?l00P00ofH5001Vob<0c03o6@3o00090<`0o`030<co003<
0?l0c03o01T0c03o0`00I_l2003oIP030<co003o0000o`0000<0o`000P3<o`000`3o000006Ko001V
o`03001Vo`@0c03o1@3oool100000040oooo00070?ooo`D000000`3oool00`000000oooo0?ooo`02
0?ooo`@0c03o1@00I_l3003oIP060<co003o0000o`000?l0003<o`000?mV1`00I_lN0<`0ob80o`00
103<0?l00`00I_l0c03o0<`0o`0H0<`0o`L006Ko00<00?mV0<co003o00000P3o0000103<o`000?mV
003oIP00ofH5001VoaX0c03o00<0o`000<`0o`3<0?l00P3<0?lR0?l001h0c03o1`00I_l2003oIP@0
o`000`00ofH5001Vo`@0c03o1@3oool100000040oooo00090?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool40<`0o`D006Ko0`00ofH01P3<o`00o`000?l0003o0000c?l0003o
IPL006Ko7P3<0?lR0?l000@0c03o00<006Ko0<`0o`3<0?l0603<0?l7001Vo`03003oIP3<o`00o`00
0080o`0000@0c?l0003oIP00ofH00?mV1@00I_lJ0<`0o`030?l0003<0?l0c03o0080c03o8P3o000N
0<`0o`L006Ko0P00ofH40?l000<00?mV1@00I_l40<`0o`D0oooo0@0000010?ooo`002@3oool00`00
0000oooo0?ooo`030?ooo`<000000P3oool30<`0o`H006Ko00<00?mV0?l0003o00001@3o0003003o
IPD006Ko6P3<0?l00`00I_l0o`000?l0000W0?l001/0c03o1@00I_l2003oIPH0o`0000<0c?l0003o
IP00ofH01P00I_lJ0<`0obX0o`006P3<0?l2003oIPD006Ko00<00?mV0?l0003o00001@3o00000`00
ofH006Ko001Vo`03001Vo`04003oIP3<0?l0c03o0<`0o`@0oooo0P0000010?ooo`002@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0`3<0?l2001Vo`800?mV00<006Ko003o
IP00ofH01P3o00000`3<o`000?mV003oIP03003oIP040<co0000I_l006Ko001VoaP0c03o;@3o000H
0<`0o`8006Ko0P00ofH00`00I_l00?mV003oIP02003oIP030<co003o0000o`000080o`001000ofH0
0`00I_l00?mV003oIP02001VoaP0c03o;@3o000H0<`0o`<006Ko00<0o`00003oIP00ofH00P3<o`00
0`00ofH0c?l00?l000050?l000H00?mV0`00I_l00`3<0?l0oooo0?ooo`030?ooo`4000000@3oool0
00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030<`0o`00ofH00?mV
008006Ko103<o`0;0?l00080c?l000<00?mV001Vo`00I_l00P00I_lD0<`0oc<0o`004`3<0?l4001V
o`800?mV00<0o`000<co003o00002P3o00040<co00@006Ko503<0?lb0?l001@0c03o1000I_l00`00
ofH0c?l00<co00020<co00T0o`0000@0c?l00?l0003o0000o`001000I_l00`3<0?l0oooo0?ooo`03
0?ooo`4000000@3oool000P0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<0c03o003o
IP00ofH00P00I_l40<co00/0o`000P3<o`000`00ofH006Ko001Vo`02001Voa@0c03o<`3o000C0<`0
o`@006Ko0P00ofH00`3o0000c?l00?l0000:0?l000@0c?l01000I_lD0<`0oc80o`00503<0?l4001V
o`03003oIP3<o`00c?l00080c?l02@3o0000103<o`00o`000?l0003o0004001Vo`030<`0o`3oool0
oooo00<0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`<006Ko00<00?mV0<co
003o00000P3o00001000ofH0c?l0003oIP00ofH40?l000040<co0000ofH00?mV003oIP<0o`000P00
ofH0103o000006Ko001Vo`00I_lA0<`0ocD0o`004@3<0?l01@00ofH006Ko001Vo`3o00000?mV00<0
o`000`3<o`000`00ofH0c?l00?l000020?l000050<co0000ofH0o`000?l00000ofH0103o0000103<
o`0006Ko001Vo`00I_lA0<`0ocD0o`004@3<0?l3001Vo`03003oIP3<o`00c?l000<0o`000`00ofH5
0?l00080c?l00P00ofH01@3<o`00o`000?l0003<o`000?mV00<006Ko1@3oool100000040oooo000?
0?ooo`030000003oool0oooo0080oooo00D00?mV0<co003<o`00c?l0001Vo`02003oIP030<co0000
I_l00?mV00800?mV1@3o00001P00ofH006Ko001Vo`00I_l0o`00001Vo`800?mV00<0c?l00?l00000
I_l00P00I_l=0<`0ocT0o`003`3<0?l2001Vo`80o`000P00ofH2001Vo`050<co0000I_l006Ko001V
o`00ofH01@3o0003003oIP06001Vo`3<o`000?mV003oIP00I_l00?mV0P3o0002001Vo`l0c03o>@3o
000=0<`0o`<006Ko00L0o`00003oIP00ofH00?mV001Vo`3<o`000?mV008006Ko00<00?mV0?l0003o
00000`3o00020<co0003003oIP00I_l00?mV00800?mV00D006Ko0?l0003o0000o`00003oIP050?oo
o`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool:001Vo`800?mV00@0c?l00?l0003o
0000o`000P00ofH3001Vo`03003oIP00I_l006Ko00<006Ko0`3o00000`00I_l0c03o0<`0o`090<`0
ocd0o`002`3<0?l00`00I_l0o`00003oIP02003oIPP006Ko0P00ofH30?l000030<co0000ofH006Ko
00X006Ko00<00?mV001Vo`3<0?l02`3<0?ll0?l000/0c03o00@006Ko003oIP00ofH00?mV1@00I_l0
0`3o000006Ko001Vo`02001Vo`05003oIP3o0000o`000?l0003<o`000P00ofH6001Vo`040<co0000
I_l006Ko001Vo`D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`X006Ko0P00
ofH0103<o`00o`000?l0003o0002003oIP<006Ko00<00?mV001Vo`00I_l00`00I_l30?l00003001V
o`3<0?l0c03o00T0c03o?@3o000;0<`0o`03001Vo`3o00000?mV00800?mV2000I_l2003oIP<0o`00
00<0c?l0003oIP00I_l02P00I_l00`00ofH006Ko0<`0o`0;0<`0oc`0o`002`3<0?l01000I_l00?mV
003oIP00ofH5001Vo`030?l00000I_l006Ko008006Ko00D00?mV0?l0003o0000o`000<co0002003o
IPH006Ko00@0c?l0001Vo`00I_l006Ko1@3oool100000040oooo000?0?ooo`8000000`3oool50<`0
o`D006Ko0`3<o`001@3o0000c?l00<co003o0000c?l000@006Ko1`3<0?l01000I_l00?mV001Vo`00
I_l70<`0od00o`00203<0?l2003oIP8006Ko1@3<0?l6001Vo`03003oIP3o0000o`000080o`0000<0
c?l0003oIP00I_l01@00I_l50<`0o`8006Ko0P3o00080<`0od00o`001`3<0?l2001Vo`03003oIP00
I_l0c03o00H0c03o1000I_l01000ofH0o`000<co003<o`040?l000D006Ko1@3<0?l40?ooo`800000
0@3oool000l0oooo00<000000?ooo`3oool00P3oool80<`0o`05001Vo`00ofH006Ko001Vo`00ofH0
0`3<o`02001Vo`800?mV00<006Ko0<`0o`3<0?l02P3<0?l00`00ofH0c03o0<`0o`030<`0od<0o`00
1@3<0?l00`00I_l0c03o0<`0o`0:0<`0o`05001Vo`3<o`00c?l0001Vo`00ofH00`3<o`001@00ofH0
06Ko003oIP00ofH006Ko00`0c03o00<00?mV001Vo`3<0?l00`3<0?m30?l000D0c03o00<0o`000<`0
o`3<0?l02P3<0?l5001Vo`<0o`0000<00?mV001Vo`00I_l00P00I_l80<`0o`D0oooo0@0000010?oo
o`003`3oool00`000000oooo0?ooo`020?ooo`T0c03o1000I_l00`3<o`000?mV003oIP04001Voa80
c03oA@3o00000`3<0?l006Ko001Vo`0?0<`0o`@006Ko00<00?mV0<co003<o`001000I_l?0<`0o`80
c?l000<0c03o0?l0003o0000@`3o00030<`0o`03001Vo`3<0?l0c03o00`0c03o1000I_l2003oIP03
0?l00000I_l006Ko00<006Ko203<0?l50?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool0
0P3oool90<`0o`<006Ko00@00?mV0?l00000ofH00?mV1000I_lA0<`0odL0o`004@3<0?l4001Vo`<0
c?l01000I_lA0<`0o`03003oIP3o0000o`0004@0o`004`3<0?l2001Vo`800?mV00<0o`00003oIP00
I_l00P00I_l90<`0o`D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`T0c03o
0`00I_l01000ofH0o`00003oIP00ofH4001Voa40c03oA`3o000A0<`0o`@006Ko0`3<o`04001Voa40
c03o00<00?mV0?l0003o0000A03o000C0<`0o`8006Ko0P00ofH00`3o00000?mV001Vo`02001Vo`T0
c03o1@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo2@3<0?l3001Vo`03003o
IP3o00000?mV00800?mV00<006Ko0<`0o`3<0?l03`3<0?m90?l001<0c03o00<006Ko0<co003<o`00
0P3<o`001000ofH006Ko001Vo`00I_lA0<`0odT0o`004@3<0?l01000I_l00?mV003oIP00ofH20?l0
00<006Ko2@3<0?l50?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool90<`0o`@0
06Ko0`00ofH2001Voa40c03oB`3o000A0<`0o`8006Ko0`00ofH4001Vo`l0c03oB`3o000A0<`0o`80
06Ko0P00ofH00`3<o`0006Ko001Vo`02001Vo`T0c03o1@3oool100000040oooo000?0?ooo`800000
0`3oool90<`0o`@006Ko00<0c?l0003oIP00ofH00P00I_l@0<`0odd0o`003P3<0?l4001Vo`03003o
IP3<o`00c?l000@006Ko3P3<0?m=0?l00100c03o0P00I_l20<co00030?l00000ofH006Ko008006Ko
2@3<0?l40?ooo`8000000@3oool000l0oooo00<000000?ooo`3oool00P3oool90<`0o`@006Ko00<0
c?l0003oIP00ofH00P00I_l@0<`0odd0o`003P3<0?l4001Vo`03003oIP3<o`00c?l000@006Ko3P3<
0?m=0?l00100c03o0P00I_l20<co00030?l00000ofH006Ko008006Ko2@3<0?l50?ooo`4000000@3o
ool000l0oooo00<000000?ooo`3oool00P3oool90<`0o`03001Vo`00ofH00?mV00@0o`0000@00?mV
001Vo`00I_l006Ko3@3<0?m>0?l000h0c03o0`00I_l50?l000<006Ko3P3<0?m>0?l000d0c03o0`00
I_l00`00ofH0o`000?l000020?l000800?mV00<006Ko0<`0o`3<0?l01`3<0?l50?ooo`4000000@3o
ool000l0oooo00<000000?ooo`3oool00P3oool80<`0o`@006Ko00D00?mV0?l0003<o`00c?l0003o
IP04001Vo``0c03oC`3o000<0<`0o`@006Ko00D00?mV0?l0003o0000o`00003oIP04001Vo``0c03o
C`3o000=0<`0o`<006Ko00D00?mV0<co003<o`00o`000<co0004001Vo`P0c03o1@3oool100000040
oooo000?0?ooo`030000003oool0oooo0080oooo1`3<0?l2001Vo`<00?mV00@0c?l00?l0003o0000
o`000P00ofH20<co008006Ko2@3<0?mC0?l000T0c03o0P00I_l20?l000800?mV0`3o0002003oIP80
c?l00P00I_l;0<`0oe40o`002@3<0?l2001Vo`800?mV00<0o`00003oIP3o00001@3o00000`00ofH0
06Ko001Vo`070<`0o`D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`L0c03o
0P00I_l3003oIP040<co003o0000o`000?l000800?mV0P3<o`02001Vo`T0c03oD`3o00090<`0o`80
06Ko0P3o0002003oIP<0o`000P00ofH20<co008006Ko2`3<0?mA0?l000T0c03o0P00I_l2003oIP03
0?l00000ofH0o`0000D0o`0000<00?mV001Vo`00I_l01`3<0?l50?ooo`4000000@3oool000l0oooo
00<000000?ooo`3oool00P3oool40<`0o`<006Ko0P3o0000103<o`000?mV003oIP3<o`030?l00007
003oIP3<o`00c?l00<co003o0000c?l0003oIP080<`0oe<0o`001P3<0?l3001Vo`04003oIP3o0000
c?l00<co00800?mV0`3o0002003oIP80o`0000<00?mV0<co0000I_l00P00I_l60<`0oe@0o`001`3<
0?l00`00I_l00?mV0?l000030?l000040<co003o0000o`000?l000@0c?l000D00?mV0?l00000ofH0
0?mV001Vo`040<`0o`D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`030<`0
o`00I_l006Ko00T006Ko00@00?mV0?l0003<o`00c?l02@00I_l00`3o0000c03o0<`0o`020<`0oeD0
o`000P3<0?l2001Vo`04003oIP00I_l00?mV003oIP8006Ko0P3o00000`00I_l00?mV0<co00020?l0
0004003oIP00I_l00?mV003oIPD006Ko0`00ofH20<`0oeD0o`00103<0?l00`3o000006Ko001Vo`07
001Vo`80c?l000<0o`00003oIP00I_l01`00I_l01000ofH0c?l00<co003<0?l50?ooo`4000000@3o
ool000l0oooo0P0000030?ooo`T0c03o0`00I_l20?l00080c?l000<00?mV001Vo`3<0?l02`3<0?mE
0?l000X0c03o0`00I_l01@3o0000c?l00<co003<o`00o`0000<006Ko2@3<0?l00`3<o`00o`000?l0
001D0?l0008006Ko2@3<0?l01000I_l00?mV0<co003<o`020?l000<006Ko2@3<0?l40?ooo`800000
0@3oool000l0oooo00<000000?ooo`3oool00P3oool90<`0o`<006Ko0P3o00020<co0003003oIP00
I_l0c03o00/0c03oE@3o000:0<`0o`<006Ko00D0o`000<co003<o`00c?l00?l00003001Vo`T0c03o
00<0c?l00?l0003o0000E03o0002001Vo`T0c03o00@006Ko003oIP3<o`00c?l00P3o0003001Vo`T0
c03o1@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo2P3<0?l3001Vo`03003o
IP00I_l006Ko008006Ko2`3<0?mG0?l000/0c03o0P00I_l3003oIP8006Ko2`3<0?mG0?l000`0c03o
0`00I_l0103<o`0006Ko001Vo`00I_l:0<`0o`D0oooo0@0000010?ooo`003`3oool00`000000oooo
0?ooo`020?ooo`X0c03o0`00I_l0103o00000?mV003oIP00I_l<0<`0oeL0o`00303<0?l01@00I_l0
0?mV003oIP00ofH006Ko00`0c03oE`3o000<0<`0o`04001Vo`00ofH00?mV0?l000<006Ko2P3<0?l5
0?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool:0<`0o`<006Ko00@00?mV001V
o`00I_l006Ko2P3<0?mJ0?l000/0c03o00D006Ko003oIP00ofH00?mV001Vo`0<0<`0oeT0o`002P3<
0?l3001Vo`040<co0000I_l006Ko001Vo`X0c03o1@3oool100000040oooo000?0?ooo`030000003o
ool0oooo0080oooo00<0o`000<`0o`3<0?l01`3<0?l2003oIP05001Vo`3o00000?mV003oIP00I_l0
2P3<0?mJ0?l000X0c03o0P00I_l00`00ofH0c?l00<co0002001Vo`X0c03oFP3o000:0<`0o`05001V
o`00ofH00?mV0?l00000I_l00P00ofH:0<`0o`D0oooo0@0000010?ooo`003`3oool00`000000oooo
0?ooo`020?ooo`030?l0003<0?l0c03o00L0c03o0P00ofH01@00I_l0o`00003oIP00ofH006Ko00X0
c03oFP3o000:0<`0o`8006Ko00<00?mV0<co003<o`000P00I_l:0<`0oeX0o`002P3<0?l01@00I_l0
0?mV003oIP3o000006Ko00800?mV2P3<0?l50?ooo`4000000@3oool000l0oooo0P0000030?ooo`03
0?l0003<0?l0c03o00L0c03o0P00I_l01000ofH0o`00003oIP00ofH2001Vo`T0c03oFP3o000:0<`0
o`8006Ko00<0c?l00?l0003o00000P00I_l:0<`0oe/0o`00203<0?l2001Vo`800?mV00<0o`00003o
IP00I_l00P00I_l80<`0o`030?l0003oool0oooo0080oooo0P0000010?ooo`003`3oool00`000000
oooo0?ooo`020?ooo`030?l0003<0?l0c03o00D0c03o0P00I_l3003oIP<0o`000P00ofH20?l000H0
c03oG@3o00050<`0o`<006Ko00<0o`000<co003o00000P3o00020<co00<006Ko1@3<0?mM0?l000H0
c03o0P00I_l2003oIP80c?l000@0o`00003oIP3<o`00c?l00P00I_l70<`0o`030?l0003oool0oooo
00<0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`<0o`000P3<0?l20<co0003
003oIP3o000006Ko00<00?mV0`3o00000`00I_l00?mV001Vo`02001Vo`03003oIP00I_l0c03o0080
c03oG@3o00020<`0o`8006Ko00H0c?l0001Vo`3o0000o`00003oIP3<o`030?l000800?mV1000I_l2
003oIP80c03oG@3o00030<`0o`03001Vo`3<o`0006Ko00@006Ko0P00ofH0103o00000?mV003oIP00
ofH3001Vo`80o`000P3<0?l30?l000D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`02
0?ooo`<0o`000P3<0?l20<co0003003oIP3o000006Ko00<00?mV0`3o00000`00I_l00?mV001Vo`02
001Vo`03003oIP00I_l0c03o0080c03oG@3o00020<`0o`8006Ko00H0c?l0001Vo`3o0000o`00003o
IP3<o`030?l000800?mV1000I_l2003oIP80c03oG@3o00030<`0o`03001Vo`3<o`0006Ko00@006Ko
0P00ofH0103o00000?mV003oIP00ofH3001Vo`80o`000P3<0?l30?l000D0oooo0@0000010?ooo`00
3`3oool00`000000oooo0?ooo`020?ooo`<0o`001`3<0?l2001Vo`05003oIP3o0000o`000?l00000
I_l0203<0?mN0?l000P0c03o0P00I_l00`3o0000c?l00<co0002001Vo`P0c03oGP3o00080<`0o`05
001Vo`3o0000o`000?l00000ofH00P00I_l70<`0o`<0o`001@3oool100000040oooo000?0?ooo`03
0000003oool0oooo0080oooo0`3o00090<`0o`03001Vo`00ofH006Ko008006Ko203<0?mO0?l000P0
c03o0P00I_l2003oIP03001Vo`3<0?l0c03o00H0c03oG`3o00080<`0o`<006Ko00<0c?l0001Vo`3<
0?l0203<0?l30?l000D0oooo0@0000010?ooo`001`3oool4000000@0oooo00<000000?ooo`3oool0
0P3oool40?l000P0c03o00D006Ko0<co0000ofH00?mV001Vo`080<`0oel0o`00203<0?l01@00I_l0
o`00003oIP00ofH006Ko00P0c03oG`3o00090<`0o`8006Ko00<0o`00001Vo`3<0?l01`3<0?l40?l0
00D0oooo0@0000010?ooo`001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo103o00080<`0o`05001Vo`3<o`000?mV003oIP00I_l0203<0?mO0?l000P0c03o00D006Ko0?l0
0000ofH00?mV001Vo`080<`0oel0o`002@3<0?l2001Vo`030?l00000I_l0c03o00L0c03o103o0005
0?ooo`4000000@3oool000P0oooo00<000000?ooo`3oool0103oool300000080oooo103o00080<`0
o`03001Vo`00ofH006Ko008006Ko203<0?mO0?l000P0c03o00D006Ko003oIP3<o`00c?l0001Vo`08
0<`0of40o`001P3<0?l3001Vo`030?l00000I_l0c03o00L0c03o103o00040?ooo`8000000@3oool0
00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`@0o`001P3<0?l3001V
o`040?l00000ofH00?mV001Vo`H0c03oHP3o00060<`0o`8006Ko00<00?mV0<co003<o`000P00I_l7
0<`0of40o`001P3<0?l01000I_l00?mV003oIP3o0003001Vo`H0c03o103o00050?ooo`4000000@3o
ool000L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`D0o`000`3<
0?l00`00I_l0c?l00?l000070?l0008006Ko0`3<0?mR0?l000<0c03o0`00I_l00`3<o`00o`000?l0
00020?l000050<co003o0000c?l00<co0000I_l00`3<0?mR0?l000<0c03o0P00ofH20?l00080c?l0
103o00000`00ofH006Ko0<`0o`030<`0o`@0o`001@3oool100000040oooo00080?ooo`8000001@3o
ool00`000000oooo0?ooo`020?ooo`D0o`001@3<0?l3001Vo`040?l00000ofH00?mV001Vo`H0c03o
HP3o00070<`0o`04001Vo`00ofH0c?l00<co008006Ko1P3<0?mR0?l000H0c03o00@006Ko003oIP00
ofH0o`000`00I_l50<`0o`D0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo0080
oooo1@3o00050<`0o`<006Ko00@0o`00003oIP00ofH006Ko1P3<0?mR0?l000L0c03o00@006Ko003o
IP3<o`00c?l00P00I_l60<`0of80o`001P3<0?l01000I_l00?mV003oIP3o0003001Vo`D0c03o1@3o
00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool50?l000L0c03o00@006Ko
0<co0000I_l006Ko1P3<0?mS0?l000L0c03o1@00I_l70<`0of<0o`001P3<0?l2001Vo`030?l00000
I_l0c03o00H0c03o1@3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool5
0?l000L0c03o00@006Ko003oIP00I_l006Ko1P3<0?mU0?l000H0c03o00@006Ko003oIP00ofH006Ko
1`3<0?mS0?l000H0c03o0P00I_l00`3o000006Ko0<`0o`060<`0o`D0o`001@3oool100000040oooo
000?0?ooo`8000000`3oool70?l000D0c03o00D006Ko0<co003<o`00c?l0001Vo`050<`0ofD0o`00
1@3<0?l01@00I_l0o`000<co003<o`0006Ko00D0c03oI@3o00060<`0o`80c?l000<0o`00001Vo`3<
0?l01P3<0?l50?l000@0oooo0P0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`L0o`00
1@3<0?l01@00I_l0c?l00<co003<o`0006Ko00D0c03oI@3o00050<`0o`05001Vo`3o0000c?l00<co
0000I_l01@3<0?mU0?l000H0c03o0P3<o`000`3o000006Ko0<`0o`060<`0o`D0o`001@3oool10000
0040oooo000?0?ooo`030000003oool0oooo0080oooo1`3o00030<`0o`8006Ko00H00?mV0?l00000
ofH00?mV0<co0000I_l40<`0ofD0o`00103<0?l00`00I_l0c?l00<co00020?l000800?mV103<0?mU
0?l000@0c03o00H00?mV001Vo`00ofH00?mV0?l00000ofH3001Vo`80c03o1`3o00050?ooo`400000
0@3oool000l0oooo00<000000?ooo`3oool00P3oool70?l000<0c03o0`00I_l0103o00000?mV003o
IP3<o`050<`0ofD0o`001@3<0?l01@00I_l00?mV003oIP00ofH006Ko00D0c03oIP3o00040<`0o`<0
06Ko00@0o`00001Vo`00I_l006Ko0`3<0?l70?l000D0oooo0@0000010?ooo`003`3oool00`000000
oooo0?ooo`020?ooo`L0o`001@3<0?l01000I_l0c?l0001Vo`00I_l50<`0ofL0o`001@3<0?l3001V
o`H0c03oIP3o00050<`0o`8006Ko00<0o`00001Vo`3<0?l0103<0?l70?l000D0oooo0@0000010?oo
o`003`3oool00`000000oooo0?ooo`020?ooo`L0o`001@3<0?l01000I_l0c?l0001Vo`00I_l50<`0
ofL0o`001@3<0?l3001Vo`H0c03oIP3o00050<`0o`8006Ko00<0o`00001Vo`3<0?l0103<0?l70?l0
00D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`L0o`001P3<0?l00`00ofH0
06Ko001Vo`050<`0ofL0o`001@3<0?l3001Vo`D0c03oI`3o00050<`0o`8006Ko00<00?mV001Vo`3<
0?l0103<0?l70?l000D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`P0o`00
103<0?l00`00I_l0c?l0001Vo`02001Vo`@0c03oI`3o00040<`0o`05001Vo`00ofH00?mV003oIP00
I_l0103<0?mW0?l000D0c03o0P00I_l00`3o000006Ko0<`0o`040<`0o`L0o`001@3oool100000040
oooo000?0?ooo`8000000`3oool80?l000@006Ko00@00?mV0?l00000ofH00?mV0P00I_l20<co0003
0<`0o`3o0000o`0006D0o`0000<0c03o001Vo`00I_l00P00I_l01000ofH0c?l00<co003o0004001V
ofL0o`0000<0c03o003oIP00ofH00P00I_l2003oIP050?l00000ofH006Ko001Vo`00ofH02@3o0004
0?ooo`8000000@3oool000l0oooo00<000000?ooo`3oool00P3oool80?l000@006Ko00@00?mV0?l0
0000ofH00?mV0P00I_l20<co00030<`0o`3o0000o`0006D0o`0000<0c03o001Vo`00I_l00P00I_l0
1000ofH0c?l00<co003o0004001VofL0o`0000<0c03o003oIP00ofH00P00I_l2003oIP050?l00000
ofH006Ko001Vo`00ofH02@3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3o
ool80?l000D0c03o00<00?mV001Vo`00I_l01@3<0?mW0?l000D0c03o0`00I_l50<`0ofP0o`00103<
0?l2001Vo`800?mV103<0?l80?l000D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`02
0?ooo`P0o`001@3<0?l00`00ofH006Ko001Vo`040<`0ofP0o`001@3<0?l3001Vo`D0c03oJ03o0004
0<`0o`8006Ko00<00?mV0<`0o`3<0?l00`3<0?l80?l000D0oooo0@0000010?ooo`003`3oool00`00
0000oooo0?ooo`020?ooo`P0o`00103<0?l01000I_l0c?l0001Vo`00I_l40<`0ofT0o`000`3<0?l0
0`00I_l00?mV003oIP02003oIP@0c03oJ03o00040<`0o`8006Ko00<0o`00001Vo`3<0?l00`3<0?l8
0?l000D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`P0o`00103<0?l20?l0
00<006Ko0`3<0?mY0?l000<0c03o00D006Ko003oIP3<o`00c?l0001Vo`030<`0ofT0o`000`3<0?l3
001Vo`030?l00000I_l0c03o00<0c03o203o00050?ooo`4000000@3oool000l0oooo00<000000?oo
o`3oool00P3oool80?l000@0c03o0P3o0003001Vo`<0c03oJ@3o00030<`0o`05001Vo`00ofH0c?l0
0<co0000I_l00`3<0?mY0?l000<0c03o0`00I_l00`3o000006Ko0<`0o`030<`0o`P0o`001@3oool1
00000040oooo000?0?ooo`8000000`3oool90?l000@0c03o00<00?mV001Vo`00I_l0103<0?mY0?l0
00@0c03o0`00I_l40<`0ofT0o`00103<0?l2001Vo`03003oIP3<0?l0c03o00<0c03o203o00040?oo
o`8000000@3oool000l0oooo00<000000?ooo`3oool00P3oool90?l000@0c03o00<00?mV0<co003<
o`00103<0?mY0?l000@0c03o00<006Ko003oIP00ofH0103<0?mY0?l000@0c03o0P00I_l00`3o0000
c03o0<`0o`020<`0o`T0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo
2@3o00000`3<0?l0c?l00<co00020?l00080c?l000@0o`00001Vo`3<0?l0c03oJ@3o00020<`0o`03
0<co003o0000o`0000@0o`000P3<0?m[0?l00003001Vo`3o0000o`0000<0o`000P3<o`000`3<0?l0
o`000?l000070?l000D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`T0o`00
00<0c03o0<co003<o`000P3o00020<co00040?l00000I_l0c03o0<`0ofT0o`000P3<0?l00`3<o`00
o`000?l000040?l00080c03oJ`3o00000`00I_l0o`000?l000030?l00080c?l000<0c03o0?l0003o
00001`3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool90?l000@0c03o
00<00?mV001Vo`00I_l0103<0?mY0?l000@0c03o0`00I_l40<`0of/0o`000P3<0?l2001Vo`03003o
IP3<0?l0c03o0080c03o2@3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3o
ool90?l000@0c03o0`00I_l20<`0of/0o`00103<0?l3001Vo`@0c03oJ`3o00020<`0o`8006Ko00<0
0?mV0<`0o`3<0?l00P3<0?l90?l000D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`02
0?ooo`T0o`0000<0c03o001Vo`00I_l0103o00000`00ofH0c03o0?l0001/0?l00003001Vo`3<o`00
o`000080c?l000@0o`00003oIP3<0?l0c03oJ`3o00000`3<0?l0o`000?l000020?l000040<co0000
I_l006Ko0<`0o`T0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo2@3o
00000`3<0?l006Ko001Vo`040?l00003003oIP3<0?l0o`0006`0o`0000<006Ko0<co003o00000P3<
o`00103o00000?mV0<`0o`3<0?m[0?l000030<`0o`3o0000o`000080o`0000@0c?l0001Vo`00I_l0
c03o2@3o00050?ooo`4000000@3oool000l0oooo0P0000030?ooo`T0o`00103<0?l3001Vo`80c03o
K@3o00020<`0o`<006Ko0P3<0?m]0?l000@0c03o00<0c?l00<`0o`3<0?l00P3<0?l90?l000@0oooo
0P0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`X0o`000`3<0?l00`00ofH006Ko001V
o`020<`0ofd0o`000P3<0?l00`00ofH0o`000?l000020<`0ofd0o`000P3<0?l2001Vo`030<co003<
0?l0c03o0080c03o2@3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool:
0?l00080c03o00@006Ko0?l00000I_l006Ko0P3<0?m]0?l00080c03o00D006Ko003oIP00ofH006Ko
0<`0o`1]0?l00080c03o0P00ofH00`3o000006Ko0<`0o`020<`0o`T0o`001@3oool100000040oooo
000?0?ooo`030000003oool0oooo0080oooo2P3o00020<`0o`04001Vo`3o000006Ko001Vo`80c03o
K@3o00020<`0o`05001Vo`00ofH00?mV001Vo`3<0?l0K@3o00020<`0o`800?mV00<0o`00001Vo`3<
0?l00P3<0?l90?l000D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`X0o`00
0`3<0?l00`00ofH0c03o0<`0o`020<`0ofd0o`000P3<0?l00`00I_l00?mV003oIP020<`0ofd0o`00
103<0?l0103<o`00c03o0<`0o`3<0?l:0?l000D0oooo0@0000010?ooo`00203oool2000000D0oooo
00<000000?ooo`3oool00P3oool:0?l00080c03o00@006Ko0<co0000ofH00?mV0P3<0?m]0?l00080
c03o1000ofH00`3<0?l0o`000?l0001[0?l00080c03o0P00ofH0103o000006Ko0<`0o`3<0?l:0?l0
00D0oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0080oooo2P3o00030<`0o`03001Vo`3<0?l0c03o0080c03oK@3o00020<`0o`<006Ko0P3<0?m^0?l0
00<0c03o00@00?mV0<`0o`3<0?l0c03o2P3o00050?ooo`4000000@3oool000T0oooo00<000000?oo
o`3oool00`3oool300000080oooo2P3o00030<`0o`040<co0000I_l006Ko0<`0ofh0o`000P3<0?l3
001Vo`80c03oKP3o00030<`0o`040?l0003<0?l0c03o0<`0o`X0o`00103oool200000040oooo000:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool:0?l000<0c03o00@0c?l0
001Vo`00I_l0c03oKP3o00020<`0o`<006Ko0P3<0?m^0?l000<0c03o00@0o`000<`0o`3<0?l0c03o
2P3o00050?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?ooo`X0o`000`3<0?l0103o000006Ko001Vo`3<0?m^0?l00080c03o00<006Ko003oIP00
ofH00P3<0?m^0?l000<0c03o00@0c?l00<`0o`3<0?l0c03o2P3o00050?ooo`4000000@3oool000P0
oooo0P0000050?ooo`030000003oool0oooo0080oooo2P3o00030<`0o`04003oIP3<0?l0c03o0<`0
ofl0o`0000@0c03o001Vo`00ofH00?mV0P3<0?m^0?l000<0c03o00@0c?l00<`0o`3<0?l0c03o2P3o
00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool:0?l000<0c03o00@00?mV
001Vo`00I_l0c03oK`3o0000103<0?l006Ko001Vo`00I_l20<`0ofh0o`000`3<0?l0103o0000c03o
0<`0o`3<0?l:0?l000D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo`X0o`00
0`3<0?l01000ofH006Ko001Vo`3<0?m_0?l000040<`0o`00I_l006Ko001Vo`80c03oKP3o00030<`0
o`040?l0003<0?l0c03o0<`0o`X0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo
0080oooo2P3o00030<`0o`04003oIP3<0?l0c03o0<`0ofl0o`0000D0c03o001Vo`00ofH00?mV0<`0
o`1_0?l000<0c03o00@00?mV0<`0o`3<0?l0c03o2P3o00050?ooo`4000000@3oool000l0oooo00<0
00000?ooo`3oool00P3oool:0?l000<0c03o00@0o`000<`0o`3<0?l0c03oK`3o00001@3<0?l006Ko
001Vo`00I_l0c03o06l0o`000`3<0?l0103<o`00c03o0<`0o`3<0?l:0?l000D0oooo0@0000010?oo
o`003`3oool2000000<0oooo303o00000`3<0?l00?mV0<`0o`020<`0ofl0o`0000D0c03o001Vo`00
I_l006Ko0<`0o`1_0?l000<0c03o00@0o`000<`0o`3<0?l0c03o2P3o00040?ooo`8000000@3oool0
00l0oooo00<000000?ooo`3oool00P3oool<0?l000030<`0o`00ofH0c03o0080c03oK`3o00001@3<
0?l006Ko001Vo`00I_l0c03o06l0o`000`3<0?l0103o0000c03o0<`0o`3<0?l:0?l000D0oooo0@00
00010?ooo`003`3oool00`000000oooo0?ooo`020?ooo``0o`0000<0c03o001Vo`3<0?l00P3<0?m_
0?l00080c03o0P00I_l00`3<0?l0o`000?l0001]0?l000<0c03o00@00?mV0<`0o`3<0?l0c03o2P3o
00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3oool<0?l000050<`0o`00ofH0
06Ko001Vo`3<0?l0K`3o00001@3<0?l0c?l0003oIP00ofH0c03o06l0o`0000D0c03o001Vo`00I_l0
o`000<`0o`0<0?l000D0oooo0@0000010?ooo`003`3oool00`000000oooo0?ooo`020?ooo``0o`00
00<0c03o001Vo`3<0?l00P3<0?m_0?l00080c03o0P00I_l00`3<0?l0o`000?l0001]0?l000<0c03o
00<00?mV0<`0o`3o00002`3o00050?ooo`4000000@3oool000l0oooo00<000000?ooo`3oool00P3o
ool<0?l000050<`0o`00ofH006Ko001Vo`3<0?l0K`3o00001@3<0?l006Ko001Vo`00I_l0c03o06l0
o`000`3<0?l00`3<o`00c03o0?l0000;0?l000D0oooo0@0000010?ooo`003`3oool00`000000oooo
0?ooo`020?ooo``0o`0000D0c03o003oIP00I_l006Ko0<`0o`1_0?l000050<`0o`00I_l006Ko001V
o`3<0?l0K`3o00030<`0o`030<co003<0?l0o`0000/0o`001@3oool100000040oooo000?0?ooo`80
00000`3oool<0?l000030<`0o`00ofH0c03o0080c03oK`3o00001@3<0?l006Ko001Vo`00I_l0c03o
0700o`000P3<0?l00`3<o`00c03o0?l0000;0?l000@0oooo0P0000010?ooo`003`3oool00`000000
oooo0?ooo`020?ooo``0o`0000<0c03o001Vo`3<0?l00P3<0?m_0?l000D0c03oL03o00020<`0o`03
003oIP3<0?l0o`0000/0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo0080oooo
303o0000103<0?l006Ko0<`0o`3<0?m`0?l000050<`0o`00I_l006Ko001Vo`3<0?l0L03o00020<`0
o`030<co003<0?l0o`0000/0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo0080
oooo303o0000103<0?l006Ko0<`0o`3<0?m`0?l000050<`0o`00I_l006Ko001Vo`3<0?l0L03o0002
0<`0o`030<co003<0?l0o`0000/0o`001@3oool100000040oooo000?0?ooo`030000003oool0oooo
0080oooo303o0000103<0?l00?mV001Vo`00I_m`0?l000050<`0o`00I_l006Ko001Vo`3<0?l0L03o
00020<`0o`030?l0003<0?l0o`0000/0o`001@3oool100000040oooo000?0?ooo`030000003oool0
oooo0?l0oooo3@3oool100000040oooo000?0?ooo`030000003oool0oooo0?l0oooo3@3oool10000
0040oooo000?0?ooo`8000005P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0C0?ooo`8000000@3oool000l0oooo
0P0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool200000040oooo
000?0?ooool000004@0000010?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.05282, -4.01427, 0.026816, \
0.026816}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(gr15 = 
        DensityPlot[
          juliaC1[x, y, 90, 
            3.96,  .01], \[IndentingNewLine]{x, \(- .5\),  .5}, {y, \(- .5\), \
 .5}, PlotPoints \[Rule] 200, Mesh -> False, 
          ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.961538 0.5 0.961538 [
[.11538 -0.0125 -12 -9 ]
[.11538 -0.0125 12 0 ]
[.30769 -0.0125 -12 -9 ]
[.30769 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -9 -9 ]
[.69231 -0.0125 9 0 ]
[.88462 -0.0125 -9 -9 ]
[.88462 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11538 -24 -4.5 ]
[-0.0125 .11538 0 4.5 ]
[-0.0125 .30769 -24 -4.5 ]
[-0.0125 .30769 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .69231 -18 -4.5 ]
[-0.0125 .69231 0 4.5 ]
[-0.0125 .88462 -18 -4.5 ]
[-0.0125 .88462 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-0.4)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-0.2)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(0.2)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(0.4)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.06731 0 m
.06731 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11538 m
.00625 .11538 L
s
[(-0.4)] -0.0125 .11538 1 0 Mshowa
0 .30769 m
.00625 .30769 L
s
[(-0.2)] -0.0125 .30769 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .69231 m
.00625 .69231 L
s
[(0.2)] -0.0125 .69231 1 0 Mshowa
0 .88462 m
.00625 .88462 L
s
[(0.4)] -0.0125 .88462 1 0 Mshowa
.125 Mabswid
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .25962 m
.00375 .25962 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .74038 m
.00375 .74038 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .06731 m
.00375 .06731 L
s
0 .01923 m
.00375 .01923 L
s
0 .93269 m
.00375 .93269 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.25962 .99625 m
.25962 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.74038 .99625 m
.74038 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.06731 .99625 m
.06731 1 L
s
.01923 .99625 m
.01923 1 L
s
.93269 .99625 m
.93269 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .11538 m
1 .11538 L
s
.99375 .30769 m
1 .30769 L
s
.99375 .5 m
1 .5 L
s
.99375 .69231 m
1 .69231 L
s
.99375 .88462 m
1 .88462 L
s
.125 Mabswid
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .06731 m
1 .06731 L
s
.99625 .01923 m
1 .01923 L
s
.99625 .93269 m
1 .93269 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FFCC00FF6600FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00CCFF00CCFF00CCFF00
CCFF00CCFF0000CCFF00FFCCCCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF6600CCFF00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF660066FF00FF6600FF6600FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600
FF660000FF66FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FFCC00FFCC00FF6600FF6600FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF0000FF6600FF66CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600
00FF00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF660000FF00FF6600FF6600FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600
FFCC00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600CCFF00FF6600FFCC00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
CCFF00CCFF0000FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FFCC00
FFCC0066FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600CCFF00FFCC00FF6600FF6600FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600CCFF0066FF0066FF00
00FFCC00FF00CC00FF00FF6600FFCC00FF0000FF00CCFF00CCFF00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600CCFF0000FF66
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600CCFF00FF6600FFCC00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
CCFF00CCFF0000FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FFCC00
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FFCC0066FF00FFCC00FF6600FF6600FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FFCC00CCFF00FFCC00
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FFCC00FFCC00FF6600FF6600FF6600
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC0066FF0000FF0000FF000000FFFFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF660000FF000000FF
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FFCC006600FF00FF66FF6600FF6600
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FFCC00FFCC00FFCC00FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600CCFF00FFCC00FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC0066FF00CCFF00CCFF00
CCFF00CCFF0000FF66FF0000CCFF00CCFF00CCFF00CCFF0000FF00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF660066FF00CCFF00FFCC00
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FFCC00CCFF00FFCC00CCFF00
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00CCFF006600FF
66FF0066FF0000CCFF00FFCC66FF0000FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FFCC0000FF66FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600CCFF006600FFFFCC00FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF6600CCFF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF660066FF00FFCC00FFCC00FFCC00FFCC00FFCC0000FF00
66FF0000FF00FF00000000FF00FF0066FF0000FF66FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00FFCC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF660066FF00CCFF0000FF00FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FFCC00CCFF00FFCC00FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF6600FF6600FF6600CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF00FF0000CC00FF00FFCC00FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC000066FFFFCC00FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF6600FF6600FFCC0066FF0066FF0000FFCCFF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF6600FF6600FF6600FF6600FF6600FF6600FFCC0066FF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00CCFF0066FF00
66FF0000FF0000CCFF00FFCC00FF0000FF66CCFF00CCFF00FFCC00FFCC00FFCC0066FF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FF0000FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF6600FF6600FFCC00CCFF00FFCC00FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FFCC00FF0066CCFF00
00FF00FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC0066FF00FF0066
66FF00CCFF00CCFF00CCFF00FFCC00CCFF0000FFCCCCFF00CCFF00CCFF00CCFF00CCFF00
66FF0000FF000000FF00CCFF00FF0066FF00CCFF00CCFF00CCFF0066FF00CCFF0000FF66
FFCC00FFCC0066FF00FFCC00CCFF00CCFF0000FF6666FF00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF6600FF6600FFCC00FFCC00FFCC00CCFF00FFCC00FF6600FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FFCC000000FF00FF0000FFCC
FFCC00FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
66FF00CCFF0066FF000000FF00CCFF00FF6600FFCC66FF00CCFF0066FF0066FF0066FF00
0066FF00FF660066FF00CCFF00FF0066FF0066FF0066FF00CCFF0066FF0000FF6600FF00
66FF0066FF00FF000066FF00CCFF00CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF6600FF6600FF6600FF6600FFCC0000FF6600FFCCCCFF00CCFF00FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FFCC0066FF00CCFF00
FFCC00FF6600FF6600FF6600FF6600FF6600FFCC00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC0066FF00CCFF00CCFF0066FF0000FF6600FF0066FF0000FFCC0066FFFF00CC
00CCFF6600FF0000FFFF0000FF00006600FF00FFCC00FFCC00FF00FF000000FF0000FF00
00FF00CCFF00CCFF00CCFF00FFCC0000FF00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF6600FF6600FF6600FF6600FF6600FF6600CCFF0000FFCCCCFF00FFCC0000FF66FFCC00
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FFCC006600FF
FFCC00FF6600FF6600FF6600FF6600CCFF00FF6600FF6600FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00FFCC00FFCC0066FF0066FF00CCFF00CCFF0000FF00CCFF0066FF00
00FF0000FFCCCC00FF00CCFF00FF0066FF00FF0066CCFF00CCFF00CCFF00CCFF0000FF66
CCFF00FFCC00FFCC00CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FFCC00CCFF00
00FF00FFCC00FFCC00CCFF00FFCC00FF6600FF6600FF6600FF6600FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00FFCC0000CCFFCCFF00FFCC00FFCC00CCFF00CCFF00CCFF00
66FF0000FF000000FF00FFCC00FF0066FF00CCFF00CCFF0066FF00FFCC00FFCC00CCFF00
CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600
FF660000FF00FF6600FF6600FF6600FFCC00CCFF00FFCC00FF6600FF6600FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FFCC00CCFF00
0066FF66FF0000FF00CCFF00FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF00
00CCFF00FF006600FF00FFCCFF000000FF6666FF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600
FF6600FF660066FF00FFCC00FFCC00CCFF00FF0000FFCC00FF6600FF6600FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FFCC00FFCC0066FF0000FF66
FF0000CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00
66FF0000FF000066FF00FF6666FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC0066FF0000FF6600FF00FFCC00CCFF00FF6600FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
00FF6600FFCCCCFF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00
66FF0000FF000066FF0066FF66FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00FFCC0000FF6666FF00CCFF0000FFCC66FF00FFCC00FFCC00
FFCC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
CCFF0066FF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0000FF00
FF00CC00FF660000FF00CCFF00FF0000FF0000FF66CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00CCFF000000FF66FF00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC000000FFFFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFF0066FF00CCFF0000FF66
CCFF0000FF0000CCFF00FF6666FF00CCFF0066FF0000FF6600FF66CCFF00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF6600FF660000CCFFFF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC0000FF00CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC0066FF00FFCC00FFCC00FFCC00FF6600FF6600FFCC00CCFF00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF660000FF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF0000FF00FF000000FFCCCCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC0066FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF660066FF00FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC0066FF0000FF66FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00CCFF0066FF000066FFFFCC0000FF00FFCC00FF0000FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600
FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF0000FF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600CCFF0066FF00CCFF00
FFCC00FFCC00CCFF00CCFF0000CCFFFFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC0066FF0000FFCC66FF00CCFF0000FF00CCFF00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF0000FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00CCFF00
CCFF00FFCC00FFCC0066FF0000FF00CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FFCCFF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
CCFF0066FF000066FF00CCFF66FF00CCFF00CCFF00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600CCFF00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF0000FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF660000FF66FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
00CCFFCCFF00CCFF0000FF6666FF00CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF660000FFCC00FF0066FF0066FF0066FF00FF00CC
66FF0066FF0000CCFF00FF6600FF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600CCFF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00CCFF0000FF006600FF00FF66CCFF00CCFF00FFCC000000FFFFCC00FF6600FF6600
FF6600FFCC00FFCC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC0066FF00
FFCC00CCFF0066FF0000FFCC66FF00CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600CCFF00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF0000FFCC00FFCC00FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00CCFF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00CCFF0000FF660066FF66FF0066FF0066FF00CCFF0000FF00CCFF00FFCC00FFCC00
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00CCFF0000FF000000FFCCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00CCFF00CCFF00CCFF00CCFF00CCFF0000FF66
CCFF0000FF0000CCFF00FF66CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00CCFF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
66FF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF660066FF00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
00FFCC00FF00FF000000FF66CCFF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF660000FF00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC0000CCFFFFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFF0000FFCC00FF0000FFCC
00FFCC0066FFCC00FF00FFCCFF0000FF006600FFCC66FF0066FF00FFCC00FFCC00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
CCFF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC0066FF00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00CCFF0000FFCC66FF0066FF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00FFCC00CCFF0066FF00CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC0000FF00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF00
CCFF0066FF00FF000000FFCC66FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC000066FF
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC0066FF00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC0000FF0000FF00CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00CCFF00FF006600FF66FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC0000FF00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00CCFF00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF0066FF000000FF00FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF0000FF00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF00
CCFF0000FF00CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00CCFF0000FF66CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FFCC00FFCC00CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC0066FF0000CCFFFFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0000FF66
CCFF0066FF0000FF6666FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC0000FF66FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC0000FF00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
CCFF0000FFCC00FF66CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00FFCC00CCFF0000FF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF0066FF00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF0000FF00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF0000FF66CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00CCFF00CCFF00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
66FF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FFCC00CCFF00FFCC00FFCC00FFCC00
CCFF006600FFCCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00FFCC00FFCC00CCFF0000FF66CCFF00FF000000FF00FFCC00FFCC00FFCC00
CCFF00FFCC00FFCC00CCFF0000FF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC0066FF00FFCC00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
66FF0066FF0000FFCC00FF0066FF0066FF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFF0000FF66FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF660000FF66
CCFF00CCFF00CCFF00FFCC00FFCC0000FF00FFCC00FFCC00FFCC0066FF00FFCC00FFCC00
CCFF0000FF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600CCFF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC0066FF00CCFF0066FF00CCFF0000CCFF00FF0066FF00CCFF00FFCC00FFCC00FFCC00
CCFF00CCFF00CCFF0066FF00CCFF0000FF00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC0000FF6600CCFF66FF00FFCC00
FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF00CCFF0000FF6666FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC0000FF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFF00CCFF0066FF00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC0000FF66CCFF00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00CCFF0066FF00CCFF00
00FF0000FF00CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600
0000FFFF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00CCFF00FF006600FF0000CCFF00FFCC00FF66CCFF00CCFF00FFCC00CCFF00
CCFF0000CCFF00FF66CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF0066FF0000FF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0000FF66FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00
CCFF00CCFF0000FF6666FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC0000CCFFFFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF0000FF00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
CCFF00CCFF0066FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00CCFF0066FF0000FF00
6600FF66FF00CCFF00CCFF006600FFFFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FF6600FF6600FF6600FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC0066FF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF0066FF0000FF0000CCFF00FF0066FF00CCFF00CCFF00CCFF00
00FF0000FF0000FF66CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFF0000CCFF66FF00
CCFF0066FF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0066FF0000CCFF66FF0066FF0000FF66CCFF00CCFF00CCFF00FFCC00CCFF00CCFF00
00FF66FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC0066FF00FFCC00FFCC0000CCFF0066FFCCFF00CCFF00CCFF00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00CCFF0000FF00FF00CCCCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF00
0066FF00FF0066FF00CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600CCFF00FF6600FF6600FF6600FF6600FF6600FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC0000FF66CCFF00CCFF00FFCC00FFCC00CCFF00FFCC00FFCC00CCFF00
FFCC00FFCC00FFCC0066FF000066FF00FF66FF006600FF6666FF0066FF00CC00FF0000FF
CCFF0066FF00CCFF0066FF00CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC0000FFCCFF0066
00FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
6600FFFF00000000FF00FFCC00FF00CCFF00CCFF00CCFF0066FF00CCFF0066FF0000FF66
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC0000FF66CCFF0066FF00CCFF00FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00CCFF0000FF0000FF0000FF66CCFF0066FF00CCFF0066FF0000FF0000CCFF
00FF6666FF00CCFF00FFCC00FFCC00FFCC00FFCC0066FF00FFCC00FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00CCFF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00FFCC0000FF6666FF00FFCC0066FF00FFCC00FFCC000066FF
CCFF00CCFF00CCFF00CCFF0066FF0000FF000000FF00CCFF00FFCC00CCFF66FF0000FF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFF000066FF6600FF
66FF00CCFF00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FF0066FF0000FF00CCFF00CCFF00CCFF00
66FF0000FF00FF00CC00FFCC66FF0066FF00CCFF00CCFF000066FF66FF0000FF6666FF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF0000FFCC00FFCCCCFF00FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC0000FF00CCFF00CCFF0066FF00CCFF0000CCFF00FF6666FF0066FF0000FF006600FF
00FFCC0066FF66FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF00
FFCC00FFCC00FF0000FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF660066FF00FFCC00CCFF00CCFF000066FF66FF0066FF0000FF00
66FF00CCFF0000CCFF66FF0066FF006600FFFF00CC0066FF00FF6600FF00CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600CCFF00CCFF0066FF00CCFF00CCFF0000FFCC
00FF00CCFF00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0000FF0000CCFF00FF0066FF0066FF00
00FF00CC00FF6600FF00CCFF00FF6666FF000066FF66FF006600FF00FF66CCFF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF00FFCC00
FFCC00FFCC00FFCC00CCFF0066FF00FF00CC66FF000000FFCCFF00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0066FF0000FF6600FF6600FFCCFF0000
00FF6666FF00CCFF00CCFF00CCFF00CCFF0000FF00CCFF00FFCC0000FF66FFCC00CCFF00
00FF00CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00CCFF0000FF0066FF0000FFCC
00FF0066FF0000FF0066FF0066FF006600FF00CCFFFF00660066FF66FF0066FF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
66FF0066FF00CCFF00CCFF00CCFF00CCFF0000FFCCCCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF0000CCFF00FF000000FF0066FF00FF00
00FF6600FFCCFF000000CCFF00FFCC00FF6600FF6600FFCC0000FF00FF0066FF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FF00CCFF00
FFCC00FFCC00CCFF0066FF0066FF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0000FF0000FFCC6600FFFF0066
CC00FF00FF0066FF0066FF00CCFF0000FF0000FF6600FF0000FF0000CCFF66FF00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFF0066FF00
CCFF00CCFF0066FF00CCFF00CCFF0066FF0000FF66CC00FFFF000000FF0066FF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF0000FFCC66FF0066FF00CCFF0000FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF0066FF0000FF00CC00FF
FF00CC0000FFCC00FFFF0000FF00CC00FF6600FF0000FF0066FF00CCFF00CCFF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF00
CCFF00CCFF00CCFF0066FF0000FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0066FF0000FFCCFF000000FFCC
00FF6666FF0066FF0000FF0066FF0066FF0000FF0066FF00CCFF00FFCC0066FF00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC0000FF00FFCC00
FFCC00FFCC00CCFF00CCFF0066FF0000CCFF00FF0000CCFF00CCFF00FF0066FF00CCFF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF0066FF000066FF00FF0066FF0000FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF00
FF000000CCFFFF000000CCFF00FFCC00FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF000066FF
66FF0066FF0000FF660000FFCCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000FF0000FFCCFF006600CCFF
66FF0066FF00CCFF00CCFF00CCFF0066FF00CCFF0066FF00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF0066FF0066FF0000FF66FF00CC00FF0066FF0066FF00
00FFCCCCFF00CCFF00CCFF00CCFF0066FF00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF0066FF0000FF666600FF00FF6666FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF00
00FF6600FFCCFF000000FFCC00FF6600FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF00
00FF0000FF000066FF00FF6600FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF0066FF0000FFCC0000FF00FF00
00CCFF66FF00CCFF00CCFF00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF0000FF66FF000000CCFF0066FF00FF00
00FF6666FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF00
CCFF0066FF0000FF666600FF00FFCC00FF0066FF0066FF00CCFF00CCFF00CCFF00FFCC00
FFCC00FFCC00CCFF00CCFF0000CCFFCCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF66
00CCFF00CCFFFF000000CCFF6600FF0000FF00FF0066FF00CCFF00CCFF00CCFF00CCFF00
66FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00CCFF0000FFCCCCFF00CCFF0066FF00
0066FF0000FF00FFCC00FF66CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
00FFCCCCFF00CCFF00CCFF00CCFF0000FF0066FF0066FF0000FF006600FF00FFCC00FF00
66FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF0066FF0066FF0000CCFF00FFCC0000FF00FFCC66FF00CCFF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FFCC0000FFCCCCFF00CCFF0066FF0000FF6666FF00
00FF0000FFCC00FF0000FF66CC00FF00FF6600FFCC66FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0000FF6666FF0066FF0066FF0066FF0066FF0000FF00
00FF000066FFFF000000CCFF00FF6600FF0066FF0066FF0066FF0066FF0066FF0000FF66
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF0000FF0000FF00
0000FF0000FF00FFCC00FF0066FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF0066FF000066FF00FFCC00FF6600FFCC6600FF00FF6666FF00
66FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF0000FF6600FFCC00FF0066FF0000FF6600FF6666FF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FF0000FF6666FF00
66FF0066FF0066FF0066FF0000FF66CC00FF00FF0066FF00CCFF00CCFF00CCFF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF6600FF0000FFCC66FF0000FF0000FF00
00CCFF00FFCCFF006600FFCC0066FF00FF0000FF0066FF000000FF00FF0000FF6666FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF0000CCFF
6600FF00FF6666FF0000FF000066FF00FF6666FF00CCFF0066FF00CCFF0066FF00CCFF00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF0000FF666600FF00FF6600FF66
66FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00CCFF0000CCFF00FF66CCFF00CCFF00CCFF0066FF0000FF0000CCFF00FF6600FF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00
CCFF00CCFF00CCFF0000FF0000FF0000FF000066FF66FF00CCFF00CCFF00CCFF000000FF
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF00FF000000FF0000FF0000FF00
00FF6600CCFFFF000000CCFF00FF6600FF0000FF0000FF00FF00CC00FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0000FF00CCFF00CCFF00CCFF0066FF0000FF660000FF
00CCFF66FF0066FF00CCFF0066FF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF0000FF6600FFCC00FF0066FF00
00FF00FF0000CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0000FF6666FF0000CCFF66FF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF00CCFF0000FF0066FF0000FF0066FF0000FF6666FF0066FF006600FF66FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF0000FF666600FF00FF66
00CCFF0066FFFF00660066FF00CCFF00FFCC0066FF00FF6600FF0066FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0000FF0066FF0066FF0066FF0000FF0000FF6600FF66
66FF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000CCFF00FF660066FF00FF6666FF00CCFF00
CCFF00CCFF0066FF0000FFCCCCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF0066FF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF0066FF00CCFF00CCFF00CCFF0066FF0066FF0000CCFF00FF660066FF66FF00
66FF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0066FF0000FF0000FF0000FF66
0000FFFF0000FF00CCCC00FF0066FF00FF6600FF0000FF0066FF0066FF0066FF0066FF00
CCFF00CCFF00CCFF00CCFF0066FF0000FF0000FF0066FF0000FF0000FF6666FF0066FF00
CCFF0066FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF000000FF66FF0000FFCCCCFF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC0066FF00CCFF00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000FF6666FF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0000FF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF66CC00FF00FF6600FF00
0000FF66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF0000FF66
00FFCC0000FFFF00000066FF00FFCC00FF6600FF0000FF0066FF0066FF0066FF0066FF00
66FF00CCFF00CCFF0066FF0066FF0066FF0000FF6600FFCC0066FF66FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000FF00CCFF00CCFF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000FF66CCFF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF000066FFFFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0000FF6666FF0000FF6600FF66FF000000FF66
66FF0066FF0000FFCC66FF0066FF0066FF0000FF0000FF0000FF0000FF6600FFCC00FFCC
00FFCC0066FFFF00006600FF00FFCC00FFCC00FFCC00FF0000FF0000FF0000FF6666FF00
66FF0066FF0066FF0066FF0000FF0000FF66FF0000FF000000FF0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0000FF66FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FF6600FF0000FF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0000FF6666FF00
CCFF0000FF00CCFF00CCFF00CCFF00FFCC00CCFF00CCFF0000FF66FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0000FF00CC00FF00FF0000FF0000CCFF00CCFF
00FFCC00FF0000FF0066FF0066FF0066FF0000FF6600FFCC00FF0000FF0000FFCC00CCFF
6600FFFF0066FF0000FF00000066FF6600FF00FF6600FF0000FF0000FFCC00FF0066FF00
66FF0066FF0000FF6666FF0000FF006600FF00FFCC00FF0000CCFF00FF0066FF00CCFF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0000FF6666FF0066FF0066FF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000FF0000CCFF
6600FFCCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF0066FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF00
00FF660066FF00FF0000FF0066FF0000FF0000FF0000FFCC00FF6600FF6600FF6600FFCC
00CCFF0000FFFF00006600FF00CCFF00CCFF00FF6600FF6600FFCC00FFCC00FF0000FF00
66FF0000FF0000FF6600FFCC00FF6600FF660066FF66FF0066FF0000FF0066FF00CCFF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC000000FFFFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF00CCFF00FFCC00
FFCC00FFCC00CCFF00CCFF0066FF00CCFF0066FF00FF0000CCFF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF660066FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0000FFCC00FF666600FF
66FF0066FF00CCFF0066FF0066FF0000FF0000FF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF00
00FF6600FF660066FF00FF6600FF0000FF6600FF6600FFCC00FF6600FFCC00FFCC00FFCC
6600FF0000FFFF0000FF00000000FF00CCFF0000FF00FFCC00CCFF00FF6600FF6600FF00
00FF0000FF006600FF00FF6600FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF00
00FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF000000FFCCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0000FF6600FF0000FFCC66FF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0066FF0000FF00FF0000
00FFCC66FF0000FF6600FF000066FF66FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF00
00FF0066FF0000FF0000FF660000FF00CCFF0066FF0066FF0066FF00CCFF00CCFF00CCFF
0066FF0000FFFF0000FF00CC0066FF0066FF6600FF00CCFFFF006600CCFF00FFCC00FFCC
00FFCC00FF6600FF6600FF6600FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CC00FF
66FF0000FF00CCFF00CCFF0066FF0066FF0000CCFF0066FFCC00FF66FF00CCFF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00CCFF0066FF0066FF0000FF00FF0066
0066FF00FF6600FFCC66FF0066FF0000FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0066FF0066FF0000FF000000FF0066FFFF00CCFF00000000FF0000FF0000FFCC00FF
0066FF6600FFCC00FFFF0000FF0066CC00FFFF00CCFF0000FF0000FF0000CC00FFCC00FF
00FF0000FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0000FF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00
66FF00CC00FF00FF0000FF6666FF0000FFCC00CCFF00FF6666FF00CCFF00CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF0066FF00CC00FF0066FF66FF0000FF0000FF6600FF0000FF000066FFCC00FF
00CCFF00FF6666FF0066FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000CCFF
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0066FF0066FF0000FF0000FF0000FFCC00CCFFFF0000FF0066FF0000CC00FFFF00CC
CC00FF6600FF6600FF6600FFFF00CCCC00FFFF00000000FF6600FF0066FF00FFCC00FF66
00FF0066FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FFCCFFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00
66FF0066FF0000FF000000FF00FF0000FF66FF000000FF6666FF0066FF00CCFF0066FF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00CCFF00CCFF00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
66FF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF0066FF00CCFF0066FF0066FF0066FF0066FF0000FF0000FFCC
CC00FF00CCFF00FF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0066FF0066FF0000FF6600FF6600FFCC0066FF0066FF0066FFFF0000FF0000FF0000
FF0000CC00FF6600FF0000FF0000FF0066FF0066FF00CCFF0066FF00CCFF00FFCC00FF66
00FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF00CCFF0066FF0066FF0000FF00CC00FFFF00666600FF00FF0000FF0000FF6600FF00
66FF0000FF0066FF0000FF6666FF00CCFF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF660000FF66FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0000FF66CCFF00CCFF0066FF0000FF6600FF66
FF000000FF6666FF0000FFCCCCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF00
00FFCCCCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
00FF6600FF6600CCFF0066FF0000FF00CCFF00FF6600FFCC0066FF00CCFF6600FF6600FF
FF0000FF0000CC00FF6600FF0066FF6600FF00CCFF0066FF00FFCC00FF660066FF0066FF
00FFCC00FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF0000FF0000FF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF00CCFF00CCFF0066FF0000FF000066FF0000FF0066FF66FF0000FF00FF00CC00FF00
66FF0000FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF00
FF00660066FF00FFCC00FF6600FF660000FFCCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00
00FF00CCFF00CCFF00CC00FFCCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF00CCFF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF00
66FF0066FF0000FF0000FF6600FF0000FF6600FF66FF006600CCFF00FFCC00CCFF0066FF
FF0000FF0000CC00FF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF66
00FF6600FF6600FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF0066FF0000FF66CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF00CCFF0066FF0066FF0000FF000000FF00FF6600FFCC66FF00CCFF00CCFF0000CCFF
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF00FF00CC00FFCC
00CCFF00FF6666FF0066FF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
00FF6666FF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF00
66FF0066FF0066FF0000FF0000FF0000FF0000FF6600FF6600FFCC00FFCC6600FFCC00FF
FF0000FF0000CC00FF0066FF0000FF0000FF00FFCC00FF6600FF6600FF0000FF0000FF00
00FFCC66FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC0000FF00CCFF00CCFF0000FF6600FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF0066FF0066FF0000FF0000FF66FF000000FF6666FF0066FF00CCFF00CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF0066FF0066FF0066FF00
00FFCC00FF6666FF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF0000FFCC
00FF0000FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF000066FF66FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0000FF0000FF0000FF0000FF6600FF6600FF6600FFCC00CCFF0066FF
CC00FFFF0000FF00000066FF00CCFF00FFCC00FFCC00FF6600FF6600FF0000FF0000FF00
00FF0066FF0066FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0000FF00CCFF0066FF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00
CCFF00CCFF0066FF0066FF0000FF660000FF00FF6600FF0066FF00CCFF00CCFF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC0000FF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0000FFCC66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00
66FF0000FF0066FF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0000CCFF00FF0066FF0066FF0000FF0066FF0066FF00
66FF0066FF0066FF0000FF0000FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFF6600FF
6600FFFF0000FF00CCFF00CC00CCFF00CCFF0066FF00FFCCFF00CC00FF6600FF0000FF00
00FF0066FF0066FF0066FF0066FF0066FF0000FF6666FF0066FF0066FF0066FF0066FF00
00FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0000FF66FF00CC66FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF006600FF00FF6666FF000000FF00FF0066FF00CCFF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC0000FFCCFFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF00CCFF0000FFCCFFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC0000CCFFFFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0000FF6666FF0066FF00CCFF00CCFF00CCFF00CCFF0066FF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0000FFCC66FF0066FF00CCFF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0000CCFF00FF0000FF0000CCFF00FF6666FF00
66FF0066FF0000FF0000FF0000FF000066FF00FFCC6600FF00CCFF00CCFF0066FFFF00CC
FF0000FF0000FF00CCFF00660066FF00CCFF0000FF00CCFF00CCFF00FFCC00FF6600FF00
00FF0066FF0066FF0066FF0066FF0066FF0000FF0066FF0066FF0000FF0066FF000000FF
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0000FF0000FFCC66FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF0000FF0066FF0000FF00CCFF00CCFF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00CCFF00
00FF6600FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0000FF6600FF6666FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF00CCFF00CCFF00CCFF00CCFF00
66FF0000FF0000FF6666FF0000FF0000CCFF00FF66CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF0000CCFF00FFCC00FF0000FFCC
00FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FFCC00FFCC0000FF0066FF
CC00FFFF00006600FF0066FF0066FF00FFCC00FFCC00FF6600FF6600FF6600FF0000FF00
00FF0000FF0066FF0066FF0066FF0000FF0000FF0066FF0000FF0000FF6600FF0066FF00
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF000000FFCCFF00
CCFF00CCFF0066FF0000FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF006600FF00FF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF0066FF00CCFF00CCFF00CCFF00CCFF00
00FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0000FF6600FFCC00FF0000FF6600FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF00
66FF0000FF6600CCFF00FF000000FFFF00CC66FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF0000FF66FF000000FFCC00FF66
00FF0000FF6600FF0000FF0000FF0000FF0000FF6600FF6600CCFF00CCFF00CCFF0066FF
6600FFFF00006600FF0066FF00CCFF00CCFF00FFCC00FF6600FF6600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF6600CCFFFF000000FF6600FF6666FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF00
66FF0066FF0066FF0000FFCC66FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF00CCFF00
CCFF00CCFF0066FF0066FF0000FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF0000CCFF66FF0066FF00CCFF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF0000FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FF000066FF0066FF0000FFCC
00FF0000CCFF0000FF00FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF66CC00FF
00FF6600FF66FF00CC00FF6600FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF0000FF6600FF6600FFCC0066FF
00FF6600FFCC00FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFF0066FF6600FF
FF0000FF0000FF00660000FF0066FF00FFCC00FFCC00FF6600FF6600FF6600FF0000FF00
00FF0000FFCC00FF0000FF00FF000000FFCCFF000000FFCC00FF0066FF0066FF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF00
00FF6666FF0000FF000000FF00FFCC66FF00CCFF00CCFF00CCFF0000FF00CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
00FFCC0066FF66FF0000FF6600CCFF66FF0066FF00CCFF00CCFF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC0000FFCCFFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000FF6600CCFF
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF0066FF0000FF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0066FF0066FF00
66FF00FF0000CC00FF00FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF00
00FF0000CCFF6600FF00FF6600FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF0000FF0000FF0000FF0000FF0000FF66
0066FFFF006600CCFF00FF6600CCFF00FF6600FF660066FF0066FF0066FF0066FF0000FF
FF00CCFF00006600FF0000FF00CCFF00CCFF00CCFFFF006600FF6600FF6600FF6600FF66
00FF666600FF00FF6600CCFFFF00000066FF00FFCC0066FF00FF0066FF0066FF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF0000FF00
00FF0000FFCC00CCFF0000FF00FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0000FF6600FFCC00CCFF00FF6600FF0000FF6600FF66CCFF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF0066FF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0000FFCC00CCFF00FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0000FF0000FFCC6600FF00FFCC00FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0066FF0066FF0000FF0000FF0000FF00
00FFCC00FFCC00FFCC00CCFF0066FF00FFCC0066FF00CCFF0066FF0066FF0066FF0000FF
CC00FFFF0000CC00FF0000FF6600FF0066FF6600FF00FFCC00FF6600FF66FF000000FF66
FF00000066FFFF000000FF6600FF6600CCFF00FF0000FF6600FFCC00FF0066FF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF00
66FF0000FF000000FF6600FF0000FF0066FF00FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0000FF000000FF00FF6600FF0000FF0000FF6666FF00CCFF00CCFF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF00
66FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF0000CCFF00FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0000FF0000FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
00FF000066FF00FF660066FF00FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF66
00FF6600FF6600FF6600FFCC00FFCC00CCFF6600FFFF0066FF00006600FFCC00FF6600FF
FF0000FF0000FF0000FF00CCFF00CCFF00000000FF0066FF00FFCC00FFCC6600FF00CCFF
00CCFFFF00000066FF00FF6600FF0000FF0000FF0000FF0066FF0066FF0066FF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF00
00FF0000FF66FF00000066FF00FF0066FF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0000FF0000CCFFFF000000FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0000FF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF0000CCFFCCFF0000FF00CCFF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0000FF0000FFCC6600FF66FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
00FF6666FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0066FF0000FF00FF000000FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF00
00FF0000FF0000FF0000FF6600FF6600FFCC00FFCC0066FFFF0066FF0066FF0000FF0066
FF0066FF00CCFF00CCFF0000FF0066FF00CCFF00000000FF00FFCC00FFCC00FFCC00FF66
00FF6600FF6600FFCC00FF6600FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF00
00FFCC00FFCCFF000000FF6600FF6666FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0000FF66CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0000FF0000FF6600FF0000FF66CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF006600FF66FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0066FF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF0000FF0066FF000066FF66FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0000FF0000CCFF66FF0066FF0066FF0000FF00CCFF00CCFF0066FF0066FF00
00FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0066FF0000FF0000FF6600FF0000FF0066FF0066FF0000FF0066FF0066FF0066FF00
66FF0066FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF00
00FF0000FF0000FF0000FF6600FF6600FFCC0066FF0000FF0066FFCC00FFCC00FFFF00CC
FF0000FF00006600FF0000FFCC00FF0000FF0066FF00CCFF00FFCC00FF6600FF6600CCFF
00FF0000FF0000FF0000FF6600FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0066FF00
00FF00CC00FF00FFCC00FF0000FF6600FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0000FFCC66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0000FF0000FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FF00CCFF00
CCFF0000FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF00CCFF0000FF0066FF00CCFF00CCFF00CCFF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0066FF006600FF00FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
00FFCC66FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF00
66FF0066FF0000FF0000FFCC00FFCC00FF0000FF0000FF0066FF0066FF0066FF0066FF00
66FF0066FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF00
00FF0000FF0000FF0000FF6600FF6600FFCC0000FF00CCFF0000FF0066FF0000FFFF0000
FF0000CC00FF6600FF0066FFCC00FF00CCFF0066FF0000FF00FFCC00FF6600FF6600FF00
00FF0000FF0000FF0000FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF00CCFF00CCFF0066FF0066FF0066FF0066FF0066FF0066FF00
00FF0000FF6600FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0000FF6666FF0066FF00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0000FF0000CCFF00CCFF00FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
00FF0000FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF00CCFF00CCFF00CCFF0066FF0000FF0066FF00CCFF0066FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF00CCFF00CCFF00CCFF0066FF00
00FF0066FF0000FF000000FF00FFCC00FF6600FF6666FF0066FF0066FF0000FF6600FF00
00FF6666FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF66
00FF0000FF0000FF0000FFCC0066FF0000FF00FF6600FF0066FF0066FF0066FF0066FF00
66FF0066FF0000FF0000CCFF66FF0066FF0066FF0066FF0066FF0000FF0000FF6600FF00
00FF0000FF0000FF0000FF6600FF6600FF6600FFCC00FFCC00CCFF0066FF0000FFCC00FF
FF0000CC00FF0000FF0066FF00CCFF00CCFF00FFCC00CCFF00CCFF00CCFF00FF6600FF00
00FF0000FF0000FF0000FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0066FF0066FF0066FF00
00FF0000FF6600FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF0000FF0000FFCC66FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0000FF6600FF6666FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF00CCFF00CCFF00
00FFCC66FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00
00FFCC66FF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF0000FF00CCFF00CCFF00CCFF0000FF66FF00CC00FF0000FF0000FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF0000FF0066FF0066FF0066FF0066FF00
66FF0000FFCC00FF6600CCFFFF00CC00FFCC00FF0066FF0066FF0066FF0000FF000066FF
0066FF00FF6600FF0066FF0066FF0066FF00CCFF0066FF0066FF0066FF0066FF0066FF00
66FF0000FF0000FF6600FF66FF000000FFCC00FF0000FF0066FF0066FF0066FF0066FF00
66FF0066FF0000FF6600FFCC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF66
00FF660000FF00FF6600FF6600FF6600FF6600FFCC0066FFFF0000CC00FF6600FFFF0000
FF0000FF00000000FF0000FF00CCFF00CCFF00FFCC00FFCC00FF6600FF6600FF6600FF00
00FF0000FF0000FF0000FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF6600FF0000FF00
00FFCC6600FF0066FF66FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF0066FF00FF00CC66FF0000FF0066FF0066FF0066FF0000FF00
66FF0000FF0000FFCC00FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
00FF66CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF0066FF00
0066FF66FF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF0066FF00CCFF00CCFF0066FF00
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0000FF0000FF0000FF0000CCFF00FFCC00FF0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF660066FF00FF0000CCFF66FF0066FF00
66FF0000FF0000FF6600CCFF00CCFF00FFCC00FF0000FF0000FF0000FF0000FF6600FFCC
00FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0000FF0000FF66FF000000FFCC00FF6600FF0066FF0066FF0066FF0066FF00
66FF0066FF0000FF0000FF6600FFCC00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF666600FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF0000FFFF00CC
FF00006600FF0000FF6600FF0000FF6600FFCC00FF00FFCC00FF6600FF6600FF6600FF66
00FF0000FF0000FF0000FF0000FF0000CCFF66FF0066FF0066FF0066FF0066FF0066FF00
00FF0000FF6666FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF6600FFCC
00FFCC0066FF00FF6600CCFF00FF0000FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0066FF0066FF000066FF00FF6600FF6666FF0066FF0066FF0000FF00
00FF6600FF666600FF00FF0000FF0000FF6666FF0066FF0066FF0066FF0066FF006600FF
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF00
00FF6666FF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF00CCFF00CCFF00CCFF0000FF0000FFCC00FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF000066FF00FF0000FFCCCC00FF00FF0066FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF66FF000000FF6600FF0066FF00
00FF0000FF0000FF660066FF0000FF00FFCC0000FF00FF0000FF0000CCFF0000FF00FF00
00FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0000FF0000FF0000FF6600FF6600FF0000FF0066FF0066FF0066FF0066FF00
66FF0066FF0000FF0000FF006600FF00FF6600FF6600FF0000FF0000FF0000FF0000FF00
00FF6600FF6600CCFFFF00000000FFFF00CC00FFCC00CCFF0066FF0066FFCC00FFFF0066
FF0000CC00FF0000FF00CCFF00CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF0000FF0066FF0066FF0066FF0066FF0066FF0000FF00
00FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF66
00CCFF00CCFF00CCFF0000FF00FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0000FF0000FF6600FFCC0066FF00FF6666FF0066FF0066FF0000FF00
0066FFCC00FF0000FF00FFCC0000FF66FF0066FF0066FF0000FF0066FF0000FF6600FF66
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00CC00FF00FF000000FF
00FF6666FF0066FF0066FF0000FFCCCCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FFCC
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF66CC00FF00CCFF00FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF6600CCFF00FF66FF00CC00FF0000FF66
00FF0000FF6600FFCC6600FFFF006600CCFF00FF6600FF6600FF6600CCFF00FFCC00FF66
00FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF0066FF0066FF0066FF0066FF00
66FF0066FF0000FF0000FF0000FF6600FF6600FF0000FF0000FF0066FF0066FF0066FF00
66FF0000FF0000FF0000FF0000FFCC00CCFF00FFCC00FF0000FF0000FF0000FF0000FF00
00FF6600FFCC00FFCC00FFCC00CCFF0000FF0066FF0066FF0066FF0000FF6600FFFF0066
FF0000CC00FF0000FFFF00CC6600FF00FFCC00FFCC00FFCC00FFCC00FFCC0000FF00FF66
00FFCC00FFCC00FF6600FF0000FF0000FF0000FF0000FF0000CCFF00FF0000FF0000FF00
0000FF00FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FFCC
0066FF00FFCC00FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0000FF0000FFCC00FF6600FF0000FF0000FF0000FF00
00FF660000FF0066FF00FF6600FF0066FF0066FF0066FF0000FF0000FF000000FF66FF00
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF000066FF
0066FF00FFCC00FF6666FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0000FFCC00FF000000FF00FF0066FF0066FF0066FF00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0066FF0000FF6600FF000066FF00FF66
00FF6600FFCC00FFCC0066FFFF00000066FF00CCFF00FFCC00CCFF00FF6600FF0000FF00
00FF0066FF0066FF0066FF0066FF0066FF0000FFCC00FF6666FF0066FF0066FF0066FF00
66FF0066FF0000FF6600FF6600FFCC6600FF00CCFF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF6600FFCCCC00FFFF00000066FF00FF0000FF0000FF0000FF00
00FF6600FF6600FF6600FF6600FFCC00FFCC0066FF0066FFCC00FFFF0000FF0066FF0000
FF0000FF00CCCC00FF0066FF00CCFF0066FF0066FFFF000000FFCC0066FF0000FFFF0000
00FFCC00CCFF00FF6600FF0000FF0000FF0000FF0000FF0000FF6600FF0000FF0000FF66
0066FF00FFCC66FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF0000FF00
0066FF00FF6600FFCC00FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0000FF0000FF00FF000000FF6600FF0000FF0000CCFF
00FFCC0000FF6600FF00FF6600FFCC00FF0000FF0000FF0000FF66FF000000FF0066FF00
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF000000FF
00FF6666FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF0066FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF00FF000000FF0066FF0066FF0000FFCC
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FFCC00FF66
0066FFFF00000066FF0066FFFF00CCCC00FFFF00CC0000FF00FFCC00FF6600FF0000FF00
00FF0000FF0066FF0066FF0066FF0000FF0000CCFF00FF6600FF0066FF0066FF0066FF00
66FF0000FF0000FF0000FF0000FF66FF00000000FF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF6600FFCC6600FF00FFCC00FF6600FF6600FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FFCC00FFCC00CCFF6600FF6600FFFF0066FF0066FF0000
FF00CCFF0000FF0000FF0000FF0000FF00CCFF0066FF000000CCFF00CCFF0066FF00CCFF
00FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF0000FFCC
00FF6600FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF0000FF00
FF000000FF0000FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0066FF00
66FF0066FF0066FF0066FF0066FF0000FF006600FF00FF660000FFCC00FF00FF6600FF66
00CCFFFF00CC6600FF00FFCC00FF6600FF0000FF0000FF0000CCFF00FF6600FF6600FF66
66FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF00FF0066
6600FF66FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF6666FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000CCFF00FFCC00FF000000FF66FF00
66FF0066FF0066FF0000FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF0000FF66
00FF6600CCFFFF0000FF0000FF00CC6600FFCC00FF0066FF6600FF00FF6600FF0000FF00
00FF0000FF6600FF0000FF0000CCFF00FF0000FF6600FF6600FF0000FFCC00FF0000FF00
00FF0000FF0000FF0000FF0000FF6600CCFF00FF6600FF0000FF0000FF0000FF6600FF00
00FF0000FF0000FF0000FF0000FF6600FFCC00FFCC00FF6600FFCC00FF6600FF6600FF66
00FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFF00CCFF0066FF6600FFFF00CCFF0066
CC00FFCC00FFFF00CC0066FF00CCFF6600FF00CCFF0000FF00FFCC00FFCC00FFCC00FFCC
0000FF00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF66FF00CC00FFCCCC00FF
00FF6600FF0000FF0000FF0066FF0066FF0066FF0000FF0000FF0000FF0000FF6600FF66
0066FF00FF6600FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF6600FF66
66FF0066FF0066FF0066FF0066FF0000FF0000FF0000FF0000FFCC00CCFF00FFCC00CCFF
0066FFFF00000000FF00FFCC00FFCC00FF6600FFCCCC00FF00FF0000FF0066FF0066FF00
66FF0066FF0066FF00CCFF00CCFF00CCFF0066FF0066FF0066FF0066FF0000FF0000FF00
66FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF0000FFCC
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0066FF00CCFF00CCFF00CCFF0066FF0066FF00FF006600FF6666FF00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF0066FF0000FFCC00FF6600FFCCCC00FF00FF6600FF0066FF00
66FF0066FF0066FF0000FF0000FF0066FF0066FF0066FF0000FF0000FF0000FF0000FF00
00FFCC00CCFF0000FF0000FFFF00006600FF00CCFF00FFCC00FFCC00FF6600FF6600FF66
FF000000FF0000FF0000FF0000FF0000FFCC00FFCC00FF660066FF00FF0000FF0000FF00
00FF6600FF0000FF0000FF0000FF6600FFCC00FF6600FF6600FF6600FF66FF006600FF66
00FF0000FF0000FF0000FF6600FF6600FFCCFF000000CCFF00FF6600FF6600FF6600FF66
00CCFF00FFCC00FFCC00FFCC00FFCC6600FF0000FF0000FF0066FF6600FFFF0000FF0000
CC00FF0000FF0066FF0000FF00CCFF00FFCC00FFCC00FFCC00CCFF00FFCC00FF6600FF66
00FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF660066FFFF0000
FF00CCFF00CC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FFCC
0066FF00CCFF00FF0000FF0000FF0066FF0066FF0066FF0066FF0000FF0000FFCC00FFCC
00FF0066FF0066FF0066FF0000FF0000FF0000FF0000FF0000FF6600FFCCCC00FFCC00FF
6600FFFF0066FF00CC0000FFCC00FFCC00FF00FF6600FF6600CCFF00FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF006600FF66FF0000FF0000FF0000FF00
66FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF66
66FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF00
66FF0000FF0066FF0066FF0066FF0066FF0066FF0000FFCC66FF0066FF0000FF66CCFF00
CCFF00CCFF0066FF0066FF0066FF0066FF0000FF0000FF00CC00FF00FFCC00FFCC66FF00
66FF0066FF0066FF0000FF0000FF6600FF0000FF0000FF0000FF0000FF6600FF6600FF66
00FF6600FFCC6600FF0000FFFF0000FF0000FF000000CCFF00FFCC00FFCC00FFCCCC00FF
00FF6600FF0000FF0000FF0000FF0000FF666600FF0066FF00FF6600FF0000FF0000FF00
00FF0000FFCC00FF6600FF66CC00FF00CCFF00CCFF00FFCC00FF6600FFCC00CCFF0000FF
00FF6600FF0000FF6600FF6600FF6600FFCC0066FF0066FF00FFCC00FF6600FF6600FF66
00FFCC0066FF00CCFF00FFCC00FFCC00CCFF0066FF0000FFFF00CCFF00CCFF0000FF00CC
0000FF0066FF0000FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF66
00FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF6600FF660066FF6600FF00FFCC
00FF6600FF0000FF0000FF0000FF0000FF0000FFCC00FF0000FF0000FF0000FF0000FF66
00FFCC00FFCC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCC
00FF0000FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF660000FF00CCFFFF0000
FF0000FF00006600FF6600FF00CCFF00FF6600FF6600FF0000FF0000FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF6600CCFF00FF66
00FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF00FF0000
00FF0066FF00CCFF00CCFF00CCFF0066FF0066FF0066FF00
00FF0066FF0066FF0066FF0066FF0000FF6600FF000000FF00FF6600CCFF66FF0066FF00
66FF0000FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF6600FF0000FF0066FF00
66FF0066FF0066FF0000FF0000FF6600FF0000FF6600FF0000FF0000FF0000FFCCCC00FF
00FFCC00FFCC00CCFF0000FFFF00CCFF00660066FF00CCFF00FFCC00CCFF0066FF00CCFF
00FFCC00FF0000FF0000FF0000FF0000FF660066FF00FFCC00FF6600FF0000FF0000FF00
00FF6600FFCC00CCFF00FF6600FFCCFF00000066FF0066FF00FFCC0066FF0066FF00FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF0066FF00FFCC00FFCC00FFCC
00CCFF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF6600FFFF0066FF0000FF0000
0000FF0066FF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF66
00FF6600FF6600FF6600FF6600FF6600FF0000FF6600FF6600FF6600FFCC0066FF00FFCC
00FF6600FF0000FF0000FF0000FF0000FF0000FF6600FF0000FF0000FF0000FF666600FF
0066FF00FF6600FF0000FF0000FF0000FFCC00FF0000FF0000FF0000FFCC00FF6600CCFF
FF00CC00FF0000FF0000FF0000FF0000FFCC00FF6600FF6600FF6600FFCC00CCFF0000FF
FF00CCCC00FF0066FFFF00CC00CCFF00FFCC00FF6600FF0000FF0000FF0066FF0066FF00
66FF0066FF0000FFCC66FF0066FF0066FF0066FF0066FF0000FF0000FF66FF000000FFCC
00FF6666FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF66
66FF0066FF0066FF0066FF0066FF0000FF0066FF0066FF00
00FFCC66FF0066FF0066FF0066FF0000FF000000FF00CCFF00FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF6600FFCC00FF6600FF00
00FF0000FF0000FF0000FFCC00FFCC00CCFF00FF6600FF0000FF0000FF00FF006600CCFF
0066FF00CCFF0066FF6600FFFF00CCFF0066FF00000066FF0066FF00CCFF00FFCC00FF66
00FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FF6600FF6600FF0000FF00
00FF6600FFCC00CCFFFF00CC00FFCC0066FFFF00CC0066FF0066FF00CCFF00FFCC00FF66
00FF6600FFCC00FFCC00FF6600FF6600FFCC00CCFFFF000000FFCC00FFCC00CCFF00FFCC
00FFCC00CCFF6600FF00CCFF00CCFFFF00CC0066FFCC00FFFF00CCFF0000FF0066FF00CC
0000FFFF00660000FF6600FF00CCFF00CCFF00CCFF00FFCC00CCFF00FF6600FF6600FF66
00FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FFCC00FF6600FFCC00FFCC00FF66
00FF6600FF0000FF0000FF0000FF0000FF0000CCFF00FF6600FF6600FF6600FF6600FFCC
00FF6600FF6600FF0000FF0000FF6600FF0000FF0000FF0000FF0000FF6600FFCC0066FF
00FF6600FF0000FF0000FF0000FF0000FF666600FF00CCFF00CCFF00FFCC0000FF0000FF
FF0000FF00006600FF0066FF00FFCC00FF6600FF6600FF0000FF0000FF0000FF0000FF00
00FF0000FFCC00FF6666FF0066FF0066FF0066FF0066FF0000FF0000FFCC00CCFF00FF00
00FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF0000FFCC
00FF0000FFCC66FF0066FF0066FF0066FF0000FF0066FF00
00FF0000FF0066FF0066FF0066FF0000FF0000FF6600FF6600FF0066FF0066FF0066FF00
66FF0000FF0000FFCC66FF0066FF0066FF0000FF0000FF0000FF6600FFCC00FF0000FF00
00FF0000FF0000FF0000FF0000FF660066FF00FF6600FF0000FF0000FF6600FF6600FF66
00FFCC00CCFF0066FFCC00FFFF0000FF00CC6600FFFF00CC00CCFF00FFCC00FFCC00FF66
00FF6600FF6600FF6600FF6600FF6600FFCC0000FF00CCFF00FF6600FF6600FF6600FF66
00FF6600FF6600FFCC00CCFF0066FFCC00FFFF0000FF000000CCFF00FFCC00FFCC00FFCC
00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF00CCFF00CCFF00CCFF00FFCC
00CCFF00CCFF0000FF0000FF0066FF0066FFFF00666600FFCC00FFFF0066FF00000000FF
0066FF0066FF0066FF0000FF0066FF0066FF00CCFF00FFCC00FFCC00FFCC00FF6600FF66
00FF6600FFCC00FFCC00FF6600FF6600FF6600FF6600FF666600FF0066FF00CCFF00FFCC
00FFCC00FF6600FF0000FF0000FF0000FF6600FF66CC00FF00FF6600FF6600CCFF0066FF
00CCFF00FFCC00FF6600FF6600CCFF00FF6600FF0000FF0000FF0000FF6600FF6600CCFF
00FF6600FF6600FF0000FF0000FF0000FF6600FFCC00CCFF0066FF00CCFF0066FFFF00CC
FF0000CC00FF6600FF00CCFF00FFCC00FFCC00CCFF00FFCC00FF6600FF0000FF0000FF00
00FF0000FF6600FF0000FF0066FF0066FF0066FF0000FF0000FF0000FF660000FF00FF00
66FF0066FF0066FF0066FF0066FF0000FF0066FF0066FF0066FF0066FF0000FF6600FFCC
00FFCC00FF0066FF0066FF0066FF0066FF0000FFCC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF0066FF0066FF0066FF00
66FF0000FF0000FF6600FF0000FF0000FF0000FF0000FF0000FF66CC00FF00FF6600FF00
00CCFF00FF0000FF0000FF0000FF6600CCFF00FFCC00FF6600FF6600FFCC00FF6600FF66
00FFCC00CCFF00CCFF6600FFFF0000CC00FF0000FF00CCFF00CCFF00FFCC00FFCC00FF66
00FF6600FFCC00FF6600FF6600FF6600FFCC0066FF00FFCC00FF6600FF6600FF660066FF
00FF6600FF6600FFCC00FFCC0000FF6600FFFF00000000FF0066FF00CCFF0000FF00FFCC
00FFCC0066FF0066FF00FFCC00FFCC0000FF00CCFF0066FF0000FF0066FF0066FF00CCFF
0066FF00CCFF0066FF0000FFFF0000FF00006600FFFF00CCFF0000CC00FF0000FF0000FF
0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC
00CCFF00CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FFCC6600FF00CCFF00CCFF
00FF6600FF6600FF6600CCFF00FF6600FF6600FF660066FF00FFCC00FFCC00CCFF0000FF
00CCFF00CCFF00FFCC0066FF0066FF00FFCC00FF0000FF0000FF0000FF6600FF666600FF
00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF0066FFCC00FFFF00CC
FF0000FF00CCCC00FF00CCFF00CCFF0066FF0066FF00FFCC00FF6600FF0000FF0000FF00
00FFCC00CCFF00FF6600FFCC00FF0000FF0000FF0000FF0000FF000066FF00FFCC00FF66
66FF0066FF0066FF0066FF0066FF0000FF0066FF0066FF0066FF0066FF0000FF0000FFCC
00FF6600FF0066FF0066FF0066FF0000FF0000FFCCFF0000
00FF0000FF0000FF6600FF0000FF0000FFCC00CCFF00FFCC00FF0000FF0000FF0066FF00
00FF0000FF00FF000000CCFF00FF0000FF0000FFCC00FF6600FF660066FF00FFCC00FF66
0066FF00FF6600FF6600FF6600FF6600CCFF0066FF00FF6600FF660000FF00FFCC00FFCC
00FFCCFF00CC0000FFFF0000FF0000CC00FF0000FFFF00CC0000FF0066FF00FFCC00FFCC
0066FF0066FF00FFCC00FF6600FF6600FFCCFF000000CCFF00FFCC00FF6600FFCC00CCFF
FF000000FFCC00CCFFFF00CC0066FF6600FFFF00006600FF0066FF6600FF0000FF00FFCC
00FFCC00CCFF00CCFF00FFCC00FFCC00CCFFCC00FF6600FFFF00000000FF0066FF0066FF
FF00000066FF6600FFFF00CCCC00FF6600FFFF00CCFF0000FF00006600FF0000FF0066FF
0066FF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC
00FFCC0066FF00FFCC00FF6600FF6600FF6600FF6600FFCC00FFCC6600FF00FFCC00FF66
00FF6600FF6600FF660066FF00FF6600FF6600FF6600FFCC0000FF00CCFF0066FFFF0066
0066FF00CCFF0066FF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600CCFFFF0000
00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCCCC00FF0000FFFF0066
FF0000CC00FF6600FF00CCFF00CCFF00CCFF00FFCC00FF6600FF6600FF0000FF0000FF00
00FFCCFF000000FF6600FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FF6600FF00
00FF0066FF0066FF0066FF0000FF0000FF0066FF0066FF0066FF0066FF0000FF0000FF00
00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF66
00FF6600FF6600FFCC00FF0000FF0000FF6600FFCC00FF6600FF0000FF0000FF0000FF00
00FF0000FF0000CCFF00FFCC00FF0000FF0000FFCCFF000000FFCCCC00FF0066FFCC00FF
00FFCC00FF6600FFCC00FF6600FF6600FFCC0000FF00FFCC00FFCC00CCFF0000FF00FFCC
00CCFF00CCFF0066FFCC00FFFF0000FF00CC0000FF0000FF0066FF00CCFF00FFCC00FFCC
00CCFFFF000000FFCC00FFCC00CCFF00FFCC0000FF00CCFF00FFCC00FFCC00FFCC0066FF
00CCFF00FFCC00CCFF00CCFF0000FFFF0000FF0000FF00000000FF0066FF00CCFF00CCFF
00CCFF0066FF0000FF00CCFF0000FF00CCFF0066FF6600FFFF00006600FF6600FF0066FF
FF00000000FFCC00FFFF0066FF0000FF0066FF0000FF00CCFF0000FF00CC0000FF0000FF
0066FF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF6600FF
0066FF00CCFF00FFCC00FFCC00FF6600FF6600FF6600FFCC00CCFF6600FF00FFCC00FFCC
00FF6600FF6600FF6600CCFF00FF6600FF6600FF6600FFCC00FFCC0066FFFF0066FF0000
FF00000000FF00CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF
00FFCC00FF6600FF6600FF666600FF00FFCC00FFCC00CCFF00CCFF00CCFF0000FFFF00CC
FF0000CC00FF0066FF00CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF660066FF
00FF6600FFCC00FF6600FF0000FF0000FF000066FF00FF6600FF6600CCFF00FF6600FF00
00FF0000FF0000FF0000FF6600FF6600FF0000FF0066FF0066FF0000FF0000FF0000CCFF
FF000000FF6600FF0000FF0000FF6600FF0000FF0000FF66
00FF66FF006600FFCC00FF6600FF6600FF66CC00FF00FF6600FF0000FF0000FF6600FF00
00FF0000FF0000FF6600FFCC00FF6600FFCC00FF6600FFCC00CCFFFF0000FF00CC00CCFF
00FFCC00FFCC00CCFF0066FF00FFCC00FFCC0066FF00CCFF00FFCC00FFCCCC00FF00CCFF
00CCFF0066FF6600FFFF0000FF00006600FF0000FF0066FF00CCFF00CCFF0066FF00CCFF
00CCFF0066FF00FFCC00FFCC00CCFF00CCFF6600FF0066FF6600FF00CCFF00FFCC0066FF
0000FF00CCFFFF00CC0066FF0000FF6600FFFF0000CC00FF0000FF0000FF0066FF0000FF
00CCFF0066FF0000FF0066FF6600FF0066FF0000FF6600FFFF0000FF00CC6600FFCC00FF
6600FFFF0066CC00FFFF0066FF0000FF0000FF0066CC00FF6600FF0000FF0000FFFF0000
0066FF0066FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF
FF00000000FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FF00FFCC00FFCC
00FFCC00FF6600FFCC00CCFF00FFCC00FFCC00FFCC00CCFF00CCFF0066FF6600FFFF0000
6600FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FFCC0066FF
00CCFF00FFCC00FFCC00FFCC0000FF00CCFF00FFCC00FFCC0066FFFF00CC0000FFFF00CC
FF00CC0000FF0066FF00CCFF00CCFF00CCFF00FFCC00FF6600FFCC00FF6600FF6600FF66
00CCFF0000FF00FF6600FF6600FF0000FF660000FF00FFCC00FFCCFF000000FFCC00FF66
0066FF00FF0000FF0000FF006600FF00CCFF00FF0000FF0000FF6600FF0000FF0000FF66
00FFCC00FF6600FF0000FF0000FFCC00FF6600FF6600FFCC
00FFCC00FFCC00FFCC00FF6600FFCC00FFCCCC00FF00FF6600FF6600FF66FF00CC00FF66
00FF6600FF6600FF6600FFCC00FF6600FFCC6600FF00FFCC0066FF6600FFCC00FFFF0000
0066FF00FFCC00CCFF00FFCC00FFCC0066FFFF0066FF006600CCFF00CCFF0066FF0066FF
0066FFFF00CCCC00FFFF00CCFF00006600FF6600FF0066FF0066FF0066FF00CCFF00CCFF
0066FF0066FF00CCFF0066FF00CCFFCC00FFCC00FFFF00CC0066FF00CCFF00CCFF00CCFF
6600FF0066FF0000FF0000FF0000FFCC00FFFF0000CC00FF6600FF0000FF0066FF0000FF
0066FFCC00FFCC00FFFF00000000FF6600FF6600FFCC00FFFF0000FF00CCFF00CCFF0066
FF00CCFF0000FF0000FF0000FF0066FF0000FF00006600FF0000FF0066FF0066FF0066FF
0000FF6600FF0000FF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00CCFF00CCFF0000FF
6600FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FF00FFCC00FFCC
00CCFF00FFCC00FFCC0066FF00CCFF00FFCC00FFCC00CCFF6600FF0066FF6600FFFF0000
6600FF0066FF0066FF00CCFF00FFCC00FFCCFF00000000FF00FFCC00FFCC00FFCC00CCFF
00CCFF00FFCC00FFCC00FFCC00CCFF0066FF00CCFF00CCFF00CCFF0066FF6600FFFF0000
FF00006600FFFF00CC0000FF00CCFF00FFCC00FFCC0000FF0000FF00FFCC00FF6600FF66
00FFCC00FFCC00FF6600FF6600FFCC00FF6600FFCCFF000000CCFFCC00FF00FFCC6600FF
00FF6600FF0000FF0000FF660066FF00FF6600FF0000FF0000FF6600FF0000FF0000FF66
00FFCC00FF6600FF6600FF6600FFCC00CCFF00FF6600FF66
00FFCC00CCFF00FFCC00FFCC00FFCC0066FFFF00666600FF00FFCC00FFCC0066FF00FF66
00FF6600FFCC00FFCCFF00CC00CCFF00FFCC0066FF0000FF0066FFCC00FFFF00000066FF
00CCFF00CCFF0066FF00CCFF0066FF0000FFFF0000CC00FF0066FF0000FF0000FFFF0000
6600FFCC00FFFF0066FF0000CC00FF0000FF0000FF0066FF0066FFCC00FF0000FF0066FF
0066FF0066FF0066FFCC00FF0066FFCC00FFFF00CCCC00FF6600FF0066FF0000FF0000FF
FF00006600FF0000FF6600FFCC00FFFF0000FF0066FF00CC6600FFFF00000000FF6600FF
6600FF6600FFFF0000CC00FFCC00FFFF0000FF0000FF0000FF0000FF0066FF0000FF0000
FF0000FF0000FF0000CC00FF6600FFCC00FFFF00006600FFCC00FF0066FF0066FF0066FF
00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF0066FF
0066FF00CCFF00FFCC00FFCC00FFCC00CCFF0066FF00CCFF0000FF0000FF00CCFF00CCFF
00CCFF00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FFFF0000FF0000
FF00000000FF0066FF00CCFF00FFCC00CCFF0066FF00CCFF00FFCC00CCFF0066FF0066FF
0000FF6600FF00CCFF00CCFF00CCFF0000FF00CCFF0066FF0066FF0000FFFF00CCFF0000
CC00FF0000FF0066FF00CCFF00CCFF00FFCC00FFCC0066FF0066FF00FFCC00FFCC00FFCC
0066FF00FFCC00FFCC00CCFF00CCFF00FFCC00FFCC00CCFFFF00CCFF006600CCFF00FFCC
00FF6600FF6600FF6600FF66CC00FF00FF6600FF0000FF0000FF6600FFCC00FF6600FF66
00FFCC00CCFF00CCFF00FF6600FFCCCC00FF00FFCC00CCFF
00CCFF0066FF00CCFF0066FF00CCFF0000FFCC00FF6600FF00CCFF00FFCC00CCFF00FFCC
00FFCC00CCFF00CCFFFF00CC0066FF0066FFFF00660066FF0000FFFF0000CC00FF0000FF
FF00000066FFFF00000000FFCC00FF6600FFFF0000FF00CCCC00FFFF0066FF0000FF0000
FF0000FF0000FF0000FF00CC6600FF0000FF0000FF0000FF0000FFCC00FF0066FF0000FF
0000FF6600FF0000FF6600FF0000FF6600FFFF0066FF00CC6600FF0000FF6600FF6600FF
FF0000CC00FFCC00FFFF0000FF0000FF0000FF00CCCC00FFFF0000CC00FFFF00CCFF0066
CC00FFFF0066FF0000FF0066FF0000FF0000FF0000FF0000FF00CCFF00CCFF0000FF0000
FF0066CC00FFCC00FF0000FF0000FFFF00CC6600FF6600FF0066FF0066FF00CCFF00CCFF
00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FFFF0000
0066FF00CCFF00CCFF00FFCC00FFCC00CCFF0000FF0000FFCC00FFCC00FF0066FF0000FF
00CCFF00CCFF00CCFF0066FFCC00FF00CCFF00CCFF0066FF0066FF0000FFFF00CCFF0000
CC00FF0000FF0066FF00CCFF0066FF00CCFFFF006600CCFF00CCFF00CCFF0066FFFF0000
FF00000066FF0066FF0066FF6600FF6600FF0000FF0066FFFF0000CC00FFFF00CCFF00CC
CC00FFFF00660000FF00CCFF00CCFF00CCFF00CCFF0066FF00CCFF00FFCC00CCFF00CCFF
0000FF00CCFF00CCFF00FFCCFF000000FFCC00CCFFFF00006600FFCC00FF0000FF00CCFF
00FFCC0066FF00FF6600FFCC00CCFF00FF6600FF6600FF6600FFCC00FFCC00FF6600FFCC
0066FF0000FF00CCFF00FFCC00FFCC0066FF00CCFF0066FF
0000FFFF00000000FF0000FF0000FF6600FFFF00006600FF6600FF0066FF6600FF0000FF
0000FFFF00CC6600FFFF00666600FFCC00FFFF0066FF00CCFF0000FF0000CC00FFCC00FF
FF0000CC00FFFF0066FF0000FF0066FF0000FF0000FF0066FF0000FF0000FF0000FF0066
FF0000CC00FF6600FFFF00CC0000FF0000FF0000FF0000FF0000FFFF00000000FF6600FF
CC00FFFF00666600FFFF00CCFF00CCFF0000FF0000FF00CCFF00CCFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0066CC00FFCC00FFCC00FFCC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00CCCC00FFFF00CCCC00FF6600FFFF00CCFF0000FF00CC
6600FF0000FF6600FF6600FF0066FF6600FF0066FFCC00FF0066FF0066FF00CCFF00CCFF
00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF6600FFCC00FF
0000FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FFFF0066FF00006600FF0066FF
00CCFF0066FF00CCFF0066FF6600FF0066FF0066FF6600FF0000FF0000FFFF0066FF0000
CC00FF6600FF0066FF0000FFCC00FFFF00000000FF0066FF0066FF0066FF6600FFCC00FF
FF00006600FF0000FF6600FF0000FFFF00CCCC00FFFF0000FF00CCFF0066FF00006600FF
0000FF0000FF0066FF0066FF0000FF00CCFF00CCFF0000FF00CCFF00CCFF00CCFF0000FF
FF00000000FF00CCFF00CCFF0000FF00CCFF0066FF6600FFFF0000CC00FF0066FF00CCFF
00CCFF00CCFF00FFCC00CCFF00CCFF00FFCCFF00CC00FFCC00FFCC00CCFF00FFCC00CCFF
0000FFCC00FF0000FF0066FF00CCFF0000FFCC00FF0066FF
FF0000FF0000FF0066FF0000FF0000FF0000FF00CCFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00CCFF00CCFF0000FF0000CC00FFFF00CCFF0066CC00FFCC00FFFF00CC
FF0000FF0066FF0000FF00006600FF6600FFCC00FFFF0000CC00FFCC00FF6600FF6600FF
FF00000000FF0000FFCC00FF6600FF0000FF0000FF0000FF0000FF6600FFFF0000FF00CC
FF0066FF0000FF0000FF0000FF0000FF0000FF0066FF0066FF0000FF0066FF0000CC00FF
CC00FFFF0000CC00FFCC00FF6600FF6600FFCC00FF6600FFFF00CCFF0000FF0000FF0000
FF00CCFF00CCFF0000FF00006600FF0000FF6600FF0000FF0000FFFF0000FF0000CC00FF
0000FF0066FF0000FFCC00FF0066FF0066FF0066FF6600FF0066FF0066FF00CCFF00CCFF
00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF
0000FF00CCFF00CCFF00CCFFCC00FF0066FF0066FF0000FFFF0000FF00006600FFFF00CC
0066FFCC00FF0066FF6600FFFF0000FF00CC0000FF6600FF6600FFCC00FFFF0000FF0066
FF00CC0000FF0000FF6600FF0000FF0000FFFF00CCCC00FF0000FF6600FFFF00CCFF00CC
FF00006600FF6600FFFF00CCFF00CCFF00CCFF0000FF0000FF0000FF0000CC00FF6600FF
6600FF0000FF0066FF0000FFCC00FF0066FFFF00CC0000FF0000FF0066FF0066FF6600FF
FF0000CC00FF0066FF0066FF0000FF6600FFFF0000FF0066FF00006600FF0000FFFF0066
0000FF0066FFFF00CC6600FF0000FFFF00006600FF00CCFF00CCFFFF00CC6600FF0000FF
6600FFFF00000000FF6600FF0000FFFF0066FF00CCCC00FF
CC00FFFF00CCFF00660000FF6600FF0000FFFF00006600FF0000FF6600FFFF00CC00CCFF
00CCFF6600FFFF00000000FF6600FFFF00CC0066FF0000FFFF00660000FF6600FFFF0000
FF0066FF00006600FF0000FF0066FF0066FFCC00FFFF00006600FF0066FF0066FF0000FF
0000FFFF00CC0066FFCC00FF0000FF0066FF0000FF6600FF6600FFCC00FFFF0000FF0000
FF0000FF0000FF00CCFF00CCFF00CC6600FF6600FFFF0000FF00CCFF00CC6600FF0000FF
CC00FFFF00CC0000FF0000FF6600FF0000FF0000FFFF00CCFF0066FF0000CC00FF6600FF
6600FF0000FFFF00CCFF00006600FF0066FFCC00FF0066FFFF00CC6600FFFF0000FF0000
0000FF0066FF0066FFCC00FF00CCFF00CCFF00CCFF0000FF0000FF0066FF00CCFF00CCFF
00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF
6600FF0066FF0066FF0066FFCC00FF0000FF0066FF0000FFCC00FFFF0000FF00000000FF
0000FF6600FF0000FF6600FFFF0000FF0000FF00CCFF00CCFF0000FF0000FF0000FF00CC
6600FFCC00FF6600FF6600FFCC00FFCC00FFFF0000CC00FFCC00FFFF0000FF0066FF0000
FF0066FF0066FF0000FF0000FF0000FF0000FF0000FF0066FF00CCFF00006600FF0000FF
0000FF0000FF0000FF6600FFCC00FF0000FF0000FFFF00006600FF6600FFCC00FFCC00FF
FF0000CC00FF6600FF6600FFFF0000FF0000FF0066FF0000FF00CCCC00FFCC00FFFF0066
FF00CCCC00FFFF0000FF0000FF00CCFF00CCFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00CCFF0000FF0000FF0000FF0066FF0000FF0000
0066FFCC00FF0000FF00CCFF0066FF0000FFCC00FF0000FF00CCFF00FFCC00CCFF00FFCC
00FFCCFF00CC00FFCC00CCFF00CCFF00FFCC00CCFF00CCFF00CCFF0066FFCC00FFFF0000
6600FF0066FF00CCFF0000FF00CCFF00CCFF0000FFFF00000000FF00CCFF00CCFF00CCFF
0000FF00CCFF00CCFF0000FF0066FF0066FF0000FF0000FF6600FFFF0000FF0066FF00CC
FF0000CC00FFFF00CC0000FF6600FF0000FF6600FFFF0000CC00FF6600FF0066FF0066FF
0066FF0000FFFF0000CC00FF0000FF0066FF6600FFCC00FFFF0000FF00660000FF0000FF
6600FF0066FF0066FF6600FF0066FF00CCFF0066FF00CCFF0066FF6600FFFF0000FF0066
0000FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF0000FFCC00FF6600FF00CCFF00CCFF
00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF
CC00FF0066FF6600FF0066FF6600FF6600FF0000FF6600FFFF00CCFF0000FF00CC6600FF
CC00FFFF00CCCC00FFFF00CCFF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FF
CC00FFCC00FFCC00FFFF0066FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00CC
FF00CCFF0000FF0000FF00CCFF00CC6600FFFF0066CC00FF6600FF0000FFFF00000000FF
0000FF0000FF0000FF0000FFFF00CC6600FFCC00FFFF0000FF0066FF0000FF0000FF0000
FF0066FF0000FF0000FF0066FF0000FF0066CC00FFFF0000CC00FFCC00FFFF0000FF0000
FF00CCFF0066CC00FF6600FFFF00666600FFFF00CC0000FF0000FF6600FF0066FF6600FF
6600FFFF00006600FF0000FF0000FF0000FFFF00000000FF
0066FF00CCFF0066FF00FFCC00FFCC00CCFF0000FF0066FF00FFCC00FF6600FFCC00FFCC
00FF6600FF6600FF6600CCFF00FFCC00FF660066FF00FFCC00CCFF0000FFCC00FF6600FF
FF000000CCFF00FFCCFF000000FFCC00CCFF00CCFF0000FF00CCFF00CCFF00FFCC00CCFF
0066FF00CCFF00CCFF00CCFF00CCFF0000FFFF0066CC00FFFF00CCFF00CCCC00FFFF0000
0066FF0000FF6600FF6600FF0066FF0066FF0066FFFF0000FF00000066FF00CCFF00CCFF
00CCFFFF006600CCFF0066FF00CCFF0066FF0000FFCC00FFFF0000FF00CC0000FF0066FF
0066FF00CCFF00CCFFCC00FF0066FF00CCFF00CCFF00CCFF0000FF0066FFCC00FFCC00FF
0000FF0000FF00CCFF00FFCC00FFCC00CCFF00CCFF0066FFFF00000066FF0066FF00CCFF
00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF
6600FF6600FFFF00CC0000FF0000FFCC00FFCC00FFFF0066FF0000FF0000FF00CCFF00CC
FF0000FF0000FF0000FF0000FF0066FF0000FF0066CC00FFFF0066FF00CCCC00FFFF0000
CC00FFFF00CCFF0000FF0000FF0000CC00FFCC00FFFF00006600FF6600FF0000FF6600FF
FF00CCFF00666600FF0000FF6600FF0000FF6600FF0000FF0000FF0066FFCC00FF0000FF
0000FF0000FF0000FF6600FFFF00CCFF0000FF0000FF0000FF0000FF0000FF0066CC00FF
FF00CCFF00006600FFCC00FF0000FFFF00000066FFFF00000000FFCC00FFFF00000000FF
0066FFFF00660066FF0066FFFF00CC00CCFF00CCFF00FFCC00FFCC00CCFF00FFCC00CCFF
6600FFCC00FF0000FF00CCFF0066FF00CCFF0066FF00CCFF
00CCFF00FFCCCC00FF00FFCC00FF6600CCFF00CCFF00FFCC00FF6600FF6600FFCC00FF66
00FF0000FF0000FF66CC00FF00FF6600FF6600FF6600FF6600FFCC00CCFFFF0066FF00CC
00CCFF00FFCC00FFCC00CCFF00CCFF00FFCC00FFCC0066FF00FFCC00FFCC00FFCC0066FF
0066FF00FFCC00FFCC00CCFF00CCFF0066FF0000FFCC00FFFF0000FF00CC0000FF0066FF
0066FF00CCFF0000FF00CCFF00CCFF00CCFF6600FF0000FF0066FF0066FF00CCFF00FFCC
00CCFF0066FF00CCFF00FFCC00CCFF0066FF0000FFFF0000FF0000FF00000000FF0066FF
00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00CCFF00CCFF00CCFF0000FF0000FF
00CCFF0066FF00CCFF00FFCC00FFCC00FFCC00CCFF0066FF0066FF00CCFF00CCFF0066FF
00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FFCC00FF
6600FFFF0000CC00FF6600FFCC00FFFF0000FF0000FF0000FF0000FF0000FF0066FF0000
FF0000FF0000FF0000CC00FFCC00FFFF00006600FF6600FF6600FF0000FFFF00006600FF
FF00CCFF0066FF0000CC00FF6600FF0000FF6600FFFF00000000FF0000FF0066FF6600FF
CC00FFFF00CCCC00FF0066FFCC00FF0066FF0066FF0066FF0066FF0000FFCC00FF0066FF
0066FF0000FF0000FFCC00FFFF0000FF0066CC00FF6600FFFF00000000FF0000FF0066FF
CC00FFFF00000000FF0066FF00CCFF0066FF00CCFF00CCFF0066FFFF0000CC00FF0066FF
0000FF0066FF00FFCC00CCFFFF00CC00FFCC00FFCC00FF6600FF660066FF00FFCC00FFCC
6600FFFF00660066FF00FFCC00FFCC00FFCC00CCFF00FFCC
00FF6600FF6600CCFF00FFCC00FF6600FF6600FF6600FFCC00FF6600FF0000FF0000FF66
00FF0000FF0000FF660066FF00FF6600FF0000FF0000FF666600FF00FFCCCC00FF00CCFF
FF000000FFCC00FF6600FFCC00FF6600FF6600FFCC00FFCC00FF6600FF6600FFCC0000FF
0000FF00FFCC00FFCC00CCFF0000FFFF00CC6600FFFF0000FF00006600FF0066FF00CCFF
00CCFF00CCFF0066FF00CCFF00FFCC00FFCC00FFCC00CCFF00CCFF00FFCC00FFCC00FFCC
0000FFFF000000FFCC00FFCC00CCFF0066FF0066FF6600FFFF00006600FF0066FF6600FF
00CCFF00FFCC00FFCC00CCFF0066FF00FFCC00FFCC00CCFF00FFCC00FFCC0000FF00CCFF
00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF6600FF0000FF00CCFF00CCFF00FFCC
00FFCC00FFCC00CCFF00CCFF0066FF0000FF6600FF0000FF0066FF0066FF0066FF0000FF
6600FFFF0000FF0000FF0066FF0000FF0000FF0000FF00CCFF0066FF00CCFF00CCFF0000
CC00FF6600FF6600FF0000FFFF0000CC00FFCC00FF0066FF0000FF0066FF0000FF6600FF
CC00FFFF0000CC00FF0000FF0000FF0000FF0066FF6600FF00CCFF00CCFF00CCFF0066FF
FF00CCCC00FFCC00FF00CCFF0066FF00CCFF0066FF0066FF00CCFF00CCFF0066FF0066FF
0066FF6600FF6600FFFF0000FF00CCCC00FFFF00CC0066FF0066FF0066FF00CCFF00CCFF
FF0066FF00660066FF00FFCC00FFCC00CCFF00FFCC0066FFFF0000CC00FF6600FF0066FF
00FFCC6600FF00FFCC00FF6600FFCC00FF6600FF6600FF6600FF66FF00CC00FF6600FF66
00FF66CC00FF00FFCC00FFCC00FF6600FFCC00FFCC00FFCC
00FFCC00FF6600FF6600FFCC00FF0000FF0000FF6600FFCC00FF6600FF0000FF0000FF66
00FF0000FF0000CCFF6600FF00FF0000FF0000FF000066FF00FF6600FFCCFF000000FFCC
00FFCC0000FF00FF6600FF0000FF6600FF660000FF00CCFF00FF6600FF6600FF6600FFCC
00FF6600FFCC00CCFF00CCFF00CCFF0066FF0000FFFF00CCFF00CC0000FFFF00CC0066FF
00FFCC00FFCC00CCFF0000FF00FFCC00FFCC00FFCC00CCFF0066FF00FFCC00FF6600FF66
00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF6600FFFF00006600FF0066FF00CCFF
00CCFF00FFCC00FFCC00FFCC00CCFF00FFCC00FF6600FFCC00FFCC00FFCC0000FF00CCFF
00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FFFF00000066FF00CCFF00FFCC00FFCC
00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF0066FFFF00000000FF0000FF6600FF
CC00FFFF0066FF0000FF0000FF0066CC00FFFF00666600FFCC00FF6600FFFF00CCFF0000
6600FF0000FF0066FF6600FF0066FF0000FF0066FF00CCFF0000FF0066FF0000FF0000FF
CC00FFFF00006600FF0000FF0066FFFF00CC00CCFF0000FF0066FF00FFCC00CCFF6600FF
0066FF6600FF00CCFF00CCFF00FFCC00FFCC0066FF00CCFF00CCFF0066FF00CCFF00CCFF
0066FF0000FF6600FFFF0000FF00006600FF0066FF00CCFF00CCFFCC00FF00FFCC00FFCC
00CCFF0066FF00FFCC00FFCC0066FF00CCFF00FFCC00FFCC00CCFFFF00CCFF000000CCFF
00FFCC00FF6600FFCC00FF6600FFCC00FF6600FF0000FF0000FF0000FF6600FF0000FF00
00FF66CC00FF00FF6600FF6600FF6600FFCCFF006600FF66
00FF6600FF0000FF0000FF6600FF0000FF0000FF66FF000000CCFF00FF0000FF0066FF00
66FF0000FF0000FF0000FF6600FF6600FF0000FF0000FF0000FF0000FF6600CCFF00FF66
00FF660066FF00FF0000FF0000FF0000FF6600FFCC00FF660066FF00FF6600FF6600FF66
00FF6600FF6600FFCC00FFCC00CCFF0066FFCC00FFFF0000FF00CC0000FF00CCFF00CCFF
00CCFF00FFCC00FFCC6600FF00FF6600FF6600FF6600FFCC00CCFF00FFCC00FF6600FF66
00FF6600FF6600FF6600FF6600FFCC00CCFF0000FFFF0000FF0000FF00660066FF00FFCC
00FFCC00FF6600FF6600FF6600CCFF00FF6600FF6600FF6600FFCC00FFCC6600FF00CCFF
00FFCC00FF6600FF6600FF6600FFCC00FFCC00CCFF0066FF6600FF00CCFF00FFCC00FFCC
00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0066FF0000FF0000FFFF00CCFF0000
FF00CCFF0000FF0066FF0000FF0066CC00FF0000FFFF00000066FF6600FF6600FFFF0000
6600FF0066FF00CCFF0000FF00CCFF0000FF0066FF00CCFF00CCFF00CCFF0066FF0000FF
FF0000FF0000FF00000000FF00CCFF00CCFF00FFCC00CCFF0066FF00FFCC00FFCC00FFCC
00CCFF0000FF00FFCC00CCFF00FFCC00FFCCFF000000CCFF00FFCC00FFCC00CCFF0066FF
0000FF0000FFFF00CCFF0000CC00FF0066FF00CCFF00CCFF00FFCC0000FF00CCFF00FFCC
00FFCC0000FF00FFCC00FF6600FF6600FFCC00FF6600FFCCCC00FF0066FFCC00FF00FFCC
FF000000FFCC00FF0000FF0000FFCC00CCFF00FF0000FF0000FF0000FF0000FF0000FF00
00FF6600FFCC00FF6600FF0000FF0000FFCC00FF6600FF66
00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF0000FF0066FF0066FF00
66FF0066FF0000FF0000FF0066FF0066FF0066FF0000FF0000FF0000FF6600FFCC00FF00
00FF0000FF0000FF0000FF0000FF0000FF66FF000000FFCC00FF0000FF0000FF0000FF66
00FF6600FFCC00CCFF00CCFF00CCFF6600FFCC00FFFF0000FF00660000FFCC00FF00FFCC
00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FFCCFF000000CCFF00FF6600FF66
00FF6600FF6600FF6600FF6600FFCC0066FF00CCFF0066FFFF00660066FF00CCFF0000FF
00FFCC00FF6600FF6600FF660066FF00FF6600FF6600FF6600FF6600FFCC6600FF00FFCC
00FFCC00FF6600FF6600FF6600FF6600FFCC0066FF00FFCC00FFCC00CCFF00FFCC00FFCC
00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF6600FFFF0000
FF0000FF00CC6600FFCC00FFFF00CC6600FF0066FFFF00000066FF0066FF0000FFFF0000
6600FFCC00FF00CCFF00FFCC00FFCC00CCFF00CCFF00FFCC00FFCC0000FF6600FF0066FF
6600FFFF00006600FF0066FFFF00CC00CCFF00FFCCFF000000CCFF00FFCC00FF6600FFCC
00CCFFFF000000FFCC00FF6600FF6600FFCC0066FF0066FF00FFCC00FFCC0066FF0000FF
FF00CC0000FFCC00FFFF0000FF00000000FFFF00CC00FFCC00FFCC00FFCC0000FF00FF66
00FF660066FF00CCFF00FF6600FF6600FF6600FF660066FF00FF6600FFCC0066FF00FF66
00FF6600FFCC00FF0000FF0000CCFFFF000000FF0000FF0066FF0000FF0000FF0000FF00
00FFCC00CCFF00FFCC00FF0000FF0000FF6600FF0000FF00
FF000000FFCC00FF0066FF0066FF0066FF0000FF0000FF6600FFCC00FF0066FF0066FF00
66FF0066FF0000FF0066FF0066FF0066FF0066FF0066FF0000FF6600FFCC0066FF00FF00
00FF0000FF0000FF0000FF0000FFCC00FF6600CCFF00FFCC00FF0000FF0000FF0000FF66
00FFCC0066FF0066FF00CCFF00CCFFCC00FFFF00CCFF0000FF00CCCC00FF0066FF00CCFF
00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FFCC6600FF00FF6600FF6600FF00
00FF0000FF0000FFCC0066FF0066FF00FFCC00CCFF00CCFF0000FF00CCFF00FFCC00FFCC
0066FF00FF6600FF6600FF6600CCFF00FF6600FF6600FF6600CCFF00CCFF6600FF00FFCC
00FF6600FF6600FF6600FF6600FF6600FFCC00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC
00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF0000FFCC00FFFF0000
FF00CC6600FFFF0000FF00000000FF0066FF00CCFF0066FF00CCFF0066FF0066FF0000FF
0066FF00CCFF0000FF00FFCC00FFCC0066FF0066FF00FFCC00FFCC0000FF00CCFF0066FF
0000FFFF00006600FF0000FF00FFCC00FFCC00FF6600FF660066FF00FF6600FF6600FF66
00FFCC0066FF00FFCC00FF6600FF6600FF6600FFCC00FF6600FF6600FFCC00FFCC00CCFF
00CCFF0000FFCC00FFFF00006600FF00CCFF00CCFF00FFCC00FF6600FF6600FFCC00FF66
00FF6600FFCC00CCFF00FF6600FF0000FF0000FF0000CCFF00FF0000FF66CC00FF00FF66
00FF0000FF0000FF0000FF0000FF0000FF6600FF0066FF0066FF0066FF0066FF0000FF00
00FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFCC66FF0066FF0066FF0066FF0000FF0000FFCC00FFCC00FF6666FF0066FF00
66FF0066FF0000FF0066FF0066FF0066FF0066FF0066FF0000FF000000FF00FF6600FF00
00FF0066FF0066FF0066FF0000FF0000FF0000FF6600FF0000FF0000FF0000FF0000FF66
00FFCC00CCFF00FFCC00FFCC00CCFF6600FFCC00FFFF0000FF00CC0066FF00CCFF0066FF
00CCFF00FFCC00FF6600FF0000FF0000FF0000FF6600FF6600CCFF00FF6600FF6600FF00
00FF0000FF0000FF6600CCFF00FF6600FF6600FFCC00CCFF0066FF00CCFF00FF6600FF66
CC00FF00FF6600FF6600FF0000FF0000FF0000FF6600FFCC00FFCC00CCFF0066FF6600FF
00FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FF6600FF6600FF6600FFCC00FFCC
00FFCC00CCFF0066FF0066FF0000FF0066FF0066FF0066FF0000FFFF0000FF0066CC00FF
6600FFFF00660066FF0066FF0000FF0000FF00CCFF00CCFF00FFCC00CCFF00CCFF00CCFF
0066FF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF
FF0000FF0000CC00FF0066FF00CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FF66
00CCFF0000FF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00CCFF
FF00CC6600FFFF00CCFF0000CC00FF0066FF00CCFF00FFCC00FF6600FF6600FF6600FF00
00FF0000FF660066FF00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FF66
00FF0000FF0066FF0066FF0066FF0000FFCC00FF0066FF0066FF0066FF0066FF0000FF00
00FF6600FF6600FF0066FF0066FF0066FF0000FF0000FF00
66FF0000FF0066FF0066FF0066FF0066FF0000FFCC00FF0000FFCC00FF0000FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF0000CCFF00FFCC00FF00
66FF0066FF0066FF0066FF0066FF0000FF6600FFCC00FF0000FF0000FF0000FF0000FF00
00FF0000FF6600FF6600FFCC0066FF6600FFFF0000FF00000000FF0000FF00FFCC00CCFF
00CCFF6600FF00FF6600FF0000FF0000FF0000FF0000FF660066FF00FFCC00FF6600FF00
00FF0000FF0000FF0000FF6600FF0000FF0000FF6600FF6600FFCC00FF6600FF6600FF66
00FF6600CCFF00FF0000FF0000FF0000FF0000FF0000FF6600FF6600FFCC00FFCC00FF66
00FFCC00FF6600FF6600FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF6600CCFF
00FFCC00CCFF00CCFF00CCFF6600FF0000FFFF00660000FFFF00CCFF0066FF0000FF00CC
CC00FF0066FFFF00CC00CCFF00CCFF6600FF00CCFF00FFCC00FFCC00CCFF00FFCC00FFCC
FF000000CCFF00FFCC00FF6600FF6600FFCC00FFCC00FF6600FF6600FFCC00CCFF0066FF
0066FFFF00CC0066FF00FFCCFF00CC00CCFF00FFCC00FF6600FF0000FF0000FF6600FF66
00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF0066FF
0066FFFF0000FF0066FF00CC6600FF0066FF00CCFF0066FF00CCFFFF006600FF0000FF00
00FF0000FF6600CCFF00FFCC00FFCC00FF0000FF0000FF0000FF0000FF6600FFCC00FF66
00FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF00
00CCFF0000FF00FF0066FF0066FF0066FF0066FF0000FFCC
66FF0066FF0000FF0066FF0066FF0066FF0066FF0066FF0000FF6666FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF6600FFCCFF000000FF6600FF00
66FF0066FF0066FF0066FF0066FF0000FFCC66FF0066FF0066FF0066FF0000FF0000FF00
00FF0000FF6600FFCC00CCFFFF00CC0066FFCC00FFFF00CC0000FF00CCFF00FFCC00FF66
00FF6600FF6600FFCC00FF0000FF0000FF0000FF00FF00CC00CCFF00FF6600FFCC00FF00
00FF0000FF0000FFCC00FF0000FF0000FF0000FF660066FF6600FF00FF6600FF0000FF00
00FF0000FF6600FF0000FF0000FF0000FF0000FF0000FF6600FFCC0066FF00FFCC00FF66
00FF6600FF6600FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC
00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0066FF0000FFFF0000FF0000FF00666600FF
0066FF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF00CCFF00FFCC00FFCC00FFCC0066FF
00CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF660066FF0066FF00FFCC
0066FF0066FFFF000000FFCC00FF6600CCFF00FFCC00FF6600FF0000FF0000FF0000FF66
00FFCC0066FF00FF6600FF0000FF0000FF0000FF0000FFCC00CCFF0066FF00CCFF00FFCC
00CCFF0066FFFF0066FF00CC0000FF00CCFF00FFCC00FFCCCC00FF00FFCC00FF0000FF00
00FF0000FF6600FF0000FF6600FF0066FF0066FF0066FF0066FF0000FF0000FF0000FF66
00FF0066FF0066FF0066FF0066FF0066FF0000FF0066FF0066FF0066FF0000CCFF00FF66
0000FF00FF0000FF6666FF0066FF0066FF0066FF0000FF00
66FF0066FF0066FF00CCFF00CCFF00CCFF0066FF0000FF00FF000000FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF0000FF6600CCFF00FF6600FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF00
00FF0000FF6600FF6600CCFF6600FF6600FFFF0000FF0000FF000000CCFF0000FF00FF66
00FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF0000FFCC00FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FFCC00FF6600FF0000FF0000FF00
00FF0000FFCC00FF0000FF0000FF0000FF0000FF0000FF6600FFCC6600FF0066FF00FF66
00FF6600FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FFCC
00FFCC00FFCC00FFCC00CCFF00CCFF0000FF0066FF0000FFFF00CCFF0000FF00CCFF00CC
0000FF0066FF00CCFF00FFCC00FFCC00CCFF0066FF00FFCC00FF6600FF6600FF6600FFCC
0066FF0066FF00FFCC00FF6600FF6600FF6600FF0000FF660000FF00CCFF00FFCC00FF66
00FFCC00CCFF00CCFFCC00FF00FF6600FF6600FFCC00FF0000FF0000FF0000FF0000FF66
0066FF6600FF00FF6600FF0000FF0000FF0000FF0000FF66CC00FF00FFCC00FFCC00FFCC
00CCFFFF0000FF0000FF00000000FF6600FF00FFCC00FF6600FF6600FF6600FF6600FF00
00FF0000FF0000FF0000FF6600FF0066FF0066FF0066FF0066FF0000FFCC00FFCCCC00FF
00FF0000FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF0000FF6666FF0066FF00
00FFCC66FF0066FF0066FF0066FF0066FF0000FF0066FF00
66FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF6666FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF0000FF0000FF0066FF00
6600FF66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000CCFF
00FF6600FF66CC00FFCC00FF0000FFFF00CCFF00666600FFCC00FFCC00FF00FFCC00FF66
00FF0000FF0000FF0000FF0066FF0066FF0066FF0000FF0000FFCC00FFCC00FF0066FF00
66FF0066FF0066FF0000FF0000FF0000FF0000CCFF0066FF00FFCC00FF6600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF00CCFF00CCFF00000066FF00FF6600FF66
00FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FFCC00CCFF
00FFCC00FFCC00FFCC00CCFF0000FF0066FF0000FFCC00FFFF0000FF00006600FF0066FF
0000FF0000FF6600FF00FFCC00FFCC00FFCC00FFCC00CCFF00FF6600FF6600FF6600FF66
00CCFFFF000000FFCC00FF6600FF6600FF0000FF0000FF0000FF66FF006600FF6600FF66
00FF6600FF6600FFCC00FF6600FF0000FF0000FF0000FF6600FF0000FF0000FF000066FF
00FF6600FFCC00FFCC00FF0000FF0000FF0000FF00FF000000FF6600FF6600FF6600FFCC
00FFCC00CCFF6600FFFF00000000FF0000FF00CCFF00FFCC00FF0000FF0000FF0000FF00
66FF0066FF0066FF0000FF0000FF0066FF0066FF0066FF0066FF0000FF0000FF66CC00FF
00FFCC00FF6600FFCC66FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF66
FF006666FF0066FF00CCFF00CCFF00CCFF0066FF0066FF00
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FFCC00FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF0000FF0066FF0066FF00
66FF0066FF00CCFF00CCFF00CCFF0066FF0066FF0066FF0066FF0066FF0000FF0000FF00
CC00FF00FFCC00FF6600FFCC00FFCC0000FFFF00000066FF00CCFF00FFCC00CCFF00FFCC
00FF0000FF0000FF0066FF0066FF0066FF0066FF0066FF0000FF6600FF6666FF0066FF00
66FF0066FF0066FF0066FF0000FF0000FF0000FF660066FF00FF6600FF6600FF0000FF00
00FF0066FF0066FF0066FF0000FF0000FF0000FF0000FF66CC00FF00FFCCFF00CC00FF66
00FF0000FF0000FF0000FF0000FF0000FF0000FF660000FF00FFCC00FFCC00FFCC00FFCC
0000FF00CCFF6600FF00CCFF0066FFFF00CCCC00FFCC00FFFF0066FF00CC6600FF0066FF
00CCFF00CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FFCC
00FF6600FFCC00FFCC00FF6600FF0000FF0000FF0000FF0000FF0000FF6600FF0000FF00
00FF0000FF6600CCFF00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FF00
00FF6600FF6600FF0000CCFF00FF0000FF0000FF6600FF0000FF0000FF0000FF666600FF
0066FFCC00FF6600FFFF00CCFF0000FF000000CCFF00FF6600FF6600FF0000FF0066FF00
66FF0066FF0066FF0066FF0000FF0066FF0066FF0066FF0066FF000000FF00FF0000FFCC
00CCFF66FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
00FF6666FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF006600FFFF006600FF0066FF0066FF00
66FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF6600FF6600FF6600CCFF
00FF0000FF0000FF0000FF6600FFCC6600FFFF00CC00CCFF00FF6600FF66CC00FF0000FF
00FF666600FF00FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0066FF0066FF00
66FF0066FF0066FF0066FF0000FF0000FF0000FF00FF000000FF0000FF0000FF0066FF00
66FF0066FF0066FF0066FF0066FF0000FF0000FF0000FF6600FFCC00FF0000FF6600FF66
00FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600CCFF0066FF00CCFF00CCFF
FF0000FF0066FF00CCFF0000FF0000FF0000FF0000FF00CCFF0000FF0066FF00666600FF
6600FF00CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FF6600FFCC6600FF00FFCC00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF000000FFFF000000FF6600FF0000FF0000FF0066FF0066FF0066FF0066FF0000FF00
00FF6600CCFF00FF0066FF0066FF0066FF0000FF0000FF0000FF0000FF0000FF6600FFCC
0000FFFF00CCCC00FFFF00CC0066FF0066FFFF00000066FF00FF6600FFCC00FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0000FFCC66FF0066FF0000FF00
FF000066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
00FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF660000FF00FF0066FF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF00FF000000FF66
00FF0000FF0000FF0000FFCC00FF666600FF0000FF00FFCC00CCFF00FF0000FF0000FF66
FF000000FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0000FF0000FFCC00FF660066FF00FF0000FF0000FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0000FFCC0066FF00FF6600FF0000FF0000FF66
00FF0000FF0000FF0000FF0000FF0000FF6600CCFF00FFCCFF00000000FF0066FF00FFCC
FF00000066FF0066FF00CCFF0066FFCC00FFFF00CCFF0000FF0000FF0066FF0000CC00FF
0066FF0066FF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF00
0066FFFF0000CC00FF00FFCC00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000CCFF6600FF00FFCC00FF6600FF6666FF0066FF0066FF0066FF0066FF0066FF00
00FF6600FFCC66FF0066FF0066FF0066FF0066FF0000FF0000FF0000FF0000FF6600CCFF
00FFCC00CCFF0066FFFF00000066FF00FFCC00FFCC00FF6600FF660066FF00FF0000FF66
66FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF00
0000FF00FF0000FFCC66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0000FF6600FFCC0066FF0066FF00FF0066FF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF000000FF00FF0000FF00
66FF0066FF0066FF0000FF0000FF660066FF0000FF00FF6600FF0000FF0000FF0000FF00
00FF6600FFCC00FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0000FF0000FF0000FFCC0066FF00FFCC00FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0000FF000000FF00FF0000FF0000FF0000CCFF
00FF0000FF0000FF0000FF0000FF0000FF6600FFCC00FFCC00FF660000FF00FFCC00FFCC
00FFCC00FFCC00FFCC6600FFFF00CC0000FFCC00FFFF0000FF00666600FF0000FF0066FF
0066FF0066FF0000FF00CCFF00FFCC00FFCC00FFCC00FF6600FF0000FF0000FF0000FF00
00FF0000FFCC00CCFF00FFCC00FF0000FF0000FF0066FF0066FF0066FF0066FF0000FF00
00FF0000FF0000FF6600FF6600FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF00
00FF0000FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF6600FFCC00CCFF00FF66
00FF6600FF6600CCFFFF00666600FF00FFCC00FF6600FF0000FF6600FF00FF00CC00FF66
00CCFF00FF6666FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF0000CCFF
CC00FF00FF6666FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
00FFCC66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0000FFCC66FF0066FF0066FF0000FF660000FF00FF00CC00FF66FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF6600FF6666FF0000FF00
66FF0066FF0066FF000000FF00FFCC0000FFCC00FF0066FF00FF0066FF0066FF0066FF00
00FF660066FF00FFCC00FF6600FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0000FF000000FF00CCFF00CCFF00CCFF00FF6600FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF0000FF0066FF0066FF0066FF00
66FF0066FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF66
00FFCC00FFCC00FFCC00CCFF00CCFF0000FFCC00FFFF0000FF0066CC00FF0066FF0066FF
00CCFF00FFCCFF00CC0000FFFF000000CCFF00FF6600FF6600FF0000FF0000FF0000FF00
00FF0000FF6600FF666600FF00FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF00
00FF0000FF0000FF6600FF6600FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF000000FF00CCFF00FF00
00FF000000FF00FFCC0000FF0066FF00FF6600FF0000FF0066FF0000FF0000FF66FF0000
00FF6666FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF00
CC00FF00FFCC00FF000066FF66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
00FF0000FFCC00FF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF6600FF0066FF0066FF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF006600FF66FF0066FF0066FF00
66FF0066FF0000FF6600FF0000FF006600FF00FF6600FF6600FF0066FF0066FF0066FF00
00FF6600FF660066FF66FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0000FF0000FF0000CCFF00FF660066FF00FFCC00FFCC00FF6600FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0000FF6600FF0066FF0066FF0066FF0066FF00
66FF0066FF0000CCFF00FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF66
00FFCCCC00FF6600FF0000FF6600FF0000FF6600FFFF0000FF00CC0000FF0066FF00CCFF
00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF6600FF00FF6600FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFCC00FF6600FF0066FF0066FF0066FF0066FF0066FF0066FF00
00FF0000FF6600FFCCFF000000FF6600FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF0000FFCC00FF6600FF0000FF00
00FF0000FF0000FFCC00CCFF00CCFF00FF6600FF0066FF0066FF0066FF0000CCFF00FF00
0066FF00FF66CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF00
00FFCC00CCFF00FF0000FF0000FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
66FF00CCFF00CCFF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0066FF000066FF66FF00CCFF00CCFF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF66CCFF00CCFF00CCFF00CCFF00
CCFF0066FF0066FF0066FF0000FF0000FFCC00FF0066FF0000FF0066FF0066FF0066FF00
00FF0066FF00FF00CC66FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0066FF0066FF0066FF000066FF6600FF00FFCC00FF0000FF0000FF6666FF00
66FF0066FF0066FF0066FF0066FF0066FF0000FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF66
00FFCC00FFCC00CCFF00CCFF0000FF0000FFFF0000FF0000FF00006600FFCC00FFFF0000
0066FF00FFCC00FF6600FF6600FF6600FF660000FF00FF6600FF6600FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFCC00FF6666FF0066FF0066FF0066FF0066FF0066FF00
00FF0000FF0000FFCCFF000000FF6600FF6600FF0066FF0066FF0066FF0066FF0066FF00
66FF00CCFF0066FF0066FF0066FF0000FF0000FF660066FF0066FF00FF0066FF0066FF00
66FF0000FF0000FFCCFF00CC00CCFF00FF6600FFCC66FF0066FF0066FF0066FF0066FF00
00FF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF0000FF00
00FF00FF00CC00FF66CCFF00CCFF00CCFF0000FF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0066FF0000FFCC
CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF0000FFCCCCFF00CCFF00CCFF00CCFF00
66FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0066FF0000FF6600FF6666FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0000FFCC00FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF0066FF0066FF0066FF0000FF0000FF6600FF0066FF0066FF0066FF0000FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600CCFF00CCFF
00CCFF00FFCC00CCFF00CCFF0066FF0000FFCC00FFFF0000CC00FF0000FF0066FF00CCFF
00FFCC00FFCC00FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF6600FF0066FF00
66FF0066FF0066FF0066FF0000CCFF00FF0066FF0066FF0066FF0066FF0066FF0066FF00
00FF0000FF660000FF0066FF00FFCC00FF0000FF0000FF0000FF6666FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF6600FF0000FF6666FF0066FF00
66FF0000FF6600FF6600FFCC0000FF00FF0066FF0000FF0066FF00CCFF00CCFF00CCFF00
66FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF00CCFF00
66FF0000FF0066FF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0000FF0000FF0066FF00CCFF00CCFF00CCFF00
CCFF00CCFF00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0000FF0000CCFF00CCFF00FF0066FF0066FF00CCFF00CCFF00CCFF00
CCFF0066FF0066FF0000FF66CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF0066FF0066FF0066FF0000FF0000FF6600FF0066FF0066FF0066FF0066FF00
66FF0066FF00CCFF00CCFF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FFCC
0000FF0066FF00CCFFCC00FF0066FF6600FFCC00FFFF0000FF00000000FF0066FF0000FF
00CCFF0000FF00FFCC00FF6600FF6600FF0000FF0000FF0000FF0000FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF00
00FF0000FF0000FF0000FFCC00FFCC00FF0066FF0066FF0066FF0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FFCC66FF0066FF0066FF0066FF00
66FF0066FF0066FF0000FF006600FF66FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF00
CCFF0066FF0000FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0000FF00CCFF00CCFF0000FF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0066FF0000FF0000FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0000FFCCCCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF0000FF0000FF6600FF0000FFCCCC00FF00FF0066FF0066FF0066FF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0000FF0000FF0000FF6600FF0000FF0000FF0000CCFF00FF6600FF6600FFCC
00CCFF0066FF0000FFCC00FF0000FF6600FFFF0000FF0000FF00CCCC00FFCC00FF0066FF
0000FF0066FF00FFCC00FF6600FF6600FF0000FF0000FF0000FF0000FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0000FF0066FF0066FF0066FF0066FF0066FF0000FF00
66FF0066FF0000FF0000FF0000FF6600FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF0066FF0066FF00CCFF00CCFF00
00FF0066FF0066FF0066FF0000CCFF00FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF000066FF66FF0000FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
66FF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF0066FF006600FFCCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0000FF6600FF0000FF6600FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0000FF66CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF0066FF0000FF6600FF66FF000000FFCC00FFCC00FF0066FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0000FF0000FF0000FF6600FFCC00FF6600FF6600FF6600FFCC00FFCC00FFCC
0000FFFF0000FF00CCFF0066FF0000FF00CCFF00CCFF0066FF0066FF0000FF0066FF0066
0066FF00FFCC00FFCC00FF6600FF6600FF0000FF0000FF0000FF0000FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0000FF00FF000000FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF66CCFF00CCFF00CCFF00CCFF00
CCFF0066FF0066FF006600FF00FFCC00FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00
00FF00CCFF0000CCFFCCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
00FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF0066FF0000FF00FF000000CCFF00FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0000FF0066FF0000FF000066FFFF000000FF6600FF0066FF0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0066FF00
00FF0000FF0000FF0000FF0000FF660066FFFF000000CCFF00CCFF6600FF00FFCC00FFCC
0066FF0000FFFF0000FF00CCFF00CCFF0000FF0000FF00006600FFCC00FF6600FFFF0000
FF00666600FF00CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0066FF0066FF0000FF000066FF00FF660066FF00FF0066FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0066FF0000FF0000FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF0000FF0000CCFFCCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF00
66FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF00
00FF6600FF0000FF0000FF660000FF00FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0000FF000066FF0000FF6600FF0000FF00FF0066FF0066FF0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF0000FFCC
00FF6600FF0000CCFF00FF6600FF66FF00000066FFFF000000FF66FF000000FF6600FF66
00FFCC6600FF0066FF6600FF0000FFCC00FFFF0000CC00FF0000FF0066FF0066FF0066FF
00CCFF0066FF00FFCC0066FF00CCFF00FFCC00FFCC00FFCC00FF0000FF0000FF0066FF00
66FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0000FF0000FFCC6600FF00FFCC00FF0066FF0066FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0066FF0000FF0000CCFF00FFCC66FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00
66FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
00FF6600FF6600FF0000FF6600CCFF00FFCC00FF6666FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0066FF0066FF0000FF000000FF00CCFF00FFCC00FF0000FF0000FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF00
0066FF00FFCC0066FFFF000000CCFF00FF666600FF00FF6600FF6600FF6600FF6600FF66
FF006600CCFF00CCFF00CCFF0000FF6600FFFF0000FF00CC0000FF0066FF0066FF0066FF
0066FF00FF6600FF6600CCFF00FF6600CCFFFF00660066FF00FF6600FF0000FF0000FF00
00FF0000FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF0066FF0000FF0000FF666600FF00CCFF00FF0000FF0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0066FF0000FF00CC00FFFF000066FF0066FF0066FF00CCFF00CCFF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC0000FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
00CCFF00FF6666FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC0000FFCCFFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
CCFF0066FF0066FF0000CCFF00FF6666FF000066FF00FFCC66FF00CCFF00CCFF00CCFF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0000FF00CCFF00
CCFF00CCFF0066FF0000FFCC0000FF00FF0066FF0000FF6600FF0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF00
00FFCCFF000000FFCCFF000000FF0000FF0000FFCC00FF0000FF0000FF0000FF6600FF66
00FF6600FFCC00FFCC0066FF0000FFFF0066FF0000FF00006600FF0066FF00CCFF00FFCC
00FFCC00FFCC00FF6600FF6600FF6600FF6600FFCC00FF660066FF00FFCC00FF6600FF66
00FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF0066FF0000FF0000FF66FF00CC00FF6600FF66CC00FF00FF6666FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0066FF0000FF000000FF00CCFF00FF0000FFCC66FF0066FF00FF0000
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF0000FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
CCFF0066FF0066FF0000CCFFCCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0000FF0066FF0066FF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF0000FFCC66FF0066FF0066FF0000FF0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF6600FF66FF0000
00CCFF00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF66
00FF6600FFCC00CCFF00CCFF0066FF6600FFFF00006600FF0066FF00CCFF00CCFF00CCFF
00FF6600FF6600FF0000FF0000FF0000FF0000FF6600FF0000FF6600FFCCFF000000FF66
00FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF00FF00CC0000FF00FF0000CCFF00FF6666FF0000FF0066FF0066FF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF0000FF0000FF6600FF0000FFCC00FF6666FF0066FF00CCFF00CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF0000FF00
CCFF00CCFF00CCFF00CCFF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
CCFF00CCFF0000FF006600FF66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF0000FF0066FF00CCFF00CCFF00CCFF000000FFCCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF0000FF6600FF00
66FF0000FF0000FF0066FF0066FF0066FF0000FF0000FF0000FF0000FF0000FF6600FF66
00FF6600FFCC00FFCC0066FF0066FF6600FFFF0000CC00FF0066FF0000FF00FFCC00FFCC
00FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FF0000FFCC00CCFF
00FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0000FF6600CCFF00FF0066FF0000FF6600FF0066FF00CCFF00CCFF00CCFF00CCFF00
66FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
66FF0066FF0066FF0066FF0066FF0000FF6600FF6666FF00CCFF00CCFF00CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF0066FF0000FF0000FF66
CCFF00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
CCFF0000FF0066FF0000FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF00CCFF0066FF0000FFCC00FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF000000FF66FF0000FF0066FF00
66FF0000FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF0000FF6600FFCC00CCFF
00CCFF0000FF00CCFF0066FFFF0066FF00CCFF0000FF0000FF00CC0066FF00CCFF00CCFF
6600FF00FFCC0066FF00FF0000FF0000FF0066FF0066FF0066FF0000FF6600CCFF00FF00
00FF0000CCFF66FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF0066FF00CCFF0066FF0066FF0000FFCC66FF00CCFF00CCFF00CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF6666FF00CCFF00CCFF00CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC0000CCFFFFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC0000FFCCCCFF00CCFF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0000FFCCFFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000FF00
0000FF66FF0000FF666600FF66FF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF00CCFF0066FF00FF00CC00FF66CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF0066FF0066FF0066FF0066FF00
66FF0000FF6666FF0066FF0066FF0066FF0066FF0000FF0000FF0000FF0000FF66FF00CC
00FFCC0066FF00CCFF00CCFFFF00CCFF00CCFF00006600FF6600FF00CCFF00FFCC00FFCC
00FFCC00FF6600FF6600FF6600FF0066FF0066FF0066FF0066FF0066FF0000FF0066FF00
66FF0000FF0000CCFF66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF00CCFF00CCFF00CCFF0066FF0000FF0066FF00CCFF00CCFF00CCFF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FFCC66FF0066FF00CCFF00CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC0000FF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF00
00FF0000FF660000FF00FF6666FF0066FF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF0066FF0066FF00CCFF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF0066FF0066FF0066FF0066FF0066FF0000FF0000FF0000FF0000FF0000FF66
00FF6600FFCC00FFCC00CCFF0066FFFF0000FF0000CC00FF0066FF00CCFF00FFCC00FF66
00FF6600FF6600FF0000FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF000066FF66FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF0000FF0000FFCC66FF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF6600FFCC66FF0066FF0066FF0066FF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0066FF00
66FF0000FF66FF000000FF6600FF0066FF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF0000FF0000FF66CCFF00CCFF0000FF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0066FF0066FF0066FF0066FF0000FFCC00FF0000FF0000FF0000FF66
00FF6600FFCC0000FF0000FF0066FFCC00FFFF0000FF0000CC00FF6600FF00FFCC00FFCC
00FF6600FF6600FF0000FF0000FF0066FF0066FF0066FF0066FF0066FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF0000FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0000FF0066FF0000FF66CCFF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF6600CCFF00FFCCFF00CC66FF00CCFF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0000CCFFCCFF00CCFF0066FF00
00FFCC00FF660000FF00FF0066FF0066FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF0000FF6666FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF0066FF0000FF0000FF6600FF6600FF6600FF6600FF6600FFCC
00FFCC00FFCC00CCFF00CCFF0066FFCC00FFFF0000FF00000066FF00CCFF00FFCC00CCFF
FF006600FF6600FF6600FF0000FF6600FF0066FF0066FF0066FF0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CC00FFCCFF00CCFF0000FF00CCFF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF000000FF00FF6600FF6600FFCC0066FFFF006600FF0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0000FF0066FF0000FF00FF00CC00FF0066FF00
0066FF0000FF0066FF00FF0066FF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF0000FF0000FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF0066FF0066FF0000FF0000FFCC0066FF0066FF00FF6600FFCC
0066FF00CCFF6600FF0066FF6600FFCC00FFFF0000FF00006600FF6600FF00CCFF0066FF
00FFCC00FF6600CCFF0000FF0066FF00CCFF00FF6600FF6666FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0000FFCC66FF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF00CCFF00CCFF0000FFCC66FF0000FF66FF000000FF6600FF6666FF00CCFF00
CCFF0000FF66CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC0000FF66FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00CCFF0066FF0000FF6666FF0000FF0066FF0000FF0000FF6600FF0000FF00
6600FFFF0066CC00FF00FF0066FF0066FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF0066FF0066FF0066FF0066FF0000FF0000FF6600FFCC00CCFF0066FF
00CCFF0066FF0066FF0000FF0000FF6600FFCC00FFFF0000FF0000FF0000FF00000066FF
0066FF0066FF00FFCC00FF6600FF6666FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0000FF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF00CCFF00CCFF00CCFF0000FF0000CCFFCC00FF00FFCC00FF0066FF0066FF00
66FF0066FF00CCFF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC0066FF00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
CCFF00CCFF00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF00CCFF0066FF0066FF00
00FF66FF000000FF6600FF000000FF00FF0066FF0066FF00CCFF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC0000FFCCCCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0066FF0066FF0066FF0066FF0000FF0000FF6600FFCC0066FF6600FF
0000FFFF0000CC00FFFF00CC6600FF6600FF6600FFCC00FFFF00CCCC00FFFF0000FF0066
FF000000CCFF00FFCC00FF0000FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000CCFFCCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF00CCFF00CCFF0066FF0066FF0000FF6600CCFFCC00FF0066FF00FF0000FF00
00FF6600FF0066FF000066FFCC00FF66FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0066FF00
00FF6600CCFF00FFCC66FF0000FF6600FF00CC00FF66FF00CCFF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC0000FF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF0066FF0066FF0066FF0066FF0000FF0000FF00CC00FFCC00FFFF0000FF0000
FF0000FF00CCCC00FFFF0066FF0000CC00FF6600FF0066FFCC00FF0000FF0000FF0000FF
FF0000FF00CC0066FF0000FF00FF0066FF0066FF0066FF0066FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF0000FF0066FF0066FF0000FFCC00FF660066FFFF006600FF0066FF0066FF00
CCFF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF00CC00FF
0066FF00CCFF66FF0066FF00CCFF00CCFF0000FF0066FF00CC00FFCCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
66FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF0066FF0066FF0000FF0000FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFFFF0066
00CCFF6600FF0066FF0066FFFF00CCFF00000000FF0066FF00CCFF00CCFF00CCFF0066FF
0066FF0066FF00CCFF0000FF00FF6600FF0066FF0000FF0066FF0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF0066FF000066FF00FF0000FF6666FF0000FFCCFF000000FF0066FF00CCFF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF00
00FFCC00FF0000FF66CCFF00CCFF00CCFF00CCFF00CCFF00CCFF000000FFCCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FF0000FF0066FF0066FF0066FF00
66FF0066FF0066FF0000FF0000FF666600FF00FF0000FF0000FF0000FF6600FF6600CCFF
00FFCC0000FF00CCFF0000FFFF0000FF00000000FF6600FF00FFCC00FFCC00FFCC00FF66
00FFCC00FF6600FF6600FF0000FF660066FF00FF6600FF6666FF0066FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF0000FF0000FF0066FF0066FF00CCFF0066FF0066FF006600FF00FF6600FFCCCCFF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
66FF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
FF000066FF00CCFF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00CCFF0066FF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
0000FFFFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0066FF0000FF0066FF00
66FF000066FF00FF6600FF6600FFCC00FF6600FF0066FF0000FF0000FF0000FFCC00FFCC
00FF6600FF6600CCFF00CCFF6600FFFF00000000FF00CCFF00FFCC00FF6600FF6600FF66
00FFCC00FF0000FF0066FF0000FF0000FF000066FF00FF6666FF0066FF0066FF0066FF00
66FF0066FF0000FF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
00FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF006600FF00CCFF00FF0066FF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF0066FF0066FF00
00FF66CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF0066FF0000FF0000CCFF
00FF0000FFCC6600FF00FF0066FF0000FF6666FF0066FF0066FF0000FF0000FFCC00FF00
00FF0000FF666600FF0066FFFF0000FF0000FF00666600FF00CCFF00FFCC00FF0000FF00
00FFCC00FF6666FF0066FF0066FF0000FF0000FF0000FFCC00CCFF00CCFF00FF0000FF00
CC00FF00FF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0000FF66
CCFF00CCFF00FFCC00CCFF00CCFF00CCFF0000FF00CCFF0066FF0000FF66CCFF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0000FF00
00FF0000FF66CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
00FF66FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF00
FF0000FF000000FF6600FF0066FF0066FF0066FF0066FF0066FF0000FF6600FF0000FF00
00FF0000FFCC00FFCC00FFCC6600FFFF00000066FF00FFCC00FFCC00FFCC00FF6600FF00
00FF0000FF0066FF0066FF0066FF0000FFCC66FF0066FF0000FF66FF000000FF6600FF66
66FF0000FF66CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC000066FFCCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0000FF6666FF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0000FF00
66FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF000066FF
00FFCC00FF6666FF0066FF0066FF00CCFF00CCFF0066FF0066FF0066FF0066FF0066FF00
00FF0000FF0000FF6600FFCC0066FFFF00000000FF00FFCC00FF6600FF0000FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF000000FF00FF0000FF66CC00FF00FF66
66FF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0000FF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000FF6666FF00CCFF00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
CCFF0066FF00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0000FFCC66FF000000FF
66FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF00CCFF0066FF0066FF0000FF6600FF00
66FF0000FF0000FF0066FF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0066FF0066FF00
00FF0000FF0000FF660066FFCC00FFFF00CCFF00000000FF00FF6600FF0000FF0066FF00
66FF0066FF0066FF00CCFF00CCFF00CCFF00CCFF0066FF0066FF000066FF00FF6600CCFF
66FF0066FF00CCFF00CCFF00CCFF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0066FF00CCFF00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00FFCC00CCFF0000FFCC66FF00CCFF00CCFF00CCFF0066FF0000FF660066FF
00FF6600CCFFCCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF00CCFF00CCFF00CCFF00CCFF0000FF0066FF0000FF6600FF6600FF0066FF00
66FF0066FF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0066FF0000FF00
00FF660066FF00FFCC00CCFF0066FFFF00660066FF00CCFF00FF666600FF00FF6600FF00
66FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF006600FF66FF0066FF00
00FF6666FF0000FF0066FF0000FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000CCFF66FF00
00FF66CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00FF000000FF0066FF0000FF0000FFCC00FF66
66FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF00CCFF00CCFF0066FF00CCFF0066FF0066FF0000CCFF0000FF00FF6666FF00CCFF00
CCFF00CCFF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF00FF00CC
00FF0000FF0000FF0000FF6600CCFFFF000000CCFF00FF6600FF0000FF0000FF00FF0000
00FF0066FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF000000FFCCFF00CCFF00CCFF00
66FF000066FF00FF0000FF0000FF00CCFF00CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FF0000FF6600CCFF00FF00
66FF00CCFF00CCFF00CCFF0000FF6600CCFFCCFF00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF0066FF0000FF6600FF666600FF00FF66
66FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00CCFF0066FF00CCFF0066FF00
CCFF0066FF0000FF660066FF00FF0066FF0000FF666600FF00CCFF00FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF0000FF6600FF000000FF
66FF0000FF0000FF000066FF00FFCCFF006600FFCC00CCFF00FF0000FF0066FF0000FFCC
00FF0000FF6666FF00CCFF00CCFF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF00CCFF00
66FF0000FF00CC00FF00FF6666FF0066FF0066FF0066FF0066FF0000FF6600FF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000FF6600FF66
66FF0000FF0000FFCC00FF66CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0066FF0000FF666600FF00FFCC
00FF6600FFCC0066FF66FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF0066FF0066FF0000FF0000FFCC0000FF0000FF00FF0000FF0000FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF0000FF6666FF0066FF0066FF00
66FF0066FF0000FF0000FF6600CCFFFF00000066FF00FF0000FF0066FF0066FF0066FF00
66FF0066FF0000FF66CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0000FFCC00FF66CC00FF00FF6600FF0000FFCC00FF0066FF0000FF6666FF00CCFF00
CCFF0000FFCCFFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF0000FFCC0000FF
00FFCC00CCFF66FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000FF0000FFCC6600FF00FF00
66FF0066FF0000FF00CCFF00CCFF00CCFF00CCFF0000FFCCFFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF0000FF6600FFCC0000FF0066FF66FF00CCFF00CCFF0000FFCC
CCFF00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF00CCFF00CCFF00CCFF00CCFF00
66FF0000FF000000FF6600FF00CCFFFF000000CCFF00CCFF00FF6666FF0066FF00CCFF00
CCFF00CCFF00CCFF0000CCFFCCFF00CCFF00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00
66FF0066FF0000FF0000FFCC6600FF00FF6666FF00CCFF0066FF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000FF6600FF000066FF00CCFFFF0000
00FF6666FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
CCFF00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000CCFF00FF000000FF00FFCC66FF00
66FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF0000FF0000FF660066FF00FF0000FF0066FF00CCFF00CCFF00CCFF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0000FF0000FF6600FFCCFF000000FFCC00FF6600FF0066FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF00CCFF0066FF0000FF666600FF00FF6666FF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC0066FF00CCFF00CCFF00CCFF00CCFF0000FFCC66FF0066FF0000FF00FF00CC
00FF6666FF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
66FF00CCFF0066FF00CCFF00CCFF00CCFF0066FF0066FF0000CCFFFF006600FFCC00FF00
66FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF000000FF00FF6666FF0066FF000066FF66FF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0000FF0000FFCC00CCFFFF000000CCFFFF000000FF0066FF0066FF00CCFF00
CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
CCFF00CCFF0000FF0066FF0000FF000066FF66FF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF0000FF0000CCFF
00CCFF00FF0000CCFF66FF00CCFF00CCFF00FFCC00FFCC00FFCC0000FF00FFCC00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC0066FF00FFCC00CCFF00
66FF0000FF0066FF0066FF0000FF0066FF0066FF0000FF6600FFCCFF000000FFCC66FF00
66FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF0000FF0066FF00CCFF00CCFF00CCFF0066FF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0066FF00
00FF0000FF0000FF66FF00CCFF0000CC00FF0000FFFF00CCCC00FF00FF0066FF0066FF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF0066FF0000FF00CCFF0066FF0066FF0000FFCCCCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0000FF00FF0000
CC00FF00FF6666FF00CCFF00CCFF0066FF00CCFF00CCFF0066FF00CCFF00FFCC00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC0066FF0000CCFF00FF00
00FF0000FF6600FF00CCFF0066FF0066FF0000FF00CC00FFFF00666600FF00FFCC00FF00
CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF0066FF0066FF0066FF00CCFF00FFCC00FFCC00CCFF0000FF00CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF0000FF000000FF
00FFCC00FF6600FF6600FFCC00CCFFFF000000FFCC00FF6600FF000066FF0000FF00FF00
00CCFF66FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF0000FFCCCCFF00CCFF00CCFF00CCFF0066FF0066FF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0066FF0066FF000066FF
FF006600CCFF6600FF66FF0066FF0000FF0066FF0000FF0000FFCC66FF0000FF00CCFF00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00CCFF0000FF00CCFF00FFCC0000FF66FFCC00
CCFF0000FF00CCFF00CCFF00CCFF00CCFF0066FF0000FF66FF000000FFCC00FF6600FF66
66FF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFF00
0000FF66FF00FF00CC66FF00CCFF00FFCC00FFCC00FFCC00FFCC0066FF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0000FF666600FF
66FF000066FF66FF0000FF6600CCFF6600FFCC00FF00FF0066FF0066FF0000FF0000CCFF
00FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00CCFF0000FF0000FFCCCCFF00CCFF0066FF00
CCFF00CCFF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF00CCFF0000FF0000FF66
0066FFFF00CC6600FF66FF0066FF0000CCFFCCFF0066FF0000FF0066FF0066FF000066FF
CCFF00CCFF00FFCC0066FF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FF0000FFCC00FFCC0066FF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF0066FF000066FF00FFCC6600FF00FF0066FF0066FF00
00FF6600CCFFCCFF0066FF00CCFF00CCFF0000FF00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
CCFF0000FFCC00FFCCCCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0066FF0000FF6666FF000066FF
CCFF00CCFF0066FF0066FF0000FFCCFF00CC00FF0066FF00CCFF00CCFF00CCFF0000FF00
66FF0000FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00CCFF0066FF006600FF0066FFCCFF00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00CCFF0000FF0066FF0000CCFF00FFCC
00CCFF0000FF00FF0066FF00CCFF00CCFF00CCFF00CCFF000066FFFFCC00FFCC0066FF00
FFCC0066FF0000FF66FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600
FF6600FF6600FF6600CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FFCC00
66FF00FFCC00FFCC00FFCC00FFCC00CCFF0066FF0000FF6600CCFF00FF0066FF00CCFF00
66FF00CCFF0000FF6600FF0000FF00CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
CCFF0066FF00CCFF0000FF66FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FF6666FF00CCFF0066FF00
CCFF00CCFF00CCFF0000FF0000FFCC0000FFFF00006600FFCCFF00CCFF00CCFF00CCFF00
CCFF0066FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FF00FF006600FFCCFFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00CCFF0066FF00CCFF0066FF00CCFF000000FFCC00FF66FF0066FF00
00FF66FF006600FF660066FF66FF00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00CCFF00
FFCC00FFCC00CCFF00CCFF0000FF66FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600
FF6600FF6600CCFF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00FFCC00CCFF0066FF0000FF000066FF00FF0066FF00CCFF00CCFF00
CCFF00CCFF00CCFF00FF00CC00FF00CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF00CCFF00CCFF00
0066FF00CCFFFFCC00FFCC0066FF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0000FF66CCFF00CCFF00FFCC00CCFF00
CCFF00CCFF0000FF6666FF0066FF0000CCFF66FF0066FF0066FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00FFCC00FFCC00FFCC00FFCC00FFCC0066FF00CCFF0066FF0000CCFFCCFF00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00FFCC00CCFF0000FF6600FF0000FF00CCFF00CCFF00CCFF0066FF00
00FF0000CCFF00FF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FFCC0066FF00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600
FF6600FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC006600FFCCFF00CCFF0066FF006600FF00FF0066FF00CCFF00FFCC00
FFCC00FFCC00CCFF00CCFF00CCFF0066FF00CCFF00CCFF00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC0000FF00
66FF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0000CCFFFFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF00CCFF00CCFF0066FF0000FF66CCFF00CCFF00CCFF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF0066FF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
00FF66FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0000FF0066FF00
CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00FFCC00CCFF0000FF6600CCFFCCFF00CCFF00FFCC00CCFF00CCFF00
00FF6600FFCC00CCFF00FF00FF0066CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF66000000FFFF6600FF6600FF6600FF6600
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00FFCC00CCFF0000FF0000FF00CCFF0066FF00CCFF00FFCC00
FFCC00FFCC00CCFF00FFCC00FFCC00CCFF0000FF66FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC0066FF00
CCFF00CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00FFCC0000FF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF0066FF0000FF66CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC0066FF0000CCFF00FF66
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC0000FF00CCFF0066FF00CCFF00CCFF00CCFF00FFCC00FFCC00FFCC00CCFF00
66FF0000FF0000CCFFCCFF0066FF00CCFF0066FF00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600CCFF00FF6600FF6600FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00FFCC00FFCC0000FF00CCFF00FFCC00FFCC0066FF00FFCC00
FFCC00FFCC0000FF00FFCC00FFCC00CCFF00CCFF00CCFF0000FF66FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC0000FF66CCFF00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC0066FF0066FF0000FF0000FFCC66FF0066FF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC0066FF00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC0000FF00CCFF00FFCC00FFCC00CCFF00FFCC00FFCC00FFCC0000FF00
FF0000CCFF0000FF66CCFF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00FFCC00CCFF006600FFCCFF00FFCC00FFCC00FFCC00CCFF00
FFCC00FF6600FF6600FF6600FFCC00FFCC00FFCC0066FF00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00CCFF00CCFF00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF00CCFF0000FF66CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC0000FF00
CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC0000FF00CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00CCFF0000FF6600FFCCCCFF00FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC0000FF00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC0000FF66FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF0066FF0000FF6666FF00CCFF0000FF66FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
00CCFF66FF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF0000FF66CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00FFCC00CCFF0000FF00CCFF00CCFF00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC0000FF00CCFF00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF0000FF000000FF66FF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC0000FF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC0000FF66FF0066CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00CCFF0000FF0000FF00FFCC00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC0066FF00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC000066FFFFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF00CCFF0066FF0000FFCCFF000066FF00CCFF0066FF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC0000FF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00CCFF0066FF00CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC0066FF0066FF0000FFCCCCFF00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF660066FF00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600CCFF00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC0066FF00
66FF0000FFCCFF0066FF000000FFCCCC00FF0066FF00FFCC00FFCC00FF0000FFCCCCFF00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC0000CCFFFFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
00FF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00FFCC00CCFF00CCFF00CCFF00FFCC00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00CCFF0000FF66FF000000FF0000FFCCFFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF660066FF00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC0066FF00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600CCFF00FFCC00FFCC00FFCC00
CCFF00CCFF00CCFF00CCFF0000FF6600CCFF00FF00CCFF0000FF66CCFF00CCFF00CCFF00
CCFF00CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00CCFF000000FF00FF00CCFF00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FFCC00FFCC00CCFF0000FF00
CCFF0066FF0066FF0066FF000066FF00FF66CCFF00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600CCFF00FFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF0000FF0000FFCC00FFCCCCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600CCFF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00CCFF0066FF0000FFCC66FF00CCFF00FFCC0066FF00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFCC00FFCC00FF6600FF6600FF6600FFCC000000FF
FFCC00CCFF00CCFF0000FF666600FF00FF00CCFF00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF0066FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600CCFF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC0000FF0000FF6600CCFF66FF0066FF00FF00CC66FF0066FF0066FF00
00FF0000FFCCFF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00CCFF0066FF0000FF66CCFF00CCFF0000CCFFFFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF660000FF66
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF0066FF0000FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600CCFF00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00CCFF00CCFF0066FF0000CCFF0066FF66FF00CCFF00FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF660000FFCCFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00CCFF0000FF0066FF00FFCC00FFCC00CCFF00CCFF00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF0066FF0000FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00CCFF0000FF00CCFF0066FF0000FFCC66FF00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC0000CCFFCCFF00CCFF00FFCC00FFCC00CCFF0066FF00CCFF00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF6600FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00CCFF00CCFF0066FF0000FF00CCFF00CCFF00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FF6600FF6600FF6600FF6600FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FF0000FFCC0000FF00FFCC000066FF66FF00CCFF00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC0000FF6666FF00FFCC00FFCC00FF6600FF6600FF6600FF6600FF660066FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF660066FF00FFCC00FFCC00FFCC00
FFCC00CCFF00CCFF00CCFF0000FFCCFF000000FF00CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC0000FF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FF6600FF6600FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00CCFF00
FFCC00FF6600FF6600FFCC00FFCC00FFCC0066FF00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00CCFF0000FF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
00CCFFFF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00CCFF0000FF66
00FF6666FF00CCFF0066FF0000FF6600CCFF00FF00CCFF0000FF66CCFF0066FF00CCFF00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FF6600
FF6600FF6600FF6600FF6600FFCC00FFCC000000FFFFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FFCC00
FFCC0066FF000000FFCCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF0000FF6600FF0000FF0000CCFF0000FF00FF66FF00CC00FF00CCFF00CCFF00FFCC00
FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC0066FF00CCFF00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FFCC00FFCC0066FF0000FFCC
CCFF0066FF0000FF66FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF00CCFF0066FF000066FF0066FF00FF0066FF00CCFF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600CCFF0000FFCC00FF66FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600CCFF00
FFCC0000FF0000FF6666FF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF00CCFF00CCFF0066FF0000FF660066FF00FF0066FF00CCFF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00CCFF00FF000000FF6666FF00FFCC00FFCC00
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600
FFCC00FF0000CCFF00FFCC00FFCC0066FF00FF6600FF6600FF6600FF6600FF6600FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
CCFF0066FF0000FF66FF000000FFCC6600FF00FF0000CCFF66FF00CCFF00FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600
FF6600FF6600FF6600FF6600CCFF0000FF0066FF000066FFCCFF00FFCC00FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600
FFCC00CCFF00FFCC00FF6600FF6600FF660000FF00FF6600FF6600FF6600FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00CCFF00CCFF00FFCC00FFCC0066FF00
CCFF00CCFF0066FF0000FF0000FFCC0000FF00FF0066FF00CCFF00CCFF00CCFF00FFCC00
FFCC00CCFF0000CCFFFFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600
FF6600FF6600FF6600FFCC00CCFF00FFCC00FFCC0000FF00CCFF00FFCC00FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FFCC00CCFF00FFCC00FFCC00CCFF0000FF66CCFF00CCFF00CCFF00
CCFF00FF006666FF0000FF0000CCFFCC00FF00FFCC00FF0066FF00CCFF0000FF00CCFF00
CCFF0066FF0066FF00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF6600FF6600CCFF00FF6600FF6600FF6600FF6600FFCC006600FFFFCC00FF6600FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FFCC0000FF66FFCC00CCFF00
00FFCCCCFF00FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC0000FF00FFCC00CCFF00CCFF00CCFF0000FF0000FF0000FF00FF000000FF00
00FFCC00FFCC6600FFFF0000FF00000000FF6600FF00CCFFFF00CC0066FF00FFCC66FF00
00FF0000FF6666FF00CCFF00CCFF0066FF00FFCC00FFCC00FFCC00FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FFCC00FF6600FF6600FF6600FF6600FF6600FFCC00CCFF0066FF00FFCC00FF6600
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600CCFF00CCFF00
00FFCC00FF66FFCC00FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FFCC00FFCC00CCFF00CCFF0066FF00FF000066FF0066FF0000FF0000FF6666FF00CCFF00
66FF0066FF0066FF0000FF0000CCFF0066FF00FF660066FF66FF0066FF0066FF00CCFF00
66FF0000FFCC00FF6600CCFF0000FF66FF00CCFF0066FF00FFCC00FFCC00FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF6600FF6600FF6600FF6600FF6600FFCC0000FFCC00FF000000FFFFCC00
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FFCC00
CCFF00FFCC00FFCC00FFCC00FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
66FF0000FF66CCFF00CCFF00FFCC0066FF00FFCC00FFCC0000FF66CCFF0066FF00CCFF00
CCFF00CCFF0066FF0000FF0000CCFF0000FF00FF0066FF00CCFF00CCFF00CCFF00CCFF00
CCFF0000FFCCCCFF00FFCC00CCFF00CCFF00CCFF0066FF00FF006666FF00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FF6600FF660000FF00CCFF00FF0066FFCC00FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FFCC00CCFF00
FFCC00FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FF0000CCFF00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC0066FF00FFCC00FFCC00FFCC00
CCFF00CCFF0000FF6600FF0000FFCC00CCFF00FF0066FF0066FF00CCFF00FFCC00FFCC00
FFCC00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF00
66FF00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF660000FFCC66FF0066FF00
FFCC00FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF6600FF6600FFCC000066FFFFCC00FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00CCFF00CCFF0000FF0000FFCCCC00FFFF0000CCFF00CCFF00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FFCC00FFCC00CCFF00FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FFCC00CCFF00FFCC00
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF660000FF00CCFF00
66FF00FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC0000FF6666FF0000FF000000FFFF000000FF0066FF0000FF00FFCC00FFCC00FFCC00
FFCC00FFCC0066FF00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600CCFF00FF6600FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FFCC006600FFCCFF00
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF660000FF66FFCC00
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00FFCC00FFCC00
CCFF0066FF0000FF0066FF0000FFCC00CCFF66FF0066FF006600FFCCFF00FFCC00FFCC00
FFCC00FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600CCFF00FFCC00CCFF00FFCC00
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FFCC00CCFF0066FF00FF6600
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC0000FF00
CCFF00CCFF00CCFF00CCFF00FF000000FF66CCFF00CCFF00CCFF00CCFF0066FF00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FFCC00CCFF00
FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FFCC00FFCC00FFCC00
FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF660000FF666600FF
FFCC00FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF66000000FF00FF00FF6600FF6600
FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC000000FF00FF0000FF0066FF00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FFCC00
FFCC00FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FFCC00CCFF00FFCC00FF6600
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FFCC00
66FF00FFCC00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FFCC00FF6600FF6600FF6600
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00CCFF0066FF0000FF00CCFF00CCFF00FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FF6600
CCFF00FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF660000FF66CCFF00FF6600FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600CCFF00
CCFF0000FF0000FF0000FFCC00FF66CC00FF00FF0000FFCC66FF0066FF00CCFF00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600
FFCC00CCFF00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000066FF00FFCC00FFCC00FF6600FF6600FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00CCFF0066FF0000FF00CCFF00CCFF00FFCC00FFCC00FFCC00FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCC00
FF6600CCFF00FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FFCC00FF6600FF6600FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6600
FF660000FF00FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF660000FF00FF6600FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF0000FF6600FF66CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF6600FF6600FFCC00FFCC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF660000FF66FF6600FF6600FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00
FFCC00FFCC00FFCC00CCFF00CCFF0066FF00CCFF00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF6600FF660066FF00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF6600CCFF00FF6600FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FFCC00FFCC00CCFF00
CCFF00CCFF00CCFF00CCFF0000FFCC00CCFFCCFF00CCFF00CCFF00CCFF00CCFF00FFCC00
FFCC00FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF6600FFCC00FF6600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=@3oool2000000@0oooo0P00
00050?ooo`<000008P3oool2000000@0oooo0P0000030?ooo`@000009P3oool2000002T0oooo0P00
00040?ooo`8000000`3oool4000002<0oooo0P0000040?ooo`8000001@3oool3000001L0oooo000d
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0803oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000009`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo02<0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0F0?ooo`00=03oool010000000oooo0?ooo`0000080?ooo`D000008@3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo02D0oooo00@000000?ooo`3oool00000
9`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0280oooo00@000000?ooo`3o
ool00000203oool5000001L0oooo000^0?ooo`@000000P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000001`0oooo100000020?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool0903oool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000X0
oooo00<000000?ooo`3oool08@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000001P0oooo000d0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`0000008P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000002D0oooo00@000000?ooo`3oool0
00009`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000280oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0000000H0?ooo`00=@3oool2000000/0oooo0P00000S
0?ooo`8000002P3oool2000002L0oooo0P00000Y0?ooo`8000002P3oool2000002@0oooo0P00000;
0?ooo`800000603oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool001/0ooooo`00000500000040oooo000K0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool06`3oool100000040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3o
ool100000040oooo000K0?ooo`030000003oool0oooo0?l0oooo0@3oool100000040oooo000K0?oo
o`800000o`3oool10?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolD0?l00004
0?mV003oc000ofH00?mV04L0o`004P3oIP030?o<00H0c?l000<00<co003oc03<o`001P3<o`020?o<
01<0ofH0B03o0000103oIP00c?l00<co003oIP0E0?l000D0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`020?oooa@0o`0000<0ofH006Ko003oIP000P3oIP160?l001@0ofH01P3oc0000`3<
o`00I_l00<co00020<co00H0ol`0503oIP170?l00080ofH00P00ofH00`3oIP00o`000?l0000C0?l0
00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooa@0o`0000<0ofH006Ko003o
IP000P3oIP160?l001@0ofH01P3oc0000`3<o`00I_l00<co00020<co00H0ol`0503oIP170?l00080
ofH00P00ofH00`3oIP00o`000?l0000C0?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`020?oooa@0o`000P3oc0030?mV04H0o`00503oIP060?o<00030<co0000ofH00?mV0080c?l0
1P3oc00D0?mV04L0o`0000@0ofH0003o003oIP00ofH05P3o00050?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool00P3ooolD0?l00080ofH00P00o`020?mV04<0o`005P3oIP060?o<00030<co
001Vo`00c?l00080c?l01@3oc00E0?mV04H0o`000P3oIP000`3oc000ofH00?mV000F0?l000D0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooa@0o`000P3oIP020<co00030?mV003o
c000o`000480o`005`3oIP040?o<0080c?l000@00?l006Ko003<o`00c?l01@3oc00F0?mV04<0o`00
0`3oIP020?o<0080I_l05P3o00050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3o
oolE0?l000040?mV003<o`00c?l00?o<0080ofH0@P3o000G0?mV00080<co001Vo`00I_l006Ko0000
ol`00?l00<`0o`00ofH2003oc0800?l00`3<o`0F0?mV04<0o`000P3oIP000`3<o`000?mV0?mV0002
0?mV01H0o`001@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo5@3o0000103o
IP00c?l00<co003oc0020?mV0480o`005`3oIP00203<o`00I_l006Ko001Vo`000?o<003o003<0?l0
0?mV0P00ol`2003o00<0c?l05P3oIP130?l00080ofH000<0c?l0003oIP3oIP000P3oIP0F0?l000D0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaD0o`000`3oIP000`3<o`00ofH0
0?o<00120?l001L0ofH0103oc0020<co0004003o001Vo`00c?l00<co00D0ol`05P3oIP120?l000@0
ofH000@0ol`00?mV003oIP00ofH05P3o00050?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool00P3ooolE0?l000050?mV003oc000ol`006Ko003oc0000`3oIP100?l001H0ofH01P3oc0000`3<
o`00I_l00<co00020<co00D0ol`05P3oIP120?l000050?mV003oc000ol`00<co003oc0000`3oIP0F
0?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaD0o`000`3oIP020?o<
00@0ofH0?`3o000F0?mV00H0ol`000<0I_l0003o0000o`000P000?l60?o<01D0ofH0@@3o00040?mV
0003003o00000?l0ofH001P0o`001@3oool100000040oooo000K0?ooo`030000003oool0oooo0080
oooo5@3o00030?mV00030?o<001V0?l00?mV00<0ofH0?P3o000G0?mV00H0ol`000<0c?l006Ko003<
o`000P3<o`060?o<01H0ofH0?`3o00020?mV00@0ol`00P3oIP0H0?l000D0oooo0@0000010?ooo`00
6`3oool2000000<0oooo5@3o00030?mV00030?o<001V0?l00?mV00<0ofH0?P3o000G0?mV00H0ol`0
00<0c?l006Ko003<o`000P3<o`060?o<01H0ofH0?`3o00020?mV00@0ol`00P3oIP0H0?l000@0oooo
0P0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaD0o`00103oIP000`3<o`00ol`00?mV
00030?mV03d0o`005@3oIP030?o<000306Ko003<o`00c?l000<0c?l000<00?mV0?l0003<o`00103<
o`02003o0080ol`05@3oIP0o0?l000<0ofH00P1Vo`000`3<o`00ol`00?mV000H0?l000D0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`020?oooaD0o`00103oIP001@3oc000c?l00?o<003o
c000c?l00080ofH0>`3o000E0?mV00D0ol`000<0c?l006H0o`1V0?l00P1Vo`001`00c?l00?o<06Ko
001Vo`000?l006Ko003<o`001@3oc00D0?mV03d0o`00103oIP000`3oc0000?mV003oIP030?mV01P0
o`001@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo5@3o00040?mV00040<co
001V0?l0ol`00?o<00D0ofH0>@3o00000`3oIP00c?l00?mV000A0?mV000306Ko003oc000ol`000@0
ol`00P00o`00101Vo`000?l00?l000000?l2003o000306Ko0000ofH0ol`000L0ol`04@3oIP030?o<
03X0o`00103oIP00101Vo`00c?l0003o0000o`030?mV01P0o`001@3oool100000040oooo000K0?oo
o`030000003oool0oooo0080oooo5@3o00040?mV00040?o<003<o`00ol`00?o<00D0ofH0>@3o0004
0?mV00030<co003oc000ol`000T0ofH02`3oc0030<co00030?l0003<0?l00?o<00800?l00P3<o`0:
0?o<00/0ofH00P3oc0000`00I_l0ol`00?mV00020?mV03T0o`001@3oIP001@3oc000I_l006Ko001V
o`000?o<0080ofH0603o00050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolE
0?l000@0ofH000@0ol`00<co003oc000ol`01@3oIP0i0?l000@0ofH000<0c?l00?o<003oc0002@3o
IP0;0?o<00<0c?l000<0o`000<`0o`00ol`00P00o`020<co00X0ol`02`3oIP020?o<0003001Vo`3o
c000ofH00080ofH0>@3o00050?mV00050?o<001Vo`00I_l006Ko0000ol`00P3oIP0H0?l000D0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaH0o`00103oIP040?o<00D0ofH0=`3o
00070?mV00040?o<001Vo`00I_l00<co00/0ol`000<0c?l00?o<003oc0000P3oc0001`3<o`00I_l0
06Ko001Vo`000?l0003<o`00ol`00P00o`000`00ofH0c?l00<co00040?o<000306Ko003oc000ol`0
00X0ol`000<0c?l00?l0003oc000203oIP0h0?l000D0ofH000@0ol`00<co003oc000ol`00`3oIP0H
0?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaH0o`00103oIP001@3o
c000o`1V0?l0IP3<o`000?l000D0ofH0=P3o000:0?mV0080ol`000@0I_l00?l0IP3o06H0I_l0103<
o`000`3oc000c?l0003oc0070<co000406Ko0000o`00003o003<o`800?l000<0I_l00<co003<o`00
0P3<o`000`1Vo`00c?l0003oIP030?o<000306Ko003oc000c?l00080c?l000<00?mV06Ko003oc000
0P3oc00:0?mV03L0o`000P3oIP040?o<00030<co003oc000ofH000@0ofH0603o00050?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool00P3ooolF0?l000<0ofH000H0ol`00000o`00o`000?l0
003oc03oc0060?mV03<0o`003P3oIP030?o<000306Ko003<o`00I_l00080003o00<00<co003oIP00
ol`00P1Vo`000`3<o`00I_l006Ko000206Ko0004001Vo`00ofH006Ko003<o`800?l00`1Vo`020<co
000306Ko0000ofH00?l000<0I_l000<0o`0006Ko003<o`000P3<o`020?o<00h0ofH0=03o00050?mV
0080ol`000<00?mV003oc03<o`000P3<o`030?mV01P0o`001@3oool100000040oooo000K0?ooo`03
0000003oool0oooo0080oooo5@3o00050?mV00050?o<001Vo`00I_l00<co003oc0001P3oIP020?o<
0300o`00403oIP040?o<000606Ko003<o`00c?l00<co001Vo`000?mV0P00o`000`1Vo`000?o<001V
o`020?l0c003003<o`1V0?l0003o00<0o`0000<0IP3o003oc000ol`00P00o`000`3o00000?l0003o
0002003o00<0c?l00P3oc0000`00o`00ol`00?mV000>0?mV03<0o`00203oIP000`3<o`000?o<0<co
00020?o<0003003oIP3oc000ofH001P0o`001@3oool100000040oooo00080?ooo`800000103oool2
000000D0oooo0`0000030?ooo`030000003oool0oooo0080oooo5@3o00050?mV00050?o<001Vo`00
I_l00<co003oc0001P3oIP020?o<0300o`00403oIP040?o<000606Ko003<o`00c?l00<co001Vo`00
0?mV0P00o`000`1Vo`000?o<001Vo`020?l0c003003<o`1V0?l0003o00<0o`0000<0IP3o003oc000
ol`00P00o`000`3o00000?l0003o0002003o00<0c?l00P3oc0000`00o`00ol`00?mV000>0?mV03<0
o`00203oIP000`3<o`000?o<0<co00020?o<0003003oIP3oc000ofH001P0o`001@3oool100000040
oooo00070?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?oooaD0o`001P3oIP020?o<000306H0o`3oc000ofH000@0ofH000@0c?l00?mV003o
IP00ofH0;P3o000D0?mV00D0ol`00P1Vo`030<co0008003o003<o`00I_l006Ko0000o`000?o<0<`0
o`00c?l2003o000306Ko003o06H0c?l000@0c?l000<00?mV0<co003<o`000P3oc0000`3<o`00ol`0
0?o<000B0?mV0340o`002@3oIP030?o<00D0ofH0603o00050?ooo`4000000@3oool000L0oooo00@0
00000?ooo`3oool00000203oool5000000<0oooo0P0000030?oooaD0o`001P3oIP020?o<00030<co
0000o`00ol`00080ol`000<0c?l00?o<003oIP00103oIP0]0?l001D0ofH0103oc0000`00c?l0c?l0
0?o<00020?o<00@0c?l000@0I_l0003o00000?l00?o<0P00o`000`1Vo`00c?l00<co000206Ko0080
ol`00`3<o`030?o<01H0ofH0;P3o00030?mV00800?l00`3oIP020?o<00030<co003oc000ofH000D0
ofH0603o00040?ooo`8000000@3oool000030?ooo`0000000000008000000P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3ooolE0?l0
00H0ofH00P3oc0000`3<o`0006Ko06Ko0002003o00030<co003oIP00ofH000D0ofH0:`3o000G0?mV
0080ol`000<0c?l00?o<003oc000103oc0001`3<o`00I_l006Ko0000c?l00?l006H0o`00ol`00P3o
00000`00ofH0I_l00<co00090?o<01P0ofH0:`3o00070?mV000306Ko003oc000ol`00080c?l000<0
o`000?o<003oIP001@3oIP0H0?l000D0oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3ooolE0?l000@0ofH00P3o
c00206Ko0003003oIP3o0000c?l00080ol`02P3oIP0W0?l001/0ofH01`3oc0030<co000406Ko0000
o`0006Ko003oIP80I_l00`3<o`080?o<01X0ofH0:@3o00090?mV00070?o<001Vo`000?mV003oIP00
o`00ol`00<co00050?mV01P0o`001@3oool100000040oooo00080?ooo`8000002`3oool2000000@0
oooo00<000000?ooo`3oool00P3ooolE0?l000@0ofH00P3oc00206Ko0003003oIP3o0000c?l00080
ol`02P3oIP0W0?l001/0ofH01`3oc0030<co000406Ko0000o`0006Ko003oIP80I_l00`3<o`080?o<
01X0ofH0:@3o00090?mV00070?o<001Vo`000?mV003oIP00o`00ol`00<co00050?mV01P0o`001@3o
ool100000040oooo000K0?ooo`030000003oool0oooo0080oooo5@3o00050?mV00@0ol`000@00?mV
003oc03<o`00c?l02P3oIP000`3oc000ofH00?l0000R0?l001d0ofH01`3oc0030<co000406Ko0000
o`0006Ko001Vo`80I_l00`3<o`070?o<01`0ofH09P3o000;0?mV0080ol`00P00ofH00`1Vo`00c?l0
003oc00206Ko00<0ol`0603o00050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3o
oolE0?l000P0ofH000<0ol`00<co001Vo`000P3oc00=0?mV0240o`007`3oIP050?o<0080c?l00P00
o`00103o0<`00?mV0000o`00c?l3003o0003003oIP3<o`00ol`000H0ol`07P3oIP0R0?l000d0ofH0
00D0ol`00<co00000?l0003o06Ko00020?o<00D0ofH0603o00050?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool00P3ooolE0?l000P0ofH00P3oc00010000?l0ol`00?o<003oc0060?mV0003
0?o<003oIP00ofH000H0ofH06`3o000R0?mV00@0ol`000<0c?l006Ko003<o`000P00ofH0103<o`00
0?l0003<o`00ofH206Ko00030<co001Vo`000?mV00800?mV00<0c?l00?o<003oc0008P3oIP0N0?l0
00D0ofH000<00<co0?mV003oIP001`3oIP001@3oc0000?l00<co003<o`00ol`000T0ofH05P3o0005
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolD0?l000T0ofH00P3oc0000`1V
o`00ol`00?o<00020?o<00<0ofH000<0ol`00<co003oc0002P3oIP0G0?l00080ofH000<0ol`00?mV
003oIP007`3oIP000`00o`00ol`00?o<00040?o<00<0c?l000<00?l00?l00000ol`0103<o`050?o<
000306Ko003oIP00ofH00240ofH06P3o00090?mV000306Ko003oIP00ofH000D0ofH00P3oc000101V
o`000?mV003oIP3oc0090?mV01H0o`001@3oool100000040oooo000K0?ooo`030000003oool0oooo
0080oooo503o00090?mV0080ol`000<0I_l00?o<003oc0000P3oc0030?mV00030?o<003<o`00ol`0
00X0ofH05`3o00020?mV00030?o<003oIP00ofH001l0ofH000<00?l00?o<003oc000103oc0030<co
0003003o003o00000?o<00@0c?l01@3oc0000`1Vo`00ofH00?mV000Q0?mV01X0o`002@3oIP000`1V
o`00ofH00?mV00050?mV0080ol`000@0I_l0003oIP00ofH0ol`02@3oIP0F0?l000D0oooo0@000001
0?ooo`006`3oool00`000000oooo0?ooo`020?oooa@0o`002@3oIP020?o<00060<co001Vo`00I_l0
001Vo`3oc0000?l00P3oc0000`3o0000ol`00?mV000>0?mV0100o`001@3oIP000`3oc000ofH00?mV
000P0?mV00P0ol`00P3<o`000`00o`00I_l00<co00020<co00L0ol`08P3oIP000`3oc000ofH00?mV
00020?mV01@0o`00303oIP020<co000306Ko003<o`00ol`00080ol`00P3<o`001000c?l0ol`00?o<
003oc0090?mV01H0o`001@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo503o
00090?mV0080ol`000H0I_l0003oc000ol`0I_l00<co0000o`020<co00030?o<003oIP00ofH000h0
ofH000<0ol`00?mV003oIP004`3oIP020?o<0200ofH0203oc0020<co0004003o001Vo`00c?l00<co
00P0ol`08@3oIP000`3oc000ofH00?mV00070?mV00`0o`00403oIP030?o<0080c?l00`3oc0001@1V
o`000?l00<co003<o`00ol`000T0ofH05P3o00050?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool00P3ooolC0?l00003003oc03oIP00ofH000@0ofH0103oc0001P3<o`00I_l0001Vo`00I_l0
0<co06Ko00<0c?l000<0ol`00?mV003oIP003P3oIP000`3<o`00ofH00?mV000C0?mV0080ol`0803o
IP080?o<0080c?l000@00?l006Ko003<o`00c?l0203oc00Q0?mV00030?o<003oIP00ofH001<0ofH0
00<00?mV0?mV003oIP003`3oIP020?o<0006003<o`3<o`00c?l00<co0000ofH0I_l00P3<o`020?o<
00T0ofH05@3o00050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolC0?l000<0
ofH00P00ol`00`00o`00I_l006Ko000206Ko00030?l0c01Vo`00I_l000800<co00<00?mV003o003o
c0000P3oc00Y0?mV00030<co003oIP00ofH001`0ofH02@3oc0020<co000406Ko003<o`00c?l00<co
00P0ol`0803oIP000`3oc000ofH00?mV000D0?mV00030?o<003oIP00ofH00100ofH00P3oc0020<co
0003003o001V0?l00?mV00<0c?l000@0ol`00000o`3oc000ol`00`3oIP030?o<01D0o`001@3oool1
00000040oooo000K0?ooo`8000000`3ooolC0?l000<0ofH00P00ol`00`00o`00I_l006Ko000206Ko
00030?l0c01Vo`00I_l000800<co00<00?mV003o003oc0000P3oc00Y0?mV00030<co003oIP00ofH0
01`0ofH02@3oc0020<co000406Ko003<o`00c?l00<co00P0ol`0803oIP000`3oc000ofH00?mV000D
0?mV00030?o<003oIP00ofH00100ofH00P3oc0020<co0003003o001V0?l00?mV00<0c?l000@0ol`0
0000o`3oc000ol`00`3oIP030?o<01D0o`00103oool200000040oooo000K0?ooo`030000003oool0
oooo0080oooo4`3o00070?mV00<0ol`000<0I_l00?o<003<o`000P1Vo`000`00ol`0I_l00<co0002
0?o<0100ofH000<0c?l00?mV003oIP005P3oIP020?o<01d0ofH01`3oc0030<co00800?o<00@00?l0
0<co003<o`00c?l01`3oc00N0?mV0080ol`000<0c?l00?mV003oIP005@3oIP020?o<0100ofH00P3o
c0020<co0003003oIP00I_l0I_l000<0I_l000@0c?l0003o003<o`00c?l00P3oc0040?mV01D0o`00
1@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo4@3o000<0?mV0080ol`000D0
c?l0003o0000o`00003o0<co00030?o<00l0ofH00P3oc00H0?mV00030?o<003<o`00ol`001`0ofH0
00<0ol`00<co003<o`00103<o`02003oIP040<co0000o`000<co003oIPD0c?l0103oc0000`3<o`00
ofH00?mV000K0?mV00040?o<001Vo`00I_l00?o<01L0ofH00P1Vo`0@0?mV00070?o<0000ol`00?l0
003o003o00000?mV0<co00050?o<00T0ofH0503o00050?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool00P3ooolA0?l000d0ofH00P3oc0040<co00@0ol`03P3oIP000`00o`00ol`00?mV000H
0?mV00040?o<0000c?l0ol`00?o<01X0ofH0103oc0000`3<o`000?o<003o0003003oc003001Vo`3<
0?l00?o<0080o`0000<0o`1V003oc01Vo`000P1Vo`050?o<01/0ofH000<0ol`00<co003<o`00603o
IP020?o<000306Ko003oIP00ofH000d0ofH00P3oc0020<co0003003oc01Vo`00I_l000<0ol`02`3o
IP0D0?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooa00o`003P3oIP04
0?o<00030<co001Vo`00c?l000<0ol`0303oIP020?o<00030<co003oIP00ofH001P0ofH000@0ol`0
003o003oc000ol`06@3oIP070?o<00070<co001Vo`00I_l00<co001Vo`00o`00003oc00206Ko0080
c?l0203oc00J0?mV00040?o<0000I_l0ol`00?o<01P0ofH00P3oc0000`1Vo`00ol`00?mV000<0?mV
00<0ol`00`00o`00103<o`00ol`00?o<003oc00=0?mV01<0o`001@3oool100000040oooo000K0?oo
o`030000003oool0oooo0080oooo403o000>0?mV00@0ol`000<0c?l006Ko003<o`000`3oc00<0?mV
0080ol`000<0c?l00?mV003oIP00603oIP00103oc0000?l00?o<003oc00I0?mV00L0ol`000L0c?l0
06Ko001Vo`00c?l006Ko003o00000?o<0080I_l00P3<o`080?o<01X0ofH000@0ol`0001Vo`3oc000
ol`0603oIP020?o<000306Ko003oc000ofH000`0ofH00`3oc003003o00040<co003oc000ol`00?o<
00d0ofH04`3o00050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool?0?l00100
ofH00`3oc0000`3<o`00o`1V003oIP040?o<00X0ofH000@0ol`0003o0000o`00ol`06P3oIP020?o<
0080c?l000<0ol`00?mV003oIP005P3oIP080?o<00<0c?l000<0I_l00000o`00o`000`3<o`0:0?o<
01P0ofH000<0ol`00<co0000o`000P3oc00J0?mV00030?o<003<o`00ol`000`0ofH000<0ol`00<co
003<o`000P00o`000`3<o`00ol`00?o<00020?o<00l0ofH04@3o00050?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool00P3oool?0?l00100ofH00`3oc0000`3<o`000?mV0<co00070?o<00D0
ofH00P3oc000103<o`00ol`00?o<003oc00J0?mV00040?o<001Vo`000<co003<o`<0ol`0503oIP0:
0?o<00800?mV00@0c?l006Ko0000ofH0I_l00`3<o`0:0?o<01H0ofH00`3oc0000`00ofH0ol`00?mV
000K0?mV00030?o<0000o`00ol`00080ol`0203oIP040?o<00050<co0000ol`00?o<003oIP3<o`00
0`3oc00?0?mV0140o`001@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo3P3o
000A0?mV00@0ol`000<0c?l0003o003oc000303oc000103<o`00I_l00?o<003oc00L0?mV00040?o<
003<o`00c?l0003o00@0ol`04@3oIP0=0?o<0080c?l000<00?mV0<co003<o`000P3<o`0;0?o<01<0
ofH00P3oc0030<co0080ol`0703oIP020?o<000306Ko003oc000ol`00080ol`0103oIP000`3oc000
c?l00?o<00030?o<00040<co001V0?l0IP3o0<co00@0ol`0403oIP0@0?l000D0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`020?ooo``0o`004P3oIP050?o<00060<co0000ofH0c?l00<co
003o00000?l0103oc0001P3<o`00ol`00?o<003oc000c?l0003o00<0ol`0703oIP030?o<000306Ko
003oc000ol`000@0ol`03P3oIP0>0?o<0080I_l000<00?o<003o001Vo`000P1Vo`0;0?o<00030<co
003oIP00ofH000l0ofH00`3oc0020<co0003003oIP3oc000ol`001d0ofH000<00?mV0<co003<o`00
0P3<o`020?o<00800?l00`3oc00206Ko0080ol`000<0c?l0003o0000o`001@3oc00A0?mV00l0o`00
1@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo303o000B0?mV00D0ol`000H0
c?l0003oIP3<o`00c?l00?l00000o`040?o<00060<co003oc000ol`00?o<003<o`000?l00`3oc00L
0?mV00<0ol`000<0I_l00?o<003oc000103oc00>0?mV00h0ol`00P1Vo`000`00ol`00?l006Ko0002
06Ko00/0ol`000<0c?l00?mV003oIP003`3oIP030?o<0080c?l000<00?mV0?o<003oc0007@3oIP00
0`00ofH0c?l00<co00020<co0080ol`00P00o`030?o<0080I_l00P3oc0000`3<o`000?l0003o0005
0?o<0140ofH03`3o00050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool;0?l0
00<0ofH000<0c?l00?mV003oIP003@3oIP001`3oc000I_l00<co003<o`00I_l00<co0000c?l00P00
o`000`1Vo`00c?l00?o<00030?o<00@0c?l000<0I_l00<co0000o`000P3oc00L0?mV00<0ol`000<0
0?mV003<o`1Vo`001`3oc0070?mV00H0ol`00P3<o`080?o<00@0c?l000<00?mV06Ko003<o`000P3<
o`0:0?o<0003003o003oc000ol`00080ol`02`3oIP040?o<0080c?l00P1Vo`030?o<01d0ofH00P3o
c002003oIP030<co003oc000ol`00080c?l00`3oc0020<co000306Ko003<o`000?l000800?l000<0
c?l00?o<003oc0000P3oc00B0?mV00h0o`001@3oool100000040oooo000K0?ooo`8000000`3oool:
0?l000D0ofH000<0003o0?mV003oIP002`3oIP030?o<0080c?l000<0o`1V003o0000c?l00P00ol`0
0`00ofH0c?l00<co00020?o<0080c?l000@00<co003oIP00ofH0c?l0103oc00L0?mV00060?o<003<
o`00c?l006Ko0000o`00c?l02P3oc002003oIPP0ol`00P1Vo`000`3<o`00ol`00?o<00040?o<00D0
c?l000<00?mV06Ko003<o`000`3<o`080?o<0003003<o`3oc000ol`001<0ol`000<0I_l0003o0000
o`000`3oc00M0?mV00050?o<003<o`00c?l00<co001Vo`00103<o`030?o<0080c?l000<0I_l0003o
001V0?l00P1Vo`020<co000306H0o`3oc000ol`000l0ofH000<0ol`00?mV003oIP000P3oIP0<0?l0
00@0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`L0o`002@3oIP00103oc000
I_l006Ko003oc0070?mV00L0ol`000<0c?l006Ko0000o`000P00c?l00`00o`00I_l00<co00030<co
00800?l00P00ofH00`3<o`00ol`00?o<00020?o<01`0ofH0103oc0001P3<o`000<co06Ko001Vo`00
c?l006Ko00H0ol`00P3<o`0:0?o<00P0c?l0101Vo`001@00c?l0I_l006Ko001Vo`000?mV00@0c?l0
00<0ol`00<co003<o`000P00ofHA0?o<000606Ko003oc000ol`00?o<0000c?l006Ko103<o`000`3o
c000ofH00?mV000K0?mV00@0ol`000<0c?l0003o003o0<`01`3<o`000`1Vo`000?l0001Vo`02003o
000306Ko003<o`00ol`000<0ol`0303oIP020<co00H0ofH02`3o00050?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool00P3oool60?l000/0ofH00P3oc0000`00ofH0c?l00<co00030?o<0005
0<co003oc000ol`00?o<003<o`00103oc0000`1Vo`0006Ko003oIP020?l0IP03003oIP1Vo`00I_l0
0080c03o00<0003o0<co001Vo`000P3<o`000`1Vo`00c?l00?o<00020?o<01`0ofH01@3oc0001@00
ol`0o`1V0?l0IP00o`00c?l000H0ol`00P3<o`0:0?o<00030<co001Vo`00I_l000L0c?l000@0IP3o
0?l000000?l00?o<0P00o`030<co0080I_l000<0c?l006Ko0000ofH00P3<o`0B0?o<00800?mV00<0
c?l006Ko003<o`00103oc00N0?mV00@0ol`000<0c?l0003o0000o`000P00ofH00`3<o`00I_l00<co
000206Ko0003003o0000c?l00?mV0080I_l000<0c?l00?o<003oc0000`3oc0000`1Vo`00ol`00?mV
00060?mV0080ol`000<0c?l00?mV003oIP001`3oIP0:0?l000D0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`020?ooo`H0o`002`3oIP020?o<0003003oIP3<o`00c?l000<0ol`000D0c?l0
0?o<003oc000ol`00<co00040?o<000306Ko0000I_l00?mV0080o`1V00<00?mV06Ko001Vo`000P3<
0?l00`000?l0c?l006Ko00020<co000306Ko003<o`00ol`00080ol`0703oIP050?o<0005003oc03o
06H0o`1V003o003<o`001P3oc0020<co00X0ol`000<0c?l006Ko001Vo`001`3<o`00101V0?l0o`00
0000o`00ol`2003o00<0c?l00P1Vo`000`3<o`00I_l0003oIP020<co0180ol`00P00ofH00`3<o`00
I_l00<co00040?o<01h0ofH0103oc0000`3<o`000?l0003o0002003oIP030<co001Vo`00c?l00080
I_l000<00?l0003<o`00ofH00P1Vo`000`3<o`00ol`00?o<00030?o<000306Ko003oc000ofH000H0
ofH00P3oc0000`3<o`00ofH00?mV00070?mV00X0o`001@3oool100000040oooo000K0?ooo`030000
003oool0oooo0080oooo103o000?0?mV0080ol`000D00?mV06Ko001Vo`00ol`006Ko00030?o<0003
001Vo`3<o`00c?l000<0c?l000L0I_l0003o00000?l0003o003<o`00ol`00<co0080I_l000<00?l0
0<co003<o`001`3oc00L0?mV00@0ol`000H0c?l0001Vo`1V0?l0IP3o06Ko003<o`050?o<00<0c?l0
2`3oc0001@3<o`000?l006Ko001Vo`000?l000@0c?l000@0I_l0003o003o0<`00?o<0`1Vo`020<co
008006Ko00<0I_l0003oIP1Vo`000P3<o`0;0?o<00030<co003oc000ol`000@0ol`00P3<o`02003o
c0030<co003oc000ol`00080ol`07P3oIP020?o<00800?l00P3<o`001@1Vo`00c?l00<co0000c?l0
0?mV00<0I_l000<00?l006H0o`00ol`00P00I_l00`1Vo`00c?l00?o<00080?o<000606Ko003oc000
ol`00?o<003o0000ol`03@3oIP070?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo0?oo
o`020?oooa@0ofH000<0I_l00?o<003<o`000P3<o`001`00I_l0I_l006Ko001Vo`000?l006Ko003<
o`000P00c?l206Ko000606H0o`3o0<`0o`3<001Vo`00ofH00?l0103<o`080?o<01`0ofH00`3<o`00
0`1Vo`00c?l00<co0002003oc003003o003<o`00ol`000@0ol`00`3<o`0;0?o<0080c?l00P00o`00
0`00c?l00?l006Ko000206Ko0004003o003<0?l0IP3o003<o`800?mV00<0I_l0001Vo`1Vo`000P1V
0?l00`00ofH0c?l00<co000=0?o<000306Ko003oc000ol`000<0ol`000H0c?l006Ko001Vo`00o`3<
06Ko00000?l20<co00<0ol`07@3oIP060?o<00<0c?l00P1Vo`03003oIP03003oc03o00000?mV0080
I_l01@3<o`000`00o`00c?l00?o<0002003oIP030?o<003<o`000?l00080c?l000<0ol`00?mV003o
IP003P3oIP050?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaH0ofH0
0`3oc0001`3<o`000?l006Ko001Vo`000?o<003o001Vo`000P00o`0206Ko000506H0o`00c?l00<co
0?l0IP00I_l00`1Vo`020<co00P0ol`0703oIP060?o<0080c?l00P1Vo`050<co0003003oc03<o`00
c?l000/0ol`000L0c?l006Ko0000c?l00<co003o00000?l006Ko00800?l000@00?mV003oc03o0000
0<co0P00ol`2003oIP06003oc0000?l0003o003o001Vo`00c?l0303oc0000`3<o`000?l00<co0003
0?o<00030<co001Vo`00I_l00080I_l00P3<o`050?o<01d0ofH01`3oc0040<co0006003o0000ol`0
0?o<06H0o`3o06H0c03o0P00o`0206Ko00040<co0000o`000?l0003oIP800?l00P00c?l00`1Vo`00
ol`00?o<00020?o<01D0ofH000<0o`000?ooo`3oool00`3oool100000040oooo000K0?ooo`030000
003oool0oooo0080oooo603oIP030?o<0080c?l000<0I_l00<co003<o`000P1Vo`020<co000606Ko
0000ofH00?mV0<`0o`3o00000?l00P1Vo`020<co00P0ol`0703oIP060?o<00<0c?l000L00?o<06Ko
001Vo`00I_l00<co0000o`00I_l00080c?l02`3oc0040<co0080I_l000L00?l00<`0o`3<0?l0o`3<
0000o`3<0?l0o`000080o`3<00<00?mV003o0000o`000P1Vo`030<co00`0ol`00P3<o`000`1Vo`00
c?l00<co00020<co000406Ko0000o`000?l00<co00L0ol`07@3oIP070?o<00<0c?l00P1Vo`02003o
c0030?l00000ol`00?mV00<0I_l000L00?l006Ko001Vo`00I_l0003o001Vo`00c?l00080ol`000<0
I_l00?o<003oc000603oIP050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolH
0?mV00<0ol`00P3<o`000`1Vo`00c?l00<co000206Ko0080c?l000H0I_l0003oIP00ofH0c03o0?l0
0000o`0206Ko0080c?l0203oc00L0?mV00H0ol`00`3<o`001`00ol`0I_l006Ko001Vo`00c?l0003o
001Vo`000P3<o`0;0?o<00@0c?l00P1Vo`001`00o`00c03o0<`0o`3o0<`0003o0<`0o`3o00000P3o
0<`00`00ofH00?l0003o000206Ko00<0c?l0303oc0020<co000306Ko003<o`00c?l00080c?l000@0
I_l0003o0000o`00c?l01`3oc00M0?mV00L0ol`00`3<o`0206Ko00800?o<00<0o`00003oc000ofH0
0`1Vo`001`00o`00I_l006Ko001Vo`000?l006Ko003<o`000P3oc0000`1Vo`00ol`00?o<000H0?mV
00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaP0ofH00`3oc002003o00<0
ol`00`3<o`00101Vo`000<co003o0000o`02003<o`03003o001Vo`00I_l000<0c?l01`3oc00K0?mV
00T0ol`000<0c?l006Ko0000I_l00P00o`000`1Vo`000?l00<co00030<co00T0ol`01P3<o`0206Ko
00800?l000@0o`00003<o`3o00000<co0P00ol`00`00o`00I_l006Ko00070<co00X0ol`000<0c?l0
06Ko0000I_l00`1Vo`000`00ofH0003o0<co00020<co00L0ol`07@3oIP070?o<00<0c?l000H0I_l0
003o0000ol`00?o<0?l0IP00c?l306Ko00<0c?l00P1Vo`000`3<o`00I_l00?o<00040?o<01T0ofH0
1@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo6@3oIP000`3oc000c?l00?o<
00060?o<0080c?l00`1Vo`000`00ofH0o`3<003o000306Ko0003003oc03<o`00c?l000<0c?l000@0
I_l00?o<003oc000ol`06P3oIP070?o<00<0c?l000H0I_l0003oIP1V0?l0IP3o003oIP1Vo`040<co
00T0ol`01P3<o`0206Ko00800?l000@00?mV003oc03o00000?o<0P00ofH00`00o`00I_l006Ko0007
0<co00P0ol`0103<o`001P1Vo`000?l0003o0000o`0006Ko003oIP800?l000<0c?l00?o<003oc000
1@3oc00M0?mV00H0ol`0103<o`0206Ko00800?o<00<0003o003o0000c?l00P1Vo`020<co00@0ol`0
00<0c?l00?o<003oc0000P3oc00J0?mV00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?oo
o`020?oooaX0ofH0203oc0030<co0080I_l000<00?mV0?l00000c?l00P00I_l00`00o`000?mV06Ko
00030<co00D0ol`06@3oIP080?o<0080I_l000<0c?l006Ko0000ofH00P1V0?l00`00ol`00?l006Ko
000206Ko00<0c?l0103oc0030<co0003003<o`3<o`00c?l000<0c?l00P1Vo`02003oIP800<co00L0
o`00003<o`1V0?l0IP3o0000o`00o`00I_l000D0c?l00P1Vo`020<co00D0ol`000<0c?l0003oc000
ol`00P3<o`001P1Vo`0006Ko001Vo`000?l00?o<003oIP<0c?l02@3oc00J0?mV0080ol`000<00?o<
0<co003<o`000`3<o`02003o0080I_l000H00?l006H0o`1V0?l00?o<003o001Vo`030<co00T0ol`0
6`3oIP050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolJ0?mV00P0ol`000<0
c?l006Ko001Vo`000P00c?l00`00ol`0003o003oc00206Ko00<0c?l02@3oc00H0?mV0080ol`000H0
0?o<0<co003<o`00c?l006Ko0000ofH206Ko0003003o0000ol`00?l000800?mV00<0c03o003oIP00
ol`00P1Vo`0;0<co0003003oIP1Vo`00I_l000@0I_l00`00o`000`00I_l0o`00003<o`02003oIP03
003o001Vo`00I_l000@0I_l000<00?mV0<co003<o`002P3<o`03003o00<0003o00<00?o<003o001V
o`000P1Vo`000`3<o`00ol`00?o<00060?o<01X0ofH01@3oc0020<co000606Ko0000I_l006Ko003o
c000ofH00?o<0P1V0?l00`00ofH0I_l006Ko00030<co00L0ol`07@3oIP050?ooo`4000000@3oool0
01/0oooo0P0000030?oooaX0ofH0203oc0000`3<o`00I_l006Ko0002003<o`03003oc0000?l00?o<
0080I_l00`3<o`090?o<01P0ofH00P3oc0001P00ol`0c?l00<co003<o`00I_l0003oIP80I_l000<0
0?l0003oc000o`000P00ofH00`3<0?l00?mV003oc00206Ko00/0c?l000<00?mV06Ko001Vo`00101V
o`03003o0003001Vo`3o00000<co00800?mV00<00?l006Ko001Vo`00101Vo`000`00ofH0c?l00<co
000:0<co00<00?l00`000?l00`00ol`00?l006Ko000206Ko00030<co003oc000ol`000H0ol`06P3o
IP050?o<0080c?l000H0I_l0001Vo`00I_l00?o<003oIP00ol`206H0o`03003oIP1Vo`00I_l000<0
c?l01`3oc00M0?mV00@0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooa/0ofH0
1@3oc0030<co0005003oIP00ol`00?l0003o001Vo`000P00ofH206Ko0080c?l02`3oc00E0?mV00L0
ol`000<0c?l0003o0000ofH01`1Vo`000`00ofH0c03o003o000206Ko00<0c?l00P1Vo`060<co0006
06Ko0000ofH00?l0003o0000ol`0I_l00`00o`001000c?l00?o<0?l0IP00ol`2001Vo`800?l000H0
I_l00000o`000?l00?l0003oIP1Vo`0<0<co000306Ko0000o`000<co0080IP3o00<00?mV06Ko0000
o`000P00I_l00`00ofH0I_l00<co000206Ko00030<co001Vo`00c?l000<0ol`05`3oIP090?o<00@0
c?l000@0I_l0003oIP1V0?l0IP3o0P00ofH306Ko00030<co003oc000ol`000D0ol`07@3oIP050?oo
o`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolK0?mV00@0ol`000@0c?l0003<o`00
c?l00?mV103<o`000`1Vo`000?l0003<o`02003oIP03003o003<o`00ol`000`0ol`04P3oIP0:0?o<
00H0c?l01000o`000`00I_l0I_l006Ko00030<co0080003o1`3<o`00101Vo`000?l0003o003o0004
003o0004003oIP00c?l0o`00003<o`800?mV0`00o`020?l0c003003o001Vo`00c?l000L0c?l000<0
0?l00<co003<o`000P3<o`000`1Vo`000?mV0000o`02003<o`80I_l000<0c?l006Ko001Vo`001@3<
o`060?o<01H0ofH02P3oc0040<co000706Ko0000ofH00?o<003oc000o`00I_l0003o00020?l00080
c?l01@3oc00N0?mV00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooa/0ofH0
0P3oc0000`3<o`00ol`00?o<00040?o<00<0c?l000<00?mV06Ko0000c?l00P1Vo`020<co00h0ol`0
403oIP0>0?o<00<0c?l00P00o`000`1Vo`000?l006Ko0002003oIP80I_l000<0IP3o06Ko001Vo`00
1`3<o`0306Ko0003003o0000ofH0IP3o00800?mV00@00<co001Vo`3o06H006Ko0P00c?l00`00ol`0
06Ko003oIP02003o0080I_l0203<o`000`00o`00I_l006Ko000206Ko0003003o0000ofH00?mV0080
I_l000<00?l00<co003<o`00103<o`0:0?o<01@0ofH0303oc0020<co0003003<o`00ofH006Ko0080
0?mV00<0I_l00<co003<o`000P3<o`000`1Vo`000?o<0<co00040?o<01h0ofH01@3oool100000040
oooo000K0?ooo`030000003oool0oooo0080oooo6`3oIP0:0?o<00@0c?l00`1Vo`020<co0100ol`0
2`3oIP0B0?o<00030<co001Vo`00c?l000<0c?l00`1Vo`000`00c?l00?mV001Vo`0306Ko00D0c?l0
1@1Vo`02003o00800?mV00@0003o0?l0003o0<`0c03o0P00I_l00`00ofH00?l0003o000506Ko00D0
c?l00P1Vo`02003o000406Ko0000o`000?l0003oIP80I_l00P3<o`000`1Vo`00c?l00<co00020<co
00l0ol`0403oIP0=0?o<00<0c?l000D0I_l00000o`1Vo`00I_l0003oc0040<co00D0ol`000<0I_l0
0<co003oIP007@3oIP050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolK0?mV
00X0ol`0103<o`0306Ko0080c?l0403oc00;0?mV0180ol`000<0c?l006Ko003<o`000`3<o`0306Ko
0003003<o`00ofH006Ko00<0I_l01@3<o`0506Ko00800?l00P00ofH010000?l0o`000?l0c03<0?l2
001Vo`03003oIP00o`000?l000D0I_l01@3<o`0206Ko00800?l000@0I_l0003o0000o`000?mV0P1V
o`020<co000306Ko003<o`00c?l00080c?l03`3oc00@0?mV00d0ol`00`3<o`001@1Vo`00003o06Ko
001Vo`000?o<00@0c?l01@3oc0000`1Vo`00c?l00?mV000M0?mV00D0oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`020?oooad0ofH02P3oc0020<co000406Ko0000ofH00?mV06Ko0080c?l0
2P3oc002003o00`0ol`000<0I_l00?o<003oc0004P3oc0060<co0080I_l000<00?mV0<`0o`00ofH0
0P00o`000`000?l0I_l006Ko000806Ko00800?l00P00ofH01000ol`0003o0?l00000I_l2003oc003
003oIP00o`000?l000L0I_l00P3<o`0406Ko0004003oIP00ol`006Ko001Vo`80I_l01P3<o`0B0?o<
00`0ofH00`3oc0000`3<o`00ol`00?o<000:0?o<00<0c?l000<0I_l0003o003<o`000`3<o`0:0?o<
01h0ofH01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo6`3oIP0<0?o<0080
c?l000<0I_l0003oIP00ofH00`3<o`080?o<00030<co0000I_l0ol`00280ol`01@3<o`000`00ofH0
I_l006Ko0002003oIP030?l00000ofH00?mV0080I_l000<00?o<06Ko001Vo`000P1Vo`04003o0003
003oIP00ol`00?o<00800?o<00<006Ko0?l0001V0?l01000ol`4003o0003003oIP1Vo`00I_l000@0
I_l00P00o`000`00ofH0o`000?l00002003o000306Ko003<o`00c?l000@0c?l0603oc0020?mV00T0
ol`000<00?mV0?o<003oc0002@3oc0020<co0003003oIP00o`000?l000<0c?l02`3oc00N0?mV00D0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooa/0ofH0303oc0030<co00800?mV
00<0I_l00<co0000o`00103<o`001@3oc000c?l00<co003<o`000?mV02@0ol`01@3<o`000`00o`00
c03o0<`0o`02003o00<00<co00<00?o<003o0000o`00101Vo`000`00ofH00?o<003oc002003o0005
003oc000c?l00<co06H0o`3o06H00P3o0002001Vo`0306H0o`00ofH00?l000800?l000<00?o<003o
001Vo`000`1Vo`001`00ofH0I_l0003o0000o`00IP3o003oc000o`000P00c?l00`00o`00I_l00<co
00040<co02@0ol`000<0I_l00?o<003oc0001`3oc0040<co0003003oIP1Vo`00I_l00080I_l02`3o
c00N0?mV00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooa/0ofH0303oc002
0<co000506Ko0000o`000?l0003<o`1V0?l0203<o`000`00o`00c?l00?o<000?0?o<00030<co003o
c000ol`00140ol`00`3<o`000`1Vo`000?l006Ko000706Ko0003003oIP00I_l00?l000800?l000<0
I_l0003o0000o`000P00ol`3003oIP800?o<00@00<co0000o`3o0000IP3o0`00c?l2003oIP<00?o<
0P00o`0206Ko0003003o0000ofH00?o<00<00?mV00H006Ko06Ko001Vo`00I_l0003o001Vo`050<co
01@0ol`000<0003o0?o<003oc0003@3oc000103<o`00I_l006Ko003<o`040?o<0080c?l000D0I_l0
0<co003<o`00I_l00?l000040<co00/0ol`07@3oIP000`1Vo`00oooo0?ooo`030?ooo`4000000@3o
ool000P0oooo0P0000040?ooo`8000000`3oool4000000@0oooo00<000000?ooo`3oool00P3ooolK
0?mV00`0ol`00P3<o`001@1Vo`000?l0003o0000c?l0IP3o00P0c?l000<00?l00<co003oc0003`3o
c0000`3<o`00ol`00?o<000A0?o<00<0c?l000<0I_l0003o001Vo`001`1Vo`000`00ofH006Ko003o
0002003o000306Ko0000o`000?l000800?o<0`00ofH2003oc004003<o`000?l0o`0006H0o`<00<co
0P00ofH3003oc0800?l00P1Vo`000`00o`000?mV003oc003003oIP06001Vo`1Vo`00I_l006Ko0000
o`00I_l01@3<o`0D0?o<00030000o`3oc000ol`000d0ol`000@0c?l006Ko001Vo`00c?l0103oc002
0<co000506Ko003<o`00c?l006Ko003o0000103<o`0;0?o<01d0ofH000<0I_l00?ooo`3oool00`3o
ool100000040oooo00070?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?oooa/0ofH02P3oc0040<co0004003oc000ofH00?mV06H0o`80I_l0
0P3<o`0206Ko00<00?l000<0c?l00?o<003oc0003`3oc0000`1Vo`00ol`00?o<000B0?o<00P0c?l0
101Vo`02003oIP04001Vo`00ofH00?mV003o00800?mV0P00ol`00`00ofH00?o<003oc002003oc004
06H0o`000?l0o`000?l00080003o00<00<co0000o`00ol`00P00c?l2003oIP@00?l000@0IP3o003o
IP00o`000?l01`1Vo`03003o00030<co003oc000ol`001<0ol`000<0c?l00?o<003oc0003P3oc002
0<co00030000o`3<o`00c?l000D0c?l00P00ofH00`00o`000?o<06Ko00030<co00/0ol`07@3oIP00
0`3oc000oooo0?ooo`030?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`040?ooo`8000000`3oool00`3oc000ofH00?mV000G0?mV00030<co003oc000
ol`000L0ol`01@3<o`001P1Vo`000?l0003o003o00000?o<06Ko00800?mV00<00?l0001Vo`1Vo`00
0`3<o`0A0?o<00<0c?l04@3oc00:0<co00<0I_l000<00?l006Ko0000o`000P00ofH00`000?l00<co
001Vo`03001Vo`@00<co00@006Ko0000o`3o0000o`3<0`00I_l01@1V0?l00<co0?l0IP3o06H00<co
00@00?o<0`00ofH2003o0080I_l02@3<o`0D0?o<00030<co001Vo`00ol`000l0ol`00`3<o`00103<
0?l0I_l0003o0000o`020<co00<0I_l000<00<co001Vo`3<0?l00P1Vo`020<co00/0ol`06`3oIP02
0?o<00@0oooo0P0000010?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`80ol`0603oIP03
0?o<000306Ko003<o`00c?l000D0c?l00P1Vo`000`3<o`00I_l006Ko0002003o00030?l0IP00I_l0
0?mV00800?o<0P1Vo`000`00o`00c?l00<co000B0?o<00040<co001Vo`00I_l00<co0100ol`02`3<
o`0506Ko00800?l000<0003o001Vo`3o0<`00P3o00030000o`80c03o00@006Ko06H0o`3<0?l0o`00
0P3o06H00`3<0?l0o`3<0?l000030?l00080c03o0`00o`0506Ko00X0c?l0503oc0000`00o`00ol`0
0?o<000A0?o<0080c?l000H0I_l00<`0o`3<0?l00?l0003oIP1Vo`02003oc003003<o`00ofH0I_l0
00D0c?l02P3oc00K0?mV0080ol`01@3oool100000040oooo00070?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`80ol`05`3oIP06
0?o<00060<co001Vo`00I_l00<`0o`00I_l0I_l00P00o`000`00ofH00?l0003o0002001Vo`030<`0
o`00c?l00?mV00<0I_l0103<o`0B0?o<00040<co0000c?l00<co0<co0100ol`02`3<o`0506Ko00<0
0?l000L00?o<003<o`3o0000o`000?l0IP3o0000c03o0080o`3<00@0c03o06H0o`1V0?l0IP3o0P3o
0<`00`3<0?l0o`000000o`0206H0o`03001Vo`00ol`00?mV00800?l01P1Vo`0;0<co0180ol`000<0
c?l0003oc03oc0004P3oc0020<co00<0I_l000<00?l00000o`00o`000P00ofH00`3o00000?mV06Ko
000206Ko00030<co001Vo`00c?l000<0c?l0103oc0020<co00030?o<003oIP00ofH001L0ofH0103o
c0050?ooo`4000000@3oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`80ol`05`3oIP060?o<00060<co001Vo`00I_l00<`0o`00I_l0I_l00P00o`000`00ofH00?l0
003o0002001Vo`030<`0o`00c?l00?mV00<0I_l0103<o`0B0?o<00040<co0000c?l00<co0<co0100
ol`02`3<o`0506Ko00<00?l000L00?o<003<o`3o0000o`000?l0IP3o0000c03o0080o`3<00@0c03o
06H0o`1V0?l0IP3o0P3o0<`00`3<0?l0o`000000o`0206H0o`03001Vo`00ol`00?mV00800?l01P1V
o`0;0<co0180ol`000<0c?l0003oc03oc0004P3oc0020<co00<0I_l000<00?l00000o`00o`000P00
ofH00`3o00000?mV06Ko000206Ko00030<co001Vo`00c?l000<0c?l0103oc0020<co00030?o<003o
IP00ofH001L0ofH0103oc0050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool0
101Vo`00ol`00?o<003oc00D0?mV00X0ol`000<0c?l006Ko003<o`001@1Vo`02003o0003003oc03<
0?l00<co00800?l01@3<o`0B0?o<00030<co0000o`000?l00080c?l03P3oc00<0<co00D0I_l00`00
ofH00`00ol`006Ko001Vo`02001Vo`D0o`0000<0c03o06H0o`000?l00P000?l2001Vo`06003<o`00
I_l006Ko003<o`00ol`00?mV0P00o`0506Ko00`0c?l0403oc0030<co000306Ko003oc000ol`00180
ol`0103<o`0206Ko0005003o003<0?l0c03o0?l0IP1V0?l00`00o`000`00ofH00?l006Ko0002003o
000306Ko0000ofH0I_l00080c?l01@3oc00F0?mV0003003oIP3oc000ol`00080ol`01@3oool10000
0040oooo000K0?ooo`030000003oool0oooo0080oooo1@3oc00A0?mV00d0ol`00P3<o`02003oIP80
c?l000H0I_l0003oIP00ofH00?mV0?l00000ofH206Ko0003003oc03<o`00c?l00080c?l04P3oc000
103<o`00I_l006Ko0000ol`20<co00`0ol`03@3<o`0206Ko00800?mV00H00<co001Vo`00I_l0003o
003<o`00ofH2003oc003001Vo`00c?l0IP3o0080IP3o0P3o00001`3<0?l0IP3o001Vo`00I_l0IP3o
003<o`00I_l00P00ol`00`00ofH006Ko001Vo`02003oc003003o001Vo`00I_l00080I_l03@3<o`0>
0?o<00<0c?l00P00o`000`3<o`00ol`00?o<000A0?o<00D0c?l000L0I_l0003o0000I_l006Ko0000
o`00I_l0I_l000800?l000<0o`3<003o001Vo`000P00o`020<co00T0ol`0503oIP040?o<0080c?l0
1@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo1`3oc00>0?mV00l0ol`01P3<
o`0206Ko0003003o003o06H006Ko00800?o<0P00ofH00`000?l0c?l00<co000B0?o<00<0c?l000<0
0?l00<co003<o`000P3<0?l00`3<o`00ol`00?o<00050?o<00@0c?l000<0I_l00<co003<o`001`3<
o`0506Ko0004003o0000ofH00?mV003o00800?mV0P3o06H00`00c?l00?o<003<o`02001Vo`80o`00
00<0c03o001Vo`00c?l00P00c?l4003oc0H00?mV00@00?l006Ko001Vo`00I_l03@3<o`0=0?o<0080
c?l00P1Vo`000`00ofH0c?l00<co000C0?o<00@0c?l00P1Vo`001P00o`00003o0000o`00ofH00?o<
06Ko00<0c?l000@00<co0<co003<o`00c?l0303oc00B0?mV00H0ol`000<0c?l00?ooo`3oool00`3o
ool100000040oooo000K0?ooo`030000003oool0oooo0080oooo2P3oc0090?mV0180ol`0103<o`00
1P1Vo`00o`3<0?l0c000ol`00<co003oIP<0I_l01@3<o`0@0?o<00@0c?l000<00?mV06Ko0000o`00
3P3<o`000`1Vo`000?l0003o00060<co00L0I_l01000o`03003oIP800?o<00<0IP3o0<`0o`3<0?l0
0P3o00000`3<0?l006Ko0000o`020000o`04003oc000ofH00?mV003oIP<00?l00P00ol`606Ko00l0
c?l02@3oc0000`00o`00c?l00<co0002003oIP03003o003<o`00c?l001<0ol`00P3<o`0306Ko0005
003o0000ofH0o`000?l00000ofH00P1Vo`050<co00l0ol`03`3oIP090?o<00D0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`020?ooo`X0ol`02@3oIP0B0?o<00@0c?l000H0I_l00?l0c03o
0<`00?o<003<o`00ofH306Ko00D0c?l0403oc0040<co0003003oIP1Vo`000?l000h0c?l000<0I_l0
003o0000o`001P3<o`0706Ko00@00?l00`00ofH2003oc00306H0o`3<0?l0c03o0080o`0000<0c03o
001Vo`000?l00P000?l01000ol`00?mV003oIP00ofH3003o00800?o<1P1Vo`0?0<co00T0ol`000<0
0?l00<co003<o`000P00ofH00`00o`00c?l00<co000C0?o<0080c?l00`1Vo`001@00o`000?mV0?l0
003o00000?mV0080I_l01@3<o`0?0?o<00l0ofH02@3oc0050?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool00P3oool60?o<00030<co003oc000ol`001h0ol`000<0c?l006Ko001Vo`000`1V
o`001000ol`00?mV06Ko001Vo`060<co0100ol`000@0c?l006Ko0000ol`00?o<0P00o`000`1Vo`00
c?l00<co000=0<co0080I_l000<006Ko06Ko001Vo`002P1Vo`04003o00@00?mV00D00?o<003<o`00
I_l006Ko0<`0o`020?l00003001Vo`00c?l00<co00800?o<0`00ofH5003o00L0I_l0203<o`000`00
o`00c?l00<co000=0<co0003003o003<o`00I_l00080I_l00P3<o`0B0?o<00D0c?l00P1Vo`001P00
ofH0003o0000o`00ofH00?l006Ko00@0c?l04`3oc00:0?mV00030?o<003<o`00ol`000P0ol`01@3o
ool100000040oooo000K0?ooo`030000003oool0oooo0080oooo1@3oc0000`00o`00ol`00?o<000;
0?o<00030<co003oc000ol`00140ol`01@3<o`0206Ko0003003oc01Vo`00I_l000L0c?l03P3oc005
0<co000306Ko0000o`00I_l000@0c?l000<0I_l00<co003<o`002P3<o`000`1Vo`000<co003o0003
06Ko0003003o001Vo`00I_l000@0I_l00P00o`03003oIP@00?o<00D00<co06H0o`1V0?l0IP3o0?l0
00020?l0c0<00<co00D006Ko003oc03o0<`0o`3<003oIP04003o00H0I_l000<00?mV06Ko001Vo`00
101Vo`02003o000306Ko003<o`00c?l000h0c?l000@00?mV0?l0c03o0<`0I_l0103<o`0@0?o<00H0
c?l000L0I_l006H0o`00ofH00?mV06Ko00000?l00?l00080I_l00P3<o`0C0?o<00030<co003oc000
ol`000T0ol`00P00ol`70?o<00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oo
o`@0c?l000<00?o<0?o<003oc000303oc0000`00c?l0ol`00?o<000A0?o<00H0c?l000<0I_l0003o
IP1Vo`000P1Vo`050<co000306Ko003<o`00ol`000X0ol`01`3<o`000`1Vo`000?o<06Ko000206Ko
00030<co001Vo`00I_l000`0c?l00P1Vo`001P00c?l00?l0003o0000o`000<co003oIP@0I_l01000
o`001000I_l00?o<06H0o`1V0?l2003<o`03001Vo`3o0<`0o`3<0080o`0000H0o`3<0?l0IP00I_l0
06Ko003<o`000?l3003<o`03003oc000ofH00?l000800?l01P1Vo`001`00o`00I_l006Ko001Vo`00
0?l006Ko00000?l00P1Vo`0A0<co0004003o0000ol`00?o<06Ko00@0c?l03P3oc0080<co000506Ko
0000o`00I_l006Ko0000o`001@3<o`0D0?o<00030<co003oc000ol`000/0ol`000<0c?l00?o<003o
c0000`3oc0000`3<o`00oooo0?ooo`030?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0
0P3oool01@00ofH00?l006Ko001Vo`00c?l000h0ol`000<0c?l00?o<003oc0004@3oc0060<co0004
06Ko0000ofH00?mV003oIPH0I_l0103<o`080?o<00030<co001Vo`00I_l000D0c?l000<0I_l0003o
0000ofH00P1Vo`000`00o`000<co003oIP0<0<co00<0I_l00P00o`000`00c?l00?o<003o0002003o
c0L00?l00`00ofH2003oc0060000o`00I_l006Ko0<`0o`3o0000IP3o0`00I_l2003oc0@00?mV1@00
o`0406Ko00800?l000D0I_l0003o0000o`000?mV003o000306Ko00/0c?l000<0003o0<co003<o`00
0P3<o`00101Vo`000?l006Ko001Vo`060<co00d0ol`0203<o`00101Vo`00IP3o003o0000o`060<co
0280ol`000<0c?l006Ko003<o`00103<o`050?ooo`4000000@3oool001/0oooo0P0000030?ooo`05
003oIP00o`00I_l006Ko003<o`003P3oc0000`3<o`00ol`00?o<000A0?o<00H0c?l000@0I_l0003o
IP00ofH00?mV1P1Vo`040<co00P0ol`000<0c?l006Ko001Vo`001@3<o`000`1Vo`000?l0003oIP02
06Ko0003003o0000c?l00?mV00`0c?l00`1Vo`02003o0003003<o`00ol`00?l000800?o<1`00o`03
003oIP800?o<00H0003o001Vo`00I_l0c03o0?l0001V0?l3001Vo`800?o<1000ofH5003o00@0I_l0
0P00o`001@1Vo`000?l0003o0000ofH00?l000<0I_l02`3<o`000`000?l0c?l00<co00020<co0004
06Ko0000o`00I_l006Ko00H0c?l03@3oc0080<co000406Ko001V0?l00?l0003o00H0c?l08P3oc000
0`3<o`00I_l00<co00040<co00@0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`020?oo
o`04003o001Vo`00c?l00<co00l0ol`00P3<o`0B0?o<00D0c?l00P1Vo`001P00ofH00?o<003oc000
o`000?mV003o0080I_l0403<o`0306Ko00800?l000<0I_l0003oIP00c?l00P00o`000`000?l0o`3<
06Ko000<0<co00<0I_l00P00o`000`00ofH0o`00003oc002003oIP03003o0000ofH00?l000@00?l0
0`00ofH3003<o`8006Ko00@0IP3o0?l0001V0?l006Ko0`00c?l01000ol`00?mV003oIP00ofH;003o
0004003oIP00c?l0o`000?l000800?mV00<0I_l00<co003<o`002`3<o`000`1Vo`000?l006Ko0003
06Ko0003003oc01Vo`00I_l000H0c?l000<0I_l00?o<003oc000203oc0040<co000306Ko003<o`00
c?l00080c?l00P1Vo`000`00o`00I_l006Ko00060<co01<0ol`000<0c?l00?o<003oc0003@3oc000
0`3<o`000<co06Ko000206Ko00030<co003oool0oooo00<0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`020?ooo`@0c?l03`3oc0000`3<o`000?l00<co000A0?o<00030<co003o0000I_l0
0080I_l000<00?o<003o0000c?l00P000?l00`00o`00I_l006Ko000C0<co000406Ko0000ofH0c03o
0<`0o`800?mV00@0o`3<003oIP00ofH00?l00P1Vo`0<0<co00<0I_l00P00o`02003oIP05003oc000
I_l006Ko003oIP00ol`01@00ofH4003oc004003<o`00I_l0IP3o06H0o`80o`0000@0o`1V0000o`00
I_l006Ko0P00ol`4003oIP@00?l000<00?o<003o0000o`000P3o00000`00ol`0o`00003oc002003o
00<0I_l03@3<o`001`1Vo`000?l0003oIP00ofH0I_l0003o00000?l00P00ol`00`1Vo`00c?l00<co
00020<co0003003o003<o`00c?l00080c?l01P3oc0060<co000706Ko0000ol`006Ko001Vo`1Vo`00
0?mV003<o`0306Ko00D0c?l04`3oc0000`00ol`0ol`00?o<000=0?o<0080c?l00P1Vo`000`00ofH0
0<co0?ooo`040?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool40<co00l0ol`0
00<0c?l006Ko0000o`003`3oc0050<co00@0I_l000@0o`000<`0o`3<0?l00?l00P1Vo`090<co0003
06Ko003<o`00c?l000P0c?l000H0I_l0003o0000o`000?l0003<o`1V0?l2003oIP03003o001Vo`00
I_l000`0c?l00P1Vo`06003o00800?mV00<006Ko0?l0IP00c?l00P00ofH00`00c?l00?mV003oIP05
001Vo`80003o00@0o`3<0?l0001V0?l0003o1000c?l00`3o06H00?mV003oIP05003oIP0306H0o`00
ofH00<co0080o`0000<006Ko003oc000I_l00P00o`0306Ko00d0c?l01000o`000`00ol`00<co0000
o`02003o00D0I_l04P3<o`001P1Vo`000?mV003oIP00ol`00<co003oIP800?l00P00ofH40<co0140
ol`00P3<o`000`1Vo`00ol`00?o<000>0?o<00@0c?l000<0I_l00?ooo`3oool00`3oool100000040
oooo000K0?ooo`030000003oool0oooo0080oooo0P3<o`0A0?o<00D0c?l03@3oc0080<co000506Ko
0000ol`00<co003<o`00o`000P1Vo`090<co0003003o003<o`00c?l000T0c?l00`1Vo`001P00o`00
0?o<06H0o`1V0?l00?o<003o00<0I_l02P3<o`0606Ko00@00?l00`00ol`2003<o`03001Vo`00ol`0
06Ko00800<co0`00I_l20000o`040<`0o`3o0000c03o0000o`80IP3o00<006Ko06H0o`00ol`00`00
ofH01P3o00000?mV0?l0003o000006Ko0?l000<00?mV00<00<co003o0000ofH00P00ol`00`00o`00
I_l006Ko000=0<co00@0I_l000<00?l00000o`1V0?l00P000?l00`00I_l00?l006Ko000D0<co00<0
I_l000<00?l00000o`00ofH00`00o`000`00ofH0I_l00<co00030<co00l0ol`0103<o`0@0?o<00@0
c?l000<0I_l00?ooo`3oool00`3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo
0P3<o`0A0?o<00D0c?l03@3oc0080<co000506Ko0000ol`00<co003<o`00o`000P1Vo`090<co0003
003o003<o`00c?l000T0c?l00`1Vo`001P00o`000?o<06H0o`1V0?l00?o<003o00<0I_l02P3<o`06
06Ko00@00?l00`00ol`2003<o`03001Vo`00ol`006Ko00800<co0`00I_l20000o`040<`0o`3o0000
c03o0000o`80IP3o00<006Ko06H0o`00ol`00`00ofH01P3o00000?mV0?l0003o000006Ko0?l000<0
0?mV00<00<co003o0000ofH00P00ol`00`00o`00I_l006Ko000=0<co00@0I_l000<00?l00000o`1V
0?l00P000?l00`00I_l00?l006Ko000D0<co00<0I_l000<00?l00000o`00ofH00`00o`000`00ofH0
I_l00<co00030<co00l0ol`0103<o`0@0?o<00@0c?l000<0I_l00?ooo`3oool00`3oool100000040
oooo000K0?ooo`030000003oool0oooo0080oooo00<0I_l00<co003oc000403oc0000`3<o`000<co
003o00030<co00/0ol`02@3<o`0206Ko00<00?l00P1Vo`080<co0080I_l02`3<o`0206Ko0003003o
0000I_l00?mV008006Ko00<00?l006Ko001Vo`000`1Vo`070<co00T0I_l000<00?l0003oIP00ofH0
0`00ofH3003oc007003<o`1V0?l0o`1V0?l0IP3o0000IP3o0<`0o`0206H0o`<0o`000`3o0<`00`3o
0000003o001Vo`03003oc00706H0o`00c?l00<co003<o`3o000006Ko003oIP05003o00D0I_l03@3<
o`0206Ko00800?l000<00?mV0?l00000I_l00P00o`000`1Vo`000?l00<co000:0<co0080I_l0203<
o`001P1Vo`000?l0003o0000c?l0o`00003o00<0I_l01P3<o`0?0?o<00040<co001Vo`00I_l00<co
0100ol`0103<o`000`00o`00oooo0?ooo`030?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool00P3oool40<co00l0ol`00P3<o`001000c?l0c?l00<co0000o`020<co00L0ol`02`3<o`0206Ko
00800?l000<00?o<06H0o`1Vo`000P1Vo`060<co0003003oIP1Vo`00c?l000X0c?l0101Vo`001000
o`00o`000?l00000o`0E06Ko00H00?l00`00ofH2003oc08006Ko0P3o06H0103o0000o`1V0?l0IP3o
06H20?l0c0060?l0003o06H0o`1V0?l0c03o0000003o1000ol`4003oIP03003oc000ofH00?l00080
0?l02@1Vo`0:0<co0080I_l000D00?l0003oc000ol`00?o<0?l00003003oIP80I_l02`3<o`02003o
IPP0c?l00`1Vo`000`00o`000?mV003o0002003oIPP0c?l03@3oc0020<co0080IP3o00<0I_l00<co
003oc0003P3oc0030<co0080I_l01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080
oooo103<o`0=0?o<0080c?l000<00?l006Ko0000I_l00P1Vo`0E0<co0080I_l00P00o`000`00c?l0
I_l006Ko000206Ko0003003o003<o`00c?l000<0I_l000<00?l006Ko001Vo`002P3<o`0406Ko0003
003o0000ofH00?mV00800?l00`1Vo`000`00o`00I_l006Ko000406Ko0003003o001Vo`00I_l000L0
I_l01P00o`03003oIP05003oc000I_l0003o0000o`00I_l00P3<0?l20?l0c080o`0000L0IP3o0000
o`3<0?l0c03o0000o`00I_l00<co00800?o<0P00ofH00`00c?l00?l0003o0002003o0004003oIP00
o`000?l0003o00X0I_l01`3<o`0506Ko00800?l000<0c03o003oc000o`000P00ofH00`00o`00I_l0
0<co000:0<co00800?o<00<0I_l00<co003<o`001@3<o`0306Ko00800?l00`1Vo`0:0<co00P0ol`0
0P3<o`000`00o`00c?l00<co0002003o0080c?l03`3oc0050<co00D0oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`020?ooo`D0c?l0303oc0040<co0003003o001Vo`00I_l000<0c?l00P1V
o`070<co0003003o003<o`00c?l000H0c?l0101Vo`000`1V0?l00?l006Ko000806Ko0003003oc01V
o`00I_l000T0c?l01@1Vo`001000o`000?o<003oc000ol`4003o00L0I_l000<00?l006Ko001Vo`00
1`1Vo`06003o00<00?mV00L00?o<0000o`00c?l00<co0000o`00I_l0003o00<0o`0000<0c03o06H0
o`00I_l00P3<0?l00`00c?l006Ko0000o`02003oc0800?mV2000o`0=06Ko00<0c?l01`1Vo`02003o
0003003oIP00o`00I_l000@0I_l02`3<o`02003oIP80I_l01@3<o`0206Ko00800?l00P00c?l00`00
o`00I_l006Ko000=0<co0080ol`01P3<o`00101Vo`000?l0003o0000o`020<co00l0ol`01@3<o`05
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool50<co00`0ol`0103<o`000`00
o`00I_l006Ko00030<co0080I_l01`3<o`000`00o`00c?l00<co00060<co00@0I_l000<0IP3o003o
001Vo`00201Vo`000`00ol`0I_l006Ko00090<co00D0I_l000@00?l0003oc000ol`00?o<1000o`07
06Ko0003003o001Vo`00I_l000L0I_l01P00o`03003oIP07003oc0000?l00<co003<o`000?l006Ko
0000o`030?l000030<`0o`1V0?l006Ko0080c03o00<00<co001Vo`000?l00P00ol`2003oIPP00?l0
3@1Vo`030<co00L0I_l00P00o`000`00ofH00?l006Ko000406Ko00/0c?l00P00ofH206Ko00D0c?l0
0P1Vo`02003o00800<co00<00?l006Ko001Vo`003@3<o`020?o<00H0c?l000@0I_l0003o0000o`00
0?l00P3<o`0?0?o<00D0c?l01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo
0P3<o`0206Ko0080c?l02P3oc0050<co000506Ko0000o`000?l006Ko003<o`000`1Vo`070<co00@0
I_l0103<o`000`1Vo`000?l006Ko0002003o00030000o`00ol`00?mV00800?mV0`1Vo`02003oIP03
003o0000ofH0I_l000<0I_l01P3<o`0206Ko00800?mV0`00o`02003oc003001Vo`000?l00?mV0080
0?l01`1Vo`000`00o`000<co003<o`0606Ko0003003o0000ofH00?l000@00?l01000ofH3003oc003
003<o`00I_l0003o0080c03o00@0o`000<`0o`000?l006Ko0`00c?l00`00ol`00<co003<o`02003<
o`03003oIP00o`000?l000H00?l04P1Vo`02003o00<0I_l00P00o`000`00ofH00?l006Ko000406Ko
00X0c?l000@0I_l0003o0000o`000?o<2P1Vo`02003oIP<0I_l0203<o`0206Ko00H0c?l000<0I_l0
0<co003<o`000`3<o`000`00ol`0I_l006Ko00030<co00d0ol`01P3<o`050?ooo`4000000@3oool0
01/0oooo0P0000030?ooo`03003oc01Vo`00c?l000@0c?l01`3oc0020<co0003003o003<o`00c?l0
0080c?l000<00?mV0?l0c03o0<`00`00o`0:0<co00<00?l01P1Vo`001P00ol`00?mV003oIP00c?l0
o`3<003oc0800?l00`1Vo`02003o008006Ko00<00?mV003o001Vo`000`1Vo`000`3<o`00I_l006Ko
000606Ko0006003o0000ofH00?mV003oIP3o00000?o<0`00o`0706Ko0003003oIP00ol`00?o<00P0
0?l00`00ofH00`000?l00?mV003oIP03003oIP06003oc000I_l006Ko0?l0003<0?l0IP3o103o0002
0000o`<00<co0P00ol`4003oIPP00?l02P1Vo`000`00o`00I_l006Ko000706Ko0003003oIP00o`00
0?l000800?o<00<0IP3o001Vo`1Vo`001@1Vo`090<co00<0I_l000<0o`3<06Ko0000o`00101Vo`00
1P00o`00I_l0003o0000o`000?o<003o00@0I_l01P3<o`000`00ofH0c?l00<co00070<co000606Ko
003<o`00c?l00<co001Vo`0006Ko0P1Vo`050<co00X0ol`00P3<o`001@1Vo`00c?l00<co003<o`00
I_l000@0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`0306Ko003<o`00c?l0
00h0c?l00P1Vo`03003o00800<co00<00?o<003o001Vo`002P3<o`02003oIP03001Vo`00o`000<co
00@0I_l000<00?l0003oIP00ofH00P00c?l00`00ol`00?l0003o0003003o00800?mV00<00?o<003o
0000o`003`1Vo`001P00o`000?mV003oIP3o00000?o<003oIP800?l01`1Vo`001000o`000?mV003o
IP00ol`9003o0003003oIP1V0?l00<co00L00?o<00<00<co001Vo`000?l00P3o0<`0103o0000IP3o
0000o`1V0?l20000o`0306H0o`3<0?l00?o<00D00?mV1`00o`000`00c?l0I_l006Ko000506Ko0080
0?l000<00?mV06Ko001Vo`001`1Vo`000`00o`000?mV003oc002003oc003001Vo`00ofH00<co00<0
0?l00P1Vo`080<co00@0I_l000<006Ko003oIP00ofH0101Vo`001@00o`000?mV003oIP00ofH0IP3o
00800?l00P00ofH606Ko000306H0o`1Vo`00c?l000P0c?l0101Vo`001000o`000?mV06Ko001Vo`06
0<co00L0ol`01@3<o`02003o0003003oc000o`00oooo00@0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`020?oooa<0c?l000<0I_l0001Vo`00o`000P00ol`00`3<0?l00?l006Ko000206Ko
00L0c?l00`1Vo`000`00ofH0o`00003oIP02003o000306Ko0000o`000?l000800?mV00<006Ko0000
o`00ol`00P000?l2003o0003003<o`000?l0003o00800?l0401Vo`03003o00800?mV0`00o`0706Ko
00<00?l000<0IP3o003oIP00ofH01`00o`02003oIP06003<o`3o0000o`000000o`3o0<`00?o<0P00
c?l2001Vo`060<`0o`3o06H0o`1V0?l0003<0?l0003o0`00c?l3003oc0X00?mV0`00o`0606Ko00@0
0?l02P1Vo`000`00o`000?mV003<o`03003<o`030000o`00o`000?l000`0I_l000H00?l0003oIP00
ofH00?o<001Vo`00ofH406Ko0007003o0000I_l0c03o0<`0o`000?l00?o<0000o`0406Ko0003003o
001Vo`00I_l000800?mV00<0I_l00<co003<o`001`3<o`001P1Vo`00c03o0<`0o`00o`00003o003o
IP@0I_l000<00?o<0<co003<o`003`3<o`000`1Vo`000?o<0?ooo`040?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool00P3ooolC0<co000306Ko0000I_l00?l000800?o<00<0c03o003o001V
o`000P1Vo`070<co00<0I_l000<00?mV0?l00000ofH00P00o`000`1Vo`000?l0003o0002003oIP03
001Vo`000?l00?o<0080003o0P00o`000`00c?l0003o0000o`02003o0100I_l00`00o`02003oIP<0
0?l01`1Vo`03003o000306H0o`00ofH00?mV00L00?l00P00ofH01P00c?l0o`000?l000000?l0o`3<
003oc0800<co0P00I_l01P3<0?l0o`1V0?l0IP3o0000c03o0000o`<00<co0`00ol`:003oIP<00?l0
1P1Vo`04003o00X0I_l000<00?l0003oIP00c?l00`00c?l00`000?l00?l0003o000<06Ko0006003o
0000ofH00?mV003oc000I_l00?mV101Vo`001`00o`0006Ko0<`0o`3<0?l0003o003oc0000?l0101V
o`000`00o`00I_l006Ko0002003oIP0306Ko003<o`00c?l000L0c?l000H0I_l00<`0o`3<0?l00?l0
0000o`00ofH406Ko0003003oc03<o`00c?l000l0c?l000<0I_l0003oc03oool0103oool100000040
oooo000K0?ooo`030000003oool0oooo0080oooo503<o`0206Ko00800?mV00<0c03o003<o`00o`00
0P1Vo`070<co000606Ko0000ofH00?mV003<o`00ofH0o`3<0P00o`000`00ofH00?l0003oIP02003o
c00306H0o`3o06H00<co00@00?mV00D00<co003oc000ol`00?mV003o000606Ko00<00?l01`1Vo`03
003o00800?mV1000o`0506Ko00@00?l000<00?o<003<o`00ol`01`00o`000`00ofH00?o<003oc002
003oc003003<o`000?l006Ko00<006Ko00P0003o06H0o`3o06H0o`1V0?l0003<0?l0003o0?l0c080
IP3o1P00ol`00`000?l00?mV003oc002003oc003003oIP00o`000?l000@00?l00P00c?l3003o0080
003o00<00?l006Ko001Vo`00201Vo`001@00o`000?o<001Vo`00I_l00?o<00800?l04@1Vo`000`00
o`000?o<003oIP05003o0006003oIP000?l0003o001Vo`00ofH00?l0101Vo`03003o00030000o`1V
o`00I_l000T0c?l00`1Vo`000`00o`0006Ko001Vo`02003oc003003oIP1Vo`00c?l00180c?l000<0
I_l00?ooo`3oool00`3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo2@3<o`00
0`1Vo`00c?l00<co00080<co000606Ko0000ol`00?l0003o00000?l00?l0101Vo`050<co00D0I_l0
00@00?mV003o0000I_l006Ko0P00ofH3003oc003001Vo`3o000006Ko00800<co00<00?o<003<o`00
ofH01000o`0606Ko0003003oc000ofH00?mV00L0I_l00`00ofH00`00ol`0IP3o003<o`0:003o0080
0?mV00<00?o<0<`0o`3o00000P00I_l5003o00D00?mV0P00ol`3001Vo`030<`0o`3o0000o`1V00<0
o`0000<0o`3<0<`0o`00I_l00P00c?l2001Vo`060?l00000ol`00?o<001Vo`000?l0o`000P00ol`0
0`00c?l00?mV003o0005003o00800?mV0P00o`001000ofH006Ko001Vo`00ol`906Ko00<00?l00P00
I_l00`00ofH00?o<003o000A06Ko00800?l000<0o`00003oIP00o`000P00o`001`00c?l00?o<0000
o`000?l0IP3o003oIP00ol`01000o`001000ofH0o`000?l00000o`0206Ko00T0c?l00`1Vo`000`00
o`00003o003oIP0306Ko01@0c?l000<0I_l00?ooo`3oool00`3oool100000040oooo000K0?ooo`03
0000003oool0oooo0080oooo2@3<o`000`00o`00I_l00<co00080<co00@0I_l000<0o`00003o001V
o`000P1Vo`000`00ol`0I_l006Ko000906Ko0006003o0000ol`00?o<003oIP00I_l0o`000`00I_l0
1`3o0<`0c03o0?l0c03o0<`0003o003oc000ofH01@00o`0406Ko0005003o0000c?l00?mV003oIP00
o`001@1Vo`04003o0003003oIP3o0000003o00X00?l00P00ofH00`00ol`0IP3o003oc00<003oIP80
0?o<00@00<co06H0o`1V0?l0IP3o0P3o06H20?l000030?l0c03o0000o`0000<0o`0000<0o`3<0?l0
IP3o00000`00c?l00`00I_l00<co003oIP02003oIPL00?l00`00ofH01000o`000?o<003oIP00ofH2
003o00P0I_l00`00o`020?l000<00?l0201Vo`000`00o`00I_l006Ko000606Ko0004003o001V0?l0
0?mV0000o`80c03o0P00ofH01P00c?l0o`3<0?l0c01V0?l00?o<003oIP@00?l000<00<co003oIP00
ofH00P00ofH306Ko00H0c?l0101Vo`000`00o`00o`1V06H0o`0306Ko00X0c?l000<0I_l00<co003<
o`001`3<o`000`1Vo`00oooo0?ooo`030?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0
0P3oool70<co0080I_l000<00?mV06Ko003<o`00203<o`0406Ko0003003<o`00ol`00?l00080003o
1@1Vo`000`00o`00I_l006Ko000406Ko00<00?l00P00ofH01P00c?l0o`000?l0003o0000o`3<06H0
o`80c03o00<006Ko06H0o`00ofH01000o`001P00ofH00?l0003o0000o`000<co003o00<00?mV00<0
0?l0003oc000o`001`00o`000`00ofH00<co003oIP04003o0003003oIP00o`000?l000D00?l000<0
0?mV003oc000ol`00P00ofH00`00ol`00?mV003oIP05003oIP@00?o<0`00c?l00`00I_l0IP3o0?l0
c0020?l0IP80c03o00L0o`3<001Vo`00c?l00<co06H0o`00c?l0003o00D00?o<0P000?l00`00ofH0
0?l0003o0005003o00800?mV00<0o`3<003oc03<0?l00P00ofH3003o00@0I_l01000o`02003oIP80
06Ko00<00?mV003o0000o`00201Vo`02003oIPL0I_l00`00o`001P00ol`00<co003<o`00ol`00<co
001Vo`80o`0000<0003o003oc000ol`00P00ofH00`00ol`0c03o003o0002003o00H0I_l0103<o`05
06Ko00800?l0101Vo`090<co0003003o0000ol`0c?l000P0c?l000<0I_l00?ooo`3oool00`3oool1
00000040oooo000K0?ooo`030000003oool0oooo0080oooo1`3<o`0206Ko0003003oIP1Vo`00c?l0
00P0c?l0101Vo`000`00c?l00?o<003o00020000o`D0I_l000<00?l006Ko001Vo`00101Vo`03003o
00800?mV00H00<co0?l0003o0000o`000?l0c01V0?l20<`0o`03001Vo`1V0?l00?mV00@00?l000H0
0?mV003o0000o`000?l0003<o`00o`03003oIP03003o0000ol`00?l000L00?l000<00?mV003<o`00
ofH01000o`000`00ofH00?l0003o0005003o0003003oIP00ol`00?o<00800?mV00<00?o<003oIP00
ofH01@00ofH4003oc0<00<co00<006Ko06H0o`3o0<`00P3o06H20<`0o`070?l0c000I_l00<co003<
o`1V0?l00<co0000o`05003oc080003o00<00?mV003o0000o`001@00o`02003oIP030?l0c000ol`0
c03o00800?mV0`00o`0406Ko00@00?l00P00ofH2001Vo`03003oIP00o`000?l000P0I_l00P00ofH7
06Ko00<00?l000H00?o<003<o`00c?l00?o<003<o`00I_l20?l000030000o`00ol`00?o<00800?mV
00<00?o<0<`0o`00o`000P00o`0606Ko00@0c?l01@1Vo`02003o00@0I_l02@3<o`000`00o`000?o<
0<co00080<co000306Ko003oool0oooo00<0oooo0@0000010?ooo`006`3oool00`000000oooo0?oo
o`020?ooo`80I_l0103<o`0306Ko00030?l0IP00ofH0I_l000L0c?l00P1Vo`001P00ol`00?mV003o
IP00ol`0c03o003oIP800?l01@1Vo`02003o00@0I_l01@00o`000`00ol`00<co0000o`020000o`04
0?l0001V0?l00<co003<o`800?o<1000ofH00`3o00000?l0003o0003003o00800?o<0P00ofH00`00
I_l00?l0003o0002003o0003003oIP00o`000?l000800?l000<00?mV003oc000ofH01000ofH00`3o
06H00?mV003oIP03003o00<00?mV00@00?o<0?l00000c?l00<co1@00ofH00`00c?l00?o<003oc003
003oc00606H0o`000?l0003o0000o`00I_l0IP3o0`3o0000103<0?l0003o001Vo`000?l2003<o`<0
0?o<0P00c?l00`00ol`00?mV003oIP03003oIPL00?l00`00ofH00`00I_l0o`000?l0c0020?l0c0X0
0?l000D00?mV003oc000I_l006Ko003<o`04003o00D0I_l000<00?l0003oc000ol`00P00o`0306Ko
00D00?l000<00?mV003oc000ol`00P3<0?l01@1V0?l0o`1V0?l0IP3o0<`0003o00<0c03o0P00ofH0
0`00c?l00?l0003o000;06Ko000306H0o`1Vo`000?l000<00?l0101Vo`090<co000306Ko0000ofH0
I_l000L0c?l00P1Vo`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool00`1V
o`000?l006Ko000606Ko0003003oc01Vo`00I_l000800?mV0`3<o`0506Ko00<00?l000@0c03o003o
c000ol`00?o<1@1Vo`000`00o`000?mV003o0004003o00D00?mV00@00?o<06H0o`1V0?l0003o103o
00000`00c?l00?o<003oc002003oc0030<`0o`00ofH00?l000@00?l000D00?mV06H0o`00I_l006Ko
003oIP05003o0005003oc000ofH00?mV003oIP3<0?l00P00c?l2003oc003003oIP00ol`00<co0080
003o00<00?mV003o0000ofH00`00ofH01@00ol`006Ko001Vo`00I_l00?o<00@00?mV00<00?o<001V
o`00c?l00`00ol`01000c?l006Ko0000o`000?l20?l0c0060?l0003o0<`0o`3<0000o`00I_l0003o
0`00c?l5003oc0L00?mV1@00o`03003oIP03001Vo`1V0?l00?o<00800?mV1P00o`000`00ol`00?l0
003o0003003o0004003oIP00ol`00?o<003oc0/00?l000@00?o<003o0000o`000?mV1`00o`001000
ofH0003o0000o`00c?l40?l00080IP3o00@00<co003oIP00ofH00?mV1000o`0<06Ko0006003o0000
ofH00?mV003<o`00ofH00?l00`1Vo`090<co0003003o003o00000?l00080I_l00`3<o`0406Ko00D0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`03003o001Vo`00I_l000<0I_l0
00H00?mV003o0000o`00003o003oIP00c?l406Ko0003003o001Vo`00I_l000D0I_l000<00?l0003o
IP00o`000P00o`0506Ko0003003o0000ofH00?l000800?mV0`00o`02003oc0030<`0o`00ol`00?o<
00800<co00<0003o0?l0c03o06H00P00I_l00`00c?l00?o<003<o`02001Vo`03003<o`00ol`00?l0
00@00?l000D00?mV001Vo`00ol`00?o<003oIP04003o0003003oIP00ol`00<co00800?mV00<00?o<
0?l00000I_l00P00I_l00`00ol`006Ko001Vo`09003oIP04003oc000c?l00<co001Vo`@00?o<00<0
0<co0000o`00c?l01@00c?l2001Vo`0306H0o`3o06H0o`000080o`0000<0003o001Vo`00I_l00`00
c?l5003oc0X00?mV00<00?l0003oIP00ofH00P00ofH00`00ol`006Ko003oc002003oIPH00?l000<0
0?mV003o0000o`000P00o`001@00ofH0IP3o001Vo`00I_l00?mV00@00?l000<00?o<003o0000o`00
0P00o`000`00ol`00?mV003<o`020?l0c0D00?l000@00?o<003oIP00ofH00?mV0P00ol`00`00c?l0
003o0?l0c0020<`0o`03001Vo`3o0<`00<co00800?o<00<00?mV003o0000o`000P00o`0506Ko0003
003oc01Vo`00I_l000@0I_l000H00?l0003oIP00ofH0o`00003oc000ofH406Ko00H0c?l00`1Vo`00
0`00ofH0I_l006Ko000406Ko00800?l00P1Vo`050?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool00P3oool00`00ol`0I_l006Ko000306Ko0005003o00000?l0003o003<o`00o`003@1Vo`00
0`00o`000?mV003oc002003oIPD00?l00P00ol`00`00c?l00?mV003oIP03003o0080o`1V00<00<co
001Vo`00c?l00P00I_l00`1V0?l0o`3<0?l0IP020?l0008006Ko00<00<co003oc000ol`02000ofH3
003oc0800?mV0`00o`000`00ofH00?o<003<o`020?l0c003003oc000I_l0o`3<00<006Ko00<00<co
003oc000ofH00P00ofH2003oc0<00?mV00@00?o<003<o`3o0000o`000P00ol`01P00c?l00?o<003o
c000ol`00<co06H0o`<00<co00L0o`3<001Vo`3<0?l0c03o0?l0c03o0000o`1V0080o`3<00@0003o
0?l0IP000?l0IP3o1000c?l00`00ol`00<co003<o`06003oIP03003oc000ofH00?mV00<00?mV00<0
0?o<003oIP00ofH00P00ol`3003oIPH00?l000<00<co003oIP00ofH00`00ofH01000ol`00?mV003o
IP00ofH2003o00800?mV1@00o`000`00ofH00?o<001Vo`02003oIPD00?l000@00?mV06H0o`00c?l0
0<co0P00ol`20000o`<0o`0000<0IP3o001Vo`00ol`00`00ofH7003o00800?o<00<00?mV06Ko001V
o`00101Vo`001000o`000?o<003oc000c?l2003o00X0I_l00`00o`001000ol`00?l0003oc000ol`5
06Ko0003003o001Vo`00oooo00@0oooo0@0000010?ooo`006`3oool2000000<0oooo00<00?o<06Ko
001Vo`000`1Vo`001@00o`00003o0000o`00c?l00?l000d0I_l000<00?l0003oIP00ol`00P00ofH5
003o00800?o<00<00<co003oIP00ofH00`00o`020?l0IP03003<o`00I_l00<co008006Ko00<0IP3o
0?l0c03o06H00P3o0002001Vo`03003<o`00ol`00?o<00P00?mV0`00ol`2003oIP<00?l000<00?mV
003oc000c?l00P3o0<`00`00ol`006Ko0?l0c003001Vo`03003<o`00ol`00?mV00800?mV0P00ol`3
003oIP04003oc000c?l0o`000?l000800?o<00H00<co003oc000ol`00?o<003<o`1V0?l3003<o`07
0?l0c000I_l0c03o0<`0o`3o0<`0o`000?l0IP020?l0c0040000o`3o06H0003o06H0o`@00<co00<0
0?o<003<o`00c?l01P00ofH00`00ol`00?mV003oIP03003oIP03003oc000ofH00?mV00800?o<0`00
ofH6003o0003003<o`00ofH00?mV00<00?mV00@00?o<003oIP00ofH00?mV0P00o`02003oIPD00?l0
00<00?mV003oc000I_l00P00ofH5003o0004003oIP1V0?l00<co003<o`800?o<0P000?l30?l00003
06H0o`00I_l00?o<00<00?mV1`00o`02003oc003003oIP1Vo`00I_l000@0I_l000@00?l0003oc000
ol`00<co0P00o`0:06Ko00<00?l000@00?o<003o0000ol`00?o<1@1Vo`000`00o`00I_l00?ooo`03
0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool00P3oool2003o00@0I_l000D00?l0003o
IP00ofH00?mV003o000506Ko0003003o0000ol`00?o<00<0I_l00`00o`000`00ofH00?o<003o0007
003o0004003oIP00I_l00?mV003oIP800?l01000ofH01`00ol`00<co001Vo`00I_l0c03o0?l0003o
0<`00P1V0?l00`3o0<`00<co003oc002003oc0L00?mV00@00?o<0000o`00c?l00<co1`00ofH01@00
ol`00<co003<o`00I_l0c03o00<0o`0000<00<co003oc000ol`02P00ol`2001Vo`<00<co0P00ol`2
003<o`<0003o0P00I_l01P3o06H0IP3o06H0o`3<0?l0o`1V0?l00080003o0`00I_l01@000?l006Ko
001Vo`00I_l00<co00@00?o<1000ofH2003oc0H00?mV0P1V0?l00`00I_l00<co003oc002003oc003
003oIP00o`000?l000800?l00P00ofH01P3<0?l00?mV003oIP00ofH00<co001Vo`800<co00<00?o<
003oIP00ofH00P00c?l00`00ofH00?l0003o0002003o00800?mV00@00<co003oIP00ofH00?mV1000
o`001000ofH00?o<003<o`00I_l2003<o`03001Vo`3o0<`0o`000080c03o00<0IP3o003<o`00ol`0
0P00ol`00`00c?l00?o<003oIP05003o00800?mV0P00o`0406Ko00800?l00P00ofH00`000?l00?l0
06Ko000506Ko00800?l01@1Vo`000`00ofH00?o<003oc002003o00D0I_l000<00?o<003o003oool0
103oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo1`00o`03003oIP03003o001V
o`00I_l000<0I_l000<00?l0003oIP00ofH01P00o`001P00ofH0c03o003oIP00ofH00?l0003<o`@0
0?l000@00?mV003<o`00ol`00?o<0P00ofH01@00ol`00?mV003oIP00ofH00?o<00<00<co00<0IP3o
0?l0003<0?l00P000?l2003<o`<00?o<0P00ofH00`00ol`00?mV003oIP02003oIP04003oc000I_l0
0?o<003oc0<00?mV0P00I_l2003oIP<00?o<00<0003o06H0o`3o00000P000?l00`00I_l00<co0000
o`03003oc08006Ko0`00ol`01@000?l00<co001Vo`00I_l0003o008006Ko0P00c?l00`00I_l00<co
001Vo`020000o`80o`0000D0IP3o0?l0c03o0<`0o`000<`0o`030000o`03001Vo`00c?l00<co00@0
0<co1`00ol`3003<o`03003oc000ofH00?mV00@00?mV0P00ol`00`1V0?l00<co003<o`04003oIP03
003<o`00ofH00?mV00800?mV00H006Ko003oc000ol`00?o<003<o`000?l3003<o`05003oc000I_l0
06Ko001Vo`00ol`01000o`02003oIP0306H0o`00ol`00?o<00L00?mV00L00?o<003<o`00I_l006Ko
0<`0o`3o0<`0o`000080o`3<00<0c03o003<o`00c?l00`00I_l00`00ol`00?mV003o0003003o0005
003oc000c?l00<co003oIP00ol`01P00o`02001Vo`03003oc000ofH0I_l000D0I_l00P00o`0506Ko
0003003o0000ol`00?mV00800?l00`1Vo`02003o0003003oc03o0000oooo00@0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`020?ooo`800?l00P00ofH2003o0004003oc000c?l00<co003o
c0@00?l000<0I_l0003o0000o`000P3o00000`00c?l00?l0003o0002003oc0800?mV00D006Ko003o
c000ol`00?mV001Vo`05003oIP03003<o`00I_l006Ko00800?mV00<0003o003oc000ol`00P00ol`0
0`3o0<`0003o0000o`020?l000060<`0o`000?l0003o0?l0c0000?l006Ko0`00ol`2001Vo`06003o
c000ofH00?mV003oIP00ol`0o`000P00c?l00`00ol`00?mV003oc002003<o`030?l00000ol`00<co
0080o`3<00<006Ko06H0o`3o00000P1V0?l00`00I_l0IP3o0000o`03003oc0800<co0`00ol`01P00
c?l0c03o06H0o`1V0?l0o`000000o`<006Ko00<0o`00001Vo`1V0?l00P3o0<`00`3<0?l0IP3o0?l0
c0030?l0000306H0o`000?l006Ko008006Ko1@00c?l6003oc006003<o`00ol`00?o<003oc000I_l0
0?o<1@00ofH3003oc00306H0o`00ol`00?mV00@00?mV00<006Ko003oIP00ofH00P00ofH01P00ol`0
003o0000o`00c?l006Ko0?l0IP8006Ko00<00<co001Vo`00ol`02000ofH01000c?l0o`00003oc000
ol`7003oIP800?o<0P3<0?l00`000?l0o`1V0?l000020<`0o`0306H0o`00c?l00<co00800<co00<0
0?o<003oIP00ofH01000o`001000ol`0o`000?l00000ofH7003o00800?o<00<00?mV003o0000o`00
101Vo`03003o00D0I_l00P00o`000`00ofH00?l0003o0006003o0003003oIP3oool0oooo00<0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`800?mV0P00ol`2003o0004003oIP00
ol`00?o<003oIPL00?l00P00c?l00`00ol`00?l0003o0002003oc0030?l00000ol`0c03o008006Ko
00<0c03o003oc000ofH00P00ol`2003oIP03003oc0000?l0003o00800?o<00@00<co0000o`000?l0
0?o<0P00c?l2001Vo`030<`0o`3o0000o`3<00<0003o00<006Ko003<o`00ol`00P00ol`00`00c?l0
o`00003oc002003oc003003<o`00ol`0003o00800<co0`00ol`2001Vo`03003<o`00ol`00<co0080
0<co00<0003o0?l0003o00000P3o00000`000?l006Ko003<o`03003<o`07001Vo`000?l00<co003<
o`000?l00<co001Vo`0206H0o`030?l0001V0?l0IP3o008006Ko00<0o`000000o`3<0?l00P3o06H0
0`3o0000o`1V0?l000020?l0c0030?l0003o0<`0003o0080003o00<006Ko003<o`00c?l00`00c?l6
003oc005003<o`1V0?l006Ko001Vo`00c?l00P00ol`4003oIP04003oc000c?l00<co06H0o`800?o<
1000ofH00`00c?l00?mV003oIP02003oIP<00?o<00<006Ko0?l0IP3o00000P3o00000`000?l00<co
003oc008003oIP04003oc000c?l00?o<003oc0<00?mV0P1V0?l2003oc0@00<co00<0003o0?l0c03o
00000P3<0?l00`00I_l00<co003oc002003oc0H00?mV00D006Ko003oIP00ol`00?o<003oIP04003o
0003001Vo`00ofH00?mV00800<co00<00?mV003o0000o`000`00o`02003oIP<00?l00P1Vo`03003o
0004003<o`3o00000?mV003oIP800?l000D00?mV003o0000o`000?l0003oIP050?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool00P3oool2003oIP800?o<0P00o`001000ofH00?o<003oc000
ofH7003o00800<co00<00?o<003o0000o`000P00ol`00`3o00000?o<0<`0o`02001Vo`030<`0o`00
ol`00?mV00800?o<0P00ofH00`00ol`0003o0000o`02003oc004003<o`000?l0003o003oc0800<co
0P00I_l00`3<0?l0o`000?l0c0030000o`03001Vo`00c?l00?o<00800?o<00<00<co0?l00000ol`0
0P00ol`00`00c?l00?o<0000o`02003<o`<00?o<0P00I_l00`00c?l00?o<003<o`02003<o`030000
o`3o0000o`000080o`0000<0003o001Vo`00c?l00`00c?l01`00I_l0003o003<o`00c?l0003o003<
o`00I_l00P1V0?l00`3o0000IP3o06H0o`02001Vo`030?l000000?l0c03o0080o`1V00<0o`000?l0
IP3o00000P3o0<`00`3o0000o`3<0000o`020000o`03001Vo`00c?l00<co00<00<co1P00ol`01@00
c?l0IP3o001Vo`00I_l00<co00800?o<1000ofH01000ol`00<co003<o`1V0?l2003oc0@00?mV00<0
0<co003oIP00ofH00P00ofH3003oc003001Vo`3o06H0o`000080o`0000<0003o003<o`00ol`02000
ofH01000ol`00<co003oc000ol`3003oIP80IP3o0P00ol`4003<o`030000o`3o0<`0o`000080c03o
00<006Ko003<o`00ol`00P00ol`6003oIP05001Vo`00ofH00?o<003oc000ofH01000o`000`00I_l0
0?mV003oIP02003<o`03003oIP00o`000?l000<00?l00P00ofH3003o0080I_l00`00o`001000c?l0
o`00003oIP00ofH2003o0005003oIP00o`000?l0003o0000ofH01@3oool100000040oooo000K0?oo
o`030000003oool0oooo0080oooo00@00?mV0?l0IP00ol`00?o<0`00ofH20<`0o`03003oIP00o`00
0?l000800?mV0`00o`02003oIP03003oc000ofH00?o<00800?mV00<00?o<003<o`3o00000P3o0<`0
0`00c?l00?o<003oc002003<o`03001Vo`00ol`00?o<008006Ko00<00<co003oc000ol`00P3<0?l2
003<o`03001Vo`1V0?l0IP3o0080o`0000@0IP3o0000o`000?l006Ko0P00c?l2001Vo`800<co00@0
06Ko003oc000ol`00?o<0P00c?l01P1V0?l006Ko001Vo`1V0?l00<co003oc08006Ko00<0003o003<
o`3o0<`00P00I_l00`000?l0IP3o0?l000020<`0o`80003o00H006Ko0000o`000?l00<co001Vo`00
0?l2001Vo`0306H0o`00I_l0003o0080IP3o00<0o`000?l0c01V0?l00P3<0?l00`1V0?l0o`1V0<`0
o`020?l0IP80o`0000@0o`1V0<`0o`3<0?l0IP3o0P000?l20?l0008006Ko1000c?l6003oc006003<
o`00I_l0o`000?l000000?l00<co1P00ol`2003<o`030000o`00ol`00?o<00800?o<00<00?mV003o
c000c?l01000ol`3003<o`03001Vo`1V0?l0o`000080IP3o00<006Ko003<o`00ol`01@00ol`3003o
IP04003oc000I_l00<co003<o`<00?o<0P000?l01000c?l00?o<003oc000I_l20?l0c0030000o`3o
0<`0o`3<0080003o00<006Ko003<o`00c?l00P00c?l00`00ol`00?mV003oc004003oIP03003<o`00
0?l0003o00800?mV00@00?l0003oIP00ofH0003o0P00ol`20?l00003003oc000ofH006Ko00@00?l0
00<0IP3o003<o`00c?l00P00o`001P00ofH00?l0003o0000o`000?mV003oc0800?mV0P00o`001@00
ol`00?mV003oIP00ofH00?o<00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oo
o`@00?o<00<00?mV003oc000ol`00P3<0?l3003oIP80o`3<1@00ofH00`00ol`00?mV003oc00206H0
o`03003oc000I_l0IP3o0080c03o00<0o`00001Vo`00ol`00P00c?l2003oc004001Vo`3o06H0o`1V
0?l0IP800<co1000I_l01@3o0<`0c03o0<`0o`3o0<`0o`0000<0IP3o0`00I_l3003<o`8006Ko00@0
0<co001Vo`00I_l00<co0P3<0?l20?l0c003001Vo`00c?l00<co00800<co00<0IP3o001Vo`000?l0
0`000?l01`3<0?l0o`000<`0o`3<0?l0IP3o0000o`00I_l00P000?l00`00I_l0c03o0<`0o`020?l0
00030000o`1V0?l0IP3o0080c03o00<0o`000?l0c03o0<`00P3o06H00`3o0<`0o`000?l000020?l0
00030?l0IP3o0000o`000080IP3o00<0003o001Vo`00I_l00P00I_l010000?l0IP3o0000o`00I_l3
003<o`@00?o<0P00c?l010000?l0IP3o06H0o`00c?l7003oc0800<co00<0003o003oc000ol`00P00
c?l2003oc003001Vo`00c?l00<co00800?o<00H00<co06H0o`1V0?l006Ko06H0o`3o000206H0o`80
06Ko00H00<co003oc000ol`00?o<0?l000000?l4003oc0<00<co0`00ol`2003<o`04001Vo`00c?l0
0<co003<o`8006Ko00<0IP3o0?l0003o00000P1V0?l00`3o0<`0003o003<o`03003oc080003o0P00
ol`2003oIP<00?o<0P00ofH01P00ol`00?mV003oIP00ol`0o`00003<o`80c03o00<00?o<06H0o`00
ofH00`00o`001000ofH006Ko003oIP00ofH2003o0006003oIP00o`000?l0003o0000ofH00?o<1000
ofH00`00ol`00<co003<o`02003oIPD0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`02
0?ooo`03003oc000c?l00?o<00<00?o<00@006Ko0?l0IP3o06H0IP3o0P00ol`2001Vo`800?mV0`00
ol`00`3o0<`00<co003oc002001Vo`030000o`00I_l0c03o0080o`0000<006Ko003<o`00c?l00P00
I_l00`00c?l006Ko0000o`020?l000030<`0o`00I_l0003o0080003o00<0o`0006H0o`3<0?l00P3o
06H00`3o0000c03o0000o`020000o`8006Ko00<0c03o0000o`000?l01000I_l20<`0o`03001Vo`3<
0?l0o`3<0080c03o00<0IP3o001Vo`000?l00P000?l00`3o0000IP3o0000o`0206H0o`030<`0o`3o
0000o`1V0080o`3<00<0IP3o0?l000000?l0101V0?l0103o0000c03o0<`0o`3<0?l50?l000030?l0
IP3o0000o`0000@0o`000P3<0?l00`1V0?l0c03o0?l0000206H0o`030<`0o`00I_l006Ko008006Ko
2@00c?l2001Vo`800<co0`00I_l00`00c?l00?o<003oc002003oc003003<o`00I_l00<co00<0003o
1000c?l2003oc0H00<co0P00I_l00`000?l0o`000?l000020?l000030000o`00I_l00<co00800?o<
00<00<co001Vo`00c?l00P00ol`00`00c?l006Ko001Vo`020000o`0306H0o`00c?l00<co00800<co
00@0003o003<o`00I_l006Ko0P000?l00`3o0<`0o`000<`0o`020000o`03001Vo`00c?l00<co00<0
0?o<0P00I_l4003oc004001Vo`00ol`00?o<003oc0800<co0`00ol`01P00c?l0o`3<0?l0IP3o06H0
0<co003oc0D00?mV00<0c03o003oIP00ofH00P00o`000`00ofH00?o<003oc002003oIP06003oc000
c?l00<co003<o`00ofH00?o<0P3<0?l00`00ol`00<co0?ooo`040?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool00P3oool01`00c?l006Ko003<o`00c?l006Ko003<o`000?l00P3<0?l00`1V
0?l00<co003oc002003<o`800?o<0`00c?l00`3o0<`006Ko001Vo`020?l0IP03001Vo`000?l0o`00
0080c03o00<0003o0?l00000I_l00P3o00000`000?l0c03o06H0o`020?l000030?l0c03<0?l0o`1V
00L0o`0000<0o`3<06H0o`000?l010000?l00`3<0?l006Ko001Vo`020000o`0706H0o`000?l0IP3o
06H0o`000?l0IP3o0?l0IP020?l0c00306H0o`000?l0IP3o0080IP3o00<0o`000<`0o`3<0?l0103o
00001P3o0<`0c03o0<`0o`3o0000c03o0?l0c080o`1V00<0c03o0?l0IP3o00000P3o06H50?l00080
o`3<0`3o00000`3o06H0c03o0<`0o`030000o`040?l0c01V0?l0IP3o06H0o`8006Ko3P00c?l2001V
o`030?l00000I_l006Ko00800<co0`00ol`00`00c?l0003o0000o`030<`0o`03001Vo`000?l00<co
00<00<co00<006Ko0<`0o`3<0?l00P00c?l3001Vo`030000o`3o0<`0o`000080c03o00<0003o001V
o`00c?l00P00I_l00`00c?l0o`1V003<o`03003<o`04001Vo`3o0000o`000?l000<006Ko0`1V0?l0
0`000?l006Ko0?l000020<`0o`80o`3<00@0c03o0?l0IP3o06H0003o1@00c?l01000I_l00<co003o
c000ol`2003<o`060000o`00c?l00<co003<o`00ol`0o`000P00ol`00`00c?l0o`0006H0o`020<`0
o`030000o`00c?l00?o<008006Ko00<00?mV003oc000c?l01000ofH3003oc003003oIP00ol`006Ko
0080003o00<00<co003oc000ol`00P00I_l00`00c?l006Ko0?ooo`040?ooo`4000000@3oool001@0
oooo0P0000050?ooo`030000003oool0oooo0080oooo00L00<co001Vo`00c?l00<co001Vo`00c?l0
003o0080c03o00<0IP3o003<o`00ol`00P00c?l2003oc0<00<co00<0o`3<001Vo`00I_l00P3o06H0
0`00I_l0003o0?l000020<`0o`030000o`3o000006Ko0080o`0000<0003o0<`0o`1V0?l00P3o0000
0`3o0<`0c03o0?l0IP070?l000030?l0c01V0?l0003o00@0003o00<0c03o001Vo`00I_l00P000?l0
1`1V0?l0003o06H0o`1V0?l0003o06H0o`3o06H00P3o0<`00`1V0?l0003o06H0o`0206H0o`030?l0
003<0?l0c03o00@0o`0000H0o`3<0<`0o`3<0?l0o`000<`0o`3o0<`20?l0IP030<`0o`3o06H0o`00
0080o`1V1@3o00020?l0c0<0o`0000<0o`1V0<`0o`3<0?l00`000?l0103o0<`0IP3o06H0o`1V0?l2
001Vo`h00<co0P00I_l00`3o000006Ko001Vo`02003<o`<00?o<00<00<co0000o`000?l00`3<0?l0
0`00I_l0003o003<o`03003<o`03001Vo`3<0?l0c03o00800<co0`00I_l00`000?l0o`3<0?l00002
0<`0o`030000o`00I_l00<co008006Ko00<00<co0?l0IP00c?l00`00c?l01000I_l0o`000?l0003o
0003001Vo`<0IP3o00<0003o001Vo`3o00000P3<0?l20?l0c0040<`0o`3o06H0o`1V0000o`D00<co
00@006Ko003<o`00ol`00?o<0P00c?l01P000?l00<co003<o`00c?l00?o<0?l000800?o<00<00<co
0?l0001V0?l00P3<0?l00`000?l00<co003oc002001Vo`03003oIP00ol`00<co00@00?mV0`00ol`0
0`00ofH00?o<001Vo`020000o`03003<o`00ol`00?o<008006Ko00<00<co001Vo`3oool0103oool1
00000040oooo000C0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool0
0`000?l0o`000000o`030000o`0306H0o`3o0000o`000080IP3o00<006Ko06H0o`1V0?l00P000?l0
1P3o0<`0IP3o06H0o`3o06H0IP3o0<`0o`80o`1V00<0o`3<0?l0003o00000`3<0?l01P3o0000c03o
0?l0IP3o06H0o`000?l0IP<0o`0000<0o`1V0?l0003o00000P3o00000`3o06H0o`000<`0o`0206H0
o`030?l0c0000?l0003o00@0003o00L0o`000000o`000?l0IP3o0<`0o`3o06H0IP3o00<0o`3<0P3o
00030?l0c0T0o`0000<0o`1V0<`0o`3<0?l00`3<0?l90?l000030?l0c03<0?l0o`3<0080c03o00<0
IP3o0?l0c03o00000P3o0<`00`1V0?l0003o06H0o`0206H0o`03001Vo`1V0?l006Ko0080c03o0P00
I_l?003<o`0406H0o`3<0?l0003o0000o`H00<co00L006Ko0000o`3o06H0o`1V0?l0001V0?l006Ko
00800<co00<006Ko003<o`00I_l00P1V0?l2001Vo`0606H0o`000?l0003o0000o`3o06H0o`000P3<
0?l00`1V0?l006Ko0000o`020<`0o`030?l000000?l006Ko00<006Ko00L0IP3o0<`0o`3o0000o`00
06H0o`000?l0IP3o0080003o00@0o`3<0<`0o`3o0000o`3<0P3o06H00`3o0000IP3o0000o`020000
o`8006Ko00D0003o003<o`00c?l00<co0000o`04003<o`040000o`3o0000003o0000o`800<co00H0
003o003<o`00c?l006Ko06H0o`3o00020<`0o`03001Vo`00c?l00<co00800<co00<00?o<003<o`00
c?l00P00ol`00`3o0<`00?o<003oc002003<o`03003oc000c?l0003o0080c03o00<0003o001Vo`00
c?l00P000?l00`3<0?l006Ko0?ooo`040?ooo`4000000@3oool001<0oooo00@000000?ooo`3oool0
0000103oool2000000<0oooo0P3o00020?l0IP<0o`000P3o0<`80?l000<0o`3<0P3o00020<`0o`03
0?l0c03o06H0c03o0080c03o00<0o`3<0?l0003o06H00`3o000206H0o`80c03o00<0o`000<`0o`3<
0?l00`1V0?l01P3o0000003o0000o`000?l0c03o06H0o`D0003o00D0IP3o0?l0003o0000o`3<0?l0
IP060?l000<0o`1V00<0o`000?l0IP3o00000`3<0?l0103o0000c03o0<`0o`3<0?l206H0o`040<`0
o`1V0?l0IP3o0?l0c0@0o`000P3o0<`30?l0000306H0o`000?l0IP3o00<0003o0P3o00020<`0o`03
0000o`00I_l0003o0080c03o0`00I_l206H0o`8006Ko3`00c?l01000I_l0003o0000o`000?l3003<
o`80c03o0P00I_l01P000?l0o`000?l0003o0000IP3o0?l0c08006Ko00<0c03o001Vo`1V0?l00P3o
00000`3o0<`0003o06H0o`0206H0o`030<`0o`3o0000o`1V0080o`3<0P000?l01P1V0?l0003o0000
o`000?l0o`3<0<`0o`80003o00<0IP3o0?l0c03o0<`00P3o000206H0o`@0o`3<1@3o00000`3<0?l0
IP3o06H0o`020000o`03001Vo`000?l0c03o008006Ko00<0o`3<0000o`000?l00`00I_l0101V0?l0
o`000<`0o`3<0?l2001Vo`060000o`1V0?l0IP3o0?l0003o06H0o`000P1V0?l00`000?l0o`1V0000
o`02001Vo`030?l0c01V0?l0003o0080o`0000<0IP3o003<o`00c?l00P3o0<`00`1V0?l0003o06H0
o`020?l000030000o`1V0?l0003o0080o`1V00<0o`3<0<`0o`3oool00`3oool200000040oooo000C
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool01`3<0?l0o`3<0?l0
IP3o06H0003o06H0o`000?l00P3o00000`1V0?l0003o06H0o`020?l0c0800<co00H0IP3o0?l0003o
0000003o06H0o`3o0<`2001Vo`030000o`3o06H0003o0080IP3o00<0o`000?l0IP3o00000P1V0?l0
0`000?l006Ko001Vo`020<`0o`030?l0001V0?l006Ko008006Ko0P000?l01P3o0<`006Ko001Vo`3<
0?l0003o001Vo`80003o0P1V0?l00`3<0?l0o`000?l000030?l000@0o`3<0P1V0?l20?l00080o`3<
00D0IP3o0000o`000?l0c03o0?l0c0030000o`0306H0o`000?l0003o0080o`3<00<0o`1V0?l0003<
0?l00`1V0?l01`000?l0o`3<0?l0003o0000IP3o001Vo`3<0?l00P00I_l00`3o0<`0IP3o0?l00002
0?l000030000o`00I_l006Ko0080c03o0`00c?l30000o`03001Vo`00c?l00<co00d00<co0P00I_l2
06H0o`<006Ko0P3<0?l00`000?l006Ko0000o`020<`0o`80o`000`000?l00`1V0?l0003o06H0o`03
0?l00080o`3<103o0000103o0<`0IP3o06H0o`3<0?l206H0o`<0c03o00L0o`000<`0o`3<0?l0c03o
0?l0003o06H0o`0000<0o`1V1P3o00001@3o06H0o`3<0?l0003o0000IP3o00D0003o00<0IP3o0<`0
o`000?l00P000?l0103o0000IP3o06H0o`1V0?l20<`0o`030?l0003<0?l0c03o0080IP3o0`3o0000
0`3o06H0o`000?l0c0030<`0o`040?l0IP3o0<`0c03o0<`0o`80o`000`3o0<`80?l00080o`3<0`3o
00020?l0IP80o`001@3oool100000040oooo000C0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool01`00I_l0c03o0000o`000?l00<co001Vo`000?l00P3<0?l00`000?l0
0<co003oc002003<o`800?o<00<0o`3<003oc000ol`00P00c?l00`00ol`00<co003<o`02003<o`06
001Vo`3<0?l0c03o0?l0001V0?l006Ko0P00c?l00`000?l00<co003<o`020000o`030?l000000?l0
0<co00<00<co00D0003o003<o`00c?l00<co0000o`02001Vo`<0003o00P0IP3o0?l0003o06H0o`1V
0?l0c03o0000c03o0?l0c080003o00<0IP3o0000o`1V0?l00P3o00000`3<0?l0IP3o001Vo`03001V
o`070000o`3o0000c03o0<`0o`000?l006Ko06H0o`020<`0o`030?l0003o06H0003o0080003o00<0
IP3o001Vo`00I_l00P1V0?l00`00I_l00<co001Vo`02003<o`03001Vo`1V0?l0o`000080o`1V00<0
003o001Vo`00c?l01@00c?l20000o`030<`0o`1V0?l00<co00h00<co0P00I_l20<`0o`03001Vo`1V
0?l006Ko00<0IP3o00L0003o06H0o`3o0<`0o`3<0?l0003o0<`0IP3o0080c03o00<0o`3<0<`0o`3o
0<`02@3o00050<`0o`030?l0IP3o0000o`0000L0o`000`3o0<`20?l000<0o`3<00@0IP3o0?l0IP3<
0?l0IP3o0P000?l00`3o0000003o0000o`040000o`060?l0c01V0?l0IP3o0<`0o`3o0000o`1V103o
00001P3o06H0o`000?l0003o0000o`1V0?l00080o`1V00<0c03o0?l0003<0?l00P3<0?l20?l00006
0?l0c03o06H0o`1V0<`0o`1V0?l0o`1V0P1V0?l00`3o0<`0003o0000o`0206H0o`03001Vo`1V0?l0
IP3o0080o`0000<0IP3o0000o`000?l00P000?l00`3o0000003o0?ooo`040?ooo`4000000@3oool0
01@0oooo0P0000050?ooo`030000003oool0oooo0080oooo00L006Ko0<`0o`000?l0003o003<o`00
I_l0003o0080c03o00<0003o003<o`00ol`00P00c?l2003oc0030?l0c000ol`00?o<00800<co00<0
0?o<003<o`00c?l00P00c?l01P00I_l0c03o0<`0o`3o0000IP3o001Vo`800<co00<0003o003<o`00
c?l00P000?l00`3o0000003o003<o`03003<o`050000o`00c?l00<co003<o`000?l00P00I_l30000
o`0806H0o`3o0000o`1V0?l0IP3o0<`0o`000<`0o`3o0<`20000o`0306H0o`000?l0IP3o0080o`00
00<0c03o06H0o`00I_l00`00I_l01`000?l0o`000<`0o`3<0?l0003o001Vo`1V0?l00P3<0?l00`3o
0000o`1V0000o`020000o`0306H0o`00I_l006Ko0080IP3o00<006Ko003<o`00I_l00P00c?l00`00
I_l0IP3o0?l000020?l0IP030000o`00I_l00<co00D00<co0P000?l00`3<0?l0IP3o003<o`0>003<
o`8006Ko0P3<0?l00`00I_l0IP3o001Vo`0306H0o`070000o`1V0?l0o`3<0?l0c03o0000o`3<06H0
o`020<`0o`030?l0c03<0?l0o`3<00T0o`001@3<0?l00`3o06H0o`000?l000070?l000<0o`3<0P3o
00030?l0c00406H0o`3o06H0c03o06H0o`80003o00<0o`000000o`000?l010000?l01P3o0<`0IP3o
06H0o`3<0?l0o`000?l0IP@0o`0000H0o`1V0?l0003o0000o`000?l0IP3o00020?l0IP030<`0o`3o
0000c03o0080c03o0P3o00001P3o0<`0o`1V0?l0IP3<0?l0IP3o0?l0IP80IP3o00<0o`3<0000o`00
0?l00P1V0?l00`00I_l0IP3o06H0o`020?l0000306H0o`000?l0003o0080003o00<0o`000000o`3o
ool0103oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo00@006Ko003<o`00I_l0
06Ko0P00ol`01P00c?l0003o0000o`00I_l00?o<003oIP<00?o<1000ofH00`00c?l00?o<003oIP02
001Vo`03003oc000c?l0003o0080c03o00<0IP3o0?l00000c?l00P00ol`00`3o00000?o<003<o`02
003<o`030000o`00c?l00<co00800?o<00<00<co001Vo`00c?l01000c?l010000?l0o`1V0?l0IP3<
0?l20?l0c080c03o00<0o`00001Vo`000?l00`1V0?l3001Vo`<0o`0000<006Ko003<o`00c?l00P00
c?l01`3o06H00<co001Vo`00I_l00<co001Vo`000?l00P3<0?l00`3o0000o`3<0000o`03001Vo`80
0<co0P3<0?l00`00I_l00<co003<o`02003<o`030000o`00I_l0c03o0080c03o0P000?l01000c?l0
0?o<003oc000ol`2003<o`8006Ko00<0o`00001Vo`00I_l03P00c?l2001Vo`<0IP3o00@0o`3<0000
o`000?l0003o0P3<0?l0103o06H0o`000?l0003o00020?l0c0D0o`000P3o06H00`3o0000o`1V0<`0
o`020?l0IP030?l0c03<0?l0o`000080c03o00<0o`3<0?l0003o00000P3o00020<`0o`060?l0001V
0?l0IP3o06H0o`000?l0IP3o0P3o0<`00`3o06H0IP3o0000o`0206H0o`040000o`1V0?l0003o0000
o`8006Ko00<0c03o0000o`000?l00`000?l00`1V0?l0o`3<0?l000060?l000030?l0IP3<0?l0o`3<
0080o`0000<0IP3o0<`0o`000?l00P3o00000`00I_l0o`000000o`020<`0o`030?l000000?l006Ko
0080o`1V0P00I_l0103o0<`00<co003<o`00c?l2003oc0800<co00<00?o<003<o`1V0?l00P3<0?l0
0`000?l00<co001Vo`02003<o`03001Vo`00c?l0oooo00@0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`020?ooo`06003<o`00ol`0c03o0<`0o`00ol`00?mV0`00c?l00`00ol`00?mV003o
IP02003oc003003oIP00o`000?l000800?mV00<0c03o003oIP00ofH00`00ofH01P00ol`00<co0?l0
IP3o06H0o`3<003<o`<00?o<0P00c?l3003oc003001Vo`00ol`00?o<00800?o<0P00I_l3003oc080
0<co00H006Ko0000o`000?l0c03o0?l0003o0<`20000o`8006Ko00<00<co0000o`00c?l00`00c?l0
0`1V0?l0003o0000o`02001Vo`06003<o`00ol`00?o<003<o`00I_l00<co0P00ol`00`00c?l006Ko
0000o`040?l000030000o`00I_l006Ko00H00<co0P00ol`4003<o`<0003o00<00<co001Vo`00c?l0
1000ol`01000c?l006Ko001Vo`00I_l2003<o`8006Ko2@00c?l4001Vo`060<`0o`1V0?l0IP3o0?l0
003<0?l0IP3o0P3<0?l60?l000030?l0IP3o0000o`0000<0o`000`3<0?l00`3o0000IP3o06H0o`02
06H0o`030000o`3o0000IP3o0080o`3<00<0o`1V0?l0003<0?l00P1V0?l00`000?l0IP3o0?l00003
0000o`07001Vo`1V0?l0c03o0<`0o`3o0<`0c03o001Vo`020<`0o`@006Ko0P000?l00`3<0?l006Ko
001Vo`030000o`070<`0o`3o0000o`1V0?l0IP3<0?l0IP3o0?l000030000o`07001Vo`3<0?l0o`00
0?l000000?l006Ko003<o`02001Vo`800<co00H006Ko0?l0003o0000c03o001Vo`000?l2001Vo`03
003oc000c?l0o`3<00<00?o<0P00ofH2001Vo`800?o<00@0IP3o0?l0IP3o06H006Ko1000ol`00`00
c?l00?o<0?ooo`040?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool2003oIP80
0<co00<00?o<003oIP00ofH00P00ofH00`00ol`00?mV003o0002003o0003003oIP00o`000?l00080
0?mV00<006Ko003oIP00o`000P00o`000`00ofH0IP3o003oc0020<`0o`03003<o`3o00000?o<0080
0?mV00<00?o<003oIP00ofH00`00ol`2003oIP800?o<0P000?l3003oc003003<o`000?l0o`3<0080
IP3o0P3o00000`1V0?l006Ko001Vo`03003<o`03001Vo`00c?l00<co00<00?o<0`00c?l4003oc003
0000o`3o00000?o<00800?o<00<00<co001Vo`00I_l00P1V0?l00`3o0000IP3o001Vo`0206H0o`03
003<o`00ol`00?o<00800<co00<006Ko003oc000ol`00P00c?l2003oc0030000o`00c?l00<co00L0
0?o<00@00<co06H0o`1V0?l0003o0P00c?l4003oc0800<co0P00I_l00`000?l0IP3o0000o`04001V
o`030000o`1V0?l0IP3o0080o`0000<0o`1V0?l0003o00000P3o00000`3o0<`0o`1V0?l0IP020?l0
c0030?l0003<0?l0c03o0080IP3o00<0003o0?l0003o00000P3<0?l01P00I_l0003o0000o`00I_l0
003o06H0o`80c03o00<0o`000<`0o`000?l00`000?l00`00I_l0IP3o003<o`03003<o`03001Vo`3o
0<`0o`3<0080c03o00@00<co001Vo`00I_l00<co0P00I_l3003<o`<006Ko0`1V0?l01@3o0000o`3<
0<`0o`3<0?l0o`3<00@006Ko0P00c?l30?l0IP03001Vo`00ol`00?o<00800<co00<00?o<001Vo`3o
00000P3<0?l00`1V0?l006Ko003oc00206H0o`03003oc000ofH00?o<00D00?mV0P3o0<`3003oIP80
c03o0P00ol`00`00ofH00?o<003oc002003oc0D0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`020?ooo`05003oc000ofH00?mV003oIP00ol`00P00o`02003oIP03003oc000ofH00?l00080
0?l000<00?mV003o0000o`000P00c?l00`1V0?l00?l0003o0002003o0003001Vo`00ofH00?o<0080
o`000P00ol`010000?l00?mV003oIP00o`02003oIP80003o00<00<co003oIP00ofH00P00ofH00`00
ol`00?mV003oc004003<o`03001Vo`000?l0003o0080o`3<00@0003o0?l0c03o0<`006Ko0P00ol`0
0`00c?l0003o0000o`03003oc0800<co00<006Ko003oc000ofH00P00ofH6003oc007003<o`00I_l0
IP3o06H0o`3o0000IP3o001Vo`03003<o`@00?o<00<00<co003oc000ofH01000ol`00`000?l00<co
003<o`06003oc006003<o`000?l0o`000?l00000I_l00<co1P00ol`4003<o`8006Ko0P3o00020000
o`0406H0o`3<0?l0c03o0?l0IP80o`000P3o06H00`3<0?l0o`1V06H0o`020<`0o`0306H0o`3o0<`0
o`000080IP3o00<0003o001Vo`1V0?l00P00I_l00`000?l006Ko003<o`020000o`03001Vo`000?l0
003o0080c03o00<0o`0006H0o`000?l00P00I_l00`3o0<`00<co0000o`02001Vo`03003oc000c?l0
IP3o008006Ko00<0IP3o003<o`00c?l00`00ol`00`00I_l00<co003<o`02001Vo`800<co00@006Ko
0000o`000?l0IP3o0P3o000206H0o`03001Vo`00c?l00<co0080c03o0P00ol`00`00c?l006Ko001V
o`02003oc003001Vo`00c?l00<co00800?o<00H00<co0?l0c03o0<`0o`00003<o`00ol`2003oIP03
003oc000ofH00?o<00800?mV0`00o`02003oIP800?l000<00?mV0<`0o`3<0?l00`00ofH2003oc003
0?l0IP00ofH0oooo00@0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`05003o
c000ofH00?mV003oIP00ol`00P00o`02003oIP03003oc000ofH00?l000800?l000<00?mV003o0000
o`000P00c?l00`1V0?l00?l0003o0002003o0003001Vo`00ofH00?o<0080o`000P00ol`010000?l0
0?mV003oIP00o`02003oIP80003o00<00<co003oIP00ofH00P00ofH00`00ol`00?mV003oc004003<
o`03001Vo`000?l0003o0080o`3<00@0003o0?l0c03o0<`006Ko0P00ol`00`00c?l0003o0000o`03
003oc0800<co00<006Ko003oc000ofH00P00ofH6003oc007003<o`00I_l0IP3o06H0o`3o0000IP3o
001Vo`03003<o`@00?o<00<00<co003oc000ofH01000ol`00`000?l00<co003<o`06003oc006003<
o`000?l0o`000?l00000I_l00<co1P00ol`4003<o`8006Ko0P3o00020000o`0406H0o`3<0?l0c03o
0?l0IP80o`000P3o06H00`3<0?l0o`1V06H0o`020<`0o`0306H0o`3o0<`0o`000080IP3o00<0003o
001Vo`1V0?l00P00I_l00`000?l006Ko003<o`020000o`03001Vo`000?l0003o0080c03o00<0o`00
06H0o`000?l00P00I_l00`3o0<`00<co0000o`02001Vo`03003oc000c?l0IP3o008006Ko00<0IP3o
003<o`00c?l00`00ol`00`00I_l00<co003<o`02001Vo`800<co00@006Ko0000o`000?l0IP3o0P3o
000206H0o`03001Vo`00c?l00<co0080c03o0P00ol`00`00c?l006Ko001Vo`02003oc003001Vo`00
c?l00<co00800?o<00H00<co0?l0c03o0<`0o`00003<o`00ol`2003oIP03003oc000ofH00?o<0080
0?mV0`00o`02003oIP800?l000<00?mV0<`0o`3<0?l00`00ofH2003oc0030?l0IP00ofH0oooo00@0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`05003oIP00o`000?l0003o0000
ofH00P00o`02003oIP030?l00000c?l00?l000800?l00P1Vo`03003o00800?mV1@00o`000`00ofH0
0<co003<o`02003oIP03001Vo`00o`000?l000800?l000D00?mV003oc000ol`00?mV001Vo`06003o
IP<00?o<00L00<co001Vo`3<0?l0c03o0?l0003o0<`0003o00@00<co0P00ol`206H0o`<00?mV0P00
ol`00`00c?l00?o<003oIP07003oIP03003oc000c?l0003o00<0o`0000<0o`1V001Vo`00ol`00P00
ol`4003oIP03003<o`00ofH00?mV00800?mV0P00ol`0101V0?l00<co003<o`00ol`4003oIP800?o<
00D00<co001Vo`00I_l0IP3o003<o`06003oc0D00<co00H006Ko0000o`000?l0003o0?l0c03o0002
0?l0c0030?l0003o06H0o`000080o`1V00<0c03o0000o`3o00000P00I_l206H0o`060?l0001V0?l0
IP3o001Vo`00c?l0003o0P00c?l00`000?l006Ko003<o`03003<o`03001Vo`000?l0o`0000<0o`00
00H0003o003<o`00c?l00<co003oc000c?l2001Vo`<00?o<0P00c?l00`000?l00?o<003<o`03003o
c0030?l00000c?l00?o<00800?o<00<00<co001Vo`000?l00P000?l00`3o0<`0o`000<`0o`02001V
o`800<co00@00?o<0000o`000?l00<co0P00ol`20000o`03003oc000ofH00?mV00800?o<00<00?mV
003oc03<0?l00P00I_l00`3<0?l00?o<0?l00002003oc0800?l000<00?o<003<o`00c?l01`00o`00
1000ofH00?o<003oc000ofH2003o00800?o<0P00ofH50?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool00P3oool00`00ofH00?l0003o0006003o0003003oIP00o`000?l000D0I_l00`00o`04
06Ko00800?l000<00?mV003oc000ol`01`00o`001000ofH0o`000?l00000ol`4003o00800?mV00<0
0?o<003<o`00c?l00P00c?l01P1V0?l0c03o0<`0o`3o0000o`1V0000o`80c03o0P00ol`7003oIP80
0?o<00<0o`00003<o`00ofH01`00ofH00`00ol`006Ko003<o`02001Vo`030?l0IP00I_l00<co0080
003o00<00?o<003oIP00ofH00P00ofH00`00I_l00?mV003oIP03003oIP03003oc01V0?l00?o<0080
0?o<1@00ofH00`00ol`006Ko003oc002003oc003003<o`00ol`00?o<00@00?o<1@00c?l3001Vo`03
0000o`1V0?l0o`000080o`0000<0o`3<06H0o`3<0?l00P3o0<`00`1V0?l006Ko0?l00003001Vo`06
0000o`3o0000IP3o06H0o`3<0?l00<co0`00ol`2003<o`<00?o<00<0003o06H0o`00I_l00P1V0?l0
0`3o0000IP3o001Vo`020?l0c003003<o`00ol`0o`0000800<co00<00?o<003oIP00ol`00P00c?l0
0`3o00000?o<003oIP02003oIP03003oc000I_l006Ko00<00?o<00<006Ko0000o`3o0<`00P000?l0
0`3<0?l0o`000?l000020000o`030?l0c000ol`00?o<00800?o<00<0003o003oIP00ofH00P00I_l0
0`00c?l00?mV003oIP03003oIP05001Vo`00ofH00?o<003oc000I_l00P00ofH2003oc0800?l000<0
0<co0?l0003o00000P00o`000`1Vo`000?l0003o0002003o0004003oc000c?l00<co003oc0800?l0
0P00ofH2003o00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`040?l00000
ol`00?l0003o00<0I_l00P00o`000`00ofH00?o<003o000506Ko00800?l01P1Vo`001000ofH00?o<
001Vo`00I_l6003o0005003oc000ofH00<co003<o`00ol`01000o`000`00ofH00?o<001Vo`02001V
o`800<co00H0c03o0?l0c03o0<`0o`000?l0c03<0?l2001Vo`03003<o`00ol`00?mV00H00?mV0P00
ol`00`1V0?l00?mV003oIP04003o0005003oc000I_l006Ko001Vo`00ol`00`00c?l00`000?l00<co
003oc002003oc003001Vo`00ofH00?mV00800?mV00<00<co003oIP00ofH00P00ofH2003<o`0306H0
o`00ol`00?o<00H00?mV00@00?o<003<o`00c?l00<co1`00ol`6003<o`06001Vo`000?l0003o0000
o`3<0?l0o`000P3o0<`00`1V0?l0o`000?l000020000o`03001Vo`00c?l006Ko00800<co0P00I_l0
1@000?l006Ko001Vo`00c?l0003o00<00?o<0P00I_l3003oc0030000o`00c?l006Ko0080003o00<0
o`0006H0o`000?l00`00ol`2003oIP8006Ko0`00ofH2003oc003001Vo`00ol`00?mV00<00?mV00<0
0?o<003oIP00ofH00`00ol`2003<o`80003o00<0c03o0?l0001V0?l00`00c?l01@00ol`00?mV003o
IP00ofH00?o<00800?mV0P00ol`00`00c?l00?mV003o0003003o0006003<o`00o`000?mV003oIP3<
0?l00?mV1P00o`02003oIP03003o001Vo`00I_l000<0I_l000@00?l0003oIP00ofH00?mV1`00o`05
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool00`00o`000?o<06Ko000406Ko
00800?l00P00ol`00`00ofH0I_l006Ko000306Ko00800?l01P1Vo`001000o`00003o003oIP00ofH2
003o00@0I_l00P00o`02003oIPD00?l000<00?mV003oc000c?l00`00ol`01`00c?l0IP3o0<`0o`3<
0?l0o`000?l0c000I_l00P00c?l01000I_l00<co003oc000ofH4003o00<00?mV00<00<co003oIP00
ofH01000o`000`00ofH00<co003<o`02003oIP05003oc000c?l00<co001Vo`00c?l00`00ofH00`3<
0?l00?mV003oIP04003o0006003oIP00ol`00?o<003oc000c?l006Ko0P1V0?l6003oIP800?o<1000
ofH4003oc003003<o`00I_l006Ko0080003o0`00I_l20000o`030?l0003o06H0c03o0080IP3o00<0
o`1V001Vo`00I_l00`000?l2003<o`800?o<0`00c?l2001Vo``00?o<00H00<co0?l0003o0000o`00
0<`0o`00I_l2003<o`03003oc000ofH00?mV00D00?mV0P00c?l00`000?l00?o<003oIP06003oIP<0
0?o<00L00<co0?l0c01V0?l0IP3o0?l0c03o0000c03o008006Ko00<00<co003oc000ofH00`00ofH2
003o00800?mV00<006Ko003oIP00o`001`00o`000`00ol`00?mV003o0002003o00<0I_l00P00ol`0
0`00o`00I_l006Ko000306Ko0005003o0000ofH00?mV003oIP00o`00101Vo`02003o00D0oooo0@00
00010?ooo`006`3oool2000000<0oooo00<00?l0003oc01Vo`00101Vo`02003o00800?o<00<00?mV
06Ko001Vo`000`1Vo`02003o00H0I_l000@00?l00000o`00ofH00?mV0P00o`0406Ko00800?l00P00
ofH5003o0003003oIP00ol`00<co00<00?o<00L00<co06H0o`3<0?l0c03o0?l0003o0<`006Ko0080
0<co00@006Ko003<o`00ol`00?mV1000o`03003oIP03003<o`00ofH00?mV00@00?l000<00?mV003<
o`00c?l00P00ofH01@00ol`00<co003<o`00I_l00<co00<00?mV00<0c03o003oIP00ofH01000o`00
1P00ofH00?o<003oc000ol`00<co001Vo`80IP3o1P00ofH2003oc0@00?mV1000ol`00`00c?l006Ko
001Vo`020000o`<006Ko0P000?l00`3o0000o`1V0<`0o`0206H0o`030?l0IP00I_l006Ko00<0003o
0P00c?l2003oc0<00<co0P00I_l<003oc006003<o`3o0000o`000?l0003<0?l006Ko0P00c?l00`00
ol`00?mV003oIP05003oIP800<co00<0003o003oc000ofH01P00ofH3003oc007003<o`3o0<`0IP3o
06H0o`3o0<`0o`000<`0o`02001Vo`03003<o`00ol`00?mV00<00?mV0P00o`02003oIP03001Vo`00
ofH00?l000L00?l000<00?o<003oIP00o`000P00o`0306Ko00800?o<00<00?l006Ko001Vo`000`1V
o`001@00o`000?mV003oIP00ofH00?l000@0I_l00P00o`040?ooo`8000000@3oool001/0oooo00<0
00000?ooo`3oool00P3oool00`1Vo`000?l006Ko000406Ko00800?o<00<00?l0003oc000o`000P00
o`0:06Ko00800?l000@00<co003oc000ol`00?l01P1Vo`000`00ofH00?o<003oc007003o00<00?mV
00<00?o<001Vo`1V0?l00`3o00020000o`800?o<0P00c?l00`1V0?l00?mV003o0004003o00800?mV
00<006Ko003oc000ofH01@00o`02003oIP800?l00`00ofH00`00ol`00?mV003oIP03003oIP03003<
o`00o`000?l000@00?l00`00ofH2003oc0800?mV00<00?o<003oIP00ofH00`00ofH00`00ol`00?mV
003oIP04003oIP800<co00@00?o<003<o`00c?l00<co0P1V0?l00`000?l0o`1V0000o`020?l0c003
0?l0IP3o0000o`3<0080c03o00<006Ko0?l0c000c?l00P00c?l00`1V0?l00<co003oc002003oc003
003<o`00ol`00?o<0080o`0000<00<co003oc000ofH00P00ofH2003oc0<00?mV00<00?o<003<o`00
I_l00P00I_l00`3o0<`006Ko003oc0020?l0c003003<o`00ol`00?mV00<00?l00P00ofH3003oc0P0
0?mV0P00ol`00`00c?l006Ko001Vo`020?l000030?l0IP3o0<`0IP3o008006Ko00<00<co001Vo`00
c?l00P3o06H3003o00800?mV00<00<co003oc000ol`01@00o`02003oIP03003oc000ofH00?l000d0
I_l000D00?l0003<o`000?l0003o003o000506Ko0003003oc03oool0oooo00<0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`020?ooo`80I_l00P00o`0606Ko0004003oIP1Vo`00I_l006Ko
00H0c?l0101Vo`000`00ofH00?o<0?l00002003oIP03003o001Vo`00I_l000@0I_l000<00?o<06Ko
001Vo`000`1Vo`04003o0006003oIP00ol`00?o<003<o`3o0<`006Ko0P3<0?l00`3o0<`0003o003<
o`02003oc0<00?mV00<00?o<003o0000o`000`00o`020?l0c003003<o`00ofH00?o<00@00?l000<0
0?o<003o0000o`000P00o`001@00ofH006Ko001Vo`1V0?l00?mV00@00?l000<00?mV003o0000o`00
1000o`02003oIP03003oc000I_l00?o<00@00?mV00<00?l0003oIP00ofH02000ofH5003oc0<00<co
0P00I_l01P000?l0o`000?l0003o0000o`1V06H0o`8006Ko1P00c?l00`000?l00<co003oc003003o
c004001Vo`00c?l00<co003oc0T00?mV0P00I_l01P00ol`006Ko001Vo`00I_l0o`00003oc0800?mV
00<00<co003oc000ofH01000o`001@00ofH00?o<003oc000I_l00?mV00D00?l000L00?o<003<o`00
I_l006Ko003<o`00ol`00<co008006Ko00<0o`1V0?l0c0000?l00P00c?l2003oc0030<`0o`00ol`0
0?o<00<00?l00P00ofH00`00o`000?mV003o000506Ko00<00?l000<00?mV003o001Vo`001P1Vo`00
0`00o`00I_l006Ko000206Ko0003003<o`00ofH0003o00800?l000<00?mV06Ko001Vo`000`1Vo`00
0`00o`00oooo0?ooo`030?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool406Ko
00<0c?l00P1Vo`000`00o`00o`00003o00090<co00<0I_l000<00?l0003oIP00c?l00P00ofH00`00
o`00I_l006Ko000:06Ko00@00?l00`00ofH00`00c?l0IP3o06H0o`040?l00004003<o`000?l0003o
003oIPL00?l000@00?mV003o0000o`000?o<2`00o`03003oc003003oIP00o`000?l000<00?l000<0
0?o<003o0000o`001000o`02003oIP03003oc01V0?l006Ko00<00?mV1@00o`07003oIPD00?o<0`00
c?l00`000?l006Ko0000o`020?l0c0030?l0003o0<`0o`3<0080003o00<006Ko003<o`00ol`00P00
ol`00`00c?l006Ko003oc004003oIP05003oc000I_l006Ko001Vo`00ol`01000ofH01`00o`000?mV
0000o`000?l00<co003oc000ofH00P00ol`2003<o`050<`0o`00ofH00?mV003oIP00ol`01@00o`00
1@00ofH006Ko001Vo`1V0?l00?mV00D00?l000<00?mV0<`0o`00ol`00`00ol`00`00c?l0o`000?l0
00020?l000040000o`1V0?l0IP3o003oc0D00?mV1@00o`000`00ofH00?l006Ko000406Ko00<00?o<
00@0c03o003o0000o`000?l01@1Vo`030<co00800?mV0P1Vo`000`00ol`0I_l006Ko000506Ko0003
003o001Vo`00oooo00@0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`80I_l0
1`3<o`000`1Vo`000?mV06Ko00090<co00@0I_l01000o`000`1Vo`00IP3o06Ko000:06Ko00800?l0
00<00<co003oIP00ofH00`3<0?l01@000?l0o`3<0?l0IP3o06H0IP3o0080c03o0P00ol`00`00ofH0
0?l0003o0003003o00<0I_l00P00o`02003oc003003o001Vo`00I_l000<0I_l01000o`001@00c?l0
06Ko001Vo`00ol`00?mV00X00?l00`3o0<`00`3o000006Ko003oIP02003oIPL00?l01@00ofH00`00
ol`00<co003<o`03003oc006003<o`000?l0003o001Vo`000?l0c03o0`3o00000`1V0?l006Ko0000
o`020000o`0306H0o`00ol`00?o<00<00?o<00<00<co003oIP00ofH00`00ofH2003<o`030?l00000
ol`00?mV00800?mV0`00o`02003oIP030?l0IP00ofH00?mV00<00?mV00<00?o<003oIP00o`000`00
o`000`00ofH00?l0003o0002003o0003001Vo`00ofH00?mV00800?o<1@00o`000`3o00000?mV003o
IP02003oIP800?o<0P00c?l00`1V0?l0o`000000o`020000o`03003<o`00ol`00?l000@00?l0101V
o`02003o00D0I_l00P00o`000`00ofH0c03o003oc002003oIP03003oc01Vo`00I_l000L0c?l000<0
I_l0003oIP3o06H00`1Vo`040<co0080I_l01@3oool100000040oooo000K0?ooo`030000003oool0
oooo0080oooo0P1Vo`070<co000306Ko0000ofH0I_l000T0c?l0101Vo`04003o000306Ko001V0?l0
I_l000X0I_l00P00o`000`00c?l00?mV003oIP030<`0o`050000o`3o0<`0o`1V0?l0IP1V0?l00P3<
0?l2003oc003003oIP00o`000?l000<00?l00`1Vo`02003o00800?o<00<00?l006Ko001Vo`000`1V
o`04003o0005003<o`00I_l006Ko003oc000ofH02P00o`030?l0c0030?l00000I_l00?mV00800?mV
1`00o`05003oIP03003oc000c?l00<co00<00?o<00H00<co0000o`000?l006Ko0000o`3<0?l30?l0
000306H0o`00I_l0003o0080003o00<0IP3o003oc000ol`00`00ol`00`00c?l00?mV003oIP03003o
IP800<co00<0o`00003oc000ofH00P00ofH3003o00800?mV00<0o`1V003oIP00ofH00`00ofH00`00
ol`00?mV003o0003003o0003003oIP00o`000?l000800?l000<006Ko003oIP00ofH00P00ol`5003o
00030?l00000ofH00?mV00800?mV0P00ol`2003<o`0306H0o`3o0000003o0080003o00<00<co003o
c000o`001000o`0406Ko00800?l01@1Vo`02003o0003003oIP3<0?l00?o<00800?mV00<00?o<06Ko
001Vo`001`3<o`000`1Vo`000?mV0?l0IP0306Ko00@0c?l00P1Vo`050?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool00P3oool00`1Vo`00c?l00<co00070<co0003003oc000o`00c?l000P0
c?l0101Vo`02003o00D0I_l0103<o`0606Ko00<00?l000@0c03o003oc000ofH00?mV0P00ol`01P00
0?l0o`000?l00000I_l00<co003oc0800<co00@00?o<003o0000o`000?l01`1Vo`02003oIPP0I_l0
0P00o`000`00ofH006Ko001Vo`02003oIP@00?l0101Vo`03003o00800?mV00<0c03o003oc03o0<`0
0P00ofH7003o0003003oIP000?l0003o00D00?o<00@0003o003<o`1V0?l00<co0P00I_l00`3o0<`0
c03o0<`0o`020?l0IP030?l0c01V0?l006Ko00<00<co1000ol`7003oIP03003oc000ofH00?mV0080
0?o<00<00?mV003o0000o`001@00o`000`00ofH00?l0003o0002003o0003003oIP00c?l00?mV00P0
0?l000<00?o<003o0000ofH00P00ofH00`00o`000<co003o0002003o0003003oIP00o`000?l00080
0?l000<00?mV06H0o`00I_l00P3<0?l00`1V0?l0o`3<0?l000020?l00003003<o`00ofH00?mV00<0
0?l01P1Vo`000`00o`00I_l006Ko000306Ko0080003o00<00?l0003oc000c?l0101Vo`090<co0004
06Ko0000ofH0I_l006Ko00L0c?l01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080
oooo00<0I_l00<co003<o`001`3<o`000`1Vo`00c?l00<co00080<co00<0I_l000<0IP3o0?l0IP00
o`00101Vo`060<co00<0I_l01000ofH00`00c?l00?l0003o0002003o0003003oIP00ol`0IP3o0080
o`3<00<00<co003oIP00ofH00P3<0?l010000?l00?mV06H0o`00o`0806Ko0003003o001Vo`00I_l0
00H0I_l00`00o`020?l000<00?l0201Vo`02003o00800?mV00<00?o<003o0000ofH00P00ofH7003o
00<00?mV00<00<co001Vo`00c?l00P00c?l00`3o0000o`1V0?l0c0050?l000030?l0c03o0000o`00
0080o`1V0`1V0?l00`00c?l00?o<003oc00<003oIP03003oc01V0?l00?o<00800?mV2P00o`000`00
0?l0o`00003oIP04003o00D0I_l000D00?l0003oIP00ofH00<co003o000406Ko00D00?l000<00?mV
003oc0000?l00P3o0<`00`3<0?l0o`3<001Vo`02001Vo`030?l00000I_l00?mV00800?o<00<00?l0
06Ko001Vo`002@1Vo`001P00ol`0I_l006Ko001Vo`000?l00?l000@0I_l02@3<o`000`1Vo`000?l0
0<co00080<co00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`0306Ko003<
o`00c?l00180c?l00`1Vo`000`00ofH0003o003o000306Ko00T0c?l00P1Vo`001000o`00o`000?l0
0000ofH4003o0003003oc000ofH0IP3o0080003o00<00?o<003<o`00o`000P00o`001000ofH0o`00
003o0000o`0A06Ko0003003o0000ol`00?mV008006Ko0`00o`0906Ko0004003oc000I_l006Ko003o
IP800?l00P00ofH6003o0007003oIP00c?l00?o<003oc03o0000003o001Vo`02003oc0040?l00000
I_l006Ko003<o`8006Ko00<0c03o0?l0c03o00000P3o00000`3o06H0o`000<`0o`03001Vo`800?o<
1@00ofH5003o008006Ko00<0o`000<`0o`00ol`00P00ofH:003o0003003<o`1V0?l00?o<00<00?mV
1`1Vo`02003oIP03003oc01Vo`00I_l000@0I_l01000o`000`00ofH00<co003oc002003<o`03001V
o`3o000006Ko00<00?o<0P00ofH2001Vo`03003o0000ofH0I_l000@0I_l01@3<o`0406Ko0006003o
00000?l00?l0003o0000ol`0I_l02P3<o`000`1Vo`00c?l00<co00070<co00D0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`020?ooo`0306Ko003<o`00c?l00140c?l000@0I_l0003oIP00
ol`00?o<0P00I_l01000o`00I_l006Ko001Vo`090<co0080I_l000@0003o003o0000o`000?l0101V
o`000`00o`000?mV001Vo`020000o`03003oIP00o`000?l000<00?l000<00?mV003oc000o`004@1V
o`02003o0005003oc000I_l006Ko003oc000o`002P1Vo`000`00o`00003o0000o`03003o00800<co
1P00o`001P00ofH00?o<003oc000ol`00?mV0000o`H00?o<00H0IP3o0?l0c03o0<`0003o0<`0o`3o
00020?l0IP0306H0o`000?l006Ko00<006Ko00<0003o003<o`00ol`00`00ol`00`00ofH00?l0003o
0005003o0003003oc000c?l00?o<00@00?l01@1Vo`04003o00800?mV0`00o`0706Ko00<00?l01P1V
o`001@00o`000?mV003oc000ol`00<co00@00?mV00<00<co0?l0IP1V0?l00P00ol`00`00ofH00?l0
003oIP02003o00030?l0c000ofH00<co00800?mV00<0I_l00<co003<o`001@3<o`0206Ko0003003o
0000c?l0c03o00800?mV0P1Vo`0D0<co00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?oo
o`020?ooo`0306Ko003<o`00c?l00140c?l000@0I_l0003oIP00ol`00?o<0P00I_l01000o`00I_l0
06Ko001Vo`090<co0080I_l000@0003o003o0000o`000?l0101Vo`000`00o`000?mV001Vo`020000
o`03003oIP00o`000?l000<00?l000<00?mV003oc000o`004@1Vo`02003o0005003oc000I_l006Ko
003oc000o`002P1Vo`000`00o`00003o0000o`03003o00800<co1P00o`001P00ofH00?o<003oc000
ol`00?mV0000o`H00?o<00H0IP3o0?l0c03o0<`0003o0<`0o`3o00020?l0IP0306H0o`000?l006Ko
00<006Ko00<0003o003<o`00ol`00`00ol`00`00ofH00?l0003o0005003o0003003oc000c?l00?o<
00@00?l01@1Vo`04003o00800?mV0`00o`0706Ko00<00?l01P1Vo`001@00o`000?mV003oc000ol`0
0<co00@00?mV00<00<co0?l0IP1V0?l00P00ol`00`00ofH00?l0003oIP02003o00030?l0c000ofH0
0<co00800?mV00<0I_l00<co003<o`001@3<o`0206Ko0003003o0000c?l0c03o00800?mV0P1Vo`0D
0<co00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`03003oc01Vo`00c?l0
0100c?l000<00?o<06Ko001Vo`000P1Vo`000`00ofH0003o003o00020<`0o`0306Ko003<o`00c?l0
00L0c?l000<0I_l0003oIP00ofH00P1Vo`000`00o`00I_l006Ko000206Ko00030000o`00ol`0003o
0080c03o00<006Ko003o001Vo`000`1Vo`000`00ofH006Ko003oc002003oIP03003o001Vo`00I_l0
00X0I_l00P00o`000`000?l00<co003<o`02003<o`03003oIP00o`00I_l000T0I_l01000o`0606Ko
00<00?l02P00ofH3003oc0<00<co00<0003o0<`0o`3o00000P3o06H00`3<0?l006Ko001Vo`02003<
o`03003oc03o0<`0003o0080o`0000<00<co003oIP00ofH01`00o`02003oIP0406H0o`00o`000?l0
003o00L0I_l00`00o`02003oIP<00?l0401Vo`02003o0080003o00<00<co003o0000o`000P000?l0
0`00ol`0003o001Vo`02003oIP800?l000H0I_l0003o0000o`000?mV0?l00000ofH306Ko00L0c?l0
0`1Vo`001`00o`00c03o003oc000ol`00?l0001Vo`1Vo`004`3<o`050?ooo`4000000@3oool001/0
oooo0P0000030?ooo`04003o0000ol`00?l0003o00D0c?l01`3oc0060<co0080I_l000<00?mV003o
001Vo`000`1Vo`090<co000306Ko001V0?l0I_l000D0I_l00P00ofH2003o000506H0o`00ofH00?mV
003oIP00o`00101Vo`02003oIP03001Vo`1Vo`00I_l00080I_l0203<o`0206Ko00<00?l000<00<co
003oIP00I_l00`00ol`00`00ofH00?l006Ko000806Ko0003003oIP00o`000?l000L0I_l000<00<co
003o0000o`001@00o`05003oIP04003oc03<0?l0IP3o0000o`80IP3o00<0003o06H0o`3o00000P3o
0<`00`000?l006Ko003<o`07003oc003003<o`1V0?l00?mV00T00?l000@00?o<003oIP00ofH00?l0
1`1Vo`02003o0003003oIP00ol`0o`0000800?mV00<00?l006Ko001Vo`003@1Vo`02003o0003003o
c000ofH00?mV00D00?l000<00?o<003<o`00c?l00P00ofH00`00o`00I_l006Ko000206Ko0003003<
o`00o`0006Ko00800?mV2P3<o`000`1Vo`000?l0003oc002003<o`<00?l00P1Vo`0@0<co000306Ko
003oool0oooo0080oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`0506Ko003<
o`00c?l00<co001Vo`000P3<o`0:0?o<00D0c?l00P1Vo`000`00I_l0I_l00<co00020<co000306Ko
003<o`00c?l000L0c?l000<00?mV0<co003<o`00103<o`0406Ko0006003o0000ol`00?l0003o001V
o`000?l0101Vo`000`00o`00I_l00?l0c00306Ko00T0c?l01P1Vo`001000I_l0IP3o003oc000ol`2
003o0003003oIP1Vo`00I_l000L0I_l000<00?l006Ko001Vo`00201Vo`08003o00@00?mV0P00ol`2
003<o`<0003o103o00000`1V0?l0c03o0?l00002001Vo`03003oc000ofH00?mV00<00?mV00@0003o
003oIP00ofH00?mV2000o`02003oc003003oIP1Vo`00I_l000D0I_l00`00o`000`00ol`0o`00003o
IP02003oIP03003o001Vo`00I_l000H0I_l000<0c?l006Ko001Vo`000P1Vo`001000o`000?mV001V
o`00I_l2003o00<0I_l00P00o`000`00ol`0o`3<003<o`02003oIP03003oc01Vo`00I_l000@0I_l0
0`00o`0:0<co00<00?l00P3o0<`00`00ofH0c?l00<co00020<co0003003o003<o`00c?l000L0ol`0
1@3<o`000`1Vo`000?o<0?ooo`040?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3o
ool60<co00d0ol`00`3<o`0206Ko0003003oc03<o`00c?l000<0c?l000<0I_l00<co003<o`00103<
o`0206Ko00P0c?l00`1Vo`02003oIPX0I_l000@00?o<003o0000o`00I_l02P3<o`0506Ko0004003o
0000ofH00?l0003o00<0I_l00P00o`0B06Ko00P00?l000<00?mV003<o`00c?l00P00c?l00`00ol`0
0<co003<o`02001Vo`030000o`3<0?l0o`000080c03o00<0003o001Vo`00c?l00`00ol`4003oIPD0
0?l000<00?mV003o001Vo`001@1Vo`02003<o`03003o001Vo`00I_l000D0I_l00P00o`000`00ofH0
003o001Vo`02003oc0<00?l00P00ofH206Ko00H0c?l0101Vo`001000ofH00?l0003oIP00ofH306Ko
00<00?mV00L00?o<0000o`00o`000?l006Ko0000o`00I_l000@0c?l0101Vo`070<co00<0I_l000D0
c?l006Ko0000o`000?l006Ko00050<co00X0ol`00P3<o`0206Ko0080c?l01@3oool100000040oooo
000K0?ooo`030000003oool0oooo0080oooo1P3<o`0=0?o<00<0c?l00P1Vo`000`00ol`0c?l00<co
00030<co000306Ko003<o`00c?l000@0c?l00P1Vo`080<co00<0I_l00P00ofH:06Ko0004003oc000
o`000?l006Ko00X0c?l01@1Vo`001000o`000?mV003o0000o`0306Ko00800?l04P1Vo`08003o0003
003oIP00c?l00<co00800<co00<00?o<003<o`00c?l00P00I_l00`000?l0c03o0?l000020<`0o`03
0000o`00I_l00<co00<00?o<1000ofH5003o0003003oIP00o`00I_l000D0I_l00P00c?l00`00o`00
I_l006Ko000506Ko00800?l000<00?mV0000o`00I_l00P00ol`3003o00800?mV0P1Vo`060<co00@0
I_l000@00?mV003o0000ofH00?mV0`1Vo`03003oIP07003oc0000?l00?l0003o001Vo`000?l006Ko
00040<co00@0I_l01`3<o`0306Ko00050<co001Vo`000?l0003o001Vo`001@3<o`0:0?o<0080c?l0
0P1Vo`020<co00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`D0c?l03`3o
c0020<co00<00?l000<0I_l00<co003<o`00103<o`020?o<00d0c?l00P1Vo`000`00o`000<co003<
o`02003o0080I_l01@3<o`0206Ko00800?mV2`3<o`0506Ko0004003o0000ofH00?l0003o00L0I_l0
0`3<o`0=06Ko00P00?l00P00ofH2003oc0040000o`00I_l00<co0<`0o`8006Ko00<0IP3o0<`0o`3o
00000P3o00000`000?l006Ko0000o`02003<o`030000o`00ol`00?mV00800?mV1P00o`0906Ko0003
003o001Vo`00I_l000D0I_l01000o`03003oc003003o001Vo`00I_l000<0I_l02@3<o`0206Ko0003
003oc01Vo`00I_l000L0I_l000<00?l006H0o`1Vo`000`1Vo`080<co0003003o003<o`00c?l000D0
c?l00P1Vo`030<co0080I_l000<00?l00<co003<o`000P3<o`0<0?o<00D0c?l01@3oool100000040
oooo000K0?ooo`030000003oool0oooo0080oooo1@3<o`0?0?o<0080c?l00P00o`020<co0003003o
003<o`00c?l000P0ol`02P3<o`0306Ko00800?l00`1Vo`070<co000306Ko0000ol`00?o<00/0c?l0
00L0I_l0003o0000ofH00?mV003o0000ol`0c03o00800?l01@1Vo`070<co00X0I_l00`00o`000`00
ofH00?l0003o0002003o0003003<o`00ofH00?mV00800?o<00@00<co001Vo`000?l0c03o0P000?l0
0`1V0?l0o`000?l000020?l0c080c03o00D006Ko0000o`000?l006Ko003oc003003oIPH00?l02@1V
o`000`00o`00I_l006Ko000406Ko0004003o001Vo`00I_l006Ko00800?l00P00ofH00`00o`00I_l0
06Ko000206Ko00X0c?l00P1Vo`001000o`00I_l006Ko001Vo`020<co0003003o001Vo`00I_l00080
I_l000<00<co003o0000o`000P1Vo`0E0<co0080I_l000<006Ko06Ko0000o`000P3<o`0=0?o<00@0
c?l01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo0P1Vo`030<co00l0ol`0
00@0c?l006Ko001V0?l0IP3o0P3<o`0=0?o<00P0c?l00P00ofH00`00o`000?mV003o000306Ko00P0
c?l00P00ofH;0<co0080I_l00`00ofH01@3o00000?o<003oc000ol`00?l00080I_l02P3<o`0906Ko
00<00?l000<00?mV003oc000ofH00`00ofH4003oc0040000o`3o0000o`3<0?l0IP80o`000P3o0<`3
0?l0IP030?l0003o06H0o`1V008006Ko0P00ol`3003oIPH00?l05@1Vo`001000o`00o`000?l00000
o`0406Ko00/0c?l000<0I_l0003oIP3<o`001@3<o`0306Ko000406H0o`00ol`00?l0003o0080I_l0
2`3<o`070?o<0080c?l000@00?l00<co003<o`000<co0P3<o`0?0?o<00@0c?l01@3oool100000040
oooo000K0?ooo`030000003oool0oooo0080oooo00<00?l00<co003<o`000P3<o`0@0?o<00040<co
001Vo`00I_l00<co00l0ol`01P3<o`0306Ko0003003o003o00000<co00800?l000<0I_l00<co003<
o`001P3<o`0206Ko00/0c?l000L00?l006Ko0000o`000?l0001Vo`3o00000?mV00800?l00P1Vo`0=
0<co00D0I_l01@00o`000`00ofH006Ko0?l00003003<o`0706H0o`00ol`00?o<003oc000I_l0003o
0?l000030?l0c0<0o`000P1V0?l00`3<0?l0IP3o0?l000020?l0IP0306H0o`00c?l00?o<00800?o<
1@00ofH00`00o`00I_l006Ko000706Ko00L0c?l01@1Vo`001P00o`0006Ko001Vo`00ofH006Ko003o
0080I_l02`3<o`0206Ko00P0c?l00P1Vo`03003o0080I_l02@3<o`0;0?o<00<0c?l000<00?l0003<
o`3<o`004@3oc0000`3<o`00I_l00?ooo`040?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool00P3oool00`00o`00c?l00<co00020<co0100ol`000@0c?l006Ko001Vo`00c?l03`3oc0060<co
00<0I_l000<00?l00?l00000c?l00P00o`000`1Vo`00c?l00<co00060<co0080I_l02`3<o`001`00
o`00I_l0003o0000o`0006Ko0?l00000ofH00P00o`0206Ko00d0c?l01@1Vo`05003o0003003oIP00
I_l0o`0000<00<co00L0IP3o003oc000ol`00?o<001Vo`000?l0o`0000<0o`3<0`3o000206H0o`03
0<`0o`1V0?l0o`000080o`1V00<0IP3o003<o`00ol`00P00ol`5003oIP03003o001Vo`00I_l000L0
I_l01`3<o`0506Ko0006003o0000I_l006Ko003oIP00I_l00?l00P1Vo`0;0<co0080I_l0203<o`02
06Ko00<00?l00P1Vo`090<co00/0ol`00`3<o`000`00o`000<co0<co000A0?o<00030<co001Vo`00
oooo00@0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`0306Ko003<o`00c?l0
0080c?l0403oc0040<co00l0ol`0103<o`000`1Vo`000?mV003o0002003o0003003oIP000?l00?l0
00<0I_l0503<o`000`1Vo`000?l0001Vo`020000o`0306H0o`000?l00?l000@0I_l03@3<o`0206Ko
0006003o0000ol`00?o<003oIP00o`000<co0`00ofH01P3o000006Ko0?l0003o00000?mV0?l000<0
0?mV00@00?o<06H0o`00I_l0IP3o0P000?l00`3<0?l0o`000<`0o`020000o`<006Ko0P00c?l00`00
I_l00?o<001Vo`02003<o`<00?o<1000o`0606Ko00X0c?l00`1Vo`001P00o`000?o<06H0o`1V0?l0
0?o<003o00<0I_l02`3<o`000`00o`00c?l00<co00070<co0080I_l000D00?l0003<o`00c?l00?o<
06Ko00080<co00d0ol`01@3<o`0A0?o<0080c?l01@3oool100000040oooo000K0?ooo`030000003o
ool0oooo0080oooo00<0I_l00<co003<o`000P3<o`0@0?o<000306Ko003<o`00c?l00140ol`0103<
o`02003oIP800?l000<00?mV003<o`00ol`00P00ofH00`1Vo`00c?l00<co000@0<co00D0I_l00P00
o`000`000?l00<co003oc004003o00d0c?l00`1Vo`02003o0003001Vo`00ol`006Ko0080o`0000<0
0<co003oIP1V0?l01`00ofH0103o06H00<co003<o`00c?l20000o`0306H0o`3o0000o`3<0080003o
1@00I_l2003oIP06003<o`00ofH00?mV003<o`3o06H006Ko0P00ofH6003o0080I_l0303<o`0206Ko
0005003o0000ofH00?mV06H0o`00c?l00`00o`000`1Vo`00c?l00<co00080<co000306Ko003<o`00
c?l000L0c?l00P1Vo`001000o`00c03o0<`0o`3o000406Ko00D0c?l03`3oc0000`00o`00I_l00<co
000?0?o<00@0c?l01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo00@00<co
003oIP1Vo`00I_l00P3<o`0?0?o<0003003oc03oc000ol`00140ol`01@3<o`0306Ko0003003<o`00
ofH0I_l0008006Ko00<00?o<06Ko003<o`001@3<o`060?o<00@0c?l000<00?l00<co003<o`000P3<
o`001P1Vo`000?o<003oc0000?l00?l006Ko00800?mV00<00?l006Ko003<o`00303<o`0306Ko0080
0?l000<00?o<0?l00000ol`00P3o0002003o0003003oc000o`000?l000800?l01000ofH2003oc004
001Vo`000?l0003o0?l0IP80o`000P1V0?l00`00I_l00<co003oc003003oc0D00?mV00D00?o<003o
IP00I_l006Ko003oc002003oIP800?l00`1Vo`0<0<co0080I_l000@00?l0003oIP00ofH0o`3<0P00
ofH20<`0o`03003oIP1Vo`00c?l00180c?l00P1Vo`001P00o`00003o0000o`00c?l00?l0003oc0<0
I_l000<0o`000<co003oc000403oc0000`3<o`000?l00<co000?0?o<00@0c?l01@3oool100000040
oooo000K0?ooo`030000003oool0oooo0080oooo00H0c?l006Ko001Vo`00I_l0003<o`3<o`0?0?o<
00030<co003oc000ol`00140ol`01P3<o`0206Ko0003003o001Vo`00I_l000@0c?l000<0I_l00<co
003<o`000P3<o`0:0?o<000306Ko003<o`00c?l000@0c?l00P1Vo`000`00ol`0I_l006Ko000206Ko
0003003o001Vo`00c?l000`0c?l000<0I_l0003oIP00ofH00P3o00000`00c?l00?mV003o000:003o
00<00?mV00<00?o<003<o`00c?l00P00I_l00`1V0?l0o`0006H0o`02001Vo`<00<co0`00ofH5003o
0007003oIP00o`000?mV003oIP00ol`0o`00003oIP02003o00<0I_l0303<o`000`1Vo`00o`3<0000
o`02003o0003003<o`00ofH0I_l000800?l00`1Vo`0@0<co0080I_l000<00?l0003oIP00o`000P00
ol`00`00ofH0I_l006Ko00050<co0180ol`00P3<o`0?0?o<0080c?l000<0I_l0003o003oool0103o
ool100000040oooo000K0?ooo`8000000`3oool01P3<o`00I_l006Ko001Vo`000<co0<co00l0ol`0
00<0c?l00?o<003oc0004@3oc0060<co0080I_l000<00?l006Ko001Vo`00103<o`000`1Vo`00c?l0
0<co00020<co00X0ol`000<0I_l00<co003<o`00103<o`0206Ko0003003oc01Vo`00I_l00080I_l0
00<00?l006Ko003<o`00303<o`000`1Vo`000?mV003oIP020?l00003003<o`00ofH00?l000X00?l0
0`00ofH00`00ol`00<co003<o`02001Vo`0306H0o`3o0000IP3o008006Ko0`00c?l3003oIPD00?l0
00L00?mV003o0000ofH00?mV003oc03o00000?mV00800?l00`1Vo`0<0<co000306Ko003o0<`0003o
00800?l000<00<co003oIP1Vo`000P00o`0306Ko0100c?l00P1Vo`000`00o`000?mV003o0002003o
c003003oIP1Vo`00I_l000D0c?l04P3oc0020<co00l0ol`00P3<o`000`1Vo`000?l00?ooo`030?oo
o`8000000@3oool001/0oooo00<000000?ooo`3oool00P3oool50<co000306Ko003<o`00ol`00240
ol`01P3<o`02003o000306H0o`1Vo`00c?l000L0c?l03@3oc0060<co0080I_l000<00?l006Ko003<
o`000`3<o`000`000?l0c?l00<co00090<co00<0I_l000D00?l0003oIP00o`000?l006Ko0002003o
00@0I_l01@00o`04003oIP800?o<0`00I_l00`1V0?l0o`000<`0o`02001Vo`030000o`00ol`00?o<
00<00?mV1`00o`02003oc003003o0000ol`00<co00800?l00`1Vo`0<0<co0003003oIP00c?l00?l0
0080I_l000<00?mV003o001Vo`001@3<o`0206Ko00030<co003oc000ol`000H0ol`0103<o`0606Ko
00<00?mV00<0I_l00<co003<o`00103<o`0C0?o<00030<co003oc000ol`000`0ol`000D0c?l006Ko
001Vo`000?l0003oIP050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool00`3<
o`00ol`00?o<00030?o<00030<co003oc000ol`000/0ol`000<0c?l00?o<003oc0004P3oc0050<co
0005003o001Vo`00I_l0003o001Vo`00203<o`0>0?o<00@0c?l000@0I_l0003oc000ol`00?l04@3<
o`0206Ko00030000o`1Vo`000?l000<0I_l000<00?l006Ko001Vo`00101Vo`03003o0003003oIP00
ol`00<co00800<co00<0003o003<o`00I_l00P3o06H00`3o0<`0o`000?l000020?l0c003001Vo`00
c?l00<co0080IP3o00<00?o<001Vo`00o`000`00o`0406Ko0003003oIP00c?l00?l000800?l000<0
0<co06Ko001Vo`00303<o`0206Ko00060<co001Vo`00I_l006Ko0000ol`0I_l01`3<o`0;0?o<0003
0<co001Vo`00c?l000@0c?l00`1Vo`000`00ofH0I_l00<co00050<co01<0ol`000<00<co0?o<003o
c000303oc0000`00ol`0c?l00<co00020<co00D0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`020?ooo`L0ol`00P00ol`;0?o<00030<co003oc000ol`00140ol`00P3<o`0206Ko0003003o
00000?l0I_l000800?mV00<0IP3o06Ko003<o`001@3<o`0@0?o<00@0c?l000@0I_l00?l0c03o0<`0
0?mV403<o`000`1Vo`000?l0003o000606Ko0003003oIP1Vo`00I_l000@0I_l01000o`001@00ofH0
o`3<0?l0c000ol`006Ko00800<co0`3o0<`01@3o0000IP3o06H0o`1V0?l00<co00@00?o<0`00ofH2
003o00H0I_l000L00?l006Ko001Vo`00I_l0003o0000c?l0I_l000`0c?l000<0I_l00<co003<o`00
0P3<o`000`1Vo`000?l006Ko00050<co00h0ol`01`3<o`0206Ko0003003oc01Vo`00I_l000D0c?l0
4`3oc0000`3<o`00ol`00?o<000;0?o<0003003o003oc000ol`000<0ol`01@3oool100000040oooo
000K0?ooo`030000003oool0oooo0080oooo2@3oc0000`3<o`00ol`00?mV00090?mV01<0ol`0103<
o`000`1Vo`000?l0003oIP020000o`03003oIP1Vo`00I_l000D0c?l04P3oc0020<co00<0I_l000<0
c?l0003o003<o`003P3<o`000`00o`00c?l00<co00060<co00L0I_l01@00o`03003oIP800?o<00<0
0<co001Vo`00I_l00P3o00001@3<0?l006Ko001Vo`00c?l00?o<00@00?mV1000o`0<06Ko0003001V
o`1Vo`00I_l000l0c?l000<0I_l0003o0000o`000P00ol`00`1Vo`00c?l00?o<000?0?o<00H0c?l0
0P1Vo`000`00ofH00?o<06Ko000406Ko00030<co003oc000ol`001h0ol`000<0c?l00?o<003oc000
103oc0050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool90?o<00030<co003o
c000ofH000T0ofH04`3oc0040<co000306Ko0000o`000?mV0080003o00<00?mV06Ko001Vo`001@3<
o`0B0?o<0080c?l00`1Vo`000`3<o`000?l00<co000>0<co0003003o003<o`00c?l000H0c?l01`1V
o`05003o00<00?mV0P00ol`00`00c?l006Ko001Vo`020?l000050<`0o`00I_l006Ko003<o`00ol`0
1000ofH4003o00`0I_l000<006Ko06Ko001Vo`003`3<o`000`1Vo`000?l0003o0002003oc00306Ko
003<o`00ol`000l0ol`01P3<o`0206Ko0003003oIP00ol`0I_l000@0I_l000<0c?l00?o<003oc000
7P3oc0000`3<o`00ol`00?o<00040?o<00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?oo
o`020?ooo`T0ol`03`3oIP0?0?o<00D0c?l00P1Vo`001@00ofH0o`000?l00000ofH00?l000<0I_l0
0P3<o`0C0?o<0080c?l000<00?l0003oIP00ofH00P3<o`000`00o`00ol`00?o<00070?o<00l0c?l0
1P1Vo`02003oc0<00?l00`00ofH00`00ol`0003o0000o`02001Vo`030<`0o`3o0000o`000080c03o
00<0IP3o003oc000ol`00`00ofH4003o00L0I_l01P3<o`02003o000306Ko003<o`00c?l000`0c?l0
00<00?l006Ko0000ofH0103<o`0@0?o<00D0c?l00`1Vo`000`00ofH00<co003oc0020?l0c00306Ko
003<o`00c?l00080c?l04P3oc0090?mV00X0ol`01@3oool100000040oooo000K0?ooo`030000003o
ool0oooo0080oooo00<0c?l00?o<003oc000103oc00B0?mV00`0ol`00`3<o`001`00c?l0c?l00<co
003<o`00I_l0003oc000ofH00P000?l00`00o`00I_l006Ko00040<co01<0ol`00P3<o`000`00ofH0
I_l006Ko00020<co00d0ol`03@3<o`0306Ko0003003o0000ofH00?mV00@00?mV1000ol`2003<o`80
06Ko00<0c03o0?l0003o00000P00I_l00`00c?l00?o<003<o`020?l0IP800?mV00@00?l0003oIP00
ofH00?l01@1Vo`090<co000306Ko003<o`00c?l00080c?l01`3oc0000`3<o`00c03o0<`0o`020<co
0004003o003<o`00c?l00<co0180ol`00P3<o`000`000?l00?mV003oIP02003oc003001Vo`3o06H0
0?l00080I_l01P3<o`0?0?o<00h0ofH01`3oc0050?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool00P3oool20<co00@0ol`0503oIP090?o<0080c?l00P00o`000`1Vo`000?l00?l0c002003o
000306Ko0000I_l0003o008006Ko00<00?l006Ko003<o`00103<o`0C0?o<00030<co0000o`000?l0
00<0c?l03P3oc00=0<co00@0I_l000<00?l0003oc000ol`00P00I_l01`00ofH00?o<003oc000I_l0
0<co06H0o`00I_l00P1V0?l00`3<0?l0o`000?l0000306H0o`07003<o`00I_l00?o<003oc000ofH0
0<co0000o`02001Vo`03003<o`00ofH00?mV0080I_l03@3<o`0<0?o<0080c?l000@00?o<06Ko001V
o`00c?l04P3oc0040<co0005003oc01Vo`00I_l0003oIP3o00000`00ofH00`1Vo`00c?l00<co0002
003oIP80c?l03@3oc00A0?mV00D0ol`01@3oool100000040oooo000K0?ooo`030000003oool0oooo
0080oooo103oc0000`00ofH0ofH00?mV000D0?mV00D0ol`00P3<o`000`1Vo`000?mV06Ko0002003o
000306Ko0000o`000?mV00<00?l000D0IP3o0?l0IP3<0?l0c03o003o000206Ko00@0c?l0503oc000
101Vo`00c?l00<co003<o`0@0?o<00`0c?l01@1Vo`02003o0003003oIP00ol`00<co008006Ko00<0
0<co001Vo`00I_l00`000?l00`1V0?l0c03o0?l000040?l000@006Ko00@00?o<003oIP00ofH00?mV
1@1Vo`0<0<co00h0ol`00P3<o`02003o00030<co003oc000ol`00100ol`01@3<o`02003o0003003<
o`3<0?l00?o<00800?l01@1Vo`000`3<o`00I_l00<co000:0?o<01@0ofH00`3oc0000`1Vo`00oooo
0?ooo`030?ooo`4000000@3oool000P0oooo0P0000040?ooo`8000000`3oool4000000@0oooo00<0
00000?ooo`3oool00P3oool40?o<0003003oIP3oIP00ofH001@0ofH01@3oc0020<co000306Ko0000
ofH0I_l000800?l000<0I_l0003o0000ofH00`00o`001@1V0?l0o`1V0<`0o`3<0?l00?l00080I_l0
103<o`0D0?o<000406Ko003<o`00c?l00<co0100ol`0303<o`0506Ko00800?l000<00?mV003oc000
c?l00P00I_l00`00c?l006Ko001Vo`030000o`0306H0o`3<0?l0o`0000@0o`001000I_l01000ol`0
0?mV003oIP00ofH506Ko00`0c?l03P3oc0020<co00800?l000<0c?l00?o<003oc000403oc0050<co
00800?l000<00<co0<`0o`00ol`00P00o`0506Ko00030<co001Vo`00c?l000X0ol`0503oIP030?o<
000306Ko003oool0oooo00<0oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool40?o<01T0ofH000<0ol`00<co
003<o`00103oc0040<co000306Ko003<o`00I_l00080I_l000L00?mV0?l00000ofH00?mV003o0000
0?l00?l000<0I_l00P3<o`0C0?o<0003003oc03<o`00ol`00140ol`02`3<o`0606Ko00800?l000<0
0?mV003oc000I_l00P1V0?l010000?l0o`000<`0o`3o0<`406H0o`060<`0o`3o0<`0o`3<0<`0o`3o
0000o`1V0P3o00000`00c?l00?o<003o0002003o00D0I_l02`3<o`0@0?o<00040<co0000c?l00<co
0<co0180ol`0103<o`0306Ko0003003oIP00c?l0c03o008006Ko0P00o`001P00ofH00?l0003o001V
o`0006Ko0<`0o`80I_l000<0c?l00?o<003oc000103oc00G0?mV0080ol`01@3oool100000040oooo
00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool2000000<0oooo
0P3oc00K0?mV00X0ol`01@3<o`000`1Vo`000?mV003<o`02003oc00306Ko0000ofH00?l00080c03o
00<0I_l00<co003<o`004`3oc0000`00o`00ol`00?o<000B0?o<00X0c?l01@1Vo`03003o0080c03o
103o00000`3o0<`0c03o0?l0IP020?l000030<`0o`1V0?l006Ko0080c03o0`000?l20?l000030?l0
c000I_l0003o00800?l01@1Vo`0;0<co0100ol`000@0c?l006Ko001Vo`00c?l04P3oc0020<co0003
003o001Vo`00I_l000800?o<00<00?mV001Vo`3o06H00P00o`0206Ko00030<co001Vo`00I_l000L0
c?l000@0I_l00?o<003oc000ol`0603oIP020?o<00@0oooo0P0000010?ooo`001`3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool20?o<
01/0ofH02`3oc0020<co0080I_l000<0c03o001Vo`00c?l00`1Vo`020<co00800?l000<0I_l00<`0
o`3<o`000P3<o`0@0?o<000306Ko003<o`00ol`001<0ol`02@3<o`0206Ko00800?l00`00ofH4003o
c005003<o`3o06H0o`1V003<o`1V0?l00P00I_l20?l0c0030?l000000?l006Ko00@00<co1000I_l0
1`00c?l0003o003oIP00ofH00?l006Ko0000o`000`1Vo`0:0<co0140ol`00`3<o`0A0?o<00<0c?l0
00<0I_l0001Vo`00o`000P00ofH00`1Vo`000?o<0?l00002003o000306Ko003<o`00c?l000<0c?l0
2@3oc0000`3<o`00ofH00?mV000G0?mV00030?o<003oool0oooo00<0oooo0@0000010?ooo`001`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oool00`3oc000ofH00?mV000K0?mV00/0ol`00`3<o`000`1Vo`000?o<003o0002003oIPL0
c?l000<0003o0<co003<o`00403oc0000`3<o`00ol`00?o<000C0?o<00040<co0000o`000?l0003o
00L0I_l00P00o`000`00ofH0IP3o003o0003003o00800?mV0P00c?l01000ol`0003o003<o`000?l3
0?l000030000o`1V0?l00?o<00<00?o<00<00?mV003oc000ol`00P00ofH01000o`000?mV003oIP00
I_l2003oIP@0I_l0203<o`0D0?o<000306Ko003oc000ol`000l0ol`000@0c?l0003o0000o`000?l0
0P1Vo`020<co0080I_l000@0IP3o003oIP00ofH00?o<103<o`0:0?o<01/0ofH01@3oool100000040
oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool00P3oool00`3oc000ofH0
0?mV000K0?mV00/0ol`00`3<o`000`1Vo`000?o<003o0002003oIPL0c?l000<0003o0<co003<o`00
403oc0000`3<o`00ol`00?o<000C0?o<00040<co0000o`000?l0003o00L0I_l00P00o`000`00ofH0
IP3o003o0003003o00800?mV0P00c?l01000ol`0003o003<o`000?l30?l000030000o`1V0?l00?o<
00<00?o<00<00?mV003oc000ol`00P00ofH01000o`000?mV003oIP00I_l2003oIP@0I_l0203<o`0D
0?o<000306Ko003oc000ol`000l0ol`000@0c?l0003o0000o`000?l00P1Vo`020<co0080I_l000@0
IP3o003oIP00ofH00?o<103<o`0:0?o<01/0ofH01@3oool100000040oooo000K0?ooo`030000003o
ool0oooo0080oooo00<0I_l00?mV003oIP006`3oIP0;0?o<00@0c?l000D0o`0006Ko003<o`00c?l0
06Ko00020<co00@0ol`000@0c?l006Ko001Vo`00c?l03`3oc0000`000?l0ol`00?o<000B0?o<00D0
c?l000<0I_l0003o001Vo`000P1Vo`001`00I_l00?mV003oIP00ofH00?o<003oIP00o`000P1Vo`02
003o00<00?o<0P00ofH2003<o`80IP3o00<0o`000000o`00c?l00P00ol`3003oIP800?o<0P00o`00
1P1Vo`000?l0003o0000o`0006Ko003oIPP0I_l000<00?l006Ko003<o`000P3<o`0C0?o<00030<co
003oc000ol`000h0ol`000<0c?l0003o003<o`001`3<o`001@1V0?l00<co003o0000o`00I_l00080
c?l0303oc00K0?mV00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooah0ofH0
2`3oc00406Ko0003003oIP3<o`00c?l00080c?l02@3oc0000`1Vo`00ol`00?o<000R0?o<00D0c?l0
00L0I_l0003o0000c?l00<co003o0000ol`0IP3o00800?l000<0I_l0003oIP1Vo`000`1Vo`000`00
o`000?o<003o0002003o0003003oIP1V0?l006Ko00<0o`0000D0o`1V06H0o`00c?l00<co003oc002
003o00800?o<00<00?mV06Ko001Vo`000P1Vo`02003o0004003oc000c?l00<co003<o`800?l00P3<
0?l00`00o`00c?l00<co00030<co02@0ol`000D00?mV0<co003<o`00c?l00?o<00040<co0003003o
003<o`00I_l000800?mV0`3<o`0<0?o<01/0ofH01@3oool100000040oooo000K0?ooo`030000003o
ool0oooo0080oooo7P3oIP0;0?o<00<0c?l00P00o`000`00ofH0c?l00<co000;0?o<0003003oIP3o
c000ol`000L0ol`00P3oIP0H0?o<00H0c?l000<0I_l0003o0000o`000P3o00000`00ofH00?l0003o
000606Ko0003003oIP00o`000?l000800?l00`00ol`206H0o`030?l00000I_l00?o<00<00?o<00<0
0?mV003o0000o`000P00o`0406Ko0003003oc01Vo`00I_l000800?mV00<0o`00003oIP00ofH00P1V
o`000`00ofH0c?l00<co00030<co02<0ol`000<006Ko0<co003oc0001`3oc0030<co00800?mV00<0
I_l00<co003<o`00303oc00K0?mV00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`02
0?oooah0ofH02P3oc0040<co0003003o001Vo`00c?l00080c?l0303oc000103<o`00ol`00?o<003o
c00<0?mV0180ol`01P3<o`0206Ko008006Ko00<00?o<003oIP1Vo`000`1Vo`020<co00L0I_l00P00
o`001`00ofH00?o<001Vo`00I_l0o`000000o`00ol`00P00ofH2003o00X0I_l000H0003o003o0000
o`000?mV0<`0o`00ofH206Ko00H0c?l0503oc0000`1Vo`00ol`00?o<000:0?o<00800?l02P3oc002
0<co000406Ko0000ofH00?mV06Ko0080c?l02P3oc00M0?mV00D0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`020?oooah0ofH02P3oc0040<co0003003o001Vo`00c?l00080c?l0303oc000
103<o`00ol`00?o<003oc00<0?mV0180ol`01P3<o`0206Ko008006Ko00<00?o<003oIP1Vo`000`1V
o`020<co00L0I_l00P00o`001`00ofH00?o<001Vo`00I_l0o`000000o`00ol`00P00ofH2003o00X0
I_l000H0003o003o0000o`000?mV0<`0o`00ofH206Ko00H0c?l0503oc0000`1Vo`00ol`00?o<000:
0?o<00800?l02P3oc0020<co000406Ko0000ofH00?mV06Ko0080c?l02P3oc00M0?mV00D0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`020?oooah0ofH000<0c?l006Ko003oc000103oc004
0<co0005003oc01Vo`00I_l00000o`1Vo`000`3<o`0=0?o<0100ofH03`3oc0040<co000306Ko003<
o`00c?l00080I_l000@00?mV003o0000o`00I_l00P00o`0206Ko00D0c?l01@1Vo`02003o0007003o
IP00I_l0c03o0<`0o`3o0<`0o`000000o`02003oIP800?l01@1Vo`050<co00<0I_l000<006Ko003o
IP00c?l00`1Vo`040<co000306Ko003<o`00ol`00140ol`02`3oIP0@0?o<0080c?l00`1Vo`040<co
00X0ol`06`3oIP050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolN0?mV00@0
ol`000<0c?l0003oc01Vo`00103<o`001P1Vo`000?mV003oIP00I_l00?mV003<o`80c?l0303oc00D
0?mV00X0ol`01P3<o`000`00o`00I_l006Ko0002003oIP03003o001Vo`00I_l00080I_l000<00?l0
0<co003<o`001P3<o`0206Ko00800?l000@00?mV001Vo`00ol`00<co0P00I_l00`3o06H006Ko003<
o`02003oIP0306H0o`00ofH00?l000<0I_l01`3<o`0206Ko000306H0o`1Vo`00I_l000800?mV00<0
I_l0003o001Vo`000P00o`030<co00h0ol`0403oIP0>0?o<0080c?l00P1Vo`000`00c?l0I_l0003o
IP030<co00H0ol`000<0c?l00?o<003oc0006`3oIP050?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool00P3ooolN0?mV00D0ol`00P3<o`020?l00003003o001Vo`000?l000800?o<00<00?mV
06Ko003<o`000`3<o`0:0?o<01H0ofH01P3oc0050<co0080I_l000<0c?l006Ko001Vo`000P00c?l0
0`000?l00?mV06Ko00040<co0003003o003<o`00c?l000H0c?l000@0I_l0003o003o0<`0o`3<0`00
o`001P00ofH00<co003<o`3o00000<co003oIP@00?l000@0o`00003o0000o`00I_l01`3<o`020000
o`<0c?l00P1Vo`000`00I_l00?l0003o0002003o00H0c?l02P3oc00B0?mV00d0ol`000L0c?l0003o
0000ofH00?mV003<o`00o`00I_l000@0c?l000@00?mV003<o`00c?l0c?l0103oc00K0?mV00D0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooad0ofH01`3oc000103<o`00I_l006Ko
001Vo`02003oIP80IP3o00<00?mV06Ko003<o`000`3<o`090?o<01L0ofH00`3oc0000`3<o`00I_l0
0<co000206Ko00030<co001Vo`000?mV008006Ko00<00?l006Ko0000ofH00P1V0?l00`00c?l00?l0
06Ko000<0<co000306Ko0000ofH00?l00080003o00@0I_l0003o0000o`0006Ko0P00ol`00`3o06H0
0?o<003<o`03003o000606Ko0000ol`00?l0003o0000ofH0I_l01P3<o`0206Ko00<0c?l00P1Vo`00
0`00o`00c03o003oIP0706Ko0003003oIP00o`00c?l000L0ol`05@3oIP0;0?o<0080c?l00P1Vo`02
003oIP0506Ko0000o`000?l0003oc000ofH00`3<o`050?o<01/0ofH01@3oool100000040oooo000K
0?ooo`8000000`3ooolM0?mV00L0ol`000@0c?l006Ko001Vo`00I_l00P00ofH206H0o`03003oIP1V
o`00c?l000<0c?l02@3oc00G0?mV00<0ol`000<0c?l006Ko003<o`000P1Vo`000`3<o`00I_l0003o
IP02001Vo`03003o001Vo`000?mV0080IP3o00<00<co003o001Vo`00303<o`000`1Vo`000?mV003o
00020000o`0406Ko0000o`000?l0001Vo`800?o<00<0o`1V003oc000c?l00`00o`001P1Vo`000?o<
003o0000o`000?mV06Ko00H0c?l00P1Vo`030<co0080I_l000<00?l00<`0o`00ofH01`1Vo`000`00
ofH00?l00<co00070?o<01D0ofH02`3oc0020<co0080I_l00P00ofH01@1Vo`000?l0003o0000ol`0
0?mV00<0c?l01@3oc00K0?mV00@0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`020?oo
oad0ofH01`3oc0030<co0080I_l000H00?mV06H0o`1V0?l00?o<003oIP00ol`2001Vo`0306Ko003<
o`00c?l000D0ol`06P3oIP080?o<00060<co001Vo`00I_l006Ko0000o`000?o<0`000?l3003o00`0
c?l000<00?mV06Ko001Vo`00101Vo`001P00o`000?mV003<o`00c?l0o`00001Vo`<00?l01P1Vo`00
0`00ofH0c?l00<co00090<co0080I_l000<00?o<003oIP3<0?l00P00ofH00`00o`000?o<003o0002
06Ko0003003oIP1Vo`00c?l00080c?l000<00?o<0?o<003oc000603oIP090?o<00<0c?l00P1Vo`00
0`00ol`0003o003oc002003<o`80I_l000<0c?l00?o<003oc0001P3oc00J0?mV00D0oooo0@000001
0?ooo`006`3oool00`000000oooo0?ooo`020?oooa/0ofH02@3oc0030<co000306Ko0000o`000?o<
0080IP3o00<00?l006Ko001Vo`000P00o`050<co0003003oc03oc000ol`001X0ofH02@3oc0030<co
0003003oIP00ol`0003o008006Ko00<0I_l00<co003<o`000P00ol`00`3<o`00ol`00?o<00030?o<
0080c?l00P1Vo`050<co000406Ko0000o`00003o06H0o`800<co00<0o`00003<o`00c?l00P00ofH2
06Ko00D0c?l000@00<co0<co003<o`00c?l0103oc0030<co00<0I_l000L00?l0003oc01V0?l0IP3o
003oIP1Vo`00c?l00080I_l0203oc00I0?mV00D0ol`00`3<o`000`1Vo`000?mV003o0002001Vo`03
003<o`3o00000?mV0080I_l00`3<o`080?o<01X0ofH01@3oool100000040oooo000K0?ooo`030000
003oool0oooo0080oooo6P3oIP040?o<00030<co003oc000ol`00080ol`00P3<o`0206Ko0003003<
o`00o`00003o00800?o<0P1Vo`040<co00H0ol`07@3oIP070?o<00050<co0000o`000?l0003oIP00
I_l00`00o`000`1Vo`00c?l00<co00020<co00P0ol`01`3<o`0206Ko0007003o0000ofH00?o<003o
c03o00000?o<003oIP02003o0080I_l01P3<o`090?o<00@0c?l000H0I_l0003oIP1V0?l0IP3o003o
IP1Vo`030<co00L0ol`06P3oIP030?o<000306Ko003<o`00c?l000<0c?l000L00?o<06Ko001Vo`00
I_l0003o003o0<`00?mV00<0I_l00P3<o`070?o<00030<co003oc000ofH001P0ofH01@3oool10000
0040oooo000K0?ooo`030000003oool0oooo0080oooo6@3oIP050?o<000406Ko003<o`00I_l006Ko
00<0c?l00`1Vo`001P00c?l0o`1V003oc000ol`00?l006Ko00<0c?l01`3oc00M0?mV00L0ol`00`3<
o`000`000?l00?mV06Ko000206Ko0003001Vo`1Vo`00c?l000X0ol`01`3<o`0206Ko0007003o0000
ol`00<co003<o`3o00000<co0?l00002003o0080I_l01P3<o`090?o<00@0c?l000L00?l006Ko0000
o`000?l0001Vo`1Vo`00c?l000T0ol`06`3oIP070?o<00<0c?l00P1Vo`000`00o`000<co003<o`02
003o0003003<o`1Vo`00c?l00080c?l00`3oc002003o00<0ol`0603oIP050?ooo`4000000@3oool0
01/0oooo00<000000?ooo`3oool00P3ooolI0?mV00D0ol`000@0I_l00<co001Vo`00I_l00`3<o`03
06Ko0006003<o`3o06H00?o<003oc000o`00I_l00`3<o`070?o<01d0ofH01`3oc0030<co00030000
o`00ofH0I_l00080I_l000<006Ko06Ko003<o`002P3oc0070<co0080I_l000L00?l0003oc000c?l0
0<co0?l00000c?l0o`0000800?l00P1Vo`060<co00T0ol`0103<o`001`00o`00I_l0003o0000o`00
06Ko06Ko003<o`002@3oc00K0?mV00L0ol`00`3<o`0206Ko0003003o0000c?l00<co00800?l000<0
0<co06Ko003<o`000P3<o`030?o<00800?l00`3oc00H0?mV00D0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`020?oooaP0ofH00P3oc0001P1Vo`00ol`00?o<003<o`00I_l0003o00<0I_l0
00L00?l006Ko001Vo`00I_l0003oIP00ol`0o`0000800?o<0P1Vo`030<co00L0ol`07@3oIP070?o<
00040<co0000o`000?l006Ko00@0c?l000<0I_l00<co003<o`00303oc0030<co0080I_l00P00o`00
1`00ofH0o`3<0?l0003o0000c03o0000o`3o0<`00P3<0?l00`00o`00I_l006Ko00040<co00/0ol`0
0P3<o`000`1Vo`000?l00<co000306Ko0004003oc03<o`00c?l00<co00H0ol`0703oIP080?o<0080
c?l00P1Vo`000`00o`00o`000<`0o`02003oIP0306Ko003<o`00c?l00080I_l00P3<o`000`1Vo`00
c?l00<co00030?o<01P0ofH01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo
00<0o`000?mV003oIP004`3oIP040?o<000306Ko0000c?l00<co00800?l000@00?mV003o0000o`00
c?l00P1Vo`02003o00030<`0o`3o06H0IP3o00800?o<00<00?l00<co003<o`000P3<o`070?o<01d0
ofH01@3oc0020<co00@0I_l000L0c?l00?o<003oc000ol`00<co0000o`00c?l000`0ol`000<0c?l0
06Ko0000o`000P000?l01000ol`00?mV003oIP00ol`2003<o`030?l00000ol`00?mV00800?l000<0
06Ko0000o`00o`000P00c?l00`1Vo`00c?l00?o<000:0?o<0080c?l000<00?o<0<co003<o`000`3<
o`0206Ko0080c?l01P3oc00L0?mV00P0ol`00P3<o`0306Ko0005001Vo`3o06H00<co003<o`1V0?l0
0P1Vo`02003o000306Ko0000o`000?o<0080I_l000<00?l00<co003oc0000P3oc00F0?mV00D0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`D0o`00403oIP001P3oc000c?l00<co
0000o`00c?l00?o<00800?mV00<0ol`00<co0000o`001@3<o`0206Ko0003003oIP3o00000?o<00<0
0?mV0P1Vo`030<co00H0ol`07@3oIP030?o<0080c?l000<0003o06Ko003o0<`00P1Vo`000`3<o`00
ol`00?o<00030?o<000306Ko003oc000ol`000/0ol`00P3<o`001`00ofH0IP3o06H0o`1Vo`0006Ko
06Ko0000ofH00P00c?l00`1V0?l0c03o003o000306Ko0004003o0000c?l00?l0003o0080c?l02`3o
c0030<co00D0ol`000@0c?l0003o0000ol`00?o<0P3<o`00101Vo`00c?l00<co003<o`0L0?mV00P0
ol`0103<o`000`00o`000?mV001Vo`020?l0c00306H0o`1Vo`00I_l000800<co00<0c?l006Ko0000
o`000`1Vo`001P00I_l0c?l00<co003<o`00ol`006Ko01@0ofH01@3oool100000040oooo000K0?oo
o`030000003oool0oooo0080oooo1`3o000=0?mV00030?o<003o0000ol`00080ol`000<0I_l00?o<
003oc0001`3oc0001`3<o`00I_l0001Vo`00I_l00?o<06H0o`00o`000`1Vo`001@00ofH00<co0<co
003<o`00I_l00080c?l00P00o`020?o<01h0ofH0103oc0000`3<o`000?o<003oc0020<co00H0ol`0
00<0c?l00?o<003oc0002@3oc0020<co000306Ko0000ofH0I_l0008006Ko0P3<o`0206Ko00800?o<
00<0o`3<003o001Vo`00103<o`001@00o`00I_l006Ko0000o`00c?l000/0ol`00`3<o`050?o<0006
0<co001Vo`00IP3o06H0o`00I_l0c?l0103oc00L0?mV00L0ol`00P3<o`001P00o`00I_l006Ko0000
c?l00?o<003<o`80003o00<00?l006Ko003<o`00103<o`001P00I_l0ol`00?o<003oc000I_l00?o<
0080I_l000<00?mV0?o<003oc0003`3oIP040?l000D0oooo0@0000010?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`L0o`003@3oIP000`3oc000o`000?o<00020?o<000306Ko003oc000ol`000L0
ol`000L0c?l006Ko0000I_l006Ko003oc01V0?l00?l000<0I_l000D00?mV003<o`3<o`00c?l006Ko
00020<co00800?l00P3oc00N0?mV00@0ol`000<0c?l0003oc000ol`00P3<o`060?o<00030<co003o
c000ol`000T0ol`00P3<o`000`1Vo`000?mV06Ko0002001Vo`80c?l00P1Vo`02003oc0030?l0c000
o`00I_l000@0c?l000D00?l006Ko001Vo`000?l00<co000;0?o<00<0c?l01@3oc0001P3<o`00I_l0
06H0o`1V0?l006Ko0<co00@0ol`0703oIP070?o<0080c?l000H00?l006Ko001Vo`000<co003oc000
c?l20000o`03003o001Vo`00c?l000@0c?l000H006Ko0?o<003oc000ol`006Ko003oc00206Ko0003
003oIP3oc000ol`000l0ofH0103o00050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0
0P3oool:0?l000T0ofH000<0c?l00?o<003oc0001`3oIP000`3oc000I_l00?o<00040?o<00060<co
001Vo`00I_l0003oIP00c?l00?l00P1Vo`000`3<o`00I_l00<co0002003oIP800?l000<0c?l00?o<
003oc0000P3oc00N0?mV00@0ol`000<0c?l006Ko003<o`000P00ofHB0?o<0080c?l000<00?mV06Ko
003<o`000P1Vo`030<co0006003o0000ol`00?o<0000o`3o0000IP3o1`3<o`0206Ko00030<co003o
c000ol`000P0ol`00P3<o`060?o<00050<co0000o`00o`1V0?l0IP00ol`01@3oc00L0?mV00<0ol`0
00L0c?l006Ko003<o`00c?l006Ko003<o`00003o0080c03o0P1Vo`001P00ofH0o`1V0?l0IP00ofH0
06Ko06Ko00@0ol`000D0c?l00?o<003oc000ol`00<co00030?o<0080c?l000<00?mV0?o<003oc000
2`3oIP060?l000D0oooo0@0000010?ooo`006`3oool2000000<0oooo2`3o00060?mV0080c?l0303o
IP040?o<00070<co001Vo`000?l0003o0000I_l00?l006Ko00070<co00030?l0c000o`00c?l000@0
ol`07@3oIP000`3oc000c?l00<co00020<co0003001Vo`00c?l0ol`00080ol`000<0I_l00?o<003o
c0003`3oc002003oIP80c?l000<0ol`00<co003<o`000P3<o`001@00ofH0I_l006Ko001Vo`000<co
00@0I_l0203<o`0:0?o<0080c?l01P3oc0001P1Vo`00c?l006Ko001Vo`000<co0<co00@0ol`0703o
IP040?o<00030<co0000ofH00?mV00800?l0103<o`001`1Vo`000?l0003<o`00c?l00?l006Ko003<
o`001`3oc0070?mV00040?o<001Vo`00I_l00?o<00T0ofH01`3o00040?ooo`8000000@3oool001/0
oooo00<000000?ooo`3oool00P3oool<0?l000@0ofH000<0ol`00?mV003oIP003@3oIP020?o<0003
06H0o`3<o`00c?l00080I_l000<0IP3o003o001Vo`000P3<o`030?o<00@0c?l000D0I_l00<co003<
o`00c?l00?o<000M0?mV00<0ol`00P00o`000`1Vo`00ol`00?o<000C0?o<0003003<o`3oc000ol`0
00H0ol`00`3<o`0206Ko0003003oIP3<o`00c?l000<0c?l01P3oc0000`3<o`00I_l006Ko00080?o<
00800?mV2P3oc0000`3<o`000?l006Ko00020<co00030?o<003oIP00ofH001X0ofH0103oc000103<
o`000?mV003oIP00c?l20<co0080ol`00P3<o`001P00ofH00?o<003oc000c?l00?l00?l0IP80c?l0
0`3oc00=0?mV00030000o`3oIP00ofH000<0ofH02P3o00050?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool00P3oool>0?l00180ofH0103oc0001P3<o`000?l0003o0000o`00c?l006Ko0080
c?l00`3oc0020<co0080ol`000<0c?l0003oIP00ofH00P3oc00M0?mV00<0ol`00P1Vo`020<co00@0
ol`02`3oIP040?o<0003003o003oc000ol`000P0ol`00P3<o`0206Ko0003003oIP3<o`00c?l00080
c?l0203oc0020<co00H0ol`01`3oIP070?o<000306Ko0000c?l00?mV00<0ol`0703oIP020?o<0003
003o003<o`00I_l000@0c?l0103oc0001`3<o`00I_l0003o0000o`000<co0<co001Vo`000P3<o`00
0`1Vo`00ol`00?mV000>0?mV00040<co003oIP00ofH00?mV00/0o`001@3oool100000040oooo000K
0?ooo`030000003oool0oooo0080oooo3P3o000B0?mV00@0ol`000H0c?l0003o0000o`000?l00<co
001Vo`020<co00<0ol`00P3<o`020?o<00030<co0000ofH00?mV0080ol`07@3oIP030?o<0080I_l0
0P3<o`040?o<00/0ofH0103oc0000`00o`00ol`00?o<00080?o<0080c?l00P1Vo`000`00ofH0c?l0
0<co00020<co00P0ol`00P3<o`060?o<00L0ofH01`3oc0000`1Vo`000<co003oIP030?o<01`0ofH0
0P3oc0000`00o`00c?l006Ko00040<co00@0ol`000L0c?l006Ko0000o`000?l0003<o`3<o`00I_l0
0080c?l000<0I_l00?o<003oIP003P3oIP00103<o`00ofH00?mV003oIP0;0?l000D0oooo0@000001
0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`l0o`004@3oIP050?o<00800?l000<0c?l00?o<
003oc0000P1Vo`030?o<00800?l00P3oc0040<co0003003oIP3oIP00ofH001/0ofH00P3oc0000`00
ofH0c?l00<co00030?o<0140ofH000<0c?l00?o<003oc0002@3oc00206Ko00800?l000<00?o<06Ko
001Vo`003P3oc00>0?mV00H0ol`000@0I_l00?o<003oc000ol`0703oIP030?o<0003003o003<o`00
ol`00080ol`000<0c?l00?o<003oc0000P3oc0001P00o`00o`000<co003<o`000?mV0<co00D0ol`0
4P3oIP0<0?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooa00o`00403o
IP040?o<00040<co001V0?l0IP3o0<co00@0ol`000<0c?l00?o<003oIP000`3oIP040?o<000306Ko
003oc000ol`001`0ofH00P3oc0030<co0080ol`04`3oIP0;0?o<00@0c?l000<00?mV0<co003<o`00
3@3oc00A0?mV00@0ol`000@00?l00<co003<o`00ol`0703oIP020?o<000306Ko003<o`00ol`000`0
ol`000<00?l00<co003oc0000`3oc00A0?mV00h0o`001@3oool100000040oooo000K0?ooo`030000
003oool0oooo0080oooo4@3o000?0?mV00<0ol`000D0c?l0003oIP00ol`00?o<0<co00040?o<00P0
ofH00`3oc0000`00o`00ol`00?mV000K0?mV00030?o<0000ofH0ol`00080ol`05P3oIP0:0?o<0080
c?l00P1Vo`000`00ofH0I_l00<co0002003oIPX0ol`0503oIP030?o<00800<co00<0I_l00?o<003o
IP006@3oIP030?o<00030<co003oc000ol`000D0ofH01`3oc0000`3<o`000?mV0<co00030?o<0100
ofH03`3o00050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolA0?l000l0ofH0
103oc0000`3<o`000?l0003o00020<co00030?o<003oIP00ofH000X0ofH000<0ol`00<co003oc000
6P3oIP020?o<0003003o003<o`00ol`001P0ofH02P3oc0020<co00800?l000<0003o06Ko003<o`00
0P3<o`080?o<01P0ofH000<0ol`00<co003<o`000P3oc00J0?mV00040?o<0000o`000?l00?o<00X0
ofH0103oc0000`00ofH0o`1V0<co00030?o<0100ofH03`3o00050?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool00P3ooolA0?l000l0ofH0103oc0000`3<o`000?l0003o00020<co00030?o<
003oIP00ofH000X0ofH000<0ol`00<co003oc0006P3oIP020?o<0003003o003<o`00ol`001P0ofH0
2P3oc0020<co00800?l000<0003o06Ko003<o`000P3<o`080?o<01P0ofH000<0ol`00<co003<o`00
0P3oc00J0?mV00040?o<0000o`000?l00?o<00X0ofH0103oc0000`00ofH0o`1V0<co00030?o<0100
ofH03`3o00050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolC0?l000d0ofH0
0`3oc000103<o`000?l0003o0000o`030?o<00d0ofH000@0ol`006Ko003oc000ol`0603oIP020?o<
0003001Vo`3oc000ofH001T0ofH0203oc0020<co000606Ko0000ol`00?o<0?l0001Vo`00c?l00P1V
o`000`3<o`00ol`00?o<00050?o<01T0ofH00P3oc0000`00o`00ol`00?mV000I0?mV00030<co003o
c000ol`000`0ofH00`3oc0000`3<o`00I_l00<co00040?o<00h0ofH0403o00050?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool00P3ooolD0?l000/0ofH00`3oc00206Ko0003003oc03<o`00
c?l00080ol`03`3oIP000`1Vo`00ol`00?o<000H0?mV0080c?l000<0ol`00?mV003oIP006@3oIP05
0?o<00<0I_l000<00?o<0?l0IP3o00000P00ol`00`3<0?l006Ko003oc002003oc003003o0000ol`0
c?l000@0ol`06P3oIP020?o<0003003<o`3oc000ofH001P0ofH000<0ol`0003o003oIP003@3oIP04
0?o<00@0c?l00P3oc00=0?mV0140o`001@3oool100000040oooo000K0?ooo`030000003oool0oooo
0080oooo503o00090?mV00D0ol`000<0c?l0003oIP3o00000P00o`000`00ol`0ol`00?mV000?0?mV
0080I_l05`3oIP00103oc000I_l006Ko003oc00M0?mV00030<co003oc000ol`00080ol`0103<o`02
003oIP03003<o`00o`00c?l000800?mV1P3<o`000`3oc000ofH00?mV000J0?mV00030?o<003<o`00
ol`001P0ofH00P3oc00?0?mV00<0ol`000D0c?l00000o`00o`000?l00<co00020?o<00`0ofH04@3o
00050?ooo`4000000@3oool001/0oooo0P0000030?oooaD0o`00103oIP020?o<0080c?l000<00?l0
0<co001Vo`000`1Vo`001000I_l00?mV0<co003<o`020?o<0100ofH00P3oc00G0?mV00030<co003o
c000ol`001h0ofH01`3oc0020<co00800?l00P00ol`30<co00L0ol`07@3oIP020?o<01P0ofH000<0
c?l00?mV003oIP003P3oIP020?o<00030<co001Vo`000?o<0080I_l000<0c?l00?o<001Vo`000`3o
c0070?mV01<0o`00103oool200000040oooo000K0?ooo`030000003oool0oooo0080oooo5@3o0004
0?mV0080ol`00P3<o`000`00o`00c?l006Ko000306Ko0004001Vo`00ofH0c?l00<co0080ol`0403o
IP020?o<01L0ofH000<0c?l00?o<003oc0007P3oIP070?o<0080c?l00P00o`02003oc0<0c?l01`3o
c00M0?mV0080ol`0603oIP000`3<o`00ofH00?mV000>0?mV0080ol`000<0c?l006Ko0000ol`00P1V
o`000`3<o`00ol`006Ko00030?o<00L0ofH04`3o00050?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool00P3ooolE0?l000<0ol`00`3oIP020?o<00030000o`3oc000c?l00080c?l000<00?mV
06H0o`00o`000P3<o`020?o<0180ofH000<0ol`00?mV003oIP00503oIP000`3oc000ofH00?mV000N
0?mV00P0ol`00`3<o`000`1Vo`00c?l00<co00090?o<01h0ofH000<0c?l00?mV003oIP009`3oIP03
0?o<0004003o0000ofH00<co003<o`80I_l000<0o`3<06Ko001Vo`000P1Vo`000`00o`000?o<003o
c0030?mV01<0o`001@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo5@3o0009
0?mV0080ol`00P3<o`000`1Vo`000?mV0<co00020<co0003003<o`3oc000ol`00140ofH000<00?mV
0?mV003oIP004`3oIP000`3oc000ofH00?mV000O0?mV00P0ol`000@0c?l006Ko001Vo`000?l00P3<
o`080?o<0200ofH00P3oc00E0?mV00030<co003oIP00ofH000h0ofH000H0ol`00<co003<o`00c?l0
06Ko0000c?l2001Vo`0306Ko003<o`00ol`000<0ol`01P3oIP000`00ol`0o`000?l0000A0?l000D0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaH0o`002@3oIP001@3oc000c?l0
0<co0000o`00I_l000<0ol`00P3<o`030?o<0100ofH0303o00090?mV00030?o<003oIP00ofH001l0
ofH0203oc000103<o`00I_l006Ko0000o`020<co00P0ol`0803oIP020?o<01D0ofH000<0ol`00?mV
003oIP003P3oIP001P3oc000c?l00<co0000o`00c?l006Ko00800?o<00<0I_l00?o<003oc0002@3o
IP0D0?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaH0o`002@3oIP03
0?o<0003003<o`3<o`00c?l000<0ol`000@0c?l006Ko003<o`00c?l0303oIP0D0?l000@0ofH000<0
ol`00?mV003oIP00803oIP070?o<0080c?l00P1Vo`000`00o`00c?l00<co00080?o<0280ofH000<0
ol`00?mV003oIP000`3oIP0@0?l000l0ofH000L0ol`00?l0003oc000ol`0003o003oc00006Ko0080
I_l000<0c?l00?o<003oc0002@3oIP0D0?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`020?oooaH0o`002@3oIP030?o<0003003<o`3<o`00c?l000<0ol`000@0c?l006Ko003<o`00
c?l0303oIP0D0?l000@0ofH000<0ol`00?mV003oIP00803oIP070?o<0080c?l00P1Vo`000`00o`00
c?l00<co00080?o<0280ofH000<0ol`00?mV003oIP000`3oIP0@0?l000l0ofH000L0ol`00?l0003o
c000ol`0003o003oc00006Ko0080I_l000<0c?l00?o<003oc0002@3oIP0D0?l000D0oooo0@000001
0?ooo`006`3oool00`000000oooo0?ooo`020?oooaH0o`002@3oIP00103oc0000?mV003oIP1Vo`02
0?o<00L0ofH000<0I_l00?mV003oIP001`3oIP0J0?l002<0ofH000<0I_l00?o<003oc0000`3oc003
0<co00800?o<00<0o`00003o003<o`000P3<o`060?o<0003003o003oIP00ofH001l0ofH000<0ol`0
0?mV003oIP005`3o000:0?mV00030?o<003<o`00ol`000<0ofH0103oc0000`1Vo`00ol`00?o<0009
0?mV01@0o`001@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo5P3o00090?mV
00050?o<003<o`00c?l0003o003oc0002@3oIP000`00c?l0ofH00?mV00030?mV01h0o`008P3oIP02
0?o<00070<co0000ofH00?mV003oIP1Vo`00c?l006Ko0002003oIP03003<o`00o`00c?l000800?mV
00<0c?l006Ko003<o`00103oc00R0?mV01/0o`00203oIP000`3oc000ofH00?mV00040?mV00<0ol`0
00<0003o0?o<003oc000203oIP0E0?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo0?oo
o`020?oooaP0o`001@3oIP020?o<000506Ko00000?l0003o0<co003oc0003@3oIP0R0?l001h0ofH0
1`3oc000103<o`000?mV003o0000o`02003<o`030000o`00ofH0o`3<00800?l00P3<o`050?o<01l0
ofH08@3o000=0?mV0080ol`000<0I_l00<co003oc000203oIP0E0?l000D0oooo0@0000010?ooo`00
6`3oool00`000000oooo0?ooo`020?oooaP0o`000`3oc00206Ko0003003oc03<o`00I_l000800?mV
0P3oc00;0?mV02H0o`00703oIP070?o<00<0c?l000H0I_l0001Vo`00I_l006Ko003o001Vo`030<co
00L0ol`07@3oIP0S0?l000030?mV003oc000ofH000T0ofH00P3<o`000`00ol`00?mV0?o<00030?o<
00D0ofH05@3o00050?ooo`4000000@3oool000P0oooo0P0000040?ooo`8000001@3oool3000000<0
oooo00<000000?ooo`3oool00P3ooolH0?l000<0ol`00P1Vo`000`00ol`0c?l006Ko0002003oIP80
ol`02`3oIP0V0?l001`0ofH01`3oc0030<co000606Ko0000I_l006Ko001Vo`00o`00I_l00`3<o`07
0?o<01d0ofH08`3o00000`3oIP00ol`00?mV00090?mV0080c?l000<00?o<003oIP3oc0000`3oc005
0?mV01D0o`001@3oool100000040oooo00070?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?oooaP0o`001@3oIP000`3<o`00ol`0003o0002
003oIP0306Ko003oc000ofH000P0ofH0:@3o000J0?mV00P0ol`00`3<o`001P1Vo`000?mV003oIP00
I_l00?l006Ko00<0c?l01`3oc00K0?mV02L0o`002P3oIP020?o<00030<co003o00000?mV0080I_l0
0P3oc0040?mV01D0o`001@3oool100000040oooo00070?ooo`040000003oool0oooo000000P0oooo
1@0000030?ooo`8000000`3ooolH0?l000H0ofH000@0ol`00?l0003<o`00c?l00P3oc0000`1Vo`00
ofH00?mV00050?mV02/0o`00603oIP090?o<00040<co001Vo`000?mV0?l000800?o<00<0IP3o003o
0000c?l00P1Vo`000`3<o`00ol`00?o<00040?o<00030<co003oc000ol`001L0ofH0:`3o00070?mV
00060<co0000o`000?l006Ko0000I_l0c?l00P3oc0060?mV01D0o`00103oool200000040oooo0007
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?oooaP0o`001P3oIP00103oc000c?l00?o<003oc0030?mV00800?l00`3oIP0^0?l001H0
ofH00`3oc0030<co0080ol`00P1Vo`020<co000706Ko0000o`000?o<003oc0000?l00?l006Ko0004
0<co00<0ol`000<0c?l0003<o`3oc0000`3oc00E0?mV02d0o`001@3oIP000`3oc000c?l00?o<0002
0?o<0004003o003<o`00ol`00?o<00H0ofH05@3o00050?ooo`4000000@3oool000L0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo603o
00050?mV00<0ol`02@3oIP0a0?l00180ofH00P3oc0000`3<o`00ol`00?o<00020<co0003003oIP3<
o`00c?l000<0c?l000<0o`1V06Ko0000o`000P00c?l00`3<0?l00?o<003o000206Ko00030<co0000
o`00c?l00080c?l00P1Vo`050?o<01@0ofH0;P3o00030?mV00030<co003oIP00ofH000<0ofH000@0
ol`006H0o`3oc000ol`01P3oIP0E0?l000D0oooo0@0000010?ooo`00203oool2000000/0oooo0P00
00040?ooo`030000003oool0oooo0080oooo603o00050?mV00<0ol`02@3oIP0a0?l00180ofH00P3o
c0000`3<o`00ol`00?o<00020<co0003003oIP3<o`00c?l000<0c?l000<0o`1V06Ko0000o`000P00
c?l00`3<0?l00?o<003o000206Ko00030<co0000o`00c?l00080c?l00P1Vo`050?o<01@0ofH0;P3o
00030?mV00030<co003oIP00ofH000<0ofH000@0ol`006H0o`3oc000ol`01P3oIP0E0?l000D0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaP0o`0000<0ofH00?o<0000ofH00P3o
c0000`3<o`000?o<0<co00080?mV03<0o`003`3oIP00103oc0000?l00?o<003oc0030<co00@00?l0
00<0o`00003o0000o`000P00ol`01`1V0?l0o`000?l0003o0000003o06H0o`00c?l00P3o0<`00`00
I_l00?o<06Ko0002003o0003003oIP1Vo`00c?l00080c?l000<0I_l00?o<003oc0000P3oc00@0?mV
0300o`000P3oc0060?mV00050?o<003<o`00I_l006Ko003oc0001@3oIP0E0?l000D0oooo0@000001
0?ooo`006`3oool00`000000oooo0?ooo`020?oooaP0o`000`3oIP030<co0004003oc000ofH0ol`0
0?o<00D0ofH0=03o000>0?mV0080ol`00`3<o`000`1Vo`00o`0006Ko000206Ko0003003o0000ofH0
I_l00080c?l00`1Vo`001P00o`000<co003<o`00I_l00?mV001Vo`@0I_l000H0c?l006Ko001Vo`00
0?o<003oIP00c?l20000o`0306Ko003<o`00I_l000<0ol`03P3oIP0c0?l000H0ofH000H0ol`0003o
c000o`000?l00000o`3oc0030?mV01H0o`001@3oool100000040oooo000K0?ooo`030000003oool0
oooo0080oooo603o00050?mV00030?o<003<o`00ol`000<0ol`00P3oIP0g0?l000X0ofH00`3oc000
0`1Vo`000?mV0<co00020<co00030?o<001Vo`00ol`00080ol`000<00?mV0<co001Vo`00103<o`00
1`1Vo`000?l0003<o`00c?l0003o003o001Vo`001`3<o`000`00ol`0c?l00?o<00040<co000406Ko
003o06H0o`1V06Ko0080ol`02P3oIP0f0?l000D0ofH000D00?l00<co003o06H0o`1V0?o<00040?mV
01H0o`001@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo603o00030?mV0080
ol`000<0c?l00?o<003oIP00103oIP0h0?l000P0ofH000<0ol`00?l0003<o`00303oc0000`1Vo`00
ol`00?o<00020?o<0080c?l000H00?mV003o0000ol`00?o<003<o`00o`0306Ko00030<co003oc000
ol`00080ol`000<0c?l00?o<003oc0002@3oc000103<o`00I_l006Ko003oc0070?mV03L0o`001@3o
IP040?o<00@0ofH05P3o00050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolH
0?l000<0ofH00P3oc0000`3<o`00ol`00?mV00040?mV03P0o`00203oIP000`3oc000o`000<co000<
0?o<000306Ko003oc000ol`00080ol`00P3<o`001P00ofH00?l0003oc000ol`00<co003o00<0I_l0
00<0c?l00?o<003oc0000P3oc0000`3<o`00ol`00?o<00090?o<00040<co001Vo`00I_l00?o<00L0
ofH0=`3o00050?mV00@0ol`0103oIP0F0?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`020?oooaP0o`000P3oIP001@00ol`0I_l006Ko001Vo`00ol`000D0ofH0>@3o00030?mV0004
0?o<0000I_l0ol`00?o<00/0ofH02P3oc0020<co0005003o0000ol`00?o<0<`0o`3o00000`3<o`0;
0?o<00T0ofH00P3oc0000`3<o`00ofH00?mV00020?mV03T0o`001@3oIP020?o<00030<co003oc000
ofH000<0ofH05@3o00050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolH0?l0
00<0ofH00P00o`000`3<o`00I_l00?mV00030?mV03X0o`000`3oc00A0?mV00P0ol`000<00?mV06Ko
0000o`000P000?l00`3o00000?l006Ko0002003o00H0ol`000<0I_l00?mV003oIP00403oIP000`3<
o`00ofH00?l0000h0?l000D0ofH00P3oc0000`1V0?l0c?l00?mV00030?mV01D0o`001@3oool10000
0040oooo000K0?ooo`030000003oool0oooo0080oooo603o00030?mV00800?mV00<0ol`00?mV003o
IP000P3oIP0m0?l001@0ofH01@3oc000103<o`00I_l0003o001Vo`02003oc003003<o`1Vo`00I_l0
0080IP3o00<0c?l00?o<003oc0000`3oc00E0?mV03/0o`000P3oIP001@3<o`00ol`00?o<003<o`00
ol`000@0ofH05@3o00050?ooo`4000000@3oool001/0oooo0P0000030?oooaP0o`0000<0ofH00?o<
003<o`000P1Vo`030?mV03l0o`005@3oIP020?o<00800?l0103<o`020?l00003003oIP3<o`00c?l0
00<0c?l000@0I_l00?o<003oc000ol`05@3oIP0m0?l000@0ofH000<0ol`00<co003oIP000`3oIP0E
0?l000@0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaP0o`0000<0ofH00?o<
003<o`000P1Vo`030?mV03l0o`005@3oIP020?o<00800?l0103<o`020?l00003003oIP3<o`00c?l0
00<0c?l000@0I_l00?o<003oc000ol`05@3oIP0m0?l000@0ofH000<0ol`00<co003oIP000`3oIP0E
0?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaP0o`000P3oIP040?o<
0080ofH0?`3o000F0?mV00H0ol`00`3<o`000`1Vo`00c?l00?o<00050?o<01L0ofH0?P3o00030?mV
0003003oIP1V0?l0ol`000<0ofH05@3o00050?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool00P3ooolH0?l000030?mV00000?l00?l000@0ofH0@@3o000E0?mV00H0ol`000D0003o003o0000
o`000?l006Ko00060?o<01H0ofH0?`3o00040?mV0080ol`00`3oIP0E0?l000D0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`020?oooaH0o`000`3oIP001@3oc000c?l00?o<003oc000ofH0
0480o`005P3oIP050?o<00<0c?l000<0I_l00<co003oc0001@3oc00F0?mV0400o`000`3oIP001@3o
c000I_l00?o<003oc000ofH001D0o`001@3oool100000040oooo000K0?ooo`030000003oool0oooo
0080oooo5P3o00030?mV00030?o<003oIP00ofH00080ofH0@P3o000F0?mV00D0ol`000@0c?l006Ko
001Vo`000?l00P3<o`040?o<01L0ofH0@P3o00000`3oc000ofH00<co00030?mV01D0o`001@3oool1
00000040oooo000K0?ooo`030000003oool0oooo0080oooo5P3o00030?mV00030?o<003oIP00ofH0
0080ofH0@P3o000F0?mV00D0ol`000@0c?l006Ko001Vo`000?l00P3<o`040?o<01L0ofH0@P3o0000
0`3oc000ofH00<co00030?mV01D0o`001@3oool100000040oooo000K0?ooo`030000003oool0oooo
0080oooo5P3o00030?mV0004003oIP3<o`00ofH00?mV04<0o`005P3oIP030<co00800?l000H00?o<
003oIP00ofH0c03o003o0000ol`306Ko00030<co003oIP00ofH001D0ofH0@P3o00020?mV00040?o<
003<o`00c?l00?mV01D0o`001@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo
5P3o000206Ko0080ol`00`3oIP130?l001H0ofH01@3oc000103<o`00I_l006Ko0000o`020<co00@0
ol`05`3oIP130?l000040?o<003oIP00c?l00<co0080ofH0503o00050?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool00P3ooolF0?l00080ofH000<0ol`00?mV003oIP00AP3o000E0?mV00D0
ol`00`3<o`000`1Vo`00c?l00?o<00050?o<01H0ofH0@`3o00020?mV00800?l00P3oIP0D0?l000D0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaH0o`000P3oIP000`00o`00ofH0
0?l000160?l001@0ofH01P3oc0001@3<o`000?mV003oIP00ofH0c?l000H0ol`0503oIP160?l000<0
ofH00P3oc00D0?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooaH0o`00
0P3oIP000`00o`00ofH00?l000160?l001@0ofH01P3oc0001@3<o`000?mV003oIP00ofH0c?l000H0
ol`0503oIP160?l000<0ofH00P3oc00D0?l000D0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`020?oooaD0o`0000<0ofH0003oIP00ofH00P3oIP170?l001@0ofH01P3oc0030<co000306Ko
003<o`00ol`000D0ol`0503oIP160?l000<0ofH000<0I_l00?mV003o00004`3o00050?ooo`400000
0@3oool001/0oooo0P0000030?oooaD0o`0000@0ofH00<co003<o`00ofH0B03o000C0?mV0080ol`0
1P3<o`02003oc003003<o`3<o`00c?l000@0c?l00`3oc00B0?mV04L0o`000P3oIP000`3oc000ofH0
0?l0000C0?l000@0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool06`3oool10000
0040oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0@0000010?ooo`006`3ooooo000000D00000
0@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.629143, -0.599351, \
0.00400575, 0.00400575}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(gr15 = 
        DensityPlot[
          juliaC1[x, y, 90, 
            3.96,  .01], \[IndentingNewLine]{x, \(- .2\),  .2}, {y, \(- .2\), \
 .2}, PlotPoints \[Rule] 200, Mesh -> False, 
          ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 2.40385 0.5 2.40385 [
[.01923 -0.0125 -12 -9 ]
[.01923 -0.0125 12 0 ]
[.25962 -0.0125 -12 -9 ]
[.25962 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -9 -9 ]
[.74038 -0.0125 9 0 ]
[.98077 -0.0125 -9 -9 ]
[.98077 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -24 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -24 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -18 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -18 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-0.2)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-0.1)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(0.1)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(0.2)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-0.2)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(-0.1)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(0.1)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(0.2)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0096FF003CFF00
001EFF00FF7800D2FFF000FF0078FF00D2FF0078FFF000FF00D2FF00FF78001EFF00FF78
00FF7800FFD200FF7800FF7800FFD200FFD200FF7800FF7800FFD2F000FF0078FF0078FF
FF0000F000FFFF0000001EFF0078FF00D2FFFF000000D2FF00D2FF9600FF0078FF00D2FF
0078FF00D2FF001EFF3C00FF00D2FF001EFF0078FFFF00B4001EFFFF000000FF7800FF1E
96FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB40000FF1E
96FF00FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF5A00FFB400FF5A00FF5A00FF0000
FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0096FF0000FF1E
3CFF0000FF1E00FF1E3C00FF0078FFFF00B4FF00009600FF00D2FF00FFD200FFD200FFD2
00D2FF00D2FF00FFD200FF7800FFD200FFD200FF7800FF7800FFD200D2FF0078FF0078FF
0078FF0078FF3C00FFFF005AFF00003C00FFFF00B4001EFF001EFFFF0000001EFFFF005A
F000FFF000FFFF00003C00FFFF0000F000FFFF000000D2FF0078FF00FF7800FF1E001EFF
96FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF5A00FF5A003CFF0000FF1EFF5A00FF0000
FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF0096FF0096FF0096FF00
96FF0000FF7800FFD200FF1E0078FFF000FF001EFFF000FFFF00009600FF0078FF0078FF
3C00FF0078FF00FFD200FFD20078FF00FFD200FFD200FFD200FFD200FFD200D2FF00D2FF
00D2FF0078FF0078FF001EFFFF00009600FFFF0000FF005AFF00B4FF0000FF0000F000FF
3C00FF3C00FF001EFF3C00FF3C00FF001EFF0078FF00FF1E00FF1E3CFF0096FF003CFF00
00FF1E96FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000096FF00FFB400FFB400FF5A00FF5A00FF0000
FF5A00FF5A00FFB400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
96FF003CFF003CFF003CFF0000FF1E00D2FF9600FF001EFF001EFFFF0000FF0000FF00B4
FF0000001EFF0078FF00D2FF0078FF00D2FF00D2FF00D2FF00FFD200FFD200D2FF00D2FF
00D2FF001EFF00D2FF0078FF0078FF001EFFFF00B40078FF0078FF001EFFF000FF00D2FF
00D2FF0078FF00D2FF00D2FFFF000000FFD200FF1E3CFF0000FF1E3CFF0096FF0096FF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF5A00FF5A00FFB400FFB400F0FF00FF5A00FF0000
96FF00FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0096FF0000FF1E00FF78FF00B49600FF00FFD200FFD200D2FF3C00FF3C00FF
F000FFFF0000FF00003C00FFFF005A0078FF0078FF00D2FF00D2FF0078FF00D2FF00D2FF
00D2FF0078FF00D2FF00D2FF00D2FF00D2FF00D2FF00FFD200D2FF00D2FF9600FF00D2FF
00FF783C00FF00FF7800FFD2FF00B400FFD200D2FF00FF1E96FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF5A00FF5A00FF5A00F0FF00FF5A00FF5A00FF5A00FF0000
FFB400FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF003CFF003CFF0000FF1E00FFD200FFD200FF7800FFD200FFD200FFD20078FF
F000FF3C00FF9600FFFF00B4FF00B43C00FF3C00FF0078FF0078FF0078FF00D2FF00D2FF
00D2FF00FFD200FFD200FFD200FFD200FFD20078FF00FFD200FFD20078FF00D2FF00FF78
00FF780078FF00FF1E00FF7800FF783C00FF3CFF003CFF0096FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00
FF5A00FF5A00FFB400FF0000FFB400FF5A00FF5A00FF0000
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0000FF7896FF0096FF0096FF00
3CFF003CFF003CFF003C00FF00FF1E00FF1E0078FF00FF1E00FFD200FF7800FFD2001EFF
0078FF00D2FF00D2FFFF00B43C00FFF000FFFF00B4001EFF3C00FF0078FF00D2FF00D2FF
0078FF00FFD200FFD200FFD200FF7800FFD2FF000000FF7800FF7800FF7800FFD200FF78
00FF1E00FF1E00FF1E00FF1E00FF1E3CFF00001EFF3CFF003CFF003CFF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00
FF5A00FF5A00FFB400FFB400FF5A00FF5A00FF5A00FF0000
FFB400FFB400FF5A00FFB400FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF0096FF003CFF003CFF0096FF00
3CFF00FF000000FF783CFF003CFF003CFF0000FF1E3CFF0000FF1E00FF1E00FFD200FFD2
3C00FF00FFD200FFD20078FF00D2FF001EFF001EFFFF00003C00FF001EFF0078FF001EFF
0078FF001EFFFF00B400FF7800FF7800FF7800FFD200FF7800FF1E00FF1E00FF78001EFF
0078FF00FF1E3CFF003CFF003CFF003CFF003CFF0000FF7800FF783CFF0096FF003CFF00
96FF0000FF1EF0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00
FFB400FFB400F0FF00FFB400FF5A00FF5A00FF5A00FF0000
3C00FFF0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FFB400FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400F0FF00
00FF1E96FF0096FF0096FF0096FF00F0FF0096FF0096FF0000FF7800D2FF00FFD2FF00B4
3CFF003CFF003CFF0096FF0096FF0000FF1E3CFF003CFF0000FF1E00D2FF00D2FF00FF78
00FF7800FF7800D2FF00FFD200D2FF00D2FFFF00B43C00FFFF0000FF0000001EFF0078FF
00D2FF00D2FF0078FF00FFD200FF7800FF7800FF78FF000000FF1E00FF1E00FF1E00FF78
00FF7800FF1E3CFF003CFF0096FF0096FF0096FF003CFF0000FF1E00FFD23CFF0000FF1E
3CFF0096FF00F0FF00F0FF0096FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00
FF5A00FFB400001EFF96FF00FFB400FF5A00FF5A00FF0000
9600FFFFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FFB400FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400
FFB400FFB400F0FF00F0FF0000FF7896FF003CFF0096FF003CFF0000FF1E00FF1E3CFF00
96FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF000078FF9600FF3C00FF00FF1E
00FF1E00FF7800D2FF00FF7800FFD200FFD200D2FFFF005AFF00003C00FF0078FF00D2FF
00FFD200FFD200FFD200FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00D2FF0078FF3CFF0096FF0096FF0096FF0096FF003CFF003CFF0096FF003CFF0000FFD2
3C00FF00D2FF96FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400F0FF00FFB400FF5A00FF5A00FF5A00FF0000
96FF00F0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00F0FF00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF0000FF7896FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF003CFF0000FF1E3C00FF00FF7800FF1E00FF1E
00FF1E00FF7800D2FF00FF78F000FF001EFF00D2FF0078FF9600FFFF00003C00FF0078FF
00D2FF00FFD200FF7800FF7800FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF00
001EFF00FF783CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0000FF1E3CFF00
00FFD200FF1E00FF1E3CFF003CFF003CFF0096FF0096FF0096FF00F0FF00FFB400FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FFB400FF5A00FF5A00
FFB400F0FF003CFF00FF5A00FF5A00FF5A00FF5A00FF0000
FFB400F0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A0096FF00FF5A00FF5A00FF5A00
FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A0000FF1E
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF003CFF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF0096FF003CFF0000FF1E00FF1E3CFF003CFF003CFF00
00FF1E00FF1E00FF1E00FF7800FF7800FFD200D2FF001EFF3C00FFFF00003C00FF001EFF
0078FF00FFD20078FF00FF7800FF7800FF7800FF1E00FF1E3CFF003CFF003CFF003CFF00
00FF1E3CFF0000FF1E3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
00FF1EF0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A003CFF00FFB400
FFB40000FF78F0FF00FF5A00FF5A00FF5A00FF5A00FF0000
FFB40096FF00FFB400FFB400FF5A00FF5A00FFB400F000FFFF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400
001EFFFFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF003CFF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF7800FF7800FFD20078FF001EFF9600FFFF00B4FF0000FF0000
FF0000F000FF001EFFFF000000FFD2FF00000078FF00FF1E3CFF003CFF003CFF003CFF00
00FF1E96FF0096FF003CFF003CFF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
3CFF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00F0FF00
00FF1E00FF1EF0FF00FFB400FF5A00FF5A00FF5A00FF0000
FFB4003CFF0000FF1EFFB400F0FF00FFB400F0FF00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB4003CFF00FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
00FF1E00FF7800FFD200FFD2001EFF001EFF3C00FFFF005AFF00B4FF005A3C00FF001EFF
0078FF00FFD200FFD200D2FF00FF7800FFD200FFD2FF000000FF783CFF003CFF003CFF00
96FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00F0FF00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400
96FF0096FF00FFB400FFB400FFB400FF5A00FF5A00FF5A00
FFB40096FF0000FFD2F0FF0000FF1EF0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB4003CFF00FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400FFB400F0FF00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF0000FFD2
00FFD200FF7800FFD200FF7800FFD200FFD200D2FF0078FF3C00FFFF00003C00FF3C00FF
00D2FF00FFD200FF7800FF7800FF1E00FF1E00FF7800FF1E3CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400
00FF1EFF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF5A00FF5A00FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400
F0FF00FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
96FF003CFF000078FF96FF00FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400FFB40096FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FF7800FF7800FFD200D2FF001EFFFF00B49600FF0078FF
00D2FF3C00FF00FFD200FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB4003CFF00
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FFB400FFB400
00FF78FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
F0FF0096FF000078FF96FF00FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB40096FF0096FF00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FFD2FF00B4FF00B40078FF9600FFFF005AFF0000001EFF
0078FF00D2FF00FF7800FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
96FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400F0FF00FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00
F0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400F0FF009600FF96FF00F0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A000078FFFF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400F0FF00F0FF0096FF00FF005AFFB400FFB400FFB400F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FF00B4FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF003CFF0096FF0096FF003CFF003CFF003CFF003CFF00
3CFF0000FFD200FF1E00FF7800FF7800FF7800FFD200D2FF001EFFF000FF9600FF0078FF
FF000000FFD200FFD200FFD200FFD200FF7800FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400F0FF003CFF00FFB400FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB40000D2FF96FF00FFB400F0FF009600FF
96FF00F0FF00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400F0FF0000FFD2F0FF00FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400FFB400FFB40096FF0000FF78F0FF00FFB400F0FF0000FFD2
FFB400FFB400FFB400FFB400FFB400FFB40096FF0096FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB40096FF0096FF0096FF0096FF00
96FF0096FF003CFF0096FF0096FF0000D2FF3CFF003CFF003CFF0000FF1E3CFF003CFF00
00FF1E00FF1E00FF1E00D2FF00FFD200FFD2001EFF0078FFFF00B4FF0000FF00B4001EFF
0078FF0078FF00FFD200D2FF00FF7800FF1E00FF1E00FF783CFF0000FF1EFF00003CFF00
3CFF003CFF003CFF0000FF1E96FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB4003CFF00FFB40096FF00F0FF00FFB400FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00F0FF00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB40096FF003CFF0096FF009600FF
3CFF00FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400FFB4003CFF00F0FF00FFB400F0FF00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB40096FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FFB400F0FF0096FF00F0FF0000FF7896FF00F0FF003CFF00
FFB400FFB400FFB400FFB400FFB400F0FF0096FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF0096FF00
3CFF0000FF78001EFF3CFF0000FFD200FF7800FF1E00FF1E3CFF0000FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF7800D2FF0078FFF000FF001EFF001EFFFF00B4FF00009600FF
3C00FF001EFFFF00B40078FF00FFD200FF7800FF7800FF1E00FF1E00FF1E00FF1E3CFF00
3CFF0000FF7800FF1E3CFF003CFF0096FF003CFF0096FF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF0000FF1EF0FF00FFB400FFB400FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400F0FF003CFF0000FFD2
00FF1E96FF00F0FF00001EFFFFB400F0FF0096FF00FF5A00
FFB400FFB400F0FF0000FFD296FF00FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00F0FF00FFB40096FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400F0FF0000FF1E00FFD296FF00
00FF1EFFB400FFB400FFB400FFB400F0FF0096FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF003CFF003CFF0000FF7800D2FF001EFF001EFF00FFD2001EFFFF00B400D2FF
00D2FF00FFD200FFD20078FF001EFF9600FF9600FF3C00FFFF00B49600FF9600FFFF0000
F000FFF000FFFF00009600FF0078FF0078FF001EFF3C00FF0078FF9600FFFF0000F000FF
FF00B4FF005AFF00003C00FF00FFD2FF00B400D2FF00FF783CFF0000FF1E96FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB4003CFF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB4003CFF00F0FF003CFF00F0FF00FFB400FFB400FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400F0FF003CFF003CFF00
F0FF00F0FF00F0FF00FFB40096FF00FF5A00FF5A00FF5A00
FFB400FFB400FFB40000FF1EF0FF00FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00
FFB400FFB400FFB40000FF78FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400F0FF0000FF1E00FF1E00FF1E
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0000FF7800FF1EF0FF00F0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0000FF7896FF0096FF0000FF1E00FF1E3CFF003CFF003CFF0000FF7800FF1E00FF1E
00FF7800FF7800FF7800FFD20078FF3C00FF9600FFF000FFFF0000F000FF9600FF001EFF
0078FF0078FF001EFF00FFD200FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E3CFF00
3CFF0000FF7800FF1E3CFF003CFF0096FF003CFF0096FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400F0FF0000FF1EFFB400FFB400FFB400FFB400FFB400FFB400FFB40096FF00
FFB400FFB400F0FF003CFF000078FFF0FF00FFB400FFB400FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400F0FF00FF00003CFF00
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400FFB400F0FF003CFF00F0FF00FFB400F0FF00FFB400FFB400FFB400FFB400
FFB400FFB40096FF00F0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB40000FF78F0FF0096FF0096FF00
FF000096FF00F0FF0000FF1EF0FF0096FF0000FF783CFF00F0FF00F0FF00F0FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0000FF1E3CFF003CFF003CFF003CFF0000FF1E3CFF003CFF00
00FF1E00FF1E00FF1E00FF789600FF00D2FF9600FF001EFF9600FFFF005A3C00FF0078FF
00D2FF0078FF00FFD2FF000000D2FF00FF1E00FF1E00FFD23CFF003CFF0000D2FF3CFF00
3CFF003CFF003CFF0000FF1E96FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF003CFF003CFF00F0FF00FFB400FFB400FFB400FFB400FFB4003CFF00FF005A
F0FF00F0FF003CFF0096FF00F0FF00F0FF00FFB400FFB400FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00F0FF00FFB400FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400F0FF0096FF00F0FF00
F0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400FFB400F0FF00001EFF96FF0096FF00F0FF00FFB400FFB400FFB40000FFD2
FFB400F0FF0096FF003CFF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB4003CFF00FFB400FFB400FFB400F0FF00F0FF00
96FF0096FF0000FF1E00FF1E96FF0096FF0000FF1E96FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF003CFF0096FF0096FF0096FF0096FF0096FF000078FF3CFF003CFF003CFF00
3CFF0000FF1E00FFD200FFD200FF780078FF00D2FFFF00003C00FFFF00003C00FF0078FF
00D2FF00FFD200FF7800FF7800FF7800FFD200FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF0096FF0096FF003CFF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF00F0FF0096FF00F0FF00F0FF00FFB400FFB400FFB400F0FF00F0FF0096FF00
3CFF000078FFF0FF00FFB400FFB400FFB400F0FF00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A0096FF00FFB400FFB400FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB40096FF00F0FF00FFB400
FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400F0FF0000FF1E96FF0000FF1E001EFF96FF00F0FF00FFB400FFB400FFB400F0FF00
00FFD296FF00FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF003CFF00FF005A00FFD200FF1E3CFF0096FF0096FF0096FF0000D2FFF0FF00
F0FF00F0FF00F0FF00F0FF00F000FFF0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF7800FF7800D2FF00D2FF0078FF3C00FFFF0000FF00B4001EFF
0078FFFF000000FF7800FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400F0FF00F0FF00
F0FF00F0FF0000FF1E00FF7896FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FF78
00FFD296FF00F0FF00FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB4003CFF00FFB400FFB400FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB40096FF003C00FF96FF00FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400F0FF0096FF003CFF000078FF96FF003CFF00F0FF0096FF00F0FF003CFF00
00FF78F0FF00FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF0096FF0096FF0000FF1E0078FF3C00FF00FF1E00FF1E96FF0000FFD296FF00F0FF00
F0FF00F0FF00F0FF00F0FF003CFF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FF7800FFD200D2FF0078FF3C00FFFF00003C00FF0078FF
00D2FF001EFF00FF7800FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF003CFF00F0FF00F0FF003CFF00F0FF00F0FF0096FF0000FFD23CFF00
96FF0000FF1EF0FF00FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB40096FF00FFB400FFB400
FFB400FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400F0FF0000FF1EF0FF00FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400F0FF0096FF003CFF00FF005A00FFD296FF00F0FF0096FF003CFF003CFF00
F0FF0096FF003CFF00FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF0096FF0096FF0000FFD200FFD2F000FF00FF7800FF1E00FF7896FF00F0FF00
F0FF00F0FF00F0FF00F0FF0000FFD296FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0000FF1E00FF1E00FF1E
00FF1E00FF7800FF1E00FF7800FF7800FFD200FFD2001EFFF000FFFF00009600FF0078FF
00D2FF00FFD200FF7800FF7800FF7800FF7800FF1E00FF7800FF1E3CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0000FF78F0FF00F0FF00F0FF00F0FF00F0FF000078FFF0FF00
F0FF00F0FF003CFF003C00FF96FF0096FF0000FF1E96FF0096FF003CFF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400F0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB40000FFD2FFB400FFB400F0FF0000FF1EFFB400FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400F0FF00F0FF0096FF003CFF0000D2FF00FF7800FF783CFF0000FFD20078FFF0FF00
F0FF00FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF0096FF0000FF1E3CFF003CFF0000FF1E00FFD2001EFF00FF1E00FF7896FF00
F0FF00F0FF0096FF0096FF0000FFD296FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E
00FF783C00FF00FFD200D2FF00FFD200FFD29600FF0078FF001EFFFF00009600FF3C00FF
0078FF00FFD200FFD200D2FF00FFD23C00FF00D2FF0078FF00FF1E3CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
96FF0096FF0096FF003CFF0000FFD200FF1E00FF1E3C00FF96FF00F0FF003CFF00F0FF00
FFB400FFB400FFB400FFB400F0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB40096FF0000FF78F0FF00
FFB400F0FF00FFB400FFB400FFB400F0FF003CFF00F0FF0000FF1E96FF00FFB400FFB400
FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
F0FF0096FF0096FF0096FF0000FFD200D2FF3C00FF00D2FF96FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF003CFF0000D2FF96FF0096FF00FF000096FF0000FF1E00FF1EF000FF3CFF0096FF00
96FF0096FF0096FF0096FF003C00FF96FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0096FF0096FF0000FF1E3CFF003CFF0000FF1E3CFF003CFF003CFF0000FF1E
00FF7800FF7800FF78001EFF00D2FF001EFF9600FFFF0000F000FFFF00B4FF00B4FF005A
9600FF00D2FF00FFD200FFD200FF7800FF780078FF00FF1E3CFF003CFF003CFF003CFF00
96FF0096FF0096FF0096FF0096FF003CFF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000D2FF
96FF0096FF0000FF7800FF7800D2FF9600FF00FF1E00D2FF96FF00F0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400F0FF00FF0000
F0FF0096FF00FFB400FFB400FFB400F0FF00F0FF0000FFD2001EFF96FF0000FF1E96FF00
FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
96FF003CFF003CFF0000FF1E00FF1E00FFD2001EFF00FFD296FF00F0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00
3CFF003C00FF96FF00F0FF00F0FF0096FF0096FF0000FF1E96FF003CFF0096FF00FF0000
3CFF003CFF003CFF003CFF000078FF96FF0096FF003CFF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF000078FF3CFF0000FF783CFF003CFF003CFF0000FF1E
00FF1E00FF1E00FF7800FF7800FF7800FFD20078FF001EFF9600FFFF00009600FF001EFF
0078FF00D2FF00FF7800FF7800FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF0000FF1E3CFF0000FF7896FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF003CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF00
001EFF00FFD200FF783C00FF0078FF00FF78FF000096FF00F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400F0FF00
001EFF96FF00F0FF00F0FF00F0FF0096FF0096FF0000FF7800FFD296FF00F0FF00F0FF00
FFB400FFB400FFB4003CFF00FF5A00FF5A00FF5A00FF5A00
F0FF0096FF00F0FF00F0FF0096FF0000FF1E9600FF00FF7800FF783CFF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400F0FF0000FF1EFF000000FF1E96FF00F0FF00
96FF00F0FF0000FF1EF0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF00
3CFF0000D2FF00FFD200FFD200FF783CFF003CFF003CFF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF000078FF00FF7800FF1E3CFF003CFF0000FF1E
00FF1E00FF1E00FF7800FF7800FF7800FFD200D2FF0078FF001EFFFF00009600FF9600FF
00D2FF00FFD200FF7800FF7800FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF0000FF78
00FF1E3C00FF3CFF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00
F0FF0096FF003CFF0000FF1E00FF7896FF0096FF00F0FF0096FF0096FF00FF00003CFF00
00FF78001EFF00FFD2001EFF00FF1E0078FF96FF0096FF00F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400F0FF0000FF78
96FF0000FF1E96FF003CFF00F0FF0096FF0000FF7800FF1E00FFD296FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF00F0FF003CFF0000FF1E0078FF00FF7896FF0096FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0000FF78F0FF00F0FF00F0FF00F0FF0096FF00
3CFF003CFF0000FFD2FF00B40078FF00FF7800FFD23CFF0096FF0096FF003CFF003CFF00
96FF0096FF0096FF0096FF003CFF003CFF0000FF1E001EFF00FF1E00FF1E00FF1E00FF78
00FF1E00FF1E00FF7800D2FF00FFD200FFD200D2FF0078FF001EFFFF005AFF00000078FF
00D2FF00D2FF0078FF00FFD200FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF78
00D2FF3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0000FF78001EFF
001EFF00D2FFFF000000FF1E96FF0096FF0000FF7896FF00F0FF0096FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB40096FF00
F0FF00F0FF0096FF0000FF783CFF003CFF0000FF78001EFF00D2FF3CFF00F0FF00F0FF00
FFB400FFB400F0FF00FFB400FFB40000FF78FFB40096FF00
FFB400FFB40096FF00F0FF0096FF0096FF0000FFD200FFD200FF1E96FF00F0FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF003CFF0000FF7800FF789600FF00D2FF00FF1E00FF1E00FF1E00FF1E00FF1E
96FF0096FF0096FF0096FF003CFF003CFF0000FF1EFF005A00D2FF00FF1E00FF1E00FF78
00FFD200FF7800FF7800FF7800D2FFFF00B40078FF0078FF3C00FFFF005AFF0000FF005A
0078FF00D2FF00FFD200FF7800FF789600FF00FFD200FF1E00FF1E00FF1E00D2FF3C00FF
00FF1E00FF1E3CFF0096FF0096FF0096FF0096FF0096FF003CFF0096FF0096FF0096FF00
00FF1E96FF0096FF003CFF003CFF0000FF1E00FFD200FF1E00FF1E9600FF3CFF0000FF1E
3CFF0000FF783CFF0096FF0096FF0096FF0096FF00FF000000FF1EF0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF0096FF003CFF003C00FF00D2FFFF000000FF7800FF78F0FF00F0FF00
F0FF0096FF0000D2FFF0FF00F0FF0000D2FFF0FF00FFB400
FFB400FFB400F0FF00F0FF00F0FF0096FF0000FF1E9600FF00FF783CFF0000FFD20078FF
3CFF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF003CFF0000FF1E3CFF003CFF0000FFD200FF1E3CFF0000FF7800FFD200FF7800FF78
00FF1E3CFF003CFF003CFF0000FF1E3CFF0000FF1E00FF1E001EFF00FF7800FF7800FF78
0078FF00FFD200FF7800FFD200FFD200D2FF00D2FF0078FF9600FFFF0000F000FF001EFF
0078FF00D2FF00FFD200FFD200FFD2001EFF00D2FF00FF7800FF1E00FF7800D2FF00FF1E
3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF003CFF0096FF0096FF0096FF00
3CFF0000FF1E3CFF0000FF1E00FFD200FFD200D2FF001EFF3CFF003CFF0096FF0096FF00
96FF003CFF0000FF1E96FF00F0FF00F0FF00F0FF003CFF003CFF003CFF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF00F0FF0000FF1E00FF1E00D2FF3C00FF00D2FF0078FF00FF1E00FFD2
3CFF003C00FF00FFD23CFF00F0FF00F0FF00F0FF00FFB400
FFB400FFB400F0FF00F0FF0096FF003CFF000078FFFF005A00FF1E96FF0096FF0096FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF00FF00B43CFF0096FF0096FF0000FF1E96FF0096FF003CFF0000FF1E3C00FFFF0000
00FF1E00FF1E3CFF003CFF000078FF00FF1E00D2FF00FF7800FFD200FFD200FFD200FF78
00D2FF001EFF00FFD200D2FF00FFD200D2FF00D2FF0078FF001EFF9600FFFF00009600FF
001EFF00D2FF3C00FF00FFD200D2FF00D2FF00FF7800FF7800FF78001EFF00FF7800FF1E
3CFF003CFF003CFF003CFF0096FF0096FF0096FF003CFF0000FF783CFF0096FF003CFF00
3CFF0000FFD200FFD29600FF9600FF00FFD200FF1E00FF7896FF0096FF0096FF00F0FF00
F0FF0096FF00001EFFF0FF00F0FF00F0FF00F0FF0096FF00F0FF0096FF0096FF003CFF00
96FF0096FF00F0FF00FFB400FFB400F0FF00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400F0FF0096FF0096FF003CFF0000D2FF001EFF3CFF0096FF0096FF0096FF00
F0FF0096FF00F0FF0096FF00FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF0000FF1E3CFF0096FF003CFF0000FFD200FF1E96FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
00FFD296FF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0000FF1E00FFD200FF78
3CFF0000FF780078FF00FF1E00FFD200FFD200FFD200FFD20078FF9600FF00D2FF0078FF
00D2FF001EFF00FFD200D2FF00D2FF00D2FF001EFF9600FF3C00FFFF0000FF00009600FF
001EFF0078FF001EFF00D2FF0078FF00D2FF001EFF00FFD20078FF00FFD200FF7800FF78
00FF1E00FF1E3CFF003CFF003CFF003CFF0000FF1E3CFF0000FF7800FFD23CFF0000FF1E
00D2FF001EFF00FFD200FF7800D2FF00FF1E3CFF0096FF003CFF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF0096FF003CFF0000FF1EFF00000078FF3CFF0096FF00F0FF00F0FF00
F0FF00FFB400F0FF0096FF00FFB400FFB400FFB400FF5A00
96FF003CFF003CFF00F0FF00F0FF00F0FF0096FF0000FF1EFF000000FFD296FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0096FF003CFF00
96FF0096FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF0000FF1E3CFF0000FF1E
3CFF0000FF1E3CFF0000FF7800D2FFFF005AFF005A001EFF3C00FFF000FF0078FF0078FF
3C00FF001EFF00D2FF0078FF0078FF00D2FF0078FF001EFF001EFF3C00FF9600FFFF005A
FF0000F000FF3C00FF001EFFFF00000078FF9600FF0078FFFF000000D2FF00FFD200FFD2
00FF7800FFD200FF1E3CFF0000FFD200FF1E00FF1E00FFD2FF00000078FF00FF1E00FF1E
3CFF003CFF0000FF1E3CFF003CFF009600FF3CFF0096FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0000FF1EF0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00F0FF00FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF00F0FF00F0FF0096FF0000FF1E0078FF00FF1E3CFF0000FF1EF0FF00F0FF00
FFB400FFB400FFB400FFB400F0FF00FFB400FF5A00FF5A00
FFB400FFB400FFB400F0FF00F0FF00F0FF003CFF0096FF00FF00B496FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0000FF7896FF0096FF0096FF00
96FF003CFF003CFF0000FF1E00FF7800FF783C00FF001EFF9600FFFF0000F000FF9600FF
F000FFFF00B4FF0000001EFF0078FF3C00FF0078FF001EFF001EFF001EFF3C00FF3C00FF
9600FFFF005AFF0000FF0000FF00B4F000FFFF0000FF00B4FF00B43C00FFFF00B40078FF
9600FF001EFF0078FF0078FF00D2FF00FF7800FFD200FF1E00FF7800FF1E00FF7896FF00
96FF003CFF003CFF0096FF0096FF003CFF0000FF783CFF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400F0FF0000FF78F0FF00F0FF00
F0FF0000FFD296FF0096FF003CFF0000FF78F000FF00FF1E96FF00F0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00
FFB400FFB400FFB400FFB400FFB40096FF00F0FF00F0FF0000FF1E96FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FFB400FFB400FFB400F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0000FF1E96FF0096FF0096FF0096FF00
96FF0096FF003CFF003CFF0000FF1E0078FF00FF7800FFD2F000FF3C00FFFF00B49600FF
FF005AFF0000F000FFFF00003C00FF9600FF001EFF001EFF001EFF001EFF001EFFF000FF
001EFFFF00003C00FF9600FFFF00003C00FFFF005AFF005AF000FF9600FF001EFF0078FF
00D2FF00D2FF00FF1E3CFF003CFF003CFF003CFF003CFF003CFF0000D2FF96FF0096FF00
96FF0096FF003CFF0096FF0096FF003CFF0000FF7896FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00
F0FF0000FFD23CFF0000FFD200D2FF0078FF00D2FF00FF1E96FF00F0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0000FF1E3CFF0000FF1E96FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF00
96FF0096FF003CFF003CFF003CFF0000FF1E00FF7800D2FF0078FF0078FFF000FF0078FF
FF005A3C00FFFF00B4FF0000FF005A9600FFFF0000001EFF001EFF001EFF0078FF0078FF
0078FFFF005A0078FF001EFFFF005A0078FF001EFF0078FF3C00FF0078FF00FFD200FFD2
00FF7800FF7800FF1E3CFF003CFF0000FF1E96FF0096FF003CFF0000FFD296FF0096FF00
96FF0096FF003CFF0096FF0096FF0096FF0096FF003CFF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF00F0FF0096FF003CFF00FF00B400FF1E00FF1E00FF1E96FF0096FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00
FFB400FFB400FFB400FFB400FFB400FFB400F0FF003CFF0000FF1E3CFF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB40000FF1E
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF00
96FF0096FF003CFF003CFF0000FF1E00FF7800FF7800D2FF00FFD200FFD200FFD200D2FF
F000FF0078FF001EFF3C00FF9600FFFF00009600FF3C00FF3C00FF001EFF0078FF00D2FF
00D2FF3C00FF00D2FF00D2FF001EFF00D2FF00D2FF00FFD20078FF00D2FF00FFD200FF1E
FF005A00FF1E3CFF0000FF1E3CFF0096FF0096FF0096FF0096FF0096FF003CFF0096FF00
96FF0096FF0096FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF00F0FF0096FF003CFF000078FF00FFD296FF0096FF003CFF0000FF1E96FF00
F0FF00FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF0000FF78F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400F0FF0000FFD2FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF00
96FF003CFF003CFF0000FF7800FF78001EFF00FF7800FF780078FF00FF7800FFD2FF0000
00FFD200D2FF0078FF0078FF001EFF9600FFFF0000F000FF001EFF001EFF001EFF00D2FF
00D2FF00D2FF00D2FF00FFD2001EFF0078FF00FFD200FF7800FFD200FFD20078FF00FF1E
00FF1E3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FF1EF0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF0096FF0000FFD200FF1E0078FF96FF00F0FF00F0FF0096FF00F0FF00F0FF00
F0FF003CFF0000FF1EFFB400FFB400FF5A00FF5A00FF5A00
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF0000FF1E3CFF0096FF00
96FF00F0FF00F0FF0096FF00F0FF00F0FF00F0FF0000FF78F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
00FF1EFFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF003CFF00
00D2FF00FF7800D2FF00D2FF001EFF00FF1E00FF7800FF1E00FF1E00FF783C00FF00FFD2
00FFD29600FF00D2FF00D2FFFF00003C00FFFF00009600FF3C00FF0078FF00D2FF00D2FF
00FFD200FFD200D2FF00FFD200FFD200D2FF00FF7800FF7800FF7800FF78FF000000FFD2
00FF1E3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF00F0FF0000FF783CFF0096FF0096FF00F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF0096FF0000FF7800FF783CFF00
96FF00F0FF00F0FF0000FF1EF0FF0096FF003CFF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
96FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF00
00FF1E00FF1E3CFF0000FF7800FF1E3CFF0000FF1E00FF1E00FF1E0078FF00FFD200FF78
00FF7800FFD200FFD200D2FF0078FF3C00FFFF00B4FF00B49600FF0078FF00D2FF00D2FF
00FFD200FFD200FF7800FF7800FF78001EFF00FF7800FF1E00FF1E00FF1E001EFFF000FF
00FF7800FF1E9600FF3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400
FFB40096FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF00F0FF0000FF1E96FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF0096FF0000FF1E00FFD23CFF00
3CFF0096FF0096FF003CFF0000FF1E96FF0000FF1EF0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF003CFF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF00
96FF0096FF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF78
00FF7800FFD20078FF0078FF001EFFFF0000FF0000FF00B4F000FF001EFF001EFF3C00FF
0078FF00FFD200FF7800FF7800FF7800FF78001EFF00FF1E00FF1E00FF1E00FF1E00FF1E
00D2FFFF000000FF1E3CFF003CFF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF003CFF0096FF0000D2FF96FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00
FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF003CFF0000FF1EF000FF00FF1E
96FF003CFF0000FF1E00FFD200FF1EF0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
96FF0096FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF78
00FFD200FFD200D2FF00D2FF0078FF001EFFFF00B4FF00B4001EFF0078FF00D2FF00D2FF
0078FF0078FF00FFD200FF7800FF7800FF1E00FF1E00D2FF00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E001EFF3CFF003CFF0096FF0096FF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF00F0FF0096FF0000FFD23CFF003CFF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00
00FF7896FF00F0FF00F0FF00F0FF003CFF0096FF0096FF0096FF0000FF1E001EFF00FFD2
00FF1E00FF1E3CFF0096FF0096FF003CFF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF0096FF003CFF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0000FFD2F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF78
00FF7800FF7800FFD200D2FF001EFF3C00FFFF00B4FF00009600FFFF0000001EFF00FFD2
00FFD200FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF0000FF1E3CFF0000FFD23CFF0000FF1E00FF1E00FF1E3CFF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB40000FF1E
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB40096FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF00F0FF0096FF0096FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00
F0FF0000FF1E96FF003CFF00001EFF0078FF00FF1E3C00FF0078FF001EFF3C00FF00FFD2
00FF1E96FF0096FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF0096FF0096FF003CFF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF003CFF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF003CFF0000FF1E00FF1E00FFD200FF7800FF7800FF78
00FF7800FFD200D2FF00D2FF0078FF001EFFFF00B4FF00B49600FF0078FF00D2FF0078FF
00D2FF00FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF0000FF1E3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400F0FF0096FF00F0FF00F0FF00F0FF00F0FF000078FFF0FF00F0FF00
96FF0096FF0096FF003CFF0096FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00
FFB400F0FF003CFF00F0FF0096FF0096FF0096FF003CFF0096FF003CFF0000FFD200D2FF
00FF1E3CFF0096FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF0000FF783CFF00F0FF00F0FF00F0FF0096FF00F0FF00F0FF00FFB400FFB400
FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FF1E
96FF0096FF0096FF0096FF0096FF0096FF0096FF0000FFD296FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF0000FF1E00FF7800D2FF00FF7800D2FF00D2FF00FFD2001EFF
00FFD200D2FF00D2FF0078FF001EFFF000FFFF00B4FF00009600FF001EFF001EFF00D2FF
00FFD200FF7800FF783C00FF00FF7800FF1E00FF1E001EFF3CFF003CFF003CFF003CFF00
3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB4003CFF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF0000FF7896FF0096FF00F0FF0096FF00F0FF00F0FF00
F0FF0000FF1E3CFF0000D2FF96FF0096FF0096FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00
FFB400FFB400F0FF00F0FF00F000FFF0FF00F0FF0096FF0096FF0000FFD200FF1E00D2FF
3CFF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF00F0FF0000FF1E96FF00F0FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
3CFF0000FF1E96FF003CFF0096FF0096FF0096FF003CFF003CFF0096FF0096FF0096FF00
96FF0096FF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FFD200FFD200FF78001EFF
00FFD200D2FF00D2FF9600FFFF0000FF0000FF005AF000FFFF00B4FF0000FF0000001EFF
0078FF00FFD200D2FF00FFD200FF7800FF7800FF7800FF1E00FF1E3CFF003CFF003CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF0096FF003CFF0096FF0000FFD2F0FF00F0FF00
96FF0096FF0000FF1E9600FF3CFF0000FF1EF0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00FFB400FF5A00
FFB400FFB400FFB40096FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF000078FFFF0000
00D2FF3CFF0000FF783CFF0096FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF00F0FF003CFF003CFF0000FF1E96FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
3CFF0096FF0000FF7800FF1E3CFF0096FF003CFF0000FF78FF00B43CFF0096FF0096FF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF7800FF78
00FF7800FFD200D2FF9600FFFF00009600FFFF00009600FF001EFF001EFF0078FF00FFD2
00D2FF00FFD200D2FF00FFD2001EFFFF005A00D2FF00FF7800FF1E00FF1E3CFF003CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB40096FF00F0FF0096FF0000FF1E00FF1E96FF003CFF00
96FF0000FF1E00FF1E00D2FF3CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400
FFB400FFB400FFB400F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF0000FF1E3CFF0000D2FF001EFF
00FF1E00FF1E00D2FF96FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF0096FF0000FF1EFF00B496FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0000FF7800FF783C00FF3CFF0000FF1E00FFD23CFF003CFF003CFF003CFF00
3CFF0000FF1E3CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF78
00FF7800FFD200FFD200D2FF0078FF9600FFFF0000F000FF001EFF00D2FF9600FF00D2FF
00FFD200FF7800FFD200FF7800D2FF00FFD200FF7800FF1E00FF1E00FF1E00FF1E3CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0000D2FFF0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00FF00B43CFF0000D2FF00FF1E
3CFF0000FF1E00FFD200FFD23CFF0096FF0096FF00F0FF0096FF00F0FF00F0FF00F0FF00
F0FF0000FFD2F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF003CFF003CFF003CFF003CFF0000FFD2
00FF1E96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF00F0FF0096FF0000FF7896FF0096FF00F0FF00F0FF00F0FF00F0FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0000FF7896FF0096FF003CFF0000FF1E001EFFFF000000FFD20078FF3CFF003CFF00
3CFF0000FFD23CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FFD2
00FFD20078FF00FFD200D2FF0078FF3C00FFFF00003C00FF0078FF00D2FF00FFD200FFD2
00FF7800FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0096FF00
96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF003CFF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF003CFF0096FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF00F0FF0096FF0096FF003CFF00
3CFF009600FF001EFFF000FF00FF1E3CFF003CFF003CFF0000FF783CFF0000D2FF96FF00
3CFF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB40096FF00F0FF00F0FF00F0FF0096FF0096FF003CFF00
00FF1E96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0000FFD296FF0096FF00F0FF00F0FF0096FF0000FF1E
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF0096FF003CFF0000FFD20078FFF000FF00FFD200FF1E3CFF00
00FF1EFF005A00FF1E3CFF003CFF003CFF0000FF1E00FF1E00FF7800FF7800FF7800FF78
00FFD20078FF001EFF0078FF001EFF9600FFFF0000F000FF001EFF00D2FF00D2FF00D2FF
00FFD200FF7800FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0096FF0096FF00
96FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF003CFF00F0FF00
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF0000FF78F0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF0096FF0096FF00
3CFF0000FF78FF005A00FF783CFF003CFF003CFF0000FF1E3CFF0096FF00F0FF0096FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
00FF1E96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF003CFF003CFF0000FF1E96FF0000FF783CFF003CFF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF003CFF0000FF1E00FF7800FF7800FF7800FF7800FFD200FF1E
00FF78F000FF00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00D2FF001EFF00FF7800FF78
00FFD200FFD200D2FF0078FF3C00FFFF005AFF0000F000FF9600FF0078FF00D2FFFF00B4
00D2FF00FF7800FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0000FF1E96FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB40096FF00F0FF00F0FF00F0FF0096FF003CFF0000FF1EF0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
00D2FF00FF783C00FF00FF783CFF0096FF0096FF00F0FF0096FF0096FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
0078FF96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF003CFF0000D2FF3CFF0096FF0000FF1E00FF1E96FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF003CFF0000FF1E3CFF003CFF003CFF0000FF7800FF1E00FF7800FF1E
00D2FF001EFF00FFD200FF1E00FF1E00FFD200FF1E00FF1E00FF7800FFD200FFD200FFD2
00D2FF00FFD20078FF0078FF3C00FFFF00B4FF0000FF00B40078FF00D2FF00FFD200FFD2
00FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF0096FF0096FF003CFF0000FF1E3CFF003CFF0096FF0096FF00
96FF0096FF003CFF0096FF003CFF0000FF1E00FFD296FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0000D2FF96FF0096FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF0096FF0096FF00
00FF1E00FF7800FFD23CFF003CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
00FF1E3CFF003CFF0096FF00F0FF00F0FF0096FF0000FF1EF0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0096FF00
F0FF00F0FF00F0FF0096FF0096FF003CFF000078FF00FF1E00FF1E3CFF0096FF0096FF00
96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E
00D2FFF000FF00FFD200FFD2FF00B400FFD200FF7800FF7800FF7800FFD200D2FF00D2FF
FF005A00D2FF00D2FFF000FF9600FFFF00B4FF00009600FF3C00FF001EFF00D2FF00FFD2
00FFD200FF7800FFD200FF783C00FF00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF0000FFD23CFF003CFF003CFF0000FF1E3CFF003CFF0000FFD200FF1E3CFF0096FF00
96FF003CFF0000FF783CFF0000FF1E00FF7896FF0096FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF00F0FF00F0FF0096FF0000FFD2F0FF00F0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF0096FF003CFF0000FF1E
00FF1E3C00FF00FFD23CFF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF00
00FF7800FF1E96FF0096FF0096FF0000FF1E96FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
00FF1E96FF0096FF0000FFD23CFF003CFF0000D2FF3C00FF00FF1E3CFF0096FF0096FF00
96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E
0078FF00FF1E00FF1E00FF1E00FF7800FFD200D2FF00D2FF0078FF0078FFF000FF001EFF
0078FF0078FFF000FF001EFF3C00FFF000FFFF00003C00FF001EFF0078FF0078FF00D2FF
00FFD200D2FF3C00FF00FFD200FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF00
00FF7800FF1E3CFF003CFF003CFF0000FF783CFF003CFF00FF00B400FF1E00FF1E3CFF00
00FF1E00FF780078FF3CFF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0000FF783CFF0000FF1E0078FFF0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0096FF0096FF0096FF00
3CFF0000FFD200FF7800FF1E00FFD296FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF0096FF00F0FF00F0FF0096FF0096FF0096FF003CFF00
00FF78001EFF00FF1E00D2FF3CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0000FF783CFF0000FF1E00FF78F000FF00FF783CFF0096FF0096FF00
96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0000FF1E00FF1E
3CFF003CFF0000FF1E00FF1E00FF7800FF1E00FF7800FF7800D2FFFF0000FF0000F000FF
3C00FF9600FF9600FF001EFF9600FFFF00B4FF00009600FF9600FF001EFF001EFF00D2FF
00D2FF00D2FF00FFD200FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF7800FF1E3CFF003CFF003CFF0000FF7800FF1E00FFD200FFD200FF7800FFD200D2FF
00FF1E3CFF003CFF0000FF1E96FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0000FF1EF0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF003CFF00001EFF3CFF0096FF00F0FF00F0FF003CFF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
00FF1E00D2FF3CFF0096FF003CFF0096FF003CFF0096FF00F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0096FF0096FF0000FF1E00FFD2FF0000
00FF780078FF3CFF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF003CFF0000FF78001EFF00FF7800FF1E00FF1E3CFF00
96FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
3CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF78001EFF00D2FFFF00009600FF
FF005AFF0000FF0000FF00B49600FF9600FFF000FFFF0000FF005AFF005A3C00FF001EFF
F000FF00D2FF00FFD200FFD200FF7800FF1E00FF1E00FFD200FF1E00FF1E00FFD200FF1E
00FFD200FF1E9600FF00FF1E00FF1E00FF780078FF0078FFFF00000078FF00FF7800FF1E
3CFF0096FF0096FF0096FF000078FF96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF003CFF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0000FF1E00FF1E96FF0096FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF009600FF3CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF00
00FF1EFF00003CFF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF003CFF0000FF1E00FFD29600FF00FF1E3CFF0096FF00
96FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E0078FF00FFD2F000FF0078FF0078FF
3C00FF3C00FFFF00B4FF00B49600FF9600FF3C00FF9600FF9600FFFF0000FF005AFF0000
FF00B4FF00B40078FF00FFD200FF7800FF7800FF7800FFD200FF7800FF7800FFD200FFD2
0078FF00D2FF00FF78F000FF00D2FFFF005A0078FF00FFD200FF783C00FF00FF1E3CFF00
96FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FF000096FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0000FF1E96FF0096FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF0000FF1E96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
F000FF00D2FF3CFF003CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0000FF1E00FFD200FF1E3C00FF00FF1E3CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF0000FF7800FFD2001EFF0078FF00FFD200FFD200FFD2FF005A
0078FFF000FF3C00FFFF0000F000FFF000FF001EFF3C00FF001EFF3C00FF3C00FF9600FF
9600FFFF00000078FF001EFF00D2FF00FFD23C00FF3C00FF00D2FF00FFD2F000FF0078FF
001EFFF000FF00FFD200FF1E00FF1E00FF1E00FF7800FF1E00FF1E00FFD200FF7800FF1E
96FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FF783CFF00
96FF0096FF0096FF0096FF003CFF0000FF1E3CFF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF0000FF1E96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
96FF003CFF003CFF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF003CFF0000FF1E3CFF003CFF0096FF00
96FF0096FF0096FF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1EFF000000FF7800FF7800FFD200D2FF
00D2FF0078FF3C00FFFF0000FF00003C00FF001EFF0078FF0078FFFF000000D2FF3C00FF
00D2FF00FFD200FFD200FFD200FF7800FF7800FF780078FF00FF7800FF1E00D2FF00FF78
00FF7800FF7800FF1E00FF1E3CFF003CFF0000FF1E00FF1E3CFF003CFF00001EFF00FF1E
3CFF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF003CFF003CFF003C00FF
3CFF0096FF0096FF003CFF003CFF003CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400F0FF00F0FF00F0FF00001EFFF0FF00F0FF00F0FF00F0FF0096FF0096FF00
00FF1E3CFF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FF0000F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF003CFF003CFF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF003CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0000FFD200D2FF3CFF003CFF00
96FF0096FF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0000FF1E3CFF003CFF00
3CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD200FFD2
00D2FF0078FF3C00FFFF0000F000FF3C00FF9600FF0078FF00D2FF001EFF001EFF00FFD2
001EFF00FFD200FF7800FF7800FF1E00FF1E00FF1E00FF7800FF1E00FF1E00FF7800FF1E
00FF1E00D2FF00FFD23CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E
3C00FF3CFF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0000FF78
00FF1E96FF003CFF0000FF1EFF000000FF1E00FFD296FF00F0FF00F0FF00F0FF00F0FF00
F0FF003CFF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF00F0FF00F0FF00F0FF003CFF0096FF003CFF0096FF0096FF003CFF00
00FF7800D2FF3CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
3CFF0000FF1E3C00FF00FF7896FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF00FF00B496FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF003CFF0000FF7800FF783CFF00
3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
F000FF3CFF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000D2FF
00FF1E00FF1E00FF1E00FF7800FF1E00FF1E00FF1E00FF780078FF001EFF0078FF0078FF
0078FF3C00FF3C00FFFF00009600FF001EFF0078FF00D2FF00D2FF00FFD200D2FF00FFD2
00FFD20078FF00FFD200FFD200FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF7800FF1E3CFF003CFF003CFF003CFF0000FF1E3CFF003CFF0096FF0096FF00
96FF003CFF003CFF003CFF003CFF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF003CFF00
00FF1E00FF783CFF0000FFD200D2FF3CFF0096FF0096FF0096FF00F0FF00F0FF0096FF00
96FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FF1E00FF783CFF003CFF00
0078FFF000FF3CFF0096FF0096FF0096FF00F0FF00F0FF0096FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF0000FFD2F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
96FF003CFF000078FF3CFF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF0096FF00
96FF0000FF1E00FF7896FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF003CFF003CFF0000FF7800FFD200FF1E
00FF7800FF1E3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
3CFF0000FF783CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
00FF7800FFD200FF1E00D2FF00FF7800FF1E00FF7800FF7800FF7800FFD200FFD2001EFF
0078FF9600FFFF0000FF0000FF00003C00FF0078FF00D2FF00FFD200FFD200FFD200FF78
00FF7800D2FF00FFD200FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF0000FF1E00FFD23CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF00
00FF7800FF1EFF0000001EFF00FFD23CFF003CFF003CFF0096FF0000FF789600FF96FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF003CFF0000FF1E
FF0000F000FF001EFFF000FF00FF1E3CFF0096FF00F0FF00F0FF00F0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
96FF003CFF0000D2FF00FF1E96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF003CFF0000FF7896FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0000D2FF96FF003CFF003CFF009600FF00FF1E00FF78FF000000FF78
001EFF3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
3CFF0000FF1E9600FF3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF783C00FF00FFD200FF7800FFD200FF7800FF7800FFD200FFD200D2FF
0078FF001EFFFF005AFF00B49600FF001EFF3C00FF001EFF00D2FF00D2FF00FF7800FF78
00FF7800D2FF00FF7800FFD200FF7800FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF0000FF1E3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF00
3CFF0000FF1E00D2FF9600FF001EFF00FF1E00FF7800FF7800FF1E3CFF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0000FF1E
FF000000FFD23CFF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF0096FF0000D2FF96FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF00
96FF003CFF0000FF1E3CFF003CFF003CFF0000FFD296FF0096FF0096FF0096FF0000FF1E
3CFF0000FF1E3CFF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF0096FF003CFF0000FF7800FF7800FF1E00FF780078FF00FFD2
00FF1E3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
00FF7800FF7800FF783CFF003CFF0000FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF7800FFD200D2FFFF00B400D2FF001EFF0078FF00FFD20078FF00D2FF
001EFFFF00B4FF00B4F000FF001EFF0078FF00D2FF00D2FF001EFF00D2FF00FFD200FF78
00FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF0000FF1E96FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF003CFF0096FF0096FF0096FF00
3CFF0000FF1E00FFD20078FF00FF783CFF003CFF0096FF003CFF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF0000FFD2
FF00B400FF1E96FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF0096FF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF00
00FF1E3CFF0000FF7800FF783CFF0000D2FF3CFF0096FF0096FF0096FF0096FF003CFF00
00FF78001EFF3CFF003CFF0096FF003CFF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E00FFD20078FF
9600FF00FF783CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF00
3CFF003CFF0000FF7800FF1E00FF1E00FF783CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF7800FF7800FF7800D2FF00D2FF3C00FF00D2FF0078FF0078FF
001EFF3C00FFFF00009600FF3C00FF001EFF00D2FF00FFD200FFD200FFD200FFD200D2FF
00FF7800FF1E00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0000FF1E00FF1E
00D2FF00FF1E0078FF0078FF3CFF003CFF0096FF0096FF0096FF003CFF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF003CFF00
00D2FF3CFF003CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF003CFF00FFB400FFB400FFB400FFB400F0FF00
F0FF0096FF0096FF00001EFF3CFF0096FF0096FF0096FF0096FF0096FF0096FF003CFF00
001EFF00FF1E00FFD200D2FF00D2FF00FF1E3CFF0096FF0096FF0096FF003CFF003CFF00
00FF7800FF7800FF1E3CFF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF0000FF7800FF789600FF
00FF1E3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF00
3CFF003CFF0000FF1EF000FF0078FF00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD200FFD20078FFFF00B4FF005A
9600FFF000FFFF00003C00FF001EFF0078FF00D2FF00FFD200FFD200FF7800FF7800FF78
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF003CFF00
3CFF0000FF1EF000FF00D2FF00FF1E3CFF0096FF0096FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0000FF1E
00FFD296FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF003CFF0000FF1E3CFF0000FF7896FF0096FF0096FF0096FF003CFF00
3CFF0000FF1E00FFD23C00FF00FF7800FF1E3CFF0000FF783CFF003CFF003CFF003CFF00
001EFF00FF783CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF0000FF1E00FF78
00FFD23CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF003CFF003CFF00
00D2FF00FF7800FFD2001EFF00D2FF00FF7800D2FF3CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD23C00FF001EFFF000FF
FF0000FF00B4FF005AFF005A3C00FF001EFF0078FF00FFD200FFD200FF7800FF7800FF78
00FF7800FF1E00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
3CFF0000FFD200D2FF00FF1E00FF1E00FF1E3CFF0096FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FF7896FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0000FF1E96FF003CFF0000FF1E
00FFD296FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF003CFF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF0000FF7800FF7800FF1E3CFF0096FF0096FF003CFF003CFF00
3CFF0000FF1E00FFD29600FF00FF7800FF1E00FF783CFF003CFF003CFF0000FF1E00FF1E
00FF1E3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E
00FF7800FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF78FF000000FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FFD200FFD200D2FF0078FF3C00FF
FF005AFF00B49600FFFF00B4FF005AF000FF3C00FF00FFD200FFD200FF7800FF7800FF78
00FF7800FF1E00FF1E00FF1E00FF1E00FFD200FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
3CFF0000FF1E00FF1E00FF1E3CFF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF003CFF00
96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF003CFF0000FF1E
00FF7800FF1E3CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF003CFF003CFF003CFF0000FFD200FFD200FF783CFF003CFF003CFF003CFF0000FF1E
0078FF00FF7800FFD2FF00000078FFFF000000FF1E3CFF003CFF003CFF0000FF780078FF
00FF1E3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0000FF1E3CFF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF0000FF1E00FF78
3C00FF00D2FF00FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF7800FFD200FF1E00FF1E00FF7800FF783C00FF00D2FF00D2FF00D2FF001EFF9600FF
FF005A9600FF3C00FFFF00B43C00FF0078FF0078FF0078FF00D2FF00FFD200FFD200FFD2
00FF7800FF7800FF7800FF783C00FF00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0000FF1E96FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0000FF1E96FF0096FF0096FF0096FF0096FF003CFF00
00FF7800FFD23CFF003CFF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF0096FF00
96FF0096FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0000FF1E
00FF1E96FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0096FF003CFF003CFF0000FF7800FFD200FF1E00FF1E3CFF003CFF003CFF00
00FF1E00FF7800D2FFFF000000D2FF00FF7800FF1E00D2FF00FF1E00FF1EF000FF00FF1E
00FF1E00FFD200FF1E96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E00FF78
001EFF00FF7800FF1E3CFF003CFF003CFF003CFF0000FF1E3CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF1EF000FF00FF7800FFD200FF1E00FF1E00FF1E00FF1E
00FF78FF000000FF7800FF7800FF7800FF7800FFD200D2FF0078FF0078FFFF005AF000FF
FF00003C00FF001EFF0078FF0078FF00D2FF00FFD20078FF00D2FFFF0000FF000000FFD2
00FF7800FFD200FF7800FFD200FF7800FF1E00FF1E00FF7800FF1E00FF1E3CFF003CFF00
3CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF0096FF0096FF0096FF0096FF003CFF00
3CFF0000FF783CFF003CFF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF0000FFD2
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF00FF0000
00FF1E96FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
00FF1E96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0096FF0096FF003CFF003CFF003CFF0000FFD200D2FF00FF7800FF1E00FF1E
00FF1E00FFD20078FF9600FF9600FF00FFD200FFD200FF7800FFD2FF000000FF1E00FF1E
3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF0000FF1E
00FF7800FF7800FF1E3CFF003CFF003CFF003CFF0000FF7800FFD23CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FFD200FFD20078FF00FF7800FF1E00FF1E00FF1E00FF1E
00FF7800FF780078FF00FFD200FF7800FF7800FFD200FFD200D2FF0078FF9600FFFF0000
FF00B4001EFF0078FF0078FF00D2FF0078FF00FFD200FFD200FFD200FFD20078FF00D2FF
0078FFFF00B40078FF3C00FF00FFD200FF7800FFD2001EFF00FF1E00FF1E00FF7800FF1E
00D2FF00FF1E3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF000078FF96FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FFD23CFF0000FF1E
00FF1E00FFD23CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0000FF1E
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0000FF1E3CFF003CFF0000FF1E00FF1E
3CFF003CFF0096FF0096FF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
3CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF0000FFD200D2FF00FFD200FF7800FF1E
00D2FF00FFD20078FF3C00FF9600FF0078FF9600FF0078FF00FFD200FF1E00FF1E3CFF00
3CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF003CFF003CFF0000FFD200FF78
3CFF003CFF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF0000FF1E
00FF1E00D2FF00FF1E00FF1E3CFF003CFF0000FF1E0078FF00FF1E3CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF7800FF78FF000000FFD200FF7800FF1E00FF1E00FF1E
00FF7800FFD200D2FF00D2FF00FFD200FFD200D2FF00D2FF00D2FF3C00FF3C00FFFF005A
9600FF001EFF00D2FF00D2FF00FFD200FFD200FF7800FF7800FF7800FFD200FFD200FF78
00FF780078FF3C00FF001EFF001EFF00FFD200FFD200D2FF00FF7800FF7800FF7800FF1E
3CFF003CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF000078FF3CFF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF003CFF0000FF7800FF7800FF783CFF0000FF1E
00D2FF00FF7800FF1E3CFF0096FF0096FF0096FF0096FF0096FF003CFF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF003CFF00
00FF1E3CFF0000FF1E96FF0096FF0096FF0096FF003CFF0000D2FF3CFF0000FF1E00D2FF
00FF1E3CFF003CFF0000FF1E96FF0096FF0096FF0096FF0096FF0096FF003CFF00FF00B4
96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E00FFD200FF7800D2FF
0078FF0078FF001EFFFF00B4FF00B4FF0000F000FF001EFF00FF7800FF1E00FF1E3CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E
3CFF003CFF003CFF003CFF003CFF003CFF0000FF783CFF003CFF003CFF003CFF0000FF1E
00FF1E00FFD200FF1E00FF1E00FF1E00FF1E00FF7800D2FF00FF1E00FF1E00FF1E3CFF00
00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FFD200FFD200FF7800FF7800FF78
00FF7800FF7800FFD2001EFF00D2FF00FFD200D2FFFF00000078FF001EFFFF00009600FF
0078FF0078FF9600FF00D2FF00FFD200FFD200FF7800FF7800FF7800FF7800FFD200FF78
00FF7800FF7800FF7800FFD200FF7800FF1E00FF1EFF000000FF1E00FF1E3CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF000078FF3CFF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0000FF7800D2FF00FFD200FF78
001EFF00FFD200FF1E3CFF003CFF003CFF003CFF0000D2FF96FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF003CFF003CFF00
FF000000FFD23CFF0096FF0096FF0096FF0096FF003CFF0000FF1E00FFD200FF78FF0000
F000FF00FF7800FF783CFF0096FF0096FF0096FF0096FF0000FF7896FF0000FF783CFF00
96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF78
9600FF3C00FFFF0000FF00B49600FF3C00FF3C00FF00FFD20078FF00FFD200FF1E00FF1E
3CFF003CFF003CFF00001EFF3CFF003CFF003CFF003CFF0000FF7800FF1E00FFD2001EFF
00FF1E00FF783CFF003CFF003CFF003CFF003CFF0000FF783CFF003CFF003CFF0000FF1E
00FF1E00D2FF00FFD200D2FF00FF1E00FF1E00FF780078FF00FF7800FF1E00FF1E00FF1E
00FFD200FF1E00FF1E00FF1E00FF1E00FF7800FFD2FF000000FFD200FF7800FF7800FFD2
00FF7800FF7800FFD200D2FF001EFF00D2FF00D2FF0078FF3C00FFF000FFFF00000078FF
001EFF00D2FF00D2FF0078FF001EFF00FFD200FF7800FF7800FF7800FF783C00FF00FF78
00FF7800FF7800FF7800D2FF00FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF00
96FF003CFF003CFF0000FF1E00FF783CFF003CFF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E001EFF
FF005A001EFFF000FF001EFF00FF783C00FF00FF1E96FF0096FF0096FF0096FF0096FF00
96FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0000FFD200FF1E00FF1E
00FFD200FF7800FFD23CFF0096FF0096FF0000FFD23CFF003CFF0000FF1E00FF78FF0000
00FFD200FF1E3CFF003CFF0096FF0096FF0096FF0096FF0000FF1E00FF1E00D2FF3CFF00
96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF0000FF7800FFD2001EFF
00FFD29600FF0078FFF000FFF000FFFF000000D2FF00FFD200FF7800FF1E00FF1E00FF1E
00FF1E00FF78001EFF3CFF003CFF003CFF003CFF003CFF003CFF0000FFD200D2FF3C00FF
00FF7800FF1E3CFF003CFF003CFF003CFF003CFF0000FF7800FF1E00FF1E00FF1E00FF1E
001EFFFF00B4001EFF00FF7800FFD200FF7800FFD200FF7800FF1E00FF1E00FF1E00FF1E
00FF7800FF1E00FF1E00FF1E00FF1E00FF7800FF7800FFD2FF005A00FFD20078FF00D2FF
00FFD200FFD200FFD200FFD200D2FF001EFF3C00FFF000FF9600FFFF0000FF00000078FF
00D2FF00FFD200FFD200D2FF00FFD20078FF00FFD200FF7800FF7800FF7800FF1E00FF1E
00FF1E00FF1E00FF1E00FF7800FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF00F000FFFF00003CFF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E00FFD2
FF000000D2FF00FF1E3CFF0000FF1E3CFF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0000FF1E3CFF00
00FF780078FF00FF1E3CFF0000D2FF3CFF003CFF0000FF7800FF1E00FF1E00FFD2FF00B4
00FFD200FF1E3CFF003CFF003CFF0096FF003CFF003CFF0000FF1E3C00FF00FF7800D2FF
96FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
3CFF0096FF0096FF003CFF003CFF0000FF1E3CFF003CFF0000FF1E00FF1E00FF1E00FF78
00FF7800FFD20078FFFF0000F000FF0078FF001EFF0078FF00D2FF00FF7800FF1E00FF1E
00FF7800FFD200FF783CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF78FF0000
00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF0000FF1E00FFD29600FF00FF1E00FF1E
00FF7800FFD2FF00B43C00FF00FFD200FF78FF00B43C00FF00FF7800FF1E00FF1E00FF1E
00FF7800FF7800FF1E00FF1E00FF7800FF7800FF7800FFD20078FF0078FF00D2FF00D2FF
00FFD200FFD200D2FF00D2FF9600FF9600FFF000FFF000FFFF00009600FF001EFFFF00B4
001EFF00FFD200FFD200FFD200FF7800FF7800FF7800FFD200FF7800FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF7800FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E3CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FF1E3CFF003CFF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF0000FF1E00FF783C00FF
00D2FF00FF1E3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0000D2FF
3CFF0000FF1E00FFD200FF1E00FF1E3CFF003CFF0000FF1E001EFF00FF7800FFD2FF00B4
00FFD200FF78001EFF3CFF003CFF003CFF003CFF003CFF0000FF7800FF783CFF003CFF00
3CFF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00
3CFF0000FF1E3CFF003CFF003CFF003CFF0000D2FF00FF1E00FF1E00FF1E00FF1E00FF78
00D2FF0078FF001EFFFF00B4FF00B43C00FF00D2FF00FFD200FF7800FF7800FF7800FFD2
FF000000FF7800FF1E3CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF7800D2FF
00FF1E00FF1E3CFF003CFF003CFF003CFF0000FF1E00FF1EF000FF9600FF00FF7800FF78
00FF7800D2FFF000FF9600FFFF00B400D2FF00FFD200FF7800FF7800FF7800FF1E00FF78
00FF7800FFD200FFD200FF7800FF78FF000000FFD200FFD20078FFF000FF0078FF00D2FF
0078FF00D2FF9600FF0078FF0078FF3C00FFFF0000FF005AFF00B4001EFF0078FF00D2FF
00D2FF00D2FF0078FF00FF7800FF7800FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E3CFF003CFF003CFF00
3CFF003CFF0000FF1E9600FF00FF1E3CFF003CFF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E00FFD2
0078FF00FF7800FF783CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0000FFD296FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF00
3CFF003CFF0000FFD200D2FF00FF1E3CFF003CFF0000FF1E00FF1E00FFD2F000FFFF00B4
3C00FF00FF7800FF1E3CFF003CFF003CFF00FF000000D2FF00FF1E3CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
00FF1E00FF1E3CFF003CFF003CFF003CFF0000FF780078FF00FFD200FFD200FF7800FF78
00FF7800FFD20078FF3C00FFFF0000F000FF00D2FF0078FF00FFD200FFD200D2FF00D2FF
00FFD200FF7800FF1E00FF1E3CFF003CFF003CFF003CFF0000FF1E00FF1E00FF7800FFD2
00FF1E00FF1E00FF783CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF7800D2FF00FFD2
00FFD20078FFF000FFFF00B4FF005A00D2FF00FFD200FF7800FF7800FF7800FF7800FF78
0078FF3C00FF00FFD200FF7800FF7800FFD20078FF001EFF001EFFFF00009600FF0078FF
0078FF00D2FF0078FFF000FF001EFF9600FFFF0000FF00B4FF0000F000FFF000FFF000FF
00FFD200FFD200FFD200FF7800FF7800FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF7800FF1E3CFF003CFF00
3CFF0000FF1E00FF7800FFD200FF1E3CFF003CFF003CFF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF0000FF1E00FF78
00FF1E3CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF00
3CFF00001EFF00FF1E0078FF00FF7800FF7800FF1E0078FF00FF780078FF0078FFFF005A
00D2FF00D2FF00FF1E00FF1E00FF1E00FF1E00FFD200FFD23CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
00FF7800FF1E3CFF003CFF003CFF003CFF0000FF1E00FF7800FFD200D2FF00D2FF00FFD2
00FFD2F000FF001EFFFF005AFF00003C00FF001EFF00D2FF00D2FF0078FF00FFD200FF78
00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF780078FF
00D2FF00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FFD2
0078FFFF005AFF0000F000FF001EFF00D2FF00FFD200D2FFF000FF00FF7800FF7800FF78
00FFD2FF005A00FFD200FF7800FF7800FFD200FFD200D2FFFF00B49600FFFF00B4FF0000
001EFF001EFF001EFFFF005AFF00B4FF0000FF00009600FF3C00FF9600FF0078FF00D2FF
00FFD200FFD200FFD200FF7800FF7800FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E3CFF00
00FF1E00FF1EFF005A00FF1E3CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF0000FF1E00FFD2
00FFD23CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0000FFD23CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF00
3CFF003CFF003CFF0000FF1E00FF7800D2FF00FF7800FFD200FFD200FFD20078FFFF00B4
0078FF00D2FFFF000000FF7800FF783C00FF00FF7800FF1E00FF783CFF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
00FFD200FF1E3CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF7800FFD200FFD2
0078FFFF0000F000FFF000FFFF00B4FF00B4F000FF0078FF00FFD200FFD200FF7800FF78
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FFD2FF005A
00FF7800FF1E00FF1E00FF1E00FF1E00D2FF00FF1E00FF1E00FF1E00FF7800FF7800FFD2
00D2FF0078FF3C00FFFF005A9600FF00D2FF00D2FF001EFF9600FF00FFD200FF7800FF78
00FFD20078FF9600FF00FFD200FFD200D2FF00D2FF0078FF3C00FF9600FFFF00009600FF
3C00FFF000FF3C00FFF000FFFF0000FF00B49600FFF000FF0078FF0078FF0078FFFF005A
0078FF3C00FF00FFD200FFD200FF7800FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF7800FF7800FF1E
00FF1E00FF7800FF7800FF1E3CFF003CFF003CFF003CFF003CFF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF0000FF1E00FF780078FF
00FF1E3CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF003CFF0000FF7800FF1E3CFF0096FF0096FF0096FF0096FF0096FF0096FF003CFF00
3CFF003CFF003CFF0000FF1E00FF1E00FF7800D2FF001EFF0078FF0078FF001EFFFF0000
3C00FF0078FF0078FF001EFF00FFD200FF7800FF1E3CFF003CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF0096FF00
00FF7800FF1E00FF1E3CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF78
00FFD2F000FF3C00FFF000FFFF00B43C00FF3C00FF0078FF0078FF00FFD200FF7800FF78
00FF7800FF1E00FF1E00FF1E00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF789600FF
00FF7800FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FF7800FF7800FFD200D2FF
00D2FF0078FF001EFFFF00003C00FF0078FFF000FF00D2FF00FFD200FFD200FFD200FFD2
00FFD20078FF00D2FF00FFD200FFD20078FF0078FF00D2FF0078FF9600FFFF0000F000FF
9600FFF000FFFF0000FF0000F000FFFF0000001EFF0078FF00D2FF0078FF00D2FF00D2FF
001EFFF000FF00D2FF00D2FF00FFD200D2FF00FF7800FF7800FF7800FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FFD2FF000000FF78
00FF789600FF00D2FF00FF1E3CFF003CFF003CFF003CFF003CFF003CFF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF0000FF7800FFD200FF78FF0000
00FF7800FF7800FF1E00FF1E3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF003CFF003CFF0000FF7800FF1E3CFF0096FF0096FF0096FF0096FF003CFF003CFF00
3CFF003CFF003CFF003CFF0000FF1E00FF7800FFD29600FF9600FFFF00009600FFF000FF
9600FF3C00FFFF005A00FFD200FF1E00FF1E3CFF003CFF003CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF003CFF0000FF1E3CFF0096FF00
001EFF00FF7800FF1E00FF1E00FF1E3C00FF00FF1E00FF1E00FF1E00FF7800FF7800FF78
00FFD200D2FF0078FFF000FFFF005A9600FF001EFF00D2FF00FFD200FFD200FF7800FF78
00FF7800FF7800FF1E00FF7800FFD200FF7800FF1E00FF1E00FF1E00FF7800FF78F000FF
00FF7800FF7800FF1E00FF1E00FF7800FF7800D2FF00FFD200FF7800FF7800FFD20078FF
F000FF0078FFFF00B4FF005AFF0000001EFF0078FF00D2FF00FFD200FFD2001EFF00FFD2
00FFD200D2FF9600FF00D2FF00D2FF00D2FFFF00B40078FFFF00003C00FFFF005AFF00B4
F000FFFF00B4FF0000FF005A3C00FF001EFF001EFF001EFF00D2FF00D2FF00FFD200FFD2
0078FF00D2FF001EFF9600FF0078FF00FFD200FF7800FF7800FF7800FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF780078FF
001EFF9600FF00FFD200FF1E00FF7800FF7800FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF783C00FF
00FF78FF005A00FF1E3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF00
3CFF003CFF0000FF1E00FFD23CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF0000FF1E00FF1E00FF7800FFD200FFD2001EFF001EFFFF00003C00FF
0078FF0078FF00FFD200D2FF00D2FF00FF783CFF003CFF003CFF003CFF003CFF003CFF00
96FF0096FF0096FF003CFF003CFF0000FF1E3CFF0096FF00
001EFF00FF7800FF1E00FF1E00FF1E00FF7800FF7800FF7800FF7800FF780078FF00D2FF
00D2FF00D2FF0078FF3C00FFFF00003C00FF0078FF00D2FF00D2FF001EFF00D2FF00FFD2
00FF7800FF7800FF7800FF78001EFF00FF7800D2FF00FF1E00FF7800FF7800FF78001EFF
00FFD200FF7800FF7800FF7800FF7800D2FFF000FF00D2FF00FF7800FF7800FFD200FFD2
00D2FF0078FF3C00FFFF005A9600FF001EFF0078FF0078FF00D2FF00D2FFFF000000D2FF
00D2FF00D2FFFF00000078FF0078FF0078FF001EFF3C00FF3C00FFFF0000FF0000FF005A
F000FFFF00B4FF0000F000FF001EFF3C00FF0078FF001EFF3C00FF00D2FF00FFD200FFD2
3C00FF00FFD200D2FF001EFF001EFF001EFFFF005A00FFD200FF7800FF7800FF7800FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF7800FFD2
0078FFF000FF0078FFFF005A00D2FF00FF7800FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E0078FF0078FF
00FF7800FF1E3CFF003CFF003CFF003CFF003CFF003CFF0096FF0096FF003CFF0000FF1E
3CFF003CFF0000FF1E00FFD23CFF003CFF0000FF1E3CFF003CFF003CFF003CFF0000FF1E
0078FF00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FFD200D2FF001EFFFF00003C00FF
0078FF00FFD200FFD200FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF0000FF783CFF00
3CFF003CFF003CFF003CFF003CFF00FF00B43CFF003CFF00
F000FF00FF7800FF1E00FF1E00FF1E00FF78FF000000FFD200FF7800FF7800FFD200D2FF
0078FF001EFF3C00FFF000FFFF0000F000FF0078FF0078FF001EFF9600FF00D2FF00FFD2
00FF7800FF7800FF7800FFD2F000FF00FFD200FF7800FF780078FF00FF7800FF7800D2FF
00FFD200FF7800FFD200FF7800FF7800FFD200D2FF00D2FF00FFD200FFD200FFD200FFD2
FF005A001EFF001EFFFF00B4FF00B43C00FF3C00FFF000FF00D2FF00D2FF3C00FF0078FF
00D2FF001EFFFF00B4FF0000001EFFFF00B43C00FFFF0000FF00B4FF0000FF00009600FF
9600FFFF005AFF0000FF0000001EFF0078FF00D2FF00D2FF00D2FF00D2FF00FFD200FFD2
00FF7800FF7800FFD200D2FF00FFD200FFD200FFD2F000FF00FFD200FFD200FF7800FF78
00FF7800FF1E00FF1E00FF1E00FF1E00FF7800FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF7800FFD2
9600FF001EFF00FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF783CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FFD2
00FF1E3CFF003CFF003CFF003CFF003CFF003CFF0000FFD23CFF003CFF003CFF003CFF00
9600FF00FF1E00FF1EFF000000FF1E00FFD23CFF003CFF003CFF003CFF003CFF003CFF00
00FF7800FF7800FF7800FF1E00FF1E00FF780078FFFF005A0078FF001EFFFF005AFF00B4
001EFF00D2FF00D2FF00FFD200FF1E00FF1E00FF1E00FF1E00FF7800FFD23CFF003CFF00
3CFF003CFF003CFF0000FF1E00FF1E00FF783CFF003CFF00
001EFF00FFD200FF7800FF7800FF7800FF780078FF00D2FF00FF7800FF7800FFD200FFD2
00D2FF00D2FF3C00FFFF00B4FF00B49600FF0078FF0078FF3C00FF00D2FF00FFD200FFD2
00FF7800FF7800FF7800FFD20078FF00D2FF00FF7800FF7800FFD200FFD200FFD20078FF
001EFF00FFD2001EFF00FFD200FF7800FFD200D2FF3C00FF00FFD200FFD20078FF00D2FF
00D2FF0078FF001EFFFF00B4F000FF3C00FF001EFF0078FF3C00FF0078FF9600FF0078FF
001EFF001EFFFF00B4FF00009600FFFF005AFF0000FF0000FF00009600FF3C00FF3C00FF
3C00FFF000FFFF0000FF00B49600FFF000FF001EFF00D2FF00FFD200FFD200FFD200FF78
00FF7800FF7800FF7800FFD200FFD200FF7800FF7800D2FF00FF780078FF00FFD200D2FF
00D2FF00FFD29600FF00FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FFD29600FF0078FF
FF00B400FFD200FF7800FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FFD23CFF003CFF003CFF003CFF003CFF003CFF0000FF7800FFD200FFD2
00FFD200FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FFD2F000FF00FF7800FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
00FF1E00D2FF3C00FF00FFD200FF7800FF7800FF7800FFD200D2FF001EFFFF005AFF0000
0078FF00FFD200FFD200FF7800FF7800FF7800FF7800FFD200FF7800FF1E3CFF003CFF00
3CFF003CFF003CFF0000FFD200FF7800D2FF00FF7800FF1E
00FFD200FFD200FF7800FFD200FF7800FF7800FFD20078FF0078FF00FFD29600FF00FFD2
00D2FFF000FF001EFFFF005A9600FF3C00FF0078FF00D2FF00D2FF00FFD200FFD200FFD2
00FFD200FFD200D2FF00D2FF9600FF00FFD200FF7800FF7800FFD2FF00B400D2FFFF005A
001EFF0078FF00D2FF00FFD20078FF00FFD200D2FFF000FF00D2FF00D2FF00D2FF001EFF
0078FF3C00FF3C00FFFF0000F000FFF000FF001EFF3C00FF001EFF0078FF001EFF001EFF
001EFF3C00FFF000FFFF0000FF0000FF0000FF0000FF0000FF005AFF0000001EFF9600FF
3C00FF3C00FFFF0000FF005A9600FF0078FF00D2FF00D2FF00FFD200FFD200FF7800FF78
00FF7800FF7800FF7800FF7800FF7800FF7800FF7800FF7800FF7800FFD200FF7800FF78
00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF00
3CFF003CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800D2FF
001EFF00FFD20078FF00FF7800FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E3CFF003CFF003CFF003CFF0000FF1E00FF1E00FF7800FF78
00FF1E00FF1E3CFF003CFF003CFF003CFF0000FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E0078FF00FFD200FF7800FF1E3CFF003CFF003CFF003CFF003CFF00
00D2FF00FF7800FFD200FFD200D2FF00FFD200FFD2001EFF00D2FF001EFFFF00009600FF
0078FF00D2FF00FFD200FF7800D2FF00FF78F000FF00D2FF00FF1E00FF1E3CFF003CFF00
3CFF003CFF003CFF0000FF1E00FF7800FFD200FF1E3CFF00
00FFD200D2FF00FFD20078FF00FF7800FF7800FFD20078FF00D2FF00FFD200D2FF001EFF
00D2FF0078FF3C00FFFF0000F000FF9600FF3C00FF0078FF001EFF00FFD200FFD200FFD2
00FFD200FFD200FFD200D2FF0078FF00FFD200FFD200FFD200FFD200D2FF0078FFFF0000
FF00B49600FF00D2FF00D2FF001EFF00D2FF0078FF0078FF0078FF0078FF0078FF3C00FF
3C00FF3C00FFF000FFFF00009600FF3C00FF001EFF3C00FF3C00FF001EFFFF005AFF00B4
F000FFFF0000FF0000FF005AFF0000F000FF3C00FF3C00FF001EFF001EFF0078FF0078FF
0078FF9600FF3C00FFFF005AF000FF9600FF001EFF0078FF00D2FF00FFD200FFD200FF78
00FF7800FF7800FF7800FF7800FF7800FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FFD2
00FFD200FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FFD200FF1E00FF1E00FF1E00FF1E00FF7800FF1E00FF7800FF78
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF783CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FFD200FF7800FF1E00FF1E3CFF003CFF003CFF003CFF0000FF1E
00FF1E00FF1E00FF7800FF7800FFD200D2FF00D2FF0078FF001EFF3C00FFFF00B49600FF
3C00FF0078FF00D2FF00D2FFFF00B400FFD200FF7800FF7800FF1E00FF1E3CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF7800FF7800FF1E3CFF00
0078FFFF000000D2FF00D2FF00FFD20078FF00FFD200D2FF0078FF00D2FF00D2FF9600FF
0078FF9600FFFF0000FF005A3C00FF001EFF001EFF0078FF00D2FF00D2FF00D2FF3C00FF
00D2FF00FFD200FFD200D2FF0078FF00FFD200FFD2001EFF00D2FF0078FF0078FF9600FF
FF00B43C00FF001EFF00D2FF001EFF0078FF0078FF9600FFFF0000001EFF9600FF3C00FF
FF005AFF00B4FF0000FF00B49600FF3C00FF3C00FF3C00FFFF005A9600FFF000FFFF0000
FF0000FF005AFF00009600FFFF005AF000FF9600FF0078FF0078FFFF00B40078FF00D2FF
001EFF0078FF3C00FFFF0000FF0000001EFF00D2FF00D2FF0078FFFF000000FFD200FF78
00FF7800FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800D2FF
00FF7800FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF7800FF78FF00B400FF1E00FF1E00FF789600FF00FFD29600FF
00FFD200FF7800FF1E00FF1EFF000000FF7800FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF7800FF7800FFD200FFD20078FFFF0000FF0000FF00B4FF00B4
F000FF001EFF00D2FF00FFD200FFD200FFD200FF7800FF1E00FF1E00FF1E00FF1E00D2FF
3CFF0000FF1E00FF1E00FF1E00FF7800FF7800FF1E00FF1E
3C00FFFF0000F000FF00D2FF00D2FFFF00B400D2FF0078FF9600FFFF00000078FF001EFF
FF0000F000FFFF00009600FF001EFF0078FF0078FF00D2FF00D2FF00D2FF0078FF3C00FF
0078FF00D2FF00D2FF00D2FF001EFF00D2FF00D2FF9600FF0078FF0078FF001EFF9600FF
FF00B43C00FF001EFF001EFF3C00FF001EFF9600FF3C00FFFF00009600FFFF00B4FF0000
FF0000FF0000F000FF9600FF3C00FF3C00FF3C00FF3C00FF9600FFFF005AFF0000FF0000
FF00003C00FF9600FF001EFF9600FFFF00003C00FF0078FF00D2FF001EFF001EFF00D2FF
00D2FF00D2FF001EFF001EFFFF0000001EFF00D2FF00FFD200FFD200FFD200D2FF00D2FF
00FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF7800FF1E00FF1E00FF1E00FF1E00FF7800FF7800FFD2
00FF7800FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF78001EFF00FF7800FF1E00FF1E00FF7800FF7800D2FFFF005A
00FFD200FF7800FF1E00FF1E00FF78FF000000FF789600FF00FF1E3CFF003CFF003CFF00
00FF1E00FF7800FF7800FF78001EFF00D2FF00FF7800FF1E00FF1E00FF1E00FF7800FF1E
00FF1E00FF1E00FF1E00FF7800FF7800FFD200D2FF00D2FF001EFF9600FFFF00009600FF
001EFF0078FF0078FF00FFD200FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E0078FF00D2FF00FFD200FFD200FF1E
001EFFFF005A3C00FF0078FF0078FF3C00FF0078FF0078FF9600FFF000FF3C00FF9600FF
FF0000FF0000F000FF3C00FFFF00B43C00FF001EFF0078FF00D2FF0078FF0078FF001EFF
00D2FF00D2FF001EFF0078FF3C00FF9600FF0078FF0078FF001EFF3C00FF001EFF9600FF
FF00003C00FF3C00FF3C00FF9600FFFF00B4FF005AFF0000FF0000FF0000FF0000F000FF
9600FFFF00003C00FFFF00003C00FF001EFF9600FFFF00B4F000FFFF0000FF005A9600FF
3C00FF001EFF0078FF0078FF001EFF9600FF0078FF00D2FF00D2FF00D2FF00D2FF00FFD2
00FFD20078FF0078FF00D2FF001EFFFF0000001EFF00FFD200FF7800FF7800FF7800FF78
00FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FF1E00FF7800FF7800D2FF3C00FF
00FFD200FF7800FF1E00FF1E00FF1E00FF7800FF1E3CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF78FF000000FFD200FFD200FF7800FF7800FF783C00FFF000FF3C00FF
00D2FF00FFD200FF7800FFD200D2FF3C00FF00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF7800FF78FF00B400FF7800FF1E00FF1E00FF1E00FF1E00FF7800FF78
00FF1E00FF1E00FF78F000FF00FFD200FFD200FFD2001EFF3C00FFFF0000FF0000FF0000
001EFF00D2FF00FFD200FFD200FF7800FF7800FF7800FF1E00FF1E00FF1E00FF7800FF1E
00FF1E00FF1E00FF1E00FF783C00FF00FFD200FF1E00FF1E
001EFFFF005A9600FF001EFFF000FF001EFF3C00FF3C00FFF000FFFF005AFF005AFF0000
FF0000FF0000F000FF3C00FF0078FF0078FF0078FF0078FF0078FF0078FF3C00FF3C00FF
0078FF001EFF0078FF3C00FFFF00003C00FF3C00FF001EFFFF00009600FFFF0000FF0000
FF005A9600FFF000FFFF005AFF0000FF0000FF00B4F000FFF000FFFF00009600FFFF0000
001EFFFF0000001EFF9600FFF000FF001EFF3C00FF9600FFFF00B4F000FF3C00FF3C00FF
0078FFF000FF0078FF00D2FF00D2FF00D2FF0078FF00D2FF00FFD200FFD200D2FF00FFD2
00FFD20078FF00D2FF00FFD23C00FF0078FF00FFD200FFD200FF7800FF7800FF7800FF78
00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800D2FF00FF780078FF00FF7800FFD2FF00B4
00FFD200FF7800FF7800FF7800FFD200FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF7800FFD29600FF00FF7800FF7800FFD2001EFFFF0000
00D2FF00FFD200D2FF0078FF00FFD200FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF780078FF00FF7800FF7800FF1E00FF1E00FF1E00FF783C00FF
00FF7800FF7800FF7800FF7800FFD29600FF0078FF00D2FF001EFFFF0000FF00003C00FF
0078FF00D2FF00FFD200D2FF00FFD20078FF00FF7800FF7800FF7800FF78FF00B400FF1E
00FF1E00FF1E00FF1E00FF7800FFD200FF7800FF1E00FF1E
9600FFFF00009600FF9600FF9600FFF000FFFF0000FF0000FF0000FF00B4FF005A9600FF
3C00FF3C00FF9600FF001EFF0078FF0078FF0078FF0078FF0078FF0078FF3C00FF9600FF
0078FF3C00FF001EFF3C00FFFF00009600FF9600FFF000FFFF0000FF0000FF0000FF00B4
FF005AF000FFFF0000FF0000F000FFFF00003C00FF3C00FFFF00B4FF0000001EFF0078FF
0078FFF000FF0078FF0078FF0078FF3C00FF3C00FF9600FFFF0000F000FF001EFF0078FF
0078FF0078FF0078FF00D2FF00FFD200D2FF0078FF00D2FF00FFD200FFD200FFD200FF78
00FFD20078FF00D2FF00FFD200FFD200FFD2001EFF00FFD200FF7800FF7800FF7800FF78
00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FFD200FFD23C00FF001EFF00D2FFFF005A
0078FF001EFF001EFF00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF7800D2FFFF005A00D2FF00FFD20078FF001EFFFF005A
3C00FF0078FFFF00B400FFD200FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF7800FF1E
00FF1E00FF1E00FF1E00FF7800D2FF00FFD200FF7800FF7800FF1E00FF78001EFF00D2FF
00D2FF00FF7800FF7800FF7800FFD200D2FF0078FF001EFFFF0000FF005AFF0000F000FF
0078FF0078FF0078FFFF000000FFD200FF7800FF7800FF7800FF7800FFD200FFD200FF78
00FF1E00FF1E00FF7800FF78001EFF00D2FF00FF7800FF1E
FF0000FF0000F000FFFF005AFF0000FF005AFF00009600FF3C00FF9600FFFF00003C00FF
3C00FF0078FF001EFF3C00FF0078FF0078FF0078FF0078FF0078FF0078FF001EFF3C00FF
3C00FF3C00FFFF00B4FF00B4FF0000FF0000FF0000FF0000F000FFFF00B43C00FF3C00FF
3C00FFF000FFFF005A9600FF3C00FF001EFF0078FF0078FF3C00FFF000FF0078FF0078FF
00D2FF001EFF0078FF00D2FF0078FF001EFF3C00FFFF00B4FF0000F000FF3C00FF0078FF
00D2FF00D2FF0078FF00FFD200FFD200FFD20078FF0078FF00FFD200FF7800FF7800FF78
00FF780078FF00FF7800FF7800FF7800FFD200D2FF00D2FF00FFD200FF7800FF7800FF78
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FFD200FF7800FFD200D2FFFF00B4
0078FF00FFD200FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E3C00FF00FF1E
00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD2001EFFFF005AF000FFFF00B4
FF00003C00FF00D2FF00FFD200FF7800FF7800FF7800FF1E00FF1E00FF78001EFF00FF78
00FF1E00FF1E00FF7800FF7800FFD200D2FF00FF7800FF7800FF7800FF7800FF7800D2FF
0078FF00FFD200FFD20078FF00FFD200FFD200D2FF0078FF3C00FFFF0000F000FF9600FF
0078FF0078FF3C00FF00D2FF00FFD200FF7800FF7800FF7800FF780078FF00D2FF00FF78
00FF7800FF7800FF7800FF7800D2FF00FFD200FF7800D2FF
9600FF9600FFF000FFFF00009600FF3C00FF3C00FF001EFF001EFF3C00FFFF005A3C00FF
0078FF0078FF001EFF3C00FFFF00000078FF0078FF0078FF0078FF0078FF001EFFFF0000
FF0000FF00B4FF0000FF0000F000FFFF00009600FF3C00FF001EFFFF005A001EFFF000FF
9600FFF000FFFF00B4001EFF0078FF0078FF001EFF00D2FF00D2FF0078FF00D2FF00D2FF
00D2FFFF000000D2FF00D2FF001EFF001EFF001EFF9600FFFF00003C00FF001EFF0078FF
0078FF00FFD200FFD200D2FF00FFD200FFD200FFD23C00FF00FFD200FF7800FF7800FF78
00FF7800FFD200FF7800FF7800FF7800FFD200D2FF001EFF00D2FF00D2FF9600FF00D2FF
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD23C00FF
00D2FF00FFD200FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF78
00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800D2FF9600FFFF00009600FFFF005A
001EFF0078FF00D2FF00FFD200FFD200FFD200FF7800FF7800FF7800FFD200D2FF00FFD2
00FF7800FF7800FF7800FF7800FFD200D2FF00D2FF00FFD200FFD200FF7800FF7800FFD2
F000FF00D2FF00FFD200FFD200D2FF00D2FF0078FFF000FF3C00FFFF00009600FF001EFF
0078FF00D2FF00D2FF00FFD200FFD200FFD200FF7800FF7800FFD200D2FF00FFD200FF78
00FF7800FF7800FFD200FFD20078FF001EFF00D2FF00FFD2
001EFF001EFF9600FFFF00B43C00FF001EFF001EFF001EFF00D2FF0078FF9600FF0078FF
00D2FF00D2FF001EFF001EFF0078FF00D2FF00D2FF0078FF001EFFFF00B43C00FFF000FF
FF0000FF0000FF0000FF00B43C00FFFF00009600FF0078FF0078FFFF00000078FF0078FF
3C00FFFF00B4FF00B4001EFF9600FF00D2FF0078FF00FFD200FFD200D2FF00D2FF00FFD2
00FFD200D2FF00FFD200D2FF00D2FF0078FF001EFF9600FFFF00009600FFF000FF00D2FF
00D2FF00FFD200FFD200FFD200FF7800FF7800FFD2001EFF00D2FF00FFD200FF7800FF78
00FF7800FF7800FF7800FF7800FF7800FFD2FF00003C00FF00FFD200FF7800FF7800FF78
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FFD200D2FF3C00FF
00D2FF00FFD200FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FFD2
00FF7800FF7800FF7800FF7800D2FF00FFD200FFD200FFD200D2FF001EFF3C00FFFF0000
9600FF3C00FF00D2FF00D2FF0078FF00FFD200FF7800FF7800FF7800FFD20078FF00FF78
00FF7800FF78001EFF00FFD200D2FF9600FF00FFD20078FF00D2FF00FFD200FFD200FFD2
00D2FF00D2FF00FFD200D2FF001EFF0078FF9600FF001EFF9600FFFF005A9600FF3C00FF
F000FF0078FF001EFF00FFD200FFD200FFD200FFD200FFD200D2FF9600FF0078FF00FFD2
001EFF00FFD2001EFF00D2FF001EFF0078FF9600FF00FFD2
00D2FF3C00FFFF005AFF005A001EFF00D2FF00D2FF001EFF00D2FF00D2FFFF000000D2FF
00D2FF00D2FF0078FF001EFF00D2FF00D2FF00D2FF0078FF0078FF001EFF3C00FFFF0000
FF00B49600FF3C00FF3C00FF0078FF3C00FF3C00FF001EFF00D2FF001EFF00D2FF00D2FF
0078FF3C00FFFF0000001EFF00D2FF00FFD200FFD200FFD200FFD20078FF0078FF00FFD2
00FFD200FFD200FFD200FFD200D2FF001EFF9600FFFF0000FF0000F000FF3C00FF3C00FF
0078FF00D2FF001EFF00FF7800FF7800FF7800FFD23C00FF0078FF00FF7800FFD200FF78
00FF1E00FF1E00FF1E00FF780078FF00FF7800FFD200D2FF00FFD200FF7800FF7800FF78
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD2
00FFD200FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800D2FF
00FF7800FFD200FF7800FF7800FF7800D2FF001EFF00D2FF00D2FF0078FFF000FFFF0000
3C00FF001EFF0078FFF000FF00D2FF00FFD200FF7800FF7800FFD200FFD200D2FF00FFD2
00FF7800FF7800D2FF0078FF00D2FFFF00003C00FF0078FF00FFD200FFD200D2FF00FFD2
00D2FF3C00FF00D2FF00D2FF0078FF3C00FF001EFF9600FFFF005A9600FF001EFF001EFF
001EFF00D2FF00D2FF00D2FF00D2FF001EFF00FFD200FFD200D2FFF000FF00FFD200FFD2
00D2FF00FFD200D2FF0078FFFF0000FF000000D2FF00D2FF
00D2FF00D2FFFF0000FF00000078FF00D2FF00FFD200D2FF00FFD200FFD2F000FF00D2FF
00FFD200FFD2001EFF00D2FF00D2FF00D2FF00D2FF001EFF001EFF001EFF9600FFFF005A
9600FF001EFF3C00FF0078FF00D2FF00D2FF3C00FF00D2FF00FFD200D2FF00FFD200FFD2
0078FF3C00FFFF000000D2FF0078FF00D2FF00FF7800FF7800FFD200D2FF00FFD200FFD2
00FF7800FF7800FFD200D2FFF000FF0078FF001EFF3C00FFFF0000F000FF0078FF00D2FF
00D2FF001EFF00D2FF00FF7800FF7800FF7800FFD200FF7800D2FF00FF7800FF7800FF1E
00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD200FFD200FF7800FF7800FF78
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD2
00D2FF00FFD200FF780078FF00FF7800FF1E00FF1E00FF1E00FF7800FFD200FF780078FF
3C00FF00FFD200FF7800FF7800FF78001EFF00D2FF0078FF3C00FF3C00FFF000FFFF0000
FF00009600FF001EFF00D2FF00FFD200FFD200FFD200FFD200FFD20078FF0078FF00FFD2
00FFD200FFD200FFD200D2FF001EFFFF00003C00FF0078FF00D2FF00D2FF001EFF00D2FF
001EFF3C00FF3C00FF0078FF3C00FF3C00FF9600FFFF00B4FF00003C00FF001EFF0078FF
0078FF00D2FF00D2FF00D2FF001EFF0078FF00D2FF00D2FF00D2FFFF000000D2FF00D2FF
001EFF00D2FF00D2FF001EFFFF005AFF005A3C00FF00D2FF
00FFD29600FF0078FF001EFF00D2FF001EFF00FFD2001EFF00FFD20078FF9600FF00D2FF
00FFD200FFD200FFD200FFD200FFD2001EFF0078FFF000FF3C00FF9600FFFF005A9600FF
001EFF9600FF0078FF001EFF00D2FF00FFD200D2FF00D2FF00FFD200FFD200FFD200D2FF
0078FF00FFD29600FF00D2FF00FFD2001EFF00FF7800FF7800FF780078FF00FFD200FF78
00FF7800FF7800FFD20078FF00D2FF00D2FF3C00FF9600FFFF00003C00FF001EFF00D2FF
00FFD200FFD200FFD200D2FF00FF7800FF7800FF7800FF7800FFD200FF7800FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FFD200D2FF3C00FF00D2FF00FFD200FF78
00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD2
3C00FFFF000000FFD200FF7800FF7800FF7800FF7800FF7800FF7800FF7800FFD200D2FF
001EFF00FFD200FF7800FF7800FFD200FFD200FFD200D2FF00D2FFF000FF9600FFFF0000
9600FF001EFF0078FF00D2FF00D2FF00FFD200D2FF00FFD200FFD200D2FF00D2FF00FFD2
00FFD20078FF00D2FF9600FF001EFFFF00B4FF00B43C00FF0078FF0078FFFF00000078FF
0078FF9600FFFF00003C00FFFF00B4FF0000FF0000FF0000F000FF3C00FFFF00B4001EFF
0078FF00D2FF00D2FF0078FF001EFF001EFF00D2FF00D2FF0078FF9600FF0078FF00D2FF
001EFF001EFF001EFF3C00FFFF00B49600FF001EFF001EFF
00FFD200D2FF001EFF0078FF00FFD200FFD200FF7800FF7800FF7800FFD200D2FF00FFD2
00FF7800FF7800FFD200FFD200FFD200D2FF00D2FF0078FF001EFF9600FFFF00003C00FF
F000FF0078FF00D2FF00D2FF00FFD200FFD200D2FFF000FF00FFD200FF7800FF7800FFD2
00FFD200D2FF00D2FF00FFD200FF7800FF7800FF7800FF7800FFD200D2FF00FFD200FF78
00FF7800FF7800FFD200FFD200FFD200D2FF0078FF001EFFFF005A9600FFFF00009600FF
00D2FF00FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FFD200D2FF3C00FF00FFD200FF7800FF78
00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00D2FF9600FF00D2FF00D2FF
001EFF00D2FF00FFD200FF7800FF7800FF7800FFD200FF7800FF7800FF7800FF7800FFD2
3C00FF00FFD200FFD200FFD200D2FF00FFD200FFD20078FF0078FF001EFF3C00FFFF0000
9600FF001EFF001EFF001EFF00D2FF00D2FFFF000000D2FF00D2FF00D2FF0078FF00D2FF
00D2FF001EFF0078FF0078FF001EFFFF00B4F000FF9600FFF000FF001EFFFF005A001EFF
3C00FF9600FFFF0000F000FFFF0000FF0000FF00B4FF0000FF0000001EFF0078FF0078FF
0078FF0078FF0078FFFF00003C00FF001EFF0078FF0078FF3C00FFFF005A3C00FF001EFF
001EFF3C00FF3C00FF9600FFFF0000F000FF9600FF9600FF
00D2FF00FF7800FFD200D2FF00FF7800FF7800FF7800FF7800FF7800D2FF0078FF00FF78
00FF7800FF7800FF7800FFD200D2FF3C00FF0078FF0078FF9600FFF000FFFF00003C00FF
0078FF00D2FF00FFD200FFD20078FF00FFD200FFD20078FF00D2FF00FF7800FF7800FF78
00FF7800FF7800D2FF00FFD200FF7800FF7800FF1E00FF1E00FF78001EFF00FF7800FF1E
00FF1E00FF7800FF7800FF7800FFD200D2FF3C00FFFF0000FF00B4F000FFFF005A001EFF
00FFD200FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E3C00FF00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FFD20078FFFF00B400D2FF00FFD200FF78
00FFD200FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD2
00D2FF00D2FF00FFD200FF7800FF7800FF780078FF00FF7800FF7800FF7800FF7800FFD2
0078FF0078FF00FFD200FFD200FFD20078FF00D2FF00D2FF0078FF3C00FFF000FFFF0000
FF00B43C00FF001EFF0078FF00D2FF0078FF001EFF00D2FF0078FF0078FFF000FF3C00FF
0078FF0078FF001EFF3C00FF9600FFFF005AF000FF3C00FF3C00FF3C00FFFF00B4F000FF
FF0000FF0000FF0000FF0000FF00B4FF00B43C00FF3C00FF3C00FF001EFF0078FF0078FF
0078FF0078FF0078FF0078FF3C00FF001EFF0078FF3C00FF3C00FFFF00009600FF3C00FF
9600FFFF0000FF005AFF0000FF005AF000FFFF0000FF0000
00FF1E00FF7800D2FF001EFF00FF7800FF7800FF1E00FF1E00FF7800FFD200FFD200FF78
00FF7800FF7800FF7800FFD2FF00000078FF0078FF0078FFF000FFFF0000FF005AFF0000
001EFF0078FF00D2FF00FFD200FF7800FF7800FF7800D2FF00D2FF001EFF00FF7800FF1E
00FF7800FF7800FFD200D2FF00FF7800FF1E00FF1E00FF1E00FF1E00FF7800FF1E00FF1E
00FF1E00FF1E00FF7800FF7800FFD2FF00B40078FF3C00FFFF005A001EFF0078FF00FFD2
00D2FFFF005A00D2FF00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF78001EFF001EFF0078FFFF005A00D2FF001EFF3C00FF
00FFD200FFD200FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FF7800FF78
00FFD2001EFF00FFD200FFD200FFD200D2FF0078FF00FFD200FF7800FFD200FFD200FFD2
00D2FF0078FF00D2FF00FFD200D2FF0078FF0078FF0078FF0078FF001EFFF000FFFF0000
9600FF3C00FF3C00FF0078FF0078FF0078FFF000FF0078FF0078FF001EFFFF0000FF00B4
3C00FF3C00FFFF0000F000FFFF0000FF0000F000FFFF005AFF00B4FF0000FF0000FF0000
F000FF9600FF9600FFFF00003C00FF001EFF3C00FF0078FF9600FF3C00FF0078FF0078FF
0078FF0078FF0078FF0078FF001EFF9600FF3C00FF3C00FF9600FFFF005AFF00B4FF0000
FF0000FF0000F000FF9600FF9600FF9600FFFF00009600FF
00FF1E00FF1E00FF7800FFD200FF7800FF1E00FF1E00FF1E00FF1EFF00B400FF7800FF78
00FF7800FF780078FF00FFD200D2FF00FFD200D2FF0078FF3C00FFFF0000FF0000001EFF
00D2FF0078FF9600FF00FFD200FF7800FF7800FF7800FF783C00FF00FF7800FF1E00FF1E
00FF1E00FF7800FF780078FF00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF7800FFD20078FF00D2FF00FFD200D2FFFF0000001EFF00FFD200FF78
00FF789600FF00FFD200FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FFD200FF7800FF7800FF7800FFD2FF00B400FFD200FF780078FF
00FF7800D2FF00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FF7800FF78
00FFD200FFD20078FF3C00FF00FFD200D2FF0078FF00FFD200FFD200D2FF00FFD200FFD2
00D2FF0078FF00D2FF00D2FF00D2FF0078FFF000FF0078FF3C00FF3C00FFF000FFFF00B4
9600FF3C00FF001EFFF000FF9600FF001EFFFF0000001EFFFF00009600FFFF0000F000FF
F000FFFF00B4FF0000FF0000FF005AF000FF9600FFFF005AFF0000FF00009600FFFF0000
001EFF3C00FF3C00FFFF00003C00FF0078FF001EFF0078FF3C00FF3C00FF0078FF0078FF
0078FF0078FF0078FF0078FF3C00FFF000FFFF0000FF0000FF0000FF005AFF005AF000FF
3C00FF3C00FF001EFFF000FF001EFF9600FFFF005A001EFF
00FF1E00FF1E00FFD23C00FF00FF7800FF1E00FF1E00FF1E00FF1E00FF7800FF1E00FF1E
00FF1E00FF7800FF7800FF7800FFD200FFD200D2FF001EFFFF0000FF0000FF00003C00FF
001EFF00FFD200FFD200FFD2F000FF00FF7800FF1E00FF1E00FF7800FF7800FF1E00FF1E
00FF1E00FF1E00FF78FF00B400FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E3C00FF00D2FF00FFD200FF7800FFD200D2FF3C00FFF000FF3C00FF00FF78
00FF7800FF7800FFD200FFD2FF000000FF7800FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF7800FF1E00FF1E00FF1E00FF7800FFD23C00FF00D2FF00FF7800FF78
00FF1E00FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FF7800FF7800FF78
00FFD2001EFFFF0000001EFF00D2FF0078FF0078FF00FFD200FFD200D2FF00D2FF00D2FF
00D2FF0078FF9600FF001EFF0078FF0078FF001EFF3C00FF9600FFFF005AFF0000F000FF
FF00B49600FF001EFF3C00FFFF00003C00FFFF00009600FFF000FFFF0000FF0000FF0000
FF0000FF005AFF00B49600FF3C00FF3C00FF3C00FFFF00009600FF001EFF3C00FF001EFF
0078FF0078FF9600FF3C00FF0078FF001EFF00D2FF00D2FF001EFF0078FF0078FF00D2FF
0078FF001EFF3C00FFFF00B43C00FFF000FFFF0000FF00009600FF3C00FFF000FF9600FF
0078FF0078FF3C00FF0078FF0078FF3C00FFFF005A001EFF
00FF1E00FFD200FFD200D2FF0078FF00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF7800FF7800FF7800FFD20078FF0078FF001EFF9600FFFF00009600FF001EFF
00D2FF00D2FF00FFD200FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF7800FF1E00FF1E
00FF1E00FF7800D2FF001EFF00FF7800FF7800FF7800FF1E3CFF003CFF003CFF0000FF1E
9600FF00FF78FF000000FF7800FF1E00FF1E00FF7800FFD2FF005A00D2FF00FF7800FF78
00FF1E00FF1E00FF78001EFF00FF7800FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF7800FF7800FFD200FF7800FF7800FF1E
00FF1E00FF1E00FF1E00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800D2FF00D2FF00FFD200FFD2
00FFD200D2FF001EFFFF0000001EFF001EFF00D2FF00D2FF00D2FF001EFF001EFF00D2FF
0078FF3C00FFFF00009600FF001EFF9600FF3C00FFFF0000FF0000FF0000FF005A9600FF
3C00FF3C00FF3C00FF3C00FF9600FFF000FFFF0000FF0000FF0000FF00B49600FFFF0000
3C00FF9600FF001EFF3C00FF001EFF001EFF3C00FFFF00B49600FF001EFF0078FF0078FF
9600FF00D2FF00D2FF001EFF00D2FF00D2FF00D2FF0078FF3C00FF0078FF00D2FF00D2FF
00D2FF0078FF0078FF001EFF9600FFFF0000F000FFFF0000001EFF0078FFFF00009600FF
0078FF00D2FFFF00B400D2FF00D2FFF000FFFF00003C00FF
00FF1E00FF1E00FF7800FF7800FF1E00FF1E00FF1E3CFF0000D2FF00FF1E00FF1E00FF1E
00FF1E00FF7800FFD200FFD200FFD200D2FF001EFFF000FFFF00B4FF00B4FF0000FF0000
0078FF00FFD200FFD200FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF7800FF7800FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF78FF000000FF1E00FF1E00FF7800FFD29600FF00FFD29600FF00FF78
00FF1E00FF1EFF00B400FF7800FF7800FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF7800FF7800D2FF00FF7800FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FF7800FF7800FFD2FF00000078FF
00D2FF00D2FF001EFFFF0000FF00003C00FF0078FF001EFF00D2FF0078FFFF00B40078FF
0078FF9600FFF000FFFF005A9600FFFF0000FF005AFF0000FF0000F000FF9600FFFF005A
3C00FF3C00FF3C00FF9600FFFF00B4FF0000FF00B4FF005A3C00FF9600FF001EFFFF0000
9600FF0078FF0078FF001EFF00D2FF001EFF3C00FFFF00B49600FF0078FF0078FF00D2FF
001EFF00FFD200FFD20078FF00D2FF00FFD200FFD200D2FF3C00FF00D2FF00D2FF00D2FF
0078FF001EFF001EFF3C00FFFF005AFF00009600FF0078FF9600FF00D2FF00D2FF0078FF
00D2FF00FFD20078FF00FFD200D2FF00D2FFFF00000078FF
3CFF0000FF1E00FF7800FF7800FF1E00FF1E3CFF003CFF003CFF003CFF0000FF1E00FF1E
00FF7800FF7800FFD2FF00B400D2FF00D2FF0078FF3C00FF9600FFFF00B43C00FF001EFF
0078FF00D2FF00D2FF00FFD200FF7800FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF7800FFD200FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF0000FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF1E00FF78
00FF1E00FF1E00FF1E00FF1E00FFD200FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF0000FF1E00FF1E00FF1E00FF7800FFD200FFD200FF7800FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF7800FF7800FF7800FF7800FF7800FF7800FF7800FF7800FF7800FFD200FFD200D2FF
0078FF001EFF9600FFF000FFFF005A3C00FF9600FF0078FF0078FF0078FF001EFF001EFF
3C00FF3C00FFF000FFFF0000FF005AFF0000FF0000F000FFFF00B4FF005A001EFF3C00FF
3C00FF001EFF3C00FF9600FFFF0000F000FF3C00FF3C00FF3C00FF0078FF0078FF0078FF
0078FF0078FF00D2FF001EFF00D2FF00D2FF9600FFFF00B4FF00000078FF00D2FF00FFD2
00FFD200FFD200FFD20078FF00D2FF00FFD200FFD200FFD200FFD200FFD200FFD2001EFF
0078FF3C00FF9600FFF000FFFF00003C00FF0078FF00D2FF001EFF00D2FF00FFD200D2FF
0078FF00FFD200FF7800FF780078FF00FFD200D2FF00FFD2
3CFF0000FF1E00FFD200FF7800FF1E3CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E
00D2FFF000FF00FF7800D2FF00FF7800FFD200D2FF0078FF9600FFFF0000001EFF00D2FF
001EFF00FFD200FFD200D2FF00FFD200FFD200FF7800D2FF3CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF7800FFD20078FF00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E3CFF003CFF003CFF003CFF0000FF1E00FF1E00FF7800FF7800FF1E00FF1E
3CFF003CFF003CFF003CFF0000FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF0000FF1E00FF780078FF00FFD2001EFF00D2FF00FF7800FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD200FF78
00FF7800FF7800FF7800FF7800FF7800FF7800FF7800FF7800FF7800FF7800FFD200FFD2
00D2FF00D2FF0078FF9600FFFF005AFF00003C00FF3C00FF9600FF001EFFFF0000FF005A
FF0000FF0000FF0000FF0000FF0000F000FF3C00FF001EFF001EFF001EFF0078FF001EFF
3C00FF001EFFF000FFF000FFFF00003C00FF3C00FF0078FF001EFF00D2FF00D2FF00D2FF
F000FF00D2FF00FFD20078FF00FFD200D2FF0078FF001EFFFF005A00D2FFFF00B400FFD2
00FF7800FF7800FFD29600FF00D2FF00D2FF00FFD200FFD200FFD200FFD200FFD200D2FF
00D2FF0078FF3C00FF9600FFFF005A001EFFF000FF00D2FF00FFD29600FF00FFD20078FF
0078FF00FFD200FF7800FF7800FFD200FF7800FFD200FFD2
00FF1E00FF7800D2FF00FF7800FFD23CFF003CFF003CFF003CFF003CFF0000FF1E00FF78
00FFD200FF7800FF7800FF7800FF7800FFD200FFD20078FFFF0000FF005A001EFF00D2FF
00FFD200FF7800FF7800FF7800FFD23C00FF00D2FF00FF1E3CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF78F000FF00FFD200FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FFD200FFD200FFD200FF783CFF00
3CFF003CFF003CFF003CFF003CFF0000FFD23CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF0000FF1E00FF1E00FF7800FFD2FF00B40078FF9600FF00FFD200FF1E
00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF1E00FF1E00FF789600FF00FFD200D2FF00D2FF00FFD20078FF00FF78
00D2FF00FF7800FF7800FFD200FFD200FF7800FF7800FF7800FF7800FFD200FFD200FFD2
00D2FF001EFFF000FF9600FFFF00B4FF0000F000FF3C00FF3C00FF3C00FF9600FFFF0000
FF0000FF0000FF005A9600FFFF0000FF00B4001EFF001EFF0078FF9600FF0078FF3C00FF
0078FF001EFF3C00FFF000FFFF00B4001EFF0078FF00D2FF00D2FF0078FF00FFD200FFD2
3C00FF00D2FF00FFD200FF7800FFD2001EFF00FFD2001EFF0078FF00FFD200FFD200FFD2
00FF7800FF7800D2FF0078FF00FFD200FF7800FF7800FF7800FFD200FFD200D2FF3C00FF
0078FF0078FF9600FFFF00B4FF00B43C00FF00D2FF00D2FF00FFD200FFD200FF7800FF78
00D2FF0078FF00FF7800FF7800FF7800FF7800FFD2001EFF
3CFF003CFF0000FF7800FF1E00FF1E3CFF003CFF003CFF003CFF003CFF0000FFD200FF78
00FF1E00FF1E00FF1E00FF1E00FFD200D2FF00D2FF001EFFFF00B4FF005A001EFF0078FF
FF005A0078FF00FF7800FF1E00FF1E00FF7800FF7800FF783CFF003CFF003CFF003CFF00
3CFF003CFF0000FFD200FF1EFF000000FF1E00FF1E9600FF3CFF003CFF003CFF003CFF00
00FFD23CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FFD200FF1E00FF1E3CFF00
3CFF003CFF003CFF003CFF003CFF0000FF783CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF1E00FF78001EFF9600FF00FFD200FF7800FF1E00FF1E
00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF7800FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD200FFD2
F000FF00FFD200FFD200FFD200D2FF00FFD200FF7800FF7800FFD200FFD200D2FF00D2FF
00D2FF00D2FF0078FF001EFFFF0000FF0000FF005A9600FF9600FFFF0000FF0000FF00B4
FF00003C00FFFF00B4001EFFFF0000FF00B4001EFF00D2FF0078FF3C00FF00D2FF00D2FF
F000FF3C00FF3C00FFFF00B4FF00B4001EFF001EFFFF005A00FFD200FFD200FFD200FFD2
00D2FF00D2FF00FFD200FF7800FF7800FFD200FF7800FFD200D2FF00FF7800FF780078FF
00FF7800FF7800FFD2F000FF00FFD200FF7800FF7800FF7800FFD200D2FF9600FF001EFF
0078FF0078FFF000FFFF0000F000FF3C00FF001EFF0078FF00D2FF00FFD200FF7800FF78
00FFD2FF000000FF7800FF1E00FF1E00FF1E00FF78F000FF
3CFF003CFF00FF00B43CFF003CFF003CFF003CFF003CFF003CFF0000FF783CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FF7800FFD200FFD20078FF3C00FFFF0000001EFF00D2FF
00FFD200FF7800FF1E00FF1E00FF1E00FF1E00FF1E0078FF00FF1E3CFF003CFF003CFF00
3CFF0000FF1E3CFF003CFF0000FFD200FF1E3CFF003CFF0000FF1E3CFF0096FF0096FF00
3CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF780078FF0078FF00FF1E3CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF7800D2FFFF005A0078FFF000FF0078FF00FFD200FF7800FF1E00FF1E
00FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF78
00FFD2FF005A001EFF001EFF001EFF00D2FF00FFD23C00FF00FFD200FFD200D2FF3C00FF
001EFF0078FF3C00FF001EFFF000FFFF0000FF00B4F000FFFF005AFF0000FF00003C00FF
3C00FF001EFF0078FF0078FF0078FFFF000000D2FF00D2FF00D2FFFF000000D2FF00D2FF
0078FF0078FF001EFF9600FFFF005A3C00FF0078FF00D2FF00FFD200FFD200FF7800FF78
00D2FFF000FF00D2FF00FF7800FF7800FF7800FF7800FFD2001EFF00FF7800FF7800FF78
00FF1E00D2FF00FF78001EFF00FF7800FF7800FF7800FF7800FFD200D2FF001EFF00D2FF
00D2FF0078FF3C00FFFF00003C00FF0078FF00D2FF00D2FF00D2FF0078FF00FF7800FF78
00FF7800FF7800FF7800FF1E00FF1E00FF1E00FF78001EFF
96FF003CFF0000FF1E3CFF003CFF0096FF0096FF0096FF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF7800D2FF00D2FF00FFD20078FF0078FF3C00FFFF0000001EFF001EFF
00FFD200FFD200FF7800FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF0000FFD200FF1E3CFF003CFF0096FF0096FF0096FF0096FF00
96FF0096FF003CFF003CFF003CFF0000FF1EFF005A00FF783C00FF00FF7800FF1E3CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF7800FF7800FF1E00FFD29600FF001EFF0078FF00FF7800FF1E00FF1E
00FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF78
00FF7800FF7800FFD20078FF9600FF001EFF00D2FF0078FF00FFD200FFD200D2FF00D2FF
001EFF001EFF001EFF3C00FFFF005AFF0000FF00B4F000FFFF00B4FF005A3C00FFFF0000
0078FFFF00B400D2FF00D2FF00D2FF9600FF00D2FF00FFD200FFD2001EFF00FFD200FFD2
00D2FF0078FF001EFFFF0000FF005AFF00B40078FFF000FF0078FF00FFD200FF7800FF78
00FFD200D2FF00FF7800FF7800FF1E00FF1E00FF7800FF78F000FF00FF7800FF7800FF1E
00FF1E00FF1E00FF7800FFD200FF7800FF1E00FF7800FF7800FF7800FF7800FFD200FFD2
00D2FF001EFF9600FFFF005AF000FF0078FF00D2FF00FFD200FF7800FF7800FF7800FF1E
00FF1E00FF1E3C00FF00FF1E00FF1E00FF1E00FF78001EFF
96FF003CFF0000FF1E3CFF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FFD2FF005A3C00FF9600FFF000FF9600FFFF00009600FF
9600FF00FFD200FF7800FF1E3CFF003CFF003CFF003CFF003CFF003CFF0096FF0096FF00
96FF0096FF003CFF0000FF1E00FF783CFF003CFF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF0000FF1E00FF1E00FF7800FF78FF000000FF7800FFD200FF78
3CFF003CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF003CFF003CFF00
3CFF003CFF003CFF003CFF0000FF1E00D2FF9600FF00FF7800FF78FF000000FFD200FF1E
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF78
00FF7800FF7800D2FF00FFD200D2FF00D2FFF000FF001EFF00D2FF00D2FF0078FF00D2FF
0078FF001EFFFF0000F000FFFF0000FF0000F000FF9600FFF000FFFF00009600FF0078FF
00D2FF0078FF0078FF00FFD200FFD200D2FF0078FF00FFD200FFD200FFD200FFD200FFD2
00D2FFF000FF0078FF3C00FFFF0000001EFF0078FF00D2FF00D2FF00FFD200FF7800FF78
00FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF789600FF00FF7800FF1E00FF1E
00FF1E00FF1E00FF1E00FF7800FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD20078FF
0078FF3C00FF3C00FFFF00B4F000FF3C00FFF000FF00FFD200FF7800FF7800FF7800FF1E
00FF1E00FF1E00FF1E3CFF003CFF0000FF1E00FF1E00FF78
96FF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
3CFF0000FF1E00FF7800FFD2001EFF0078FF0078FF3C00FFFF0000001EFF0078FF0078FF
001EFF00D2FF00FF7800FF1E00FF1E3CFF003CFF003CFF003CFF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF0000FF1E00FF783CFF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF003CFF003CFF0000FF1E0078FF00FF7800FF1E3CFF00
3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF00
3CFF003CFF003CFF003CFF0000FF1E00FF7800FF7800FF1E00FF1E00FF7800FF7800FF1E
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF7800FF7800FF7800FF7800FFD200FFD23C00FF0078FFFF005A0078FF0078FF0078FF
F000FF9600FFFF00B4FF0000F000FF3C00FFF000FF3C00FF9600FFFF00009600FF3C00FF
0078FF00D2FF00D2FF00FFD200FFD29600FF0078FF00FFD200FF7800FF7800FFD29600FF
001EFF00D2FF00D2FF9600FFFF005A3C00FF0078FF00D2FF00FFD200FF7800FF7800FF1E
00FF1E00FF1E00D2FF00FF1E00FF1E00FF1E00FF1E00FF78FF005A00FFD200FF7800FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FFD200FFD2
0078FFF000FFFF00B4FF00B4F000FFF000FFFF00000078FF00FFD200FFD200FF7800FF1E
00FF1E00FF1E3CFF003CFF003CFF003CFF0000FF1E00FFD2
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0000FF78
00FF1E00FF783C00FF00FF7800FF78FF000000D2FF0078FFFF00B40078FF00FFD200FFD2
00FFD200FF7800D2FF00FF7800FF1E3CFF003CFF003CFF003CFF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF0000FFD296FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF003CFF003CFF0000FFD200FFD200FF1E3CFF003CFF00
3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
3CFF003CFF003CFF003CFF0000FF1EFF005A00FF1E00FF1E3CFF0000FF1E00FF1E00FF1E
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF7800FF7800FF7800FF7800FF7800FFD200FFD200FFD200D2FF0078FF9600FF3C00FF
9600FFFF0000FF0000FF00B4FF005A001EFF001EFF001EFFFF0000FF00B49600FFFF00B4
00D2FF00FFD200FFD200FF7800FF7800FFD2FF005A00FFD200FF7800FF7800FF78F000FF
00D2FF00FFD200D2FF001EFFF000FFFF0000FF005A0078FF00FFD200FF7800FF7800FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800D2FF0078FF00FF7800FF7800FF1E
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FFD20078FF00D2FF
00D2FF001EFF3C00FFFF0000FF005A001EFFF000FF00FFD200FFD200D2FF00D2FF00FFD2
00FF7800FF1E3CFF003CFF003CFF003CFF0000FF1E00FF78
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
00FFD200FFD200FF1E00FF1E00FF1E00FF1E00D2FF00D2FFFF005A0078FF0078FF00FF78
0078FF00FF1E00FF7800FF780078FF00FF1E001EFF3CFF003CFF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF003CFF003CFF0000FF1E00FF7800FF1E3CFF003CFF00
3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
3CFF003CFF003CFF0000FF1E00FFD200FF7800FF1E3CFF003CFF003CFF0000FF1E00FF78
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF7800FF7800FF7800FF7800FF7800FFD200FFD200FFD2F000FFF000FFF000FFFF0000
FF00B4FF00009600FF001EFFF000FF0078FF00D2FF0078FF0078FF9600FFFF0000001EFF
001EFF0078FF00FFD200FF7800FF7800FFD23C00FF0078FF00FF7800FF7800FF7800FF78
00FF7800FFD200D2FFFF005AFF00B4F000FF0078FF00FFD200FFD200D2FF00FF7800FF1E
00FF1E00FF1E3CFF003CFF003CFF0000FF7800FF1E00FF1E00FFD200FF7800FF1E00FF1E
3CFF003CFF003CFF003CFF0000FF1E00FF1E00FF7800FFD200D2FF00D2FF00FFD200FFD2
0078FF00D2FFF000FFFF00003C00FF0078FF00FFD200FF7800FF7800FF7800FFD200FFD2
0078FF00FF783CFF003CFF003CFF003CFF0000FF1E00FF1E
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF0000FF1E
00D2FFFF00003CFF003CFF003CFF0000FF1E00FF783C00FFFF00B4F000FF00FFD200FF1E
00FF1E3CFF003CFF0000FF1E00D2FF00FFD23CFF003CFF003CFF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0000FFD296FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF0000FF7800FF780078FF00FFD200FF1E3CFF003CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF003CFF003CFF0000FF1E9600FF00FF1E3CFF003CFF003CFF003CFF003CFF0000FF1E
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF7800FF7800FF7800FF7800FF780078FF00D2FF00D2FF00D2FF0078FF001EFFFF00B4
FF005AFF00003C00FF0078FF0078FF9600FF00D2FF0078FF00D2FF0078FFF000FF0078FF
00FFD200FFD2FF000000FF7800FF7800FFD200FFD200FF7800FF7800FF1E00FF7800FF78
00FF7800FFD200D2FFFF00B49600FFF000FF00D2FF00FF7800FF7800FF789600FFF000FF
00FF1E00FF1E3CFF003CFF003CFF003CFF0000FF1E00FF1E00D2FF00FF7800FF1E00FF1E
3CFF003CFF003CFF003CFF003CFF0000FF1E00FF78FF000000FFD200FF7800FF7800FF78
00FFD200D2FF3C00FFFF00B4FF00B4001EFF0078FF00D2FF00FF7800FF1E00FF1E00FF1E
00FF1E00D2FF3CFF003CFF003CFF003CFF0000FF1E3CFF00
F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF7800FF78
3CFF003CFF003CFF003CFF003CFF00001EFF00FF7800FFD2FF00B400FFD200FF78001EFF
00FF1E3CFF003CFF0000FF1E00FF1E00FFD200FF1E3CFF0000D2FF96FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF003CFF0000FF1E00D2FF3C00FF00FF7800FF1E3CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF003CFF003CFF0000FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF0000FF1E
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF78
00FFD200FF7800FF7800FF7800FFD200FFD200FFD2001EFFFF00B4001EFF9600FFFF0000
F000FFF000FF9600FF9600FF00D2FF00D2FF00FFD200FFD200D2FF00D2FF0078FF0078FF
00FFD200FF7800FF7800FF7800FF1E00FF1E00FF7800FF7800FF1E00FF1E00FF1E00FF78
3C00FFFF00B400FF7800FFD23C00FFFF00B400FFD200FF7800FF1E00FF1E9600FF00FFD2
00FF1E3CFF003CFF003CFF003CFF003CFF0000FF1E00FF1EFF000000FF7800FF1E3CFF00
3CFF003CFF003CFF003CFF003CFF0000FF7800FFD200FF7800FF1E00FF1E00FF7800D2FF
0078FF001EFF0078FFF000FFFF00000078FF00FFD200FF7800FF7800FF1E00FF1E00FF1E
3CFF003CFF0000FF1E3CFF003CFF0096FF0096FF003CFF00
F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0000D2FF00FF783C00FF00FF1E
3CFF003CFF0096FF003CFF003CFF003CFF0000FF1E00FFD2FF00B400FFD200FF1E00FF1E
00FF783CFF003CFF0000D2FF3CFF0000FF1E0078FF00FF783CFF0000FF1E96FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF003CFF0000FF1E3CFF0000FF1E00D2FFFF000000FFD200FF1E3CFF003CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF003CFF00FF0000F000FF3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF1E00FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF78
00FF7800FFD20078FF00FFD200D2FF00FFD200FFD200D2FF0078FFFF0000FF00009600FF
F000FF3C00FF001EFF00D2FF00FFD200FFD200FFD200FFD200D2FF0078FF00FFD2FF005A
00FFD200FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF7800FF1E00FF1E00FF1E00FF1E
00FF7800FFD200FF7800FFD200FF78001EFFFF00B4001EFF00FF1E00FF1E00FF1E00FF1E
00FF783CFF003CFF003CFF003CFF003CFF0000FF1E00FF783C00FF00D2FF00FFD23CFF00
3CFF003CFF003CFF003CFF003CFF00001EFF00FF7800FF1E00FF1E00FF1E00FF1E00FF78
00FFD200D2FFFF0000F000FFF000FF0078FF9600FF00FFD2001EFF00FFD200FF783CFF00
3CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF003CFF0000D2FF00FF1E00FF1E
96FF0096FF0096FF0096FF003CFF003CFF0000FF1E00FFD2FF000000FF7800FF1E3CFF00
3CFF0000FFD296FF0096FF003CFF0000FFD200FF7800FFD200FF1E00FF1E00FFD296FF00
96FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF00
96FF0000FF1E3C00FF00FF78001EFFF000FF001EFFFF005A001EFF00FF1E3CFF003CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF003CFF003CFF0000FF7800FF1E3CFF003CFF0096FF0096FF0096FF0096FF0096FF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E
00FF1E00FF1E00FF1E00FF7800D2FF00FF7800FF7800FF7800FF783C00FF00FF7800FF78
00FF7800FF7800FFD2001EFF0078FF00D2FF00D2FF001EFF0078FFFF0000F000FF3C00FF
0078FF00D2FF00D2FF001EFF00D2FF00FFD200FF7800FF7800FFD200FF7800FF7800FFD2
FF000000FFD200FF7800FF1E00FF1E00FF1E00FF1E00FFD200FF1E00FF1E00FF1E00FF78
0078FF00FF7800FF1E00FF1E00D2FF00FFD200D2FF00FF1E00FF1E3CFF003CFF003CFF00
00FF783CFF003CFF003CFF003CFF003CFF0000FF7800FF1E001EFF00FFD200FF1E00FF78
3CFF003CFF003CFF003CFF00001EFF3CFF003CFF003CFF0000FF1E00FF1E00FFD20078FF
00FFD23C00FF3C00FF9600FFFF00B4FF00003C00FF9600FF00FF7800FF1E00FF1E3CFF00
3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF003CFF0000FF7896FF0000FF78
96FF0096FF0096FF0096FF003CFF0000FF7800FF78F000FFFF000000FF7800FFD200FF1E
3CFF0096FF0096FF0096FF0096FF003CFF0000FFD2FF00003CFF003CFF0096FF0096FF00
96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF00
00D2FF3CFF003CFF003CFF003CFF0000FF1E00FFD2001EFF00FF7800FFD200D2FF00FF78
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF003CFF000078FF3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E
FF000000FF1E00FF1E00FF7800FFD200FF7800FF7800FF7800FF7800FFD200FF7800FF78
00FF7800FF7800FFD200FFD200D2FF9600FF0078FF0078FF9600FFFF0000001EFF0078FF
FF000000D2FF00FFD200D2FF001EFF00FFD200FF7800FF7800FF7800FF7800FF7800FFD2
00FFD200FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E3CFF0000FF1E00FF1E00FF1E
00D2FF00FF7800FF1E00FF1E00FF1E00FF1E00FFD200FF1E00FF1E3CFF003CFF003CFF00
3CFF0000FF783CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E3CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF78
001EFFF000FFFF0000FF00B4FF00B4001EFF0078FF0078FF00D2FF00FF7800FFD200FF1E
3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00FF00B43CFF0096FF0096FF00
96FF0096FF0096FF0096FF0000FF1E3CFF003CFF0000FF1E00D2FF00FF1E3CFF0000D2FF
3CFF0096FF0096FF0096FF0096FF0000FF1E3CFF0000FF1E3CFF0096FF0096FF0096FF00
96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF003CFF0096FF00
96FF0096FF0096FF0096FF003CFF0000FF1E00FF7800D2FF00FF1E3CFF0000FF7800FF78
00FF783CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF003CFF000078FF3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF7800FF7800FF78
00D2FF00FFD200FFD2001EFF001EFF3C00FF0078FF00FF7800FF7800FFD200FFD200FF78
00FF7800FF7800FFD200FFD200D2FF00D2FF001EFF9600FFFF005A3C00FF3C00FF00D2FF
00D2FF00D2FF00FFD200FFD200D2FF00D2FF00FFD200FF7800FF1E00FF1E00FF1E00FF78
00FFD2FF000000FF7800FF7800FF1E00FF1E3CFF003CFF003CFF003CFF003CFF0000FF1E
0078FF00FF1E3CFF003CFF0000FF1E00FF1E00D2FF00FF1E00FF1E3CFF003CFF003CFF00
3CFF003CFF0096FF0096FF0096FF0096FF003CFF003CFF0000FF7800FFD23CFF003CFF00
96FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FFD2
0078FF9600FF0078FF9600FF3C00FF0078FF00FFD200D2FF00FF1E00FF7800FFD200D2FF
00FFD23CFF003CFF0096FF0096FF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF0096FF0096FF003CFF003CFF0000FF1E00FF1E3CFF003CFF00
00FF1E96FF0096FF0096FF0096FF0096FF0096FF003CFF0000FF1E96FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF0000FFD200FF1E00FF1E3CFF0000FFD23CFF00
3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF000078FF3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF003CFF0000FF1E00D2FF00FF1E00FF7800FF1E00FF1E
001EFF00FFD200FF7800FFD23C00FF0078FFFF00B40078FF00D2FF0078FF00FFD200FFD2
00FFD200FFD20078FF00D2FF0078FF0078FF001EFFFF00B4FF00009600FF0078FF00D2FF
00FFD200FFD200FF7800FF7800FFD20078FF00FF7800FF7800FF1E00FF1E00FF1E00FF1E
00FF780078FF00FFD200FFD200FF1E00FF1E3CFF003CFF003CFF003CFF003CFF0000FFD2
00FF783CFF003CFF003CFF003CFF0000FF1E00FF7800FF7800FF1E3CFF003CFF003CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E00FF1EFF000000FFD2
00FF7800FFD200FFD29600FF9600FF0078FF00FFD200FF1E00FF1E00FF1E00FF7800D2FF
00FFD23CFF003CFF003CFF0096FF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FF1E96FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0000FF1EFF00003CFF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0000FFD23CFF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF0000FF783CFF003CFF0096FF0096FF0096FF00
96FF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E
00FF7800FF1E00FF1E00FF7800FFD200FF7800FFD200FF7800FFD2FF0000FF000000D2FF
0078FF00FFD200D2FF0078FF0078FF001EFF3C00FFFF0000F000FFFF005A0078FF0078FF
00D2FF00FFD200FF7800FF7800FF7800FF78FF000000FF7800FF1E00FF1E00FF1E00FF1E
00FFD200FF78F000FF00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
00FF1E3CFF003CFF003CFF003CFF0000FF1E00FF78001EFF00FF7800FF1E3CFF003CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0000FF1E00FFD200FF1E00FF1EF000FF00FF1E00FF1E
00D2FF00FF1E00FF7800D2FFFF000000D2FF00FF7800FF1E3CFF003CFF003CFF0000FF1E
00FF1E00FFD200FF783CFF003CFF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0000FF1E00FF1E96FF0096FF0096FF00
96FF0096FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF003CFF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF0000FFD200FF783CFF0096FF0096FF0096FF00
96FF0096FF0000FF1E96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
00FF1E96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF1E3C00FF00FF7800FF7800FF7800FF7800FFD200FFD200FFD200D2FF
0078FF0078FF0078FF3C00FFFF00B43C00FF9600FFFF005A9600FF001EFF00D2FF00D2FF
00D2FF3C00FF00FF7800FF7800FF1E00FF1E00FFD200FF7800FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF7800FF7800FF7800FF1E3CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF0000FF1E00D2FF3C00FF00FF7800FF1E3CFF003CFF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0000FF1E96FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF0000FF1E0078FF00FF783CFF003CFF00
3CFF0000FF1EFF00000078FFFF000000FFD200FF780078FF00FF1E3CFF003CFF003CFF00
3CFF0000FF7800FFD200FFD23CFF003CFF003CFF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF003CFF0000FF1E00FF7800FF1E3CFF0096FF0096FF00
96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF003CFF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF0096FF0096FF003CFF0000FF1E00FF1E00FF1E3CFF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FFD200FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FF7800FFD2
00FFD23C00FFF000FFFF005AFF00B49600FFFF00B4FF005A3C00FF0078FF00D2FF00FFD2
00FFD200FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF78FF000000FF7800FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF0000FF1E00FF1E00FF7800FF1E3CFF003CFF003CFF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF0000FF1E00FF1E00FF1E3CFF003CFF00
3CFF0000FF7800FF1E00FF789600FF00FFD200FF1E3CFF003CFF003CFF0096FF0096FF00
3CFF0000FF1E00FF7800FF7896FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF003CFF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0000FFD200FF1E3CFF0096FF0000FF1E
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FF7896FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF003CFF0000FF1E00FF1E00FF1E00D2FF00FFD23CFF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FF7800FFD2
00FFD20078FF001EFF3C00FFFF005AFF005AFF00B4FF0000F000FF001EFF3C00FF00FFD2
00FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF0000D2FF00FF7800D2FF001EFF00FFD200FF7800D2FF3CFF003CFF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF003CFF003CFF0000FFD200FF7800FF1E3CFF003CFF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF0000FF78001EFF3CFF003CFF003CFF003CFF00
00FF783CFF0000FF1E00FF783C00FF00FFD200FF1E3CFF003CFF0096FF0096FF0096FF00
96FF0000FF783CFF0000FF1E3CFF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0000FFD200FF1E96FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF0096FF003CFF0000FF1E00D2FFF000FF00FF1E3CFF003CFF0096FF0096FF0096FF00
96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD2
00FFD200D2FF0078FF001EFF3C00FFFF0000F000FF9600FFFF005AFF00B40078FF00FFD2
00FFD200FF7800FF7800FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E0078FFF000FF00FF1E3CFF003CFF003CFF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E9600FF00FF7800FF783CFF00
3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF0000FF1E00FF7800FF783CFF003CFF0096FF0096FF00
96FF003CFF0000FF1E00D2FF00D2FF00FFD200FF1E001EFF3CFF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF00001EFF96FF0096FF00F0FF00
F0FF00FFB400FFB400FFB400FFB4003CFF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF003CFF003CFF0000D2FF3CFF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF003CFF0096FF00
96FF0096FF003CFF003CFF000078FF0078FF00FF1E00D2FF00FF1E00FF1E96FF0096FF00
96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E00FF1E00FF1E00FF1E00FF1E00FF7800D2FF00FFD200FFD200FFD2
00FFD200D2FF001EFF3C00FF9600FFFF00003C00FF001EFF0078FF0078FF00D2FF3C00FF
00D2FF00D2FF00FF7800FF7800FF7800FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF0000FF7800FF1E00FF1E00FF783CFF003CFF003CFF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF0000FF789600FF0078FF00FFD200FF1E3CFF00
3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF003CFF0096FF003CFF003CFF00001EFF00FF783CFF0096FF0096FF0096FF00
96FF003CFF0000D2FF3CFF0000FF7800FF783CFF0000FF1E3CFF003CFF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF0096FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0000FF1EFF00B400FFD23CFF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF00
96FF003CFF003CFF0000FF780078FF00FFD200FF1E3CFF0096FF0096FF0096FF003CFF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0000FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD200D2FF001EFF
00D2FF00D2FF0078FF001EFFF000FFFF00B4FF00B4001EFF00D2FF0078FF00FFD20078FF
001EFF00D2FFFF00B400D2FF00FFD200FF7800FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF003CFF0000FF1E3CFF003CFF0000FF7800FF7800FF7896FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF0000FF1E00FFD20078FF00FF7800FF1E
00FF7800FF783CFF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF003CFF0000FF1E3CFF0000FF1E96FF0096FF0096FF00
96FF0000FFD23CFF003CFF003CFF0000FF1E3CFF0096FF0096FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0000D2FF96FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF003CFF0000FFD2FF000000FF1E96FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF0000FF1E
00FF7800FF7800FF1E001EFF9600FF00D2FF00FF1E3CFF0096FF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF003CFF003CFF0000FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF7800FFD200FF7800D2FF00FF7800FF7800FF7800D2FF00D2FF
001EFF3C00FF001EFF9600FFFF00B4FF005A001EFF0078FF00D2FF00FFD200FFD200FF78
00FF7800FFD200FF7800FFD23C00FF00FF7800FF1E00FF1E3CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF009600FF00FF1E3CFF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF00001EFF00FF78FF000000FF7800FF1E
9600FF3CFF003CFF0096FF0000D2FF96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0000FF783CFF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0000FF1E00D2FF3CFF0096FF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00
F0FF0096FF003CFF0000FF1EF000FF001EFFF000FFFF000000FF1E3CFF003CFF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF009600FF00FF7896FF00
3CFF003CFF003CFF0000FFD2001EFFFF000000FF1E00FF7896FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF003CFF003CFF003CFF003CFF0000FFD200FF1E3CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF1E00FF1E00FF7800FFD200D2FF00FF7800FF7800FFD200FFD200FFD2
00D2FF0078FF3C00FFFF0000FF0000FF00009600FF0078FF001EFF00FFD200FFD200FF78
00FF7800FF7800FF1E00FF7800D2FF00FF1E00FFD200FF783CFF003CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF003CFF0000FF783CFF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF0000FF1E00FF7800FF1E00FFD200FF783CFF00
3CFF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0000FF7800FF1E96FF0096FF00F0FF00F0FF00F0FF00
96FF0096FF0096FF0096FF003CFF000078FF3CFF0096FF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0000FFD2F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF00
F0FF00F0FF0096FF0096FF0096FF003CFF00F000FF0078FF3CFF003CFF0000FF7800FF1E
96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00F0FF00F0FF0096FF00
96FF0096FF003CFF0000D2FF00FFD23CFF0000FF7800FF1E3CFF003CFF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF003CFF003CFF003CFF003CFF0096FF0096FF0096FF003CFF003CFF00
00FF1E3CFF003CFF003CFF003CFF0000FF1E00FF7800FF1E00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FFD200FFD20078FF00FFD200FFD200D2FF00FFD200D2FF
00D2FF0078FF001EFF9600FFFF00003C00FF3C00FF0078FF0078FF0078FF001EFF0078FF
00FF7800FF1E00FF1E00FF1E00FF7800FF1E00FF1E00FF1E00D2FF3CFF003CFF003CFF00
96FF0096FF0096FF0096FF0096FF0096FF003CFF00F000FF96FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF0000FF7800FF783CFF00
96FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF00FF00B496FF0096FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF0000FF783C00FF00FF1E3CFF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF003CFF0000D2FF00FF783CFF0096FF0096FF003CFF00
96FF003CFF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF003CFF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0000FFD200FF1EFF000000FF1E3CFF0096FF0000FF1E00FF7896FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF003CFF003C00FF00FF1E3CFF003CFF003CFF00
3CFF003CFF003CFF003CFF003CFF0000FFD200D2FF00FF1E00FF1E00FF7800FF1E00FF1E
00FF7800FF1E00FF1E00FF1E00FF7800FF7800FFD2001EFF00FFD2001EFF001EFF00D2FF
0078FF9600FF3C00FFF000FFFF00003C00FF0078FF00D2FF00FFD200FFD200FF7800FF78
00FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF0000FF1E96FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF0096FF0096FF003CFF003CFF0000D2FF00FFD2
96FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF003CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF003CFF003CFF0096FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FF0000
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0096FF003CFF0000FF1E96FF0096FF00F0FF00F0FF00
F0FF00F0FF00001EFFF0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB40096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF003CFF003CFF003CFF0096FF0096FF003CFF003C00FF3CFF003CFF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF003CFF0000FF1E001EFF3CFF003CFF00
00FF1E00FF1E3CFF003CFF0000FF1E00FF1E00FF7800FF7800FF7800D2FF00FF1E00FF78
0078FF00FF7800FF7800FF7800FFD200FFD200FFD200D2FF3C00FF00D2FFFF00000078FF
0078FF001EFF3C00FFFF0000FF00003C00FF0078FF00D2FF00D2FF00FFD200FF7800FF78
FF000000FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF0096FF0096FF0096FF0096FF003CFF003CFF0000FF1E
3CFF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF003CFF003CFF0096FF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FF1E96FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF003CFF0000FF1E3CFF0096FF0096FF0096FF0096FF003CFF0000FF7896FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0000FF1E00FF7800FFD200FF1E
00FF1E00FF7800FF1E00FF1E00FF1E00FFD2F000FF001EFF0078FFF000FF00FFD200D2FF
3C00FF3C00FF00FFD200D2FF001EFF0078FFFF00009600FF9600FF3C00FF3C00FF001EFF
3C00FF001EFFF000FFF000FFFF00003C00FFF000FF0078FFFF005A00FFD200FFD200FFD2
0078FF001EFF00FFD200FF783CFF003CFF003CFF003CFF003CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0000FF1E3C00FF
00FF1E00FFD200FF1E96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF003CFF003CFF0000D2FFF000FF96FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0096FF0000FF1E96FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0000FF1E96FF0096FF00F0FF00F0FF00F0FF00F0FF0096FF00FF0000F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0000FF1E3C00FF00FF78
00FFD20078FFFF005A00D2FFF000FF00FF7800D2FF0078FF00FFD200FFD200FF7800FF78
00FFD200FF7800FF7800FF7800FFD20078FFFF00B4FF00B4FF0000FF005AFF00009600FF
9600FF3C00FF9600FF9600FFFF00B4FF00B43C00FF3C00FF0078FF0078FFF000FF00FFD2
0078FF00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF003CFF0000FF1E9600FF
00FFD200FF1E3CFF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF003CFF00FF000000FF1E96FF0096FF0096FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF00F0FF00F0FF0096FF003CFF009600FF96FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0096FF00
96FF0000FF1E00FF1E96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF003CFF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF000078FF96FF0096FF0096FF003CFF0000FF1E00FF780078FFFF0000
0078FF0078FF00FF7800FF1E00FF1E9600FF00FF1E00FFD200FF1E00FFD200FF1E00FF1E
00FFD200FF1E00FF1E00FF7800FFD200FFD200D2FFF000FF001EFF3C00FFFF005AFF005A
FF0000F000FF9600FF9600FFFF00B4FF0000FF0000FF005A9600FFFF000000D2FF001EFF
00FF7800FF1E00FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF003CFF0000FF1E00FF1E00FF78
001EFF00FF783CFF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF003CFF000078FF00FF78FF000000FFD200FF1E96FF00
96FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00
96FF003CFF0096FF003CFF0096FF003CFF0000D2FF00FF1E96FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB4003CFF00F0FF00F0FF0096FF00
3CFF00001EFF3CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0000FF1EF0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF0000FF1E3CFF003CFF0000FF1E00D2FF00FFD200FF7800FFD2
00FFD200FF1E00FF783CFF003CFF003CFF0000FF1E00FF7800FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF1E00FF7800FFD200D2FF00D2FF00D2FF001EFF001EFF9600FF
9600FFFF0000FF00B49600FF001EFF9600FF9600FF3C00FFF000FFFF0000FF000000D2FF
00FF7800FF7800FF1E00FF7800FF1E00FF1E3CFF003CFF0000FF1E00FF1E3CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF003CFF0000FF78
F000FF00FF7800FF1E3CFF0000FF7896FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF003CFF0000D2FF00FF1E001EFF00FF783CFF0096FF0096FF0096FF00
F0FF00F0FF0096FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00
F0FF00F0FF0096FF0000FFD200FF1E00FF7800FFD23CFF0096FF0096FF0096FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
0078FF00FF1E3CFF0000FF78F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF003CFF000078FF00FF7800FF1E3CFF0000FF1E00FF1EFF00B4
3CFF003CFF0000FF783CFF003CFF003CFF0000FF1E00FF783CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF1E00FF1E00FFD23C00FF00D2FF00FFD200D2FF0078FF0078FF001EFF
3C00FFFF0000F000FF3C00FF001EFFF000FF0078FF0078FF001EFFF000FF0078FF0078FF
00D2FF00D2FF00FFD200FF7800FF1E00FF1E00FF1E0078FF00FF1E3CFF003CFF003CFF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF003CFF0000FF1E
3C00FF00D2FF3CFF003CFF0000FFD296FF0096FF0000FF1EF0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0000FF1E96FF0096FF0096FF0000FF1E00FF783CFF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00
F0FF00F0FF0096FF0096FF003CFF0000FFD23C00FF00FF1E00FF1E3CFF0096FF0096FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00
00FFD296FF00F0FF00F0FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0000FF7800FF1E3CFF0000FF783CFF0096FF0096FF003CFF0000FF1E00FFD2
3CFF003CFF0000FF1E3CFF003CFF003CFF0000FFD23CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E3C00FF00FF7800FFD200FF7800FFD200FFD200D2FF001EFF3C00FF
9600FFFF0000FF00B49600FFF000FF00D2FF00D2FFFF005A00D2FF00D2FF00FFD200FF78
00FF7800FF7800FFD2FF00B400FFD200FFD2F000FF00D2FF00FF1E3CFF003CFF003CFF00
3CFF003CFF003CFF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF003CFF0000FF1E
00FF1E0078FF3CFF0096FF0096FF00F0FF00F0FF00F0FF0096FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
00FF1E96FF00F0FF00F0FF0096FF003CFF003CFF0000FF1E96FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00
F0FF00F0FF0096FF003CFF003CFF0000FFD200FF7800FF1E96FF0096FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF0096FF00
00D2FFF0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF0000FFD200FF1E3CFF0096FF003CFF0096FF0096FF0096FF0096FF003CFF003CFF00
00FF1E3CFF0096FF0096FF003CFF003CFF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD200FFD200D2FF0078FF
FF00B4FF0000FF00B43C00FF0078FF0078FF00FFD200D2FF00FFD200FFD200FFD200FF78
00FF1E00FF1E00FFD200FF1E00FF1E00FFD2001EFF00D2FF00FF1E00FF7800FF1E00FF78
3CFF003CFF003CFF0000FF1E3CFF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FF1E00FF1E96FF00
3CFF0000D2FF3CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF000078FF96FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF0096FF00
F0FF0096FF0096FF003CFF0000FF783C00FF00FF7800D2FF96FF00F0FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0000FF1E
3CFF0096FF00F0FF00F0FF00F0FF0096FF00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF00
3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0000FF1E3CFF00
96FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FF1E00FF7800FF7800D2FFFF00B400D2FF0078FF9600FF
F000FFFF0000FF005A3C00FF0078FF00D2FF00FFD200FFD200FF7800FF78001EFF00D2FF
00FF1E00FF1E00FF1E00FF1E00FF1E00FF1EF000FF00FF7800FF1E00FFD200FF7800FF78
00FF7800FF7800FF1E3CFF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF003CFF003CFF0000FF7896FF00
00FF1E3CFF003CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FF1E96FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF00F0FF0096FF003CFF00
00FF1E3CFF003CFF003CFF0000FF78FF005A00FF783CFF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0000FF78
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF003CFF0096FF0096FF00
96FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FF1E00FF7800FF7800FFD200D2FF00D2FF00D2FF001EFF
F000FFFF00009600FF001EFF0078FF001EFF0078FF00FFD200FF7800FF7800FF7800FF78
00FF1E00FF1E3CFF003CFF003CFF0000FF1EFF005A00FF1E3CFF0000FF1E00FFD2F000FF
0078FF00FFD23CFF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0000FF1E96FF00F0FF00F0FF00
96FF0096FF0000FFD296FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FF1E3CFF0096FF0096FF00F0FF00
F0FF00F0FF0096FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF003CFF0096FF0000D2FF3CFF0000FF78
3CFF003CFF003CFF0000FF1EF000FF001EFF9600FF3CFF003CFF0096FF0096FF00F0FF00
96FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF003CFF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF003CFF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF003CFF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FF7800FFD200FFD200D2FF0078FF
3C00FFFF00003C00FF0078FF00D2FF00FFD20078FF00FFD200FFD200FF1E00FF1E00FF1E
00FF1E3CFF003CFF003CFF003CFF003CFF0000FFD23CFF003CFF003CFF000078FF00FFD2
FF0000001EFF00FF1E3CFF0096FF0096FF0000FF7896FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0000FF7896FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0000FF1E00FFD23CFF003CFF003CFF00
3CFF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF0000FFD2F0FF00F0FF00F0FF00F0FF0096FF00
F0FF0096FF0096FF003CFF0000FFD200FFD200FF1E3CFF0000FF1E00D2FF3CFF00FF00B4
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0000D2FFF0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB40096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF0000FF1E00FF1E00FF1E
00FF1E00FF7800FFD200D2FF00FF7800FFD200FF7800FFD200D2FF9600FF00D2FF001EFF
F000FFFF00009600FF0078FF00D2FF00FFD200FFD200FF7800FF7800FF1E00FF1E00FF1E
00FF1E3CFF003CFF003CFF003CFF003CFF0000FF1E3CFF003CFF003CFF003CFF003CFF00
00FFD200FF1E3CFF003C00FF00FF7800FF7896FF0096FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF00FF00B400FF1E96FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF00F0FF0096FF0000D2FF00FF1E00FF1E001EFF00D2FF3CFF0000FF1E
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400F0FF00F0FF00FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00
F0FF00F0FF0096FF003CFF0000D2FF00FF1E00FF1E96FF003CFF0096FF0000FF1E00FF1E
96FF00F0FF0096FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E00FF1E
00FF7800D2FFFF005A001EFF00FFD200D2FF00FFD200D2FF00FFD20078FF001EFF001EFF
9600FFFF00009600FFFF00009600FF00D2FF00FFD200FF7800FF7800FF7800FF1E00FF1E
00FF1E3CFF003CFF003CFF003CFF003CFF003CFF003CFF0096FF0096FF003CFF00FF00B4
00FF783CFF0096FF003CFF0000FF1E00FF7896FF003CFF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0000FF1E3CFF003CFF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF0096FF003CFF0000FF783CFF0000D2FFFF00000078FF96FF0096FF00
F0FF00F0FF00F0FF00F0FF0096FF00FFB400FFB400FFB400
FF5A00FFB400F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF0000FF1E3CFF009600FF00FF1E96FF0096FF00F0FF00F0FF0000FFD296FF00
3CFF0096FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB40096FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF0000FF1E
00FF1E00FF7800FF7800FF7800FFD200D2FF00FFD20078FF001EFFFF0000FF0000FF00B4
F000FFFF005AFF0000FF00009600FF00D2FF00D2FF00FFD2001EFF00FF7800FFD200FFD2
00FF1E00FF1E3CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF003CFF00
3CFF0096FF0096FF0096FF003CFF0096FF0000FF1E3CFF0096FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF00F0FF0096FF0000FF1EF0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF00F0FF00F0FF0096FF0096FF003CFF0000D2FF00FF1E00FFD296FF00
96FF00F0FF00F0FF00F000FFF0FF00F0FF00FFB400FFB400
FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF0096FF0096FF0096FF0000D2FF3CFF0000FF1EF0FF00F0FF00F0FF0096FF00F0FF00
96FF0096FF0000FF78F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF003CFF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF003CFF00
001EFF00FF1E00FF1E00FF783C00FF00FF7800FF7800FFD200D2FF001EFF001EFF9600FF
FF0000FF00B4F000FF001EFF0078FF00D2FF00D2FF00FFD2001EFF00FFD200D2FF00D2FF
00FF7800D2FF00FF7800FF1E3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
00FFD296FF0096FF0096FF0096FF0096FF0096FF0096FF0000FF1E96FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400F0FF00F0FF00
96FF00F0FF00F0FF00F0FF003CFF0000FF78F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF00F0FF00F0FF0096FF003CFF0000FF1E00D2FF00FFD23CFF0096FF00
3CFF0096FF0096FF0096FF00F0FF003CFF00F0FF00FFB400
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF00F0FF0096FF003CFF0096FF0096FF0096FF00F0FF00F0FF000078FFF0FF00
F0FF00F0FF00F0FF0096FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF0000FF1E3CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800D2FF0078FF00D2FF0078FF9600FF
FF00B4FF00B4001EFF0078FF00D2FF00D2FF00FFD200FF7800FF7800FF7800FF7800FFD2
00FF1E00FF1E3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF003CFF00F0FF00
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF003CFF0096FF0096FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF00F0FF00F0FF0096FF0096FF0000FF1E00FFD23C00FF001EFF0078FF
3C00FF00FF1E0078FF001EFF3CFF0096FF0000FF1EF0FF00
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF00F0FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400F0FF0096FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB40000FF1EFFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF00
00FF1E00FF1E00FF1E3CFF0000FFD23CFF0000FF1E3CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD200FFD2001EFFFF00009600FF
FF0000FF00B43C00FF001EFF00D2FF00FFD200FF7800FF7800FF7800FF1E00FF1E00FF1E
00FF1E3CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0000FFD2
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400F0FF00F0FF003CFF0096FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF003CFF0096FF0096FF003CFF0000FF1E00FF1E00FFD2001EFF00FF1E96FF00
96FF0096FF003CFF00F0FF00F0FF00F0FF0096FF0000FF78
FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF003CFF003CFF0000FFD296FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
96FF0096FF003CFF003CFF00001EFF00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E00FF1E
00D2FF00FF1E00FF1E00FF7800FF7800FFD20078FF0078FF00D2FF00D2FF0078FF001EFF
FF00B4FF00B4001EFF0078FF00D2FF00D2FF00FFD200FFD200FF7800FF1E00FF1E00FF1E
3CFF003CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF0096FF0096FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF00F0FF0000FF1E00FFD200FF1E3CFF0096FF0000FF1EF000FF00FF1E3CFF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400
FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00F0FF0096FF0000D2FF96FF003CFF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF00
96FF0096FF0096FF003CFF003CFF0000FF1EFF000000D2FF00FF1E00FF1E00FF1E00FF1E
00FF1E001EFF00FF7800FF7800FF7800FF7800FFD20078FF3C00FF001EFF001EFFF000FF
FF00B4FF0000FF0000001EFF0078FF0078FF00FFD200FF7800FF7800FF1E00FF1E00FF1E
00FF1E3CFF003CFF003CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF003CFF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF0000FF1E96FF0000FF1E3CFF0096FF0096FF003CFF003CFF0000FFD200FF1E96FF00
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF0096FF0000FF1EF0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB40096FF00FFB400FFB400FFB400FFB400FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF009600FF00FF1E00FF78F000FF001EFF00FF1E00FF1E
00FF1E00FF78001EFF00FF7800FF7800FF7800FFD200FFD200D2FF00D2FF0078FF9600FF
FF00B4FF00B43C00FF0078FF00D2FF00FFD200FFD200FF7800FF7800FFD20078FF00FF1E
00FF1E00FF1E3CFF0000FF1E00FF783CFF0000FF1E00FF1E96FF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF003CFF0096FF00F0FF0000FF1EF0FF00F0FF0096FF003CFF0000FF7800FF7896FF00
96FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00
96FF0096FF003CFF0000FF78F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB40096FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E00FFD2FF000000FF7800FF78
00FF7800FF7800D2FF00FFD200FFD200D2FF00FFD200FFD200D2FF00D2FF0078FF3C00FF
9600FFFF00003C00FFFF000000D2FF00D2FF9600FF00FFD200FFD23C00FF00FF7800FF1E
00FF1E00FF7800FF1E001EFF00D2FF00D2FF00FF7800D2FF3CFF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB40000FF1EFFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
00FF78F0FF00F0FF00F0FF0096FF00F0FF00F0FF0096FF0096FF003CFF0000FF1E96FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400
FF5A00FF5A00FF5A00FFB400FFB40000FF1E3CFF00F0FF00F0FF00F0FF0096FF00F0FF00
F0FF0096FF000078FF00FF1E00FFD296FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0000FF1E96FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E00FF1E0078FF00FFD200FFD2
00FF7800FFD20078FF001EFF00FFD200D2FF00D2FF00D2FF00D2FF001EFF001EFF001EFF
F000FFFF00009600FF001EFF0078FF0078FF00D2FF00FFD2FF000000FFD200FF780078FF
00FF7800FF78001EFF00FF7800FF783CFF003CFF0096FF0096FF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB40000FFD2
F0FF00FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF0000FF7896FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400
FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400F0FF0096FF0000FF1E3CFF0096FF00
96FF0000FFD20078FF3CFF0096FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF0096FF0096FF00
96FF0096FF00F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF003CFF0096FF0096FF00
96FF0096FF0096FF003CFF0000FF1E3CFF0000FF1EFF005A00FF1E00FFD200D2FF0078FF
00FFD200D2FF00D2FF001EFF00D2FF00D2FF3C00FF00D2FF00D2FF0078FF001EFF3C00FF
3C00FF9600FFFF00009600FF3C00FF001EFF0078FFF000FF00D2FF00FFD200FFD200FFD2
00D2FF00FF7800FF7800FF1E3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB40000FF1EFFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB40096FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF003CFF0000FF1E
3CFF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400
FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400F0FF0096FF0096FF0000FF1E
00FF1E00FF1EFF00B43CFF0096FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
3CFF0096FF0096FF0096FF0096FF003CFF0096FF0096FF0096FF0096FF0000FFD23CFF00
96FF0096FF0000FF1E3CFF003CFF0000FF1E00FF7800FF7800FFD200FFD20078FF3C00FF
0078FF001EFF0078FFFF005A001EFF0078FFFF005A0078FF0078FF0078FF001EFF001EFF
001EFFFF00009600FFFF005AFF0000FF00B43C00FFFF005A0078FFF000FF0078FF0078FF
00D2FF00FF7800FF1E3CFF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF0000FF1E3CFF0000FF1E
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF00
00FF1E00D2FF0078FF00D2FF00FFD23CFF0000FFD2F0FF00F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF0000FF783CFF0096FF0096FF003CFF0096FF0096FF0096FF0096FF0000D2FF3CFF00
3CFF003CFF003CFF003CFF003CFF0000FF1E00D2FF00D2FF0078FF001EFF9600FFF000FF
FF005AFF005A3C00FFFF00009600FF3C00FFFF0000001EFFF000FF001EFF001EFF001EFF
001EFF001EFF9600FF3C00FFFF0000F000FFFF0000FF005A9600FFFF00B43C00FFF000FF
00FFD200FF780078FF00FF1E3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF00
00FF1EF0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00FFB400FFB400
FFB400FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400F0FF00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF0000FF1E
F0FF00F0FF0096FF00FFB400FFB400FFB400FFB400FFB400
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF00
00FF1EF000FF00FF783CFF0096FF0096FF0000FFD2F0FF00F0FF00F0FF0000FF78F0FF00
FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
3CFF0000FF783CFF0096FF0096FF003CFF003CFF0096FF0096FF0000FF7800FF1E00FF78
00FF1E00FFD200FF7800D2FF0078FF0078FF001EFF9600FF0078FFFF00B43C00FFFF00B4
FF00B4FF0000F000FFFF00B4FF0000FF0000FF005A9600FF3C00FF3C00FF001EFF001EFF
001EFF0078FF3C00FF0078FF001EFFFF0000FF00B4F000FF9600FFF000FFFF00009600FF
001EFF3C00FF00FF7800FF7800FF1E3CFF003CFF0096FF0096FF0096FF0096FF0000FF78
96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF00FF00B4
96FF003CFF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FF5A00FF5A00FFB400F0FF00FFB400FFB400FFB400FFB400F0FF00F0FF0000FF1E3CFF00
00FF1E0078FF00FF1E96FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400F0FF00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF00F0FF0000FF1EF0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF003CFF009600FF3CFF003CFF0000FF1E3CFF003CFF0000FF1E00FF1E0078FFFF0000
00FFD200FF1E00FF1E00FFD23CFF0000FF1E00FFD200FF7800FFD200FFD200D2FFFF0000
0078FF9600FF0078FFFF0000001EFF3C00FFF000FFFF0000FF005A9600FF3C00FF001EFF
001EFF0078FF00D2FF0078FF0078FF00D2FF001EFF3C00FF0078FF0078FFF000FF3C00FF
001EFFFF005AFF005A00D2FF00FF783CFF0000FF1E3CFF0000FF1E3CFF0000FF1E96FF00
96FF0096FF0096FF0096FF0096FF00F0FF0096FF0096FF003CFF0096FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF0000FFD2FF0000
00FF1E96FF00F0FF00F0FF00F0FF003CFF003CFF0096FF00
FF5A00FFB400FFB400FFB40096FF00F0FF00FFB400F0FF00F0FF00F0FF0096FF003CFF00
0078FFFF000000FF1E3CFF0096FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF003CFF00
96FF003CFF0000FF1E00D2FF00FF7800FFD2001EFF00D2FF00FF1E3CFF0000FFD200FF78
3CFF0000FF1E3CFF003CFF003CFF003CFF0000FF1E00FF1E00FF7800FF7800FFD20078FF
00FFD2001EFF00D2FF0078FF00D2FF001EFF0078FF001EFF9600FFFF0000FF00003C00FF
9600FF001EFF00D2FF00D2FF00D2FF00FFD2001EFF00D2FF0078FF00D2FF9600FF0078FF
00FFD200FFD200FFD200FFD200FF1E0078FF00FF783CFF0000FF7800FFD200FF1E96FF00
96FF0096FF0096FF0096FF0096FF003CFF0096FF0000FFD296FF00F0FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0096FF0000FF1E
00FFD23CFF0096FF003CFF0000FF1EF0FF00F0FF00FFB400
FFB400FFB400FFB400FFB40096FF00F0FF0096FF00F0FF0096FF0096FF0096FF003CFF00
001EFF00D2FF3CFF0096FF0096FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00F0FF00FFB400FFB400F0FF0096FF0096FF003CFF0096FF0096FF00F0FF00
96FF00F0FF00F0FF00F0FF00F0FF00001EFF96FF00F0FF00F0FF0096FF0096FF0096FF00
00FF7800FF1E00FFD29600FF9600FF00FFD200FFD23CFF003CFF0096FF003CFF0000FF78
3CFF0096FF0096FF0096FF003CFF003CFF003CFF003CFF0000FF1E00FF78001EFF00FF78
00FF7800FF7800D2FF00D2FF00FFD23C00FF00D2FF001EFF9600FFFF00009600FF001EFF
0078FF00D2FF00D2FF00FFD200D2FF00FFD2001EFF00D2FF00FF7800FFD200FFD200FFD2
00FF7800D2FF00FF1E0078FF3CFF003CFF0000FF1E00FF1EFF00003C00FF00FF1E3CFF00
96FF0096FF0000FF1E96FF0096FF003CFF00FF00B496FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF0096FF0096FF0000FF1E
FF005A0078FF3CFF0096FF00F0FF00F0FF00FFB400FFB400
FFB400F0FF00F0FF00F0FF003CFF0000FFD23C00FF3CFF0000FFD200FF1E0078FF00D2FF
3C00FF00D2FF00FF1E00FF1EF0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF003CFF003CFF00
3CFF00F0FF00F0FF00F0FF0096FF0000FF1E3CFF0096FF0096FF0096FF003CFF003CFF00
001EFF00D2FF00FFD200FFD200FF1E3CFF0000FF1E3CFF0096FF0096FF0096FF003CFF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF1E00D2FF00FF7800FF1E
00FF7800D2FF001EFF00FFD200FFD200FFD200D2FF0078FF001EFFF000FFFF00009600FF
0078FF00D2FF00D2FF00FFD200FFD200FF7800FFD20078FF00FF7800FF7800FF78001EFF
00FF1E00FF1E3CFF0000FF1E3CFF003CFF003CFF0000FF1E00FF7800FF7800FFD200FF78
3CFF0000FF1E00FFD23CFF003CFF0000FF1E3CFF0096FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF003CFF000078FF00FFD23CFF0000FF78
9600FF00FF1E96FF00F0FF00F0FF00F0FF00FFB400FFB400
FFB400F0FF0000D2FFF0FF00F0FF0000D2FF96FF00F0FF00F0FF00F0FF0000FF7800FF78
FF000000D2FF3C00FF3CFF0096FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0000FF1E
FF000096FF0096FF0096FF0096FF003CFF0000FF783CFF0000FF1E3CFF009600FF00FF1E
00FF1E00FFD200FF1E3CFF003CFF0096FF0096FF0000FF1E96FF0096FF0096FF003CFF00
96FF0096FF0096FF0096FF0096FF003CFF0000FF1E00FF1E3C00FF00D2FF00FF1E00FF1E
00FF1E00FFD29600FF00FF7800FF7800FFD200D2FF0078FFFF005AFF0000FF005A3C00FF
0078FF0078FFFF00B400D2FF00FF7800FF7800FF7800FFD200FF7800FF1E00FF1E00D2FF
FF005A00FF1E3CFF003CFF0096FF0096FF0096FF0096FF0000FF1E00FF1E00FF1E00FF1E
00FF1E00D2FF9600FF00FF7800FF783CFF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF0096FF00F0FF0096FF0000FF1E
00FFD200FFD296FF0096FF00F0FF0096FF00FFB400FFB400
96FF00FFB40000FF78FFB400FFB400F0FF00FFB400FFB400F0FF00F0FF003CFF0000D2FF
001EFF00FF783CFF003CFF0000FF7896FF00F0FF00F0FF0096FF00FFB400FFB400FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB40096FF00F0FF00
96FF0000FF7896FF0096FF0000FF1EFF000000D2FF001EFF001EFF00FF7896FF0096FF00
96FF0096FF0096FF003CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF003CFF0000D2FF00FF7800FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF7800FFD20078FF00D2FF00D2FF0078FFFF0000FF005A001EFF
0078FF00D2FF00FFD200FFD200D2FF00FF7800FF1E00FF1E00FF7800FF1E00FF1E00FF1E
001EFF00FF1E3CFF003CFF0096FF0096FF0096FF0096FF003CFF003CFF0096FF0096FF00
3CFF0000FFD200FF780078FFFF00B400FFD23CFF003CFF0096FF00F0FF00F0FF00F0FF00
F0FF0000FF78F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF0096FF00
00FF780078FF00FF1E3CFF00F0FF00F0FF00F0FF00FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF0096FF0000FFD2
00FF1E00FF7896FF00F0FF003CFF0096FF0000FF1E96FF0000FF78F0FF00FFB400FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00
96FF0096FF000078FF00FF1E001EFF00FFD2001EFF00FF783CFF00FF000096FF0096FF00
F0FF0096FF0096FF0000FF7800FF1E3CFF0096FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF003C00FF00FF1E00FF783CFF003CFF003CFF00
00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD200D2FF9600FF9600FFFF0000001EFF
0078FF00D2FF00FFD200FF7800FF7800FF7800FF1E00FF1E00FF1E3CFF003CFF0000FF1E
00FF780078FF3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
3CFF003CFF003CFF0000FF7800FFD200FFD200D2FF3CFF0096FF0096FF0096FF0096FF00
96FF0096FF00F0FF00F0FF00F0FF0000FF1EF0FF0096FF00F0FF0096FF0000FF1EFF0000
00FF1EF0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF003CFF0000FF78
00FF789600FF00FF1E96FF00F0FF00F0FF0096FF00F0FF00
FF5A00FF5A00FF5A00FF5A003CFF00FFB400FFB400FFB400F0FF00F0FF0096FF0000FFD2
00FF7896FF0096FF00F0FF00F0FF00F0FF0096FF00001EFFF0FF00FFB400FFB400FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00
96FF00FF000000FF780078FF3C00FF00FF7800FFD2001EFF3CFF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF003CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF0000FF783CFF0000FF1E3CFF003CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF1E00FF7800FF7800FF7800D2FF0078FF001EFF9600FFFF00009600FF
001EFF0078FF00FFD200FF7800FF7800FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF00
00FF783CFF000078FF3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF00
3CFF0096FF0096FF000078FF3CFF003CFF003CFF003CFF00FF000096FF003CFF0096FF00
00FF1E96FF0096FF00F0FF00F0FF0096FF003C00FF3CFF00F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF00
00FFD2001EFF00FFD200FF1E00FF1E3CFF003CFF0096FF00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB40096FF0000FF1E96FF00001EFF
00FFD2F0FF00F0FF00FFB400FFB400FFB40096FF00F0FF00FF0000F0FF00FFB400FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF0096FF00
00D2FF00FF1E9600FF00D2FF00FF7800FF7896FF0096FF0000D2FF96FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF003CFF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF00
00FF1E0078FF00FF7800FF7800FFD200FFD200D2FF9600FFFF005AFF00B4FF00B4F000FF
FF00009600FF001EFF00D2FF001EFF00FF7800FF7800FF7800FF1E3CFF003CFF003CFF00
00FF1E3CFF003CFF0000FF1E96FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00
96FF0096FF0096FF003C00FF96FF0096FF0096FF0096FF0096FF003CFF00F000FF00FF1E
00FF1E96FF00FF000096FF0096FF0000D2FF3CFF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0096FF00
00D2FF3C00FF00D2FF00FFD296FF0096FF0096FF00F0FF00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB40096FF0000FF1E
F0FF003CFF00F0FF00FFB400FFB400FFB400F0FF00FFB400F0FF0000FF7896FF00FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400F0FF00FFB400FFB400FFB400FFB400F0FF003CFF00F0FF0096FF00
3C00FF00FF1E00FF1E00FFD23CFF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF0000FF1E
0078FF00D2FF3C00FF00FFD200D2FF00FFD200FFD20078FF3C00FF9600FFFF0000001EFF
0078FF9600FF00FFD200FFD200D2FF00FFD23C00FF00FF7800FF1E3CFF003CFF003CFF00
96FF0096FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0000FFD296FF0096FF00F0FF00F0FF0096FF0000FF7800FF1E001EFF
00FFD200FF1E3CFF003CFF0000FF1E96FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400F0FF00F0FF000078FF00FFD23CFF00
00FF7800FF7800D2FF3CFF0096FF00F0FF00F0FF00FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB40000FF1EF0FF00
FFB400FFB40000FFD2FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF003CFF0096FF00
96FF0000FF1E96FF0096FF003C00FF3CFF00F0FF00F0FF00F0FF000078FFF0FF00F0FF00
F0FF00F0FF00F0FF0000FF78F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF0000FF1E
00FF7800FF1E00FF7800FF7800FF7800FF7800FFD200D2FF0078FF9600FFFF0000F000FF
001EFF00FFD200FFD200FF7800FF7800FF1E00FF7800FF1E00FF1E00FF1E00FF1E96FF00
96FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0000FFD2F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FF7800FF1E
00FF78F000FF00FFD200FFD296FF0096FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400FFB4003CFF0096FF00F0FF003CFF003CFF0096FF00F0FF00
96FF0000FFD2FF005A3CFF0096FF00F0FF00FFB400FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400F0FF0000FF1EF0FF00
FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00FFB400FFB400FFB40096FF00FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400FFB400FFB400FFB400F0FF0000FF1E96FF003CFF0000FFD296FF00F0FF00
F0FF003CFF00F0FF00F0FF003CFF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FF7800FF78001EFF00D2FF0078FF3C00FFFF00003C00FF
0078FF00D2FF00FFD200FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF003CFF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF0000FFD296FF00
00FF1E00FF1E3C00FF0078FF00FF1E96FF0096FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400FFB400FFB400F0FF0000FF783CFF00F0FF0096FF00F0FF00
3CFF0096FF000078FF3CFF0096FF00F0FF00FFB400FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB40096FF003C00FF96FF00
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB4003CFF00
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400FFB400FFB400FFB400F0FF0096FF0000FFD200FF7896FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0000FF7800FF1EF0FF00F0FF00F0FF00F0FF00FFB400FFB400
FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF003CFF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FF7800FF78FF00000078FF001EFFFF00B4FF00003C00FF
0078FF00D2FF00D2FF00FF7800FF7800FF1E00FF1E3CFF003CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F000FFF0FF00F0FF00F0FF00F0FF00F0FF0000D2FF96FF0096FF00
96FF003CFF0000FF1E00FFD2FF005A3CFF00F0FF00F0FF00F0FF00FFB400FFB400FFB400
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400FFB400FFB40096FF0000FFD2F0FF00FFB400FFB400FFB400
F0FF0096FF00001EFF00FF1E96FF0000FF1EF0FF00FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400F0FF0096FF00FFB400
FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400
96FF00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00F0FF00FFB400FFB400FFB400F0FF000078FF3CFF0096FF00F0FF00F0FF00FFB400
FFB400FFB400F0FF00F0FF0096FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF003CFF0096FF0096FF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FFD200FF7800FF7800FF7800FFD200D2FF0078FF3C00FFFF00003C00FF
FF000000D2FF0078FF00FF7800FFD200FFD200FF1E3CFF003CFF003CFF003CFF000078FF
96FF0096FF0096FF0096FF0096FF003CFF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
96FF0000FF1E96FF0096FF0000FF1E00FF1E96FF0096FF00F0FF00F0FF00FFB400FFB400
FFB4003CFF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB4003CFF0096FF00F0FF00FFB40000FFD2FFB400FFB400FFB400
F0FF0096FF0096FF00001EFFF0FF00FFB400FFB400FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400F0FF00F0FF0096FF00F0FF00FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400
F0FF00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400F0FF00F0FF0096FF003CFF00F0FF00F0FF00FF005A3CFF00FFB400FFB400
FFB400FFB400FFB400F0FF003CFF003CFF00F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF0000FF1E3CFF003CFF003CFF003CFF0000D2FF3CFF003CFF00
00FFD200FF1E00FF1E00D2FFFF000000FFD20078FF00D2FF0078FF3C00FFFF005A9600FF
001EFF9600FF00D2FF9600FF00FF7800FF1E00FF1E00FF1E3CFF003CFF0000FF1E3CFF00
3CFF003CFF003CFF0000FF1E96FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0096FF00F0FF00F0FF00F0FF00
3CFF0000FF7896FF00F0FF0000FF1EF0FF0096FF00FF000096FF0096FF00F0FF0000FF78
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400F0FF0096FF00FFB400FFB400FFB400FFB400FFB400FFB400
F0FF00FFB400F0FF003CFF00F0FF00FFB400FFB400FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB4003CFF00FF0000F0FF00FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400F0FF000078FF3CFF00F0FF00FFB400FFB40096FF00FFB400FFB400FFB400
FFB400FFB400FFB400FFB40000FF1EF0FF00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF0096FF00
96FF003CFF0096FF003CFF003CFF0000FF1E00FF783CFF003CFF0000FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF7800FFD2001EFF0078FF0078FF001EFF9600FFF000FFFF0000
F000FF9600FF3C00FF0078FF00FFD200FF7800FF7800FF7800FF1E00FF1E00FF783CFF00
3CFF003CFF0000FF1E00FF1E96FF0096FF0000FF78F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00
00FF1E00FF78F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0000FF1E00FF1E00FF1EF0FF00
FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB40000FF78FFB400FFB400FFB400FF5A00FF5A00FFB400FFB400
FFB400FFB400FFB400F0FF0000FF1EFFB400FFB400FFB400
FF5A00FF5A00FF5A0096FF00FFB400F0FF00F0FF00F0FF003CFF003CFF00F0FF00FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400
FFB400F0FF003CFF00F0FF003CFF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB4003CFF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0096FF0000FF1E3CFF00
00FF7800D2FFFF00B400FFD23C00FFFF0000FF005AFF00B4F000FFFF00009600FF0078FF
3C00FF001EFF0078FF0078FF9600FFFF0000F000FFF000FFFF00009600FF9600FFFF00B4
3C00FF9600FF9600FF001EFF0078FF00FFD200FFD200D2FF00D2FFFF00B4001EFF00FFD2
001EFF001EFF00D2FF00FF783CFF003CFF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00
F0FF0096FF00F0FF00FFB400FFB400FFB400FFB40000FF1E96FF0000FFD200FF1EF0FF00
FFB400FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB40096FF00FFB400F0FF00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400FFB40096FF0000FFD2F0FF00FFB400FFB400
FF5A0096FF00F0FF00FFB400001EFFF0FF0096FF0000FF1E00FFD23CFF00F0FF00FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400
F0FF0000FF1EF0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF0096FF0096FF00
96FF003CFF0096FF003CFF003CFF0000FF1E00FF783CFF003CFF0000FF1E00FF1E00FF1E
00FF1E00FF7800FF7800FFD20078FFFF00B4001EFF3C00FF9600FFFF0000FF00B4001EFF
001EFFF000FF0078FF00D2FF00FF7800FF1E00FF1E00FF1E00FF1E00FF1E00FF1E3CFF00
00FF1E00FF1E00FF7800FFD23CFF00001EFF00FF783CFF0096FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
F0FF0096FF00F0FF00FFB400FFB400FFB400FFB400FFB4003CFF00F0FF0096FF0000FF78
F0FF0096FF00F0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB40096FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00F0FF00FFB400F0FF003CFF00FFB400FFB400FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB4003CFF009600FF96FF003CFF0096FF00
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00F0FF00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400F0FF00
96FF00FFB4003CFF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF0096FF0000FF1E3CFF003CFF003CFF003CFF00FF000000FF1E3CFF00
00FF7800FF1E00FF1E00FF7800D2FF00FFD20078FF0078FF001EFFFF00B4FF0000FF00B4
0078FF001EFF00FFD200FFD200D2FF00FF1E00FF1E00FF1E3CFF003CFF0000FF1E3CFF00
3CFF003CFF0000D2FF96FF0096FF003CFF0096FF0096FF0096FF0096FF0096FF0096FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
96FF0096FF00FFB400FFB400FFB400FFB400FFB400FFB40000FFD2F0FF00FFB400F0FF00
00FF7896FF00FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400FFB400FFB400F0FF0000FFD2F0FF00FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00F0FF0096FF009600FFF0FF00FFB40096FF00
00D2FFFFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB4003CFF00F0FF00
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF7800FFD200FFD200FFD200FFD2FF00000078FF9600FFF000FF001EFF
00D2FF00FFD200FF7800FF7800FF7800FF1E00FFD23CFF003CFF003CFF003CFF003CFF00
96FF0096FF003CFF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FF00B4FFB400FFB400FFB400FFB400FFB400FFB400F0FF00FFB400FFB400FFB400
FF005A96FF00F0FF00F0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A000078FFFF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400F0FF0096FF009600FFF0FF00FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400F0FF00F0FF00F0FF00FFB400FFB400
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400F0FF00FFB400FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FF7800FF7800D2FF0078FF001EFFFF0000FF005A9600FF
0078FFFF00B4FF00B400FFD200FF1E00FF1E00FF1E3CFF003CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB40096FF0096FF00FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB40096FF000078FF96FF00F0FF00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB40000FF78FFB400FFB400FF5A00FF5A00
FF5A00FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB4003CFF00FFB400FFB400FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
3CFF0000FF1E00FF1E00FF1E00FF7800FFD23C00FF00D2FF0078FF9600FFFF00B4001EFF
00D2FF00FFD200FF7800FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF0096FF0096FF00
96FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400F0FF00F0FF0096FF00FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FFB400FFB40096FF000078FF3CFF0096FF00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400F0FF00FFB400FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FFB400FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A0000FF1EFFB400FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF00
00FF1E00FF7800FF1E00FF1E00FF7800FF7800FFD200D2FF3C00FF3C00FFFF00003C00FF
0078FF00D2FF00FFD200FFD200FF7800FFD200FF7800FFD200FFD23CFF003CFF0096FF00
96FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400F0FF00FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400FFB400FFB400FFB4003CFF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400F0FF0000FF1EF0FF0000FFD296FF00FFB400
FF5A00FF5A00FF5A00FFB400FFB400FFB40096FF0096FF00FFB400FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FFB400FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF5A00FF5A00FF5A00FF5A00FF5A00F0FF00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00F0FF0096FF0096FF0096FF0096FF0096FF0096FF003CFF003CFF003CFF0000FF78
FF000000FFD200FFD200FF7800D2FF00FFD200FFD20078FF001EFF3C00FFFF005AFF00B4
FF005A3C00FF001EFF001EFF00FFD200FFD200FF7800FF1E3CFF003CFF003CFF0096FF00
96FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FFB400FFB4003CFF00FFB400FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00F0FF00FFB400F0FF00FFB40000FF1E3CFF00FFB400
FF0000FF5A00FF5A00FF5A00FFB400F0FF0000FF1E00FF1EF0FF00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF5A00FF5A00FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF003CFF00F0FF00F0FF00F0FF00F0FF00
F0FF0096FF0096FF003CFF003CFF0096FF0096FF0000FF1E3CFF003CFF003CFF003CFF00
00FF1E0078FFFF000000FFD2FF0000001EFFF000FFFF0000FF0000FF0000FF00B49600FF
001EFF0078FF00FFD200FF7800FF7800FF1E00FF1E3CFF003CFF003CFF003CFF003CFF00
3CFF003CFF003CFF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00F0FF00F0FF003CFF00
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400001EFFFFB400FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000
FF0000FF0000FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
F000FFFFB400FF5A00FF5A00FFB400FFB40096FF00FFB400
FF0000FF5A00FF5A00FF5A00FF5A00F0FF0000FF78FFB400FFB4003CFF00FF5A00FF5A00
FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF5A00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400F0FF00F0FF00F0FF00F0FF00F0FF00F0FF0000FF1E96FF0096FF0096FF0096FF00
96FF0096FF0096FF0096FF003CFF0000FF1E3CFF0000FF1E3CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF7800FF7800FF780078FF00FFD20078FF001EFF3C00FFFF00003C00FF
001EFF00D2FF00FFD200FF7800FF7800FF1E00FF1E00FF1E3CFF003CFF003CFF0000FF1E
00FF1E3CFF0096FF0096FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF003CFF00F0FF00
F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB40000FF1EFF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00FF5A0096FF00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400F0FF00FFB400
FF0000FF5A00FF5A00FF5A00FF5A003CFF00F0FF00FFB400FF5A00FF5A00FFB400FF5A00
FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400F0FF0096FF00
96FF0096FF003CFF003CFF003CFF0000FF1E00FF1E00FFD23CFF0000FF1E96FF0096FF00
96FF0096FF0096FF0096FF0096FF003CFF0000FF78001EFF3CFF003CFF003CFF003CFF00
00FF1E00FF1E00FF1E00FF7800FF7800FF7800FFD200D2FF0078FF3C00FFFF00009600FF
0078FF00D2FF001EFFF000FF00FF7800D2FF00FF7800FF1E00FF1E00FF1E00FF783C00FF
00FF1E3CFF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0096FF0000FF78F0FF00
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00F0FF00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400F0FF0096FF00
FF0000FF5A00FF5A00FF5A00FFB400F0FF00FFB400FF5A00FF5A00FF5A00FF5A00FF5A00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400F0FF00
F0FF00F0FF00F0FF0096FF0096FF0096FF0000D2FF3C00FF00FFD23CFF0096FF003CFF00
3CFF0096FF0096FF0096FF0096FF003CFF000078FF00D2FF00FF1E00FF1E00FF1E00FF1E
00FF1E00FF1E00FF1E00FF7800FF7800FFD200FFD200FFD200D2FF0078FF3C00FFFF0000
FF005A00D2FF00FFD200FFD200FF7800D2FF00FF7800FF1E00FF1E3C00FF9600FF0078FF
3CFF003CFF0096FF0096FF0096FF0096FF0096FF0096FF003CFF0000FF1E00FF1E3CFF00
96FF003CFF0096FF0000FF78F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FF5A00
FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB4009600FF
FF0000FF5A00FF5A00FFB40096FF00001EFFFFB400FF5A00FF5A00FF5A00FF5A00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400F0FF0096FF00F0FF00F0FF0096FF003CFF0000FF1E3CFF0000FFD200FF1E
3CFF0096FF0096FF0096FF003CFF003CFF0000FF1E00FF7800FF7800FF1E00FF1E00FF1E
FF000000FF7800FF7800FF7800FFD20078FF00D2FF00D2FF0078FF001EFFFF0000FF0000
3C00FFFF00B400D2FF00D2FF00FFD200D2FF00FF7800FF7800FF7800D2FF00D2FF00FF1E
3CFF003CFF0000FF1E96FF0096FF003CFF003CFF003CFF00FF00B400FFD200D2FF00FF78
96FF0096FF00F0FF0096FF0096FF0096FF0096FF0000FF1EF0FF00FFB400FFB400FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400
FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400F0FF003C00FF
FF0000FF5A00FF5A00FF5A00FFB400F0FF00FFB400FFB400FF5A00FF5A00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF0000FF1E96FF003CFF0096FF003CFF0000FF78
00FF783CFF003CFF003CFF003CFF003CFF0000FF1E0078FF001EFF00FF7800FF1E00FF1E
00FF7800FFD200FF7800FF7800FF78FF00B4001EFF0078FF001EFF0078FF001EFF3C00FF
FF0000001EFF001EFF00D2FF0078FF00FFD200FFD23C00FF00FFD200FFD200FF1E00FF1E
3CFF0000FF1E3CFF003CFF003CFF0000FF78FF00003CFF0096FF003CFF003CFF0096FF00
F0FF00F0FF00F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF5A00FF5A00FF5A00FFB400FF5A00FFB400FFB400
FF0000FF5A00FF5A00FF5A00FFB400FFB400FF5A00FF5A00FF5A00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF00F0FF0096FF003CFF003CFF00
3CFF00001EFF3CFF0000FF1E00FF1E00FF1E00FF1E00FF1E00FF7800FFD200FF7800FF78
00FF78FF000000FFD200FF7800FFD200FFD200FFD20078FF00D2FF00D2FF0078FF3C00FF
001EFFFF00B4F000FF3C00FFFF00B400D2FF00D2FF0078FF001EFF00FFD200FF7800FFD2
00FF1E0078FF00FF1E00FF1E3C00FF3CFF003CFF003CFF0096FF0096FF0096FF0000FF78
F0FF00F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF5A00FF5A00FF5A00FF5A00FF5A00FFB400
FF0000FF5A00FF5A00FFB400FF0000FFB400FF5A00FF5A00FF5A00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF00
3CFF003CFF003C00FF00FF7800FF7800FF1E0078FF00FF7800FF7800D2FF0078FF00FFD2
00FFD20078FF00FFD200FFD200FFD200FFD200FFD200D2FF00D2FF00D2FF0078FF0078FF
0078FF3C00FF3C00FFFF00B4FF00B49600FF3C00FFF000FF0078FF00FFD200FFD200FFD2
00FF7800FFD200FFD200FF1E3CFF003CFF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00FFB400
FF0000FF5A00FF5A00FF5A00F0FF00FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF0096FF0096FF0096FF00
00FF1E00D2FF00FFD2FF00B400FFD200FF783C00FF00FF7800D2FF9600FF00D2FF00D2FF
00FFD200D2FF00D2FF00D2FF00D2FF00D2FF0078FF00D2FF00D2FF00D2FF0078FF00D2FF
00D2FF0078FF0078FFFF005A3C00FFFF0000FF0000F000FF3C00FF3C00FF00D2FF00FFD2
00FFD29600FFFF00B400FF7800FF1E96FF0096FF0096FF00F0FF00F0FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A0096FF00
FF0000FF5A00F0FF00FFB400FFB400FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0096FF0096FF003CFF0000FF1E
3CFF0000FF1E00FFD2FF000000D2FF00D2FF0078FF00D2FF00D2FFF000FF001EFF0078FF
0078FFFF00B4001EFF0078FF0078FF00D2FF001EFF00D2FF00D2FF00D2FF00FFD200FFD2
00D2FF00D2FF00D2FF0078FF00D2FF0078FF001EFFFF0000FF00B4FF0000FF0000001EFF
001EFF9600FF00D2FF00FF1E3CFF003CFF003CFF0096FF00F0FF00F0FF00F0FF00F0FF00
FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFB400FF5A00FF5A00
FF0000FF5A00FF5A00FFB400FFB40096FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF0096FF0000FF1E3CFF0096FF003CFF0000FF1E
00FF1E0078FF001EFF3C00FF3C00FF001EFF3C00FF3C00FFF000FFFF0000FF0000FF00B4
FF005AFF00009600FFFF0000001EFF0078FF0078FF00D2FF00D2FF00D2FF00FFD200FFD2
00FFD200FFD200FFD20078FF00FFD200FFD20078FF3C00FF0078FF0078FF9600FFFF0000
F000FF001EFFF000FF0078FF00FF1E00FFD200FF7896FF0096FF0096FF0096FF0096FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00
FF0000FF5A0000FF1E3CFF00FF5A00FF5A00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FFB400F0FF00FFB400FFB400FFB400FFB400FFB400
FFB400FFB400FFB400FFB400F0FF00F0FF00F0FF0096FF00001EFF00FF1E00FF780078FF
00D2FFFF0000F000FFFF00003C00FFFF0000F000FFF000FFFF005A001EFFFF0000001EFF
001EFFFF00B43C00FFFF0000FF005A3C00FF0078FF0078FF0078FF0078FF00D2FF00FFD2
00FF7800FF7800FFD200FFD200FF7800FFD200D2FF00D2FF00FFD200FFD200FFD200D2FF
9600FFFF0000FF00B40078FF3C00FF00FF1E00FF1E3CFF0000FF1E96FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00
FF0000FF5A00FF5A00FFB400FF5A00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FFB400FFB400FFB40096FF0000FF1EFFB400FFB400FFB400
FFB400FFB400FFB400F0FF00F0FF00F0FF00F0FF0096FF0000FF1E00FF78FF0000001EFF
FF00B40078FF001EFF00D2FF3C00FF001EFF00D2FF0078FF00D2FF0078FF9600FF00D2FF
00D2FFFF000000D2FF0078FF001EFFFF0000F000FFFF00000078FF0078FFF000FF00FFD2
00FF7800FF7800FFD200FFD200FF7800FF7800FFD200FF7800FF78001EFF00FF7800D2FF
F000FF0078FF00D2FF0078FFF000FF00D2FF00FF78001EFF3CFF0096FF00F0FF00F0FF00
F0FF00FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400FFB400F0FF00FFB400
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00
FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF5A00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5A00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00703oool2000000@0oooo0P0000030?ooo`@00000;P3oool2000000@0oooo0P0000030?oo
o`D00000<@3oool2000003D0oooo0P0000040?ooo`8000000`3oool5000002h0oooo0P0000040?oo
o`8000000`3oool400000080oooo000K0?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool0;P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0300oooo00@00000
0?ooo`3oool00000<`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo02d0oooo
00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`006`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo02d0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`0`0?ooo`040000003oool0oooo000003<0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
0P3oool001D0oooo100000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
9P3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0`0?ooo`04
0000003oool0oooo000003<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0]
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00@3oool001/0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000]0?ooo`040000003oool0oooo000000X0
oooo00<000000?ooo`3oool0<03oool010000000oooo0?ooo`00000c0?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool0;@3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000080oooo000L0?ooo`8000002P3oool2000002l0oooo0P00000:0?ooo`800000<`3o
ool2000003D0oooo0P00000:0?ooo`800000<03oool2000000X0oooo0P0000030?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3ooooo
0000004000001@3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo000000050?ooo`006`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo03/0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`00203oool2000000@0oooo0P0000030?ooo`@00000103oool00`000000oooo0?ooo`3l0?oo
o`030000003oool0oooo00<0oooo00070?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo00<0oooo00070?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool200000?`0oooo0P0000050?oo
o`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030?mJ003o0000o`0002T0o`006@3oFP000`3o
]000l?l00?nd000:0?nd00@0l?l000L0U_l003co000lo`0001ko003oN000d_l0l03o008007So00<0
0=;o001ho`3`0?l00P00d_l00`00ogP001ko003oN002003oN003003odP00ogP00?mh00<00?oB0P00
ogP00`00om80l03o0?00o`02001ho`070?l0003`0?l0l03o0?l000007_l007So003Bo`020?l00080
0=;o00H0UP3o001ho`00N?l00=;o001ho`00d_l2000No`0403`0o`00d_l001ko001ho`80o`2d00<0
01ko0?l00000ogP00P00oah00`2Fo`00l?l00?3o00030?3o00L0ok@000<00?lN09Ko002Fo`000`3o
]00I0?mJ0300o`0000<0oeX00?nd003oFP000P3oFP000`3o0000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`020?ooo`80oeX0:@3o000K0?mJ00`0ok@0103`o`00102Fo`000?lN
003o7P0lo`02003o7P0603`0o`00N?l007So0?l0]03o0000UP3o0P00d_l3003odP<00=;o00<00?oB
003oN000om800P00om82003oN003003odP00d_l00=;o00D007So00@0?03o0?l0FP3o0000?03o0P3o
0;@2000No`040?l000007_l001ko0?l0FP80l03o0P3o0000100l0?l0o`000?00o`3o0002003Bo`03
001ho`00ogP00?lN008001ko00<0U_l00?3o003`o`000P3`o`0;0?nd00030?3o003o]000oeX001T0
oeX0;`3o00020?mJ000503co0000oah00?lN0?mJ003o0000103oool00`000000oooo0?ooo`030?oo
o`00203oool2000000X0oooo0P0000050?ooo`030000003oool0oooo0080oooo0P3oFP0Y0?l001/0
oeX0303o]0020?3o00H0U_l000<00?mh003odP00oah00P00N?l00`3`0?l001ko0?00o`020?l00003
09H0o`00N?l007So0080?03o00@007So003odP00om8007So1`00om83003Bo`<007So00<001ko0?l0
002F0?l00P3o00000`3o05X0o`2d0?l000020?l000030?00o`0l0?l0?03o008001ko0P0l0?l00`00
7_l007So003o7P02003o7P0603co002Fo`00??l003co0000oah0U_l00`3`o`0=0?nd01X0oeX0;`3o
00000`2Fo`00ok@00?nd00030?mJ00030?l0003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3oool20?mJ02T0o`006`3oFP0<0?nd0080l?l01P2Fo`00
0`00ogP00?oB003o7P02001ho`030?00o`007_l0l03o0080o`0000<0UP3o001ho`00N?l00P0l0?l0
1000N?l00?oB003odP00N?l7003odP<00=;o0`00N?l00`007_l0o`0009H0o`020?l000030?l0FP3o
0;@0o`000080o`0000<0l03o03`0o`0l0?l00P007_l203`0o`03000No`00N?l00?lN00800?lN00H0
??l009Ko000lo`00??l0003o7P2Fo`030?3o00d0ok@06P3oFP0_0?l0000309Ko003o]000ok@000<0
oeX000<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo
0?ooo`020?ooo`80oeX00P3o]00W0?l001`0oeX03@3o]0050?3o000409Ko000lo`00??l003co0080
0?lN00<00=;o09H0o`007_l00P007_l20?l000070?l0]03o0000o`00000No`00N?l00=;o001ho`04
003Bo`<00?oB0`00d_l2000No`04003Bo`00N?l007So000No`80o`2d0P00N?l00`007_l0l03o0?00
o`02003Bo`07001ho`00d_l00=;o003Bo`3o00000?oB003o7P0203co0003003o7P0lo`00U_l00080
U_l00`3`o`0>0?nd01/0oeX0;@3o00030?mJ0080ok@00P3`o`000`3oFP00o`000?ooo`030?ooo`03
0000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00<0U_l00?mJ003oFP00
0P3oFP0U0?l001d0oeX02`3o]0070?3o00<0U_l000D00?lN003oN000ogP0o`2d09H0o`03003odP03
003Bo`0l0?l0?03o0080l03o0P3o00000`0l0?l0o`1J001ho`02001ho`800=;o0P00N?l3003Bo`80
07So1P00d_l00`00om800=;o003Bo`0209H0o`03003Bo`00ogP0?03o00800?mh00@00?oB0?l0]000
om800=;o0P00oah309Ko00D0l?l03P3o]00L0?mJ02/0o`00103oFP000`3`o`00oeX00?mJ00020?mJ
00030?l0003oool0oooo0080oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3oool00`3o]000oeX00?mJ00030?mJ02@0o`007@3oFP0;0?nd00L0l?l00P2Fo`0203co0080
0?lN0P00om800`00ogP00?oB003odP02003odP05001ho`3`0?l0l03o03`0o`2F0?l00P3o0;@303`0
o`@007So0`00d_l6003odP8007So0P00om800`00N?l00=;o003Bo`02003oN003001ho`00oah00?lN
00800?mh00@0?03o03co000lo`00??l00`2Fo`050?3o00d0ok@07@3oFP0Z0?l000@0oeX000<0ok@0
0?l0003o]0000`3oFP000`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo00<0ok@00?mJ003oFP00103oFP0R0?l001h0oeX02P3o]0030?3o
0003003oN02Fo`00U_l00080U_l00`0lo`001P0l0?l00?lN003o7P00oah007So003o7P800?oB00<0
0?mh003odP007_l00P00N?l2003Bo`070?l0]00l0?l0l03o0?00o`3o0;@001ko03`0o`02001ho`80
0=;o00<007So003odP00om800P00om801000ogP00?oB0?l0003o0003003oN0800?oB00<00?mh003o
7P00oah01000oah00`0lo`0001ko03co000303co000309Ko003`o`00l?l000D0l?l02`3o]00N0?mJ
02T0o`00103oFP020?nd00@0oeX000<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`006`3oool00`000000oooo0?ooo`020?ooo`030?nd003oFP00oeX000@0oeX08P3o000N0?mJ00X0
ok@00`3`o`000`00ogP0U_l009Ko000209Ko00<0??l000H0?03o003o7P00oah00?lN001ho`00oah2
003odP03003oN000om8001ko008007So0P00d_l01`3o0;@0?03o0?00o`3`0?l0o`2d000No`0l0?l0
0P00N?l2003Bo`03001ho`00om800?oB00800?oB00@00?mh003odP3o0000o`000`00ogP2003odP03
003oN000oah00?lN00@00?lN00<0??l0000No`0lo`000`0lo`000`2Fo`00l?l00?3o00050?3o00/0
ok@07P3oFP0Y0?l000@0oeX00P3o]0040?mJ00030?l0003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3oool20?nd0080oeX000<0ok@00?mJ003oFP00
0P3oFP0N0?l00200oeX0203o]0050?3o000309Ko000lo`00??l00080U_l000<0??l00?l00000ogP0
100lo`000`00oah0??l0003o7P02003o7P800?oB0P0l0?l2003odP03001ho`00d_l001ko008001ko
00L0o`0003`0o`007_l001ko001ho`007_l007So008001ko00@0o`2d003oN000ogP00?mh0P00om80
0`00ogP00?lN003o7P02003oN003000No`00N?l00?lN00H0??l00`00ogP01P0lo`00U_l003co000l
o`00U_l0003o7P<0l?l02`3o]00N0?mJ02P0o`000P3oFP030?nd00030?3o003o]000oeX000<0oeX0
00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?oo
o`020?ooo`0403`0o`3`o`00ok@00?nd00H0oeX0703o00000`3oFP00ok@00?nd000M0?mJ00<0ok@0
00<0l?l0003o7P2Fo`00102Fo`001`3`o`00U_l009Ko002Fo`000?mh003Bo`00om800P3o0;@303co
00<0U_l000<00?lN03co000lo`000P00oah2003Bo`@00?mh00<00=;o003odP00d_l00P00d_l00`3o
0;@0?03o0?l000020?l00003000No`00N?l00=;o00800=;o00<007So003odP00ogP00`00ogP00`3o
00000?lN003o7P02003o7P800?mh00@00?lN03co000lo`00??l00`2Fo`0203co0003003o7P00om80
??l000800?lN00<0??l009Ko003`o`000P3`o`000`2Fo`00l?l00?nd00080?nd0200oeX0903o0005
0?mJ0080ok@000<001ko09Ko003o]0000`3oFP000`3o0000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo000K0?ooo`8000000`3oool0102F0?l0ok@00?nd003o]0080?mJ01T0o`00103oFP00
0`3o]000oeX00?mJ000J0?mJ00H0ok@00`3`o`000`00ogP0U_l003co000209Ko000303co0000oah0
0?lN0080??l01`2Fo`0203co008007So00<0UP3o03`0o`00oah00P00oah00`00ogP00=;o003oN003
003odP03003Bo`3o05X0o`000080?03o00<007So003Bo`00om800`00om82003oN0T00?lN00@00=;o
001ho`0lo`00??l0102Fo`0303co000609Ko000lo`000?oB003odP0l0?l00=;o102Fo`050?3o00D0
ok@0803oFP0S0?l000H0oeX00P3o]0000`3`o`00ok@00?mJ00030?mJ00040?l0003oool0oooo0?oo
o`8000001@3oool001/0oooo00<000000?ooo`3oool00P3oool0102Fo`00l?l00?nd003o]00;0?mJ
01<0o`00203oFP000`3`o`00oeX00?mJ000H0?mJ00X0ok@01P3`o`000`00ogP0U_l009Ko000809Ko
000503co0000oah0?03o03`0o`00ogP01000oah01000ogP00=;o003oN03`0?l2000No`03003Bo`00
N?l0UP3o0080o`0000<0?03o001ho`00d_l00P00om83003oN0@00?lN1@0lo`0010007_l00?mh03co
000lo`0809Ko0004003o7P0lo`00??l0003odP800?lN100lo`0409Ko00030?3o003o]000ok@00080
ok@08@3oFP0Q0?l00080oeX00P3o]0020?mJ00040?nd003`o`00l?l003co00D0oeX000<0o`000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`04
09Ko003`o`00ok@00?nd00/0oeX04`3o00080?mJ00030?3o003oFP00oeX001P0oeX02P3o]0060?3o
0003003oN02Fo`00U_l000P0U_l000D0??l0003o7P0l0?l0?03o003oN004003o7P04003oN000d_l0
0?mh0?00o`8001ko00<00=;o001ho`2F0?l00P3o00000`0l0?l007So003Bo`02003odP<00?mh1000
oah503co0004000No`00ogP0??l003co00P0U_l000@00?lN03co000lo`000?oB0P00oah403co00@0
U_l000<0l?l00?nd003o]0000P3o]00Q0?mJ0240o`000P3oFP020?nd0080oeX000@0ok@00?3o003`
o`00??l01@3oFP000`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo000K0?ooo`03
0000003oool0oooo0080oooo00@0ok@00?3o003o]000ok@01P3oFP000`2Fo`00oeX00?mJ00040?mJ
00l0o`002`3oFP000`00oah0ok@00?nd000G0?mJ00/0ok@01@3`o`000`0lo`00l?l00?3o00030?3o
00D0U_l000@0??l0003o7P00oah00?lN0`0lo`04003o7P800?mh0P00om800`00d_l001ko03`0o`02
0?l0000303`0o`007_l007So00800?oB00@007So003oN000ogP00?mh0`00oah503co0005003o7P0l
o`000?lN003o7P0lo`002P2Fo`000`00oah0l?l00?3o00050?3o00T0ok@07`3oFP000`3o]000oeX0
0?l0000N0?l000D0oeX000<0??l00?nd003o]0000P00ogP00`3`o`00oeX00?mJ00030?mJ00030?l0
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3o
ool00`3o]000U_l00?nd00020?nd0080oeX00P3o]0000`3`0?l0oeX00?mJ000:0?mJ00H0o`003`3o
FP00103o]00001ko000No`3o]00E0?mJ00d0ok@00`3`o`000`0lo`00l?l00?3o00050?3o00<0U_l0
2P0lo`02003o7P800?mh0P00om800`00N?l001ko09H0o`020?l0]0<0o`000P3`0?l010007_l0o`00
003odP3o0002001ho`03003o7P0lo`00??l000<0??l000@00?lN09Ko002Fo`00U_l00P0lo`0209Ko
00L0l?l000<0??l00?3o003`o`000`3`o`0;0?nd01d0oeX00P3o]0030?mJ01/0o`002@3oFP001P3`
o`000?lN003o7P00oah0l?l00?nd00@0oeX000<0o`000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`070?nd000lo`000?lN003o7P3o]000l?l0
0?nd00020?3o00d0oeX000<0ok@00?mJ003oFP004`3oFP020?nd000303co003o]000ok@00100oeX0
4@3o]00;0?3o00L0U_l00`0lo`02003o7P03003oN000om800?oB00<001ko00<0?03o0?l0FP3o0;@0
0P3o05X00`0l0?l001ko001ho`03003odP03003Bo`00ogP00?oB00800?oB00<0o`00003oN00lo`00
0`0lo`0709Ko00T0l?l000@0U_l00?3o003`o`00l?l03@3o]00K0?mJ00030?3o003oFP00oeX000@0
oeX06@3o00000`3o]000oeX00?mJ00070?mJ00040?nd002Fo`00U_l009Ko00<0ok@0103oFP040?oo
o`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00L0ok@009Ko0000
om800?oB0?3o0000oah0l?l00080ok@03@3oFP000`3o]000oeX00?mJ000E0?mJ00030?nd000lo`00
ok@000@0ok@02P3oFP020?nd00030?3o003o]000ok@00100ok@02@3`o`0709Ko0080??l00`00om80
0`00ogP00?oB003oN003003odP03003Bo`00N?l0?03o0080o`000P0l0?l00`00d_l00?oB003odP02
003oN0800?lN0P00ogP00`00oah0??l003co000203co00L0U_l0303`o`0@0?nd01P0oeX000<0ok@0
003o7P3oFP002@3oFP0D0?l000<0oeX00P3o]0070?mJ00030?nd003`o`00ok@00080ok@01P3oFP04
0?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00D0U_l003co
0000N?l007So09Ko00020?nd02L0oeX00P3o]000102Fo`00l?l00?3o003`o`0P0?nd00T0l?l0202F
o`0403co00<00?lN0`00ogP00`00om800=;o000No`020?l0]00309H0o`00N?l00=;o0080?03o00<0
0?oB003oN000oah00`00oah503co00L0U_l02`3`o`0C0?nd01<0oeX00`3o]0000`0lo`00ok@00?mJ
000=0?mJ00`0o`002@3oFP000`3o]000oeX00?mJ00030?mJ0080ok@000<00?mh0?nd003o]0001`3o
FP040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00D0U_l0
03co0000N?l007So09Ko00020?nd02L0oeX00P3o]000102Fo`00l?l00?3o003`o`0P0?nd00T0l?l0
202Fo`0403co00<00?lN0`00ogP00`00om800=;o000No`020?l0]00309H0o`00N?l00=;o0080?03o
00<00?oB003oN000oah00`00oah503co00L0U_l02`3`o`0C0?nd01<0oeX00`3o]0000`0lo`00ok@0
0?mJ000=0?mJ00`0o`002@3oFP000`3o]000oeX00?mJ00030?mJ0080ok@000<00?mh0?nd003o]000
1`3oFP040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00D0
l?l009Ko0000N?l007So09Ko00020?nd00h0oeX000<0ok@00?mJ003oFP005`3oFP020?nd00<0U_l0
3P3o]0020?3o0100ok@0203`o`0809Ko00D0??l00`00oah01P00om80o`2d0?l0]03o0;@007So09H0
o`80o`1J00<0o`00000No`00N?l00P00d_l2003oN0@00?lN1P0lo`0709Ko00X0l?l04`3o]0000`3`
o`00oeX00?mJ000>0?mJ00<0ok@00P3`o`000`3o]000oeX00?mJ000R0?mJ00H0ok@00`3`o`020?nd
00L0oeX0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`07
0?nd003`o`00UP3o09H0o`2Fo`00l?l00?nd000>0?mJ0003001ho`3oFP00oeX001P0oeX000H0ok@0
0?3o003`o`00l?l009Ko003o05X40?nd00030?3o003o]000ok@000D0ok@00P3o0;@@0?nd00L0l?l0
102Fo`000`0lo`00U_l009Ko000703co0003003odP00oah00?mh00<00?mh00<00?oB003Bo`007_l0
0P3`0?l00`2F0?l007So0?l00005003odP03003oN000oah00?lN00L0??l01P2Fo`0:0?3o01H0ok@0
2`3oFP040?nd00040?3o000lo`00ok@00?nd01L0oeX000<0ok@00?mJ003oFP00303oFP000`3o]000
0=;o09Ko00020?nd00030?3o002F0?l0U_l00080l?l01`3oFP040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo00D0ok@00?3o0000om800?oB0?3o00040?nd00/0
oeX00P3o]00J0?mJ00@0ok@000<0U_l0003oN03`o`000P3o]0000`3`o`000?oB0?nd00060?nd00<0
U_l03`3o]00709Ko000503co002Fo`00U_l009Ko0000d_l0100lo`000`00oah0??l003co0004003o
7P07003Bo`00om800?oB003odP007_l007So0?l0]0020?l000030?l0]0007_l007So008007So00<0
0?oB003Bo`00ogP00`00oah00`00ogP0??l0003o7P020?l000D0??l000@00?lN09Ko002Fo`00U_l0
203`o`0B0?nd0080l?l03P3o]0001P0lo`00ok@00?nd002Fo`00l?l00?nd01T0oeX000<0l?l00?mJ
003oFP003@3oFP001`3o]000U_l003co000lo`00U_l009H0o`0lo`000`3o]0060?mJ00@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool40?nd000303co003`o`00
ok@00080l?l02@3oFP020?nd000309Ko003o]000oeX001X0oeX000H0ok@00?3o003`o`00U_l00?3o
0000ogP209Ko00030?3o000lo`00ok@000D0ok@000@0l?l009Ko002Fo`00l?l03@3o]0050?3o0080
U_l000@0??l0003oN0007_l0??l00P00om800`00ogP00?lN003o7P0203co00L00?lN00D00?mh003B
o`00N?l007So0?00o`02000No`80o`2d00<0o`0009H0o`0l0?l00P007_l00`3o0;@007So003odP03
003oN0D00?lN0P0lo`000`00ogP00?lN003o7P0203co000309Ko000lo`00U_l000<0U_l01@3`o`0@
0?nd00030?3o003o]000ok@000h0ok@000@0l?l0003o7P00oah0l?l00P3o]00I0?mJ00030?nd003o
FP00oeX000d0oeX00P3o]0020?3o000303co0000om800?lN0080U_l000<0l?l0000No`3o]0000P3`
o`000`2Fo`00oeX00?ooo`030?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3oool4
0?nd000303co003`o`00ok@00080l?l02@3oFP020?nd000309Ko003o]000oeX001X0oeX000H0ok@0
0?3o003`o`00U_l00?3o0000ogP209Ko00030?3o000lo`00ok@000D0ok@000@0l?l009Ko002Fo`00
l?l03@3o]0050?3o0080U_l000@0??l0003oN0007_l0??l00P00om800`00ogP00?lN003o7P0203co
00L00?lN00D00?mh003Bo`00N?l007So0?00o`02000No`80o`2d00<0o`0009H0o`0l0?l00P007_l0
0`3o0;@007So003odP03003oN0D00?lN0P0lo`000`00ogP00?lN003o7P0203co000309Ko000lo`00
U_l000<0U_l01@3`o`0@0?nd00030?3o003o]000ok@000h0ok@000@0l?l0003o7P00oah0l?l00P3o
]00I0?mJ00030?nd003oFP00oeX000d0oeX00P3o]0020?3o000303co0000om800?lN0080U_l000<0
l?l0000No`3o]0000P3`o`000`2Fo`00oeX00?ooo`020?ooo`8000001@3oool001/0oooo00<00000
0?ooo`3oool00P3oool20?nd0080l?l000<00?oB09Ko003o]0000`3o]0070?mJ00050?3o003o]000
ok@009Ko003o]0006`3oFP050?nd00060?3o0000oah00?lN003odP2Fo`000?lN1@3o]0000`3`o`00
U_l009Ko00020?3o00/0ok@0203`o`0209Ko0080??l00P00ogP00`00d_l001ko000No`02003odP03
000No`3o0;@00=;o00800=;o0P00om800`00N?l001ko09H0o`0209H0o`0303`0o`3o0;@0UP3o0080
UP3o00H0o`000?00o`3`0?l0l03o0?l0002F0?l2001ho`8001ko00<0?03o001ho`2F0?l00P3o0000
0`3`0?l0o`2d0?l0FP020?l0000403`0o`00om80o`2d003Bo`800?mh00<0??l0003o7P2Fo`00103`
o`0@0?nd000303co003o]000ok@000`0ok@000<0??l00?3o000lo`000P3`o`020?nd01X0oeX00P3o
]00>0?mJ0080ok@00P3`o`0203co00@0l?l000<0ok@009Ko003oFP000`3oFP040?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo103o]0000`00oah0l?l00?nd0005
0?nd00<0oeX00`3o]002003oN080ok@06`3oFP050?nd00030?3o0000oah00?lN00800?lN1`3`o`02
003oN003003o7P3`o`00l?l00080l?l01`3o]00:0?3o0003003oN02Fo`00U_l000<00?lN100lo`00
0`00ogP00?lN003o7P04003oN007003odP00N?l0?03o03`0o`2F0?l0l03o0?l000020?00o`0309H0
o`007_l007So008007So00<001ko003odP00ogP02000oah203co0003003oN000oah00?lN0080??l0
00<0U_l003co002Fo`000P2Fo`060?3o00l0ok@000<0l?l0003o7P3o]000203o]000202Fo`00ok@0
0?nd003o]000l?l003co0000N?l0l?l00`3o]00L0?mJ00030?nd003oFP00oeX000`0oeX00P3o]002
0?3o00030?l0000lo`00ok@000<0ok@01P3oFP040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo103o]0000`3`o`00??l00?3o00020?nd00030?3o003o]000ok@0
00D0ok@000@0U_l00?3o003`o`00ok@07@3oFP040?nd0003003oN03`o`00l?l00080U_l000L0o`00
09Ko003`o`00l?l0003o7P3`o`00U_l000800?mh00<0??l00?3o003`o`000P3`o`000`2Fo`00l?l0
0?3o000?0?3o0080U_l00P00oah503co0003003o7P0lo`00??l000@00?lN00L00?mh09H0o`00d_l0
0=;o09H0o`007_l0UP3o0080o`1J00<0?03o001ho`00d_l00P00N?l00`00om80o`00003Bo`03003o
7P03003odP0lo`00??l000800=;o1@0lo`001000oah0U_l009Ko002Fo`0:0?3o00d0ok@000<0l?l0
03co000lo`000P3`o`060?nd000303co003o05X0l?l00080l?l000@0??l009Ko003`o`00l?l00`3o
]00L0?mJ00030?3o003o]000ok@000`0oeX00P3o]0020?3o000309Ko003`o`00l?l00080ok@01`3o
FP040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo103o]000
0`3`o`0001ko09Ko000209Ko00030?3o003o]000ok@00080ok@000@00?oB0?nd003`o`00U_l00P0l
o`000`3o]000oeX00?mJ000K0?mJ0080ok@000<0??l00?nd003o]0000P3o]0020?3o0080U_l00`00
oah209Ko00800?lN00<0U_l00?3o003`o`00203`o`000`2Fo`00l?l00?3o00090?3o000303co002F
o`00U_l000@0U_l00P00N?l503co0004003o7P00om800?oB003oN08007So00<00=;o0?l0000l0?l0
0P3o00000`0l0?l007So003Bo`02003odP<00?mh00<00?oB003o7P00oah01`0lo`0309Ko000303co
002Fo`00U_l000d0l?l02@3o]0040?3o000409Ko003`o`00l?l00?3o00<0ok@00`3`o`001@2Fo`00
??l0001ho`00N?l0l?l000<0ok@00P3`o`0M0?mJ000409Ko003o]000ok@00?nd00X0oeX00`3o]002
09Ko00030?3o003o]000ok@00080ok@01`3oFP040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo103o]0000`3`o`0001ko09Ko000209Ko00030?3o003o]000ok@0
0080ok@000@00?oB0?nd003`o`00U_l00P0lo`000`3o]000oeX00?mJ000K0?mJ0080ok@000<0??l0
0?nd003o]0000P3o]0020?3o0080U_l00`00oah209Ko00800?lN00<0U_l00?3o003`o`00203`o`00
0`2Fo`00l?l00?3o00090?3o000303co002Fo`00U_l000@0U_l00P00N?l503co0004003o7P00om80
0?oB003oN08007So00<00=;o0?l0000l0?l00P3o00000`0l0?l007So003Bo`02003odP<00?mh00<0
0?oB003o7P00oah01`0lo`0309Ko000303co002Fo`00U_l000d0l?l02@3o]0040?3o000409Ko003`
o`00l?l00?3o00<0ok@00`3`o`001@2Fo`00??l0001ho`00N?l0l?l000<0ok@00P3`o`0M0?mJ0004
09Ko003o]000ok@00?nd00X0oeX00`3o]00209Ko00030?3o003o]000ok@00080ok@01`3oFP040?oo
o`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00L0ok@00?3o0000
oah00?lN09Ko0000oah001ko0080U_l000<0l?l00?nd003o]0000P3o]0000`3`o`000?oB09Ko0004
0?nd01d0oeX0203o]0030?3o0080??l000<0o`1J003odP00oah00P0lo`0309Ko00800=;o1P3`o`00
0`3`0?l0l?l00?3o00090?3o00T0U_l01@0lo`02003o7P800?mh0`00d_l01`00N?l0?03o0?l0003o
0000o`2d000No`00N?l00P3o0002003oN0@00?lN1@0lo`0709Ko000303co003`o`00l?l000h0l?l0
103o]0050?3o0004003o7P00ogP0U_l009Ko00H0l?l000<0U_l0003oN000om800P2Fo`000`3`o`00
ok@00?nd00030?nd01d0oeX000<0ok@003co000lo`000P3o]0080?mJ00<0ok@000@0U_l003`0o`0l
0?l0U_l00P3o]0090?mJ00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3oool20?nd0080l?l000<0U_l003co0000N?l00P2Fo`000`0lo`00l?l009Ko00020?3o0003
03co0000ogP0l?l000@0ok@07@3oFP090?nd00070?3o002Fo`00U_l009Ko0000oah007So03`0o`03
003o7P0409Ko0000om80U_l009Ko00H0l?l000<0??l00?3o003`o`002@3`o`0909Ko00D0??l00`00
oah01P00ogP00?oB003odP00d_l007So03`0o`80o`0000<0?03o001ho`00d_l00P007_l2003oN0@0
0?lN1@0lo`0809Ko00d0l?l000<0U_l00?3o003`o`002@3`o`000`2Fo`00??l00?3o00020?3o0003
03co003`o`00l?l00080U_l000<00?oB03co002Fo`000P00oah00`3`o`00ok@00?nd00030?nd01d0
oeX00`3o]0000`2Fo`00ok@00?nd00020?nd0080oeX01P3o]000103`o`000?lN003o7P3`o`020?nd
00T0oeX0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`80
ok@00P3`o`000`2Fo`00??l00?l0FP02003odP0309Ko003`o`00U_l000<0??l000<0l?l009Ko000l
o`000`3o]00M0?mJ00T0ok@00P3`o`0309Ko00800?oB0P3`0?l00`00ogP00?lN003oN00209Ko00H0
l?l000<00?oB09Ko003`o`002@3`o`0909Ko00D00?lN00@00?mh003o7P00ogP00?mh0`00om801`00
7_l0l03o0?l0003o0000UP3o001ho`00d_l00P00om84003oN0800?lN00<00?mh003o7P0lo`000P0l
o`0809Ko00d0l?l000<00?mh0?3o003`o`00103`o`000`00N?l0l?l00?3o00020?3o000303co000l
0?l0U_l00080U_l000<00?lN09Ko002Fo`000P0lo`070?3o0080ok@07`3oFP030?nd0080l?l0203o
]0001000om80ok@00?nd003`o`02003o7P<0ok@02@3oFP040?ooo`030000003oool0oooo00<0oooo
000K0?ooo`030000003oool0oooo0080oooo00L0ok@00?3o003`o`00l?l009Ko000lo`000=;o00<0
0?mh00@0??l0003odP00N?l007So0P3`o`050?nd01d0oeX02@3o]0020?3o0080U_l000<00?lN03co
000lo`000P00oah00`00om8001ko003o7P02003oN00309Ko003`o`00l?l000<0U_l000<00?oB09Ko
002Fo`00203`o`0809Ko00@0??l000H00?lN003oN000ogP0?03o003odP00d_l3003odP0309H0o`00
N?l001ko0080o`0000<0UP3o03`0o`00N?l00`00om800`00d_l00?oB03`0o`02003Bo`03001ho`00
oah0??l00080??l0202Fo`0;0?3o00<0U_l01P3`o`0609Ko000303co0000om800?oB00800?lN00H0
?03o09Ko003`o`00l?l003co003`o`050?nd00030?3o003o]000oeX001h0oeX00`3o]0000`2Fo`00
0?mh0?3o00020?nd00030?3o003o]000ok@00080ok@000@0l?l003co003`o`000?lN0P2Fo`050?nd
00L0oeX0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`03
0?3o002Fo`00U_l00080U_l000H00?oB003Bo`0l0?l0?03o003Bo`2Fo`040?3o00H0ok@07@3oFP08
0?nd0080l?l000<0??l0003Bo`00d_l00P2Fo`000`3o0000U_l009Ko0002003o7P030?00o`0lo`00
??l000H0U_l000<0?03o09Ko002Fo`000P2Fo`050?3o00@0U_l00P00oah203co0003003o7P0lo`00
??l00080??l000<00?lN003oN000ogP00P00ogP01`007_l00=;o000No`007_l0UP3o0?l0003`0?l0
0`3o0;@0103o05X0UP3o003Bo`00d_l2003odP800?mh0P00N?l00`00oah0??l003co000303co00H0
U_l000<0??l00?3o003`o`002@3`o`0309Ko00H0l?l000<0U_l0003Bo`2Fo`000P2Fo`02003oN080
0=;o00@0UP3o003o7P00d_l0U_l00`3`o`080?nd0200oeX00`3o]0001@3`o`00o`000?3o003`o`00
U_l000@0ok@00P3`o`001P00om8001ko09Ko002Fo`000?lN09Ko00<0ok@01`3oFP040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00<0l?l009Ko002Fo`000P2F
o`001P00om800=;o03`0o`0l0?l00=;o09Ko00@0l?l01P3o]00M0?mJ00P0ok@00P3`o`000`0lo`00
0=;o003Bo`0209Ko00030?l0002Fo`00U_l000800?lN00<0l03o03co000lo`001P2Fo`000`0l0?l0
U_l009Ko000209Ko00D0l?l0102Fo`02003o7P80??l000<00?lN03co000lo`000P0lo`000`00oah0
0?mh003oN002003oN007000No`00d_l001ko000No`2F0?l0o`000?00o`030?l0]0040?l0FP2F0?l0
0=;o003Bo`800?oB0P00ogP2001ho`03003o7P0lo`00??l000<0??l01P2Fo`000`0lo`00l?l00?3o
00090?3o00<0U_l01P3`o`000`2Fo`000=;o09Ko000209Ko00800?mh0P00d_l0102F0?l00?lN003B
o`2Fo`030?3o00P0ok@0803oFP030?nd00050?3o003o0000l?l00?3o002Fo`00103o]0020?3o0006
003odP007_l0U_l009Ko0000oah0U_l00`3o]0070?mJ00@0oooo00<000000?ooo`3oool00`3oool0
01/0oooo0P0000030?ooo`0409Ko000lo`00??l003co00800?lN00D00?oB000No`007_l00?oB09Ko
00030?3o00P0ok@0703oFP070?nd0080l?l000@0??l003`0o`2Fo`00U_l00P3`o`0309Ko0003003o
7P2Fo`00??l00080U_l000<0o`0003co000lo`000`0lo`000`00N?l0U_l009Ko000203co00T0U_l0
0P0lo`000`00N?l0??l0003oN00403co00@00?lN0`00ogP2003odP03001ho`007_l0UP3o0080o`00
00<0UP3o000No`00N?l00P00d_l3003oN0@00?lN1P0lo`001000oah0??l003co0000ogP309Ko00T0
l?l000@0U_l003co000lo`00U_l01P3`o`001`2Fo`00??l0000No`007_l00?oB003oN00l0?l00P00
N?l00`00ogP0o`0009Ko00030?3o00T0ok@0803oFP040?nd00040?3o00007_l001ko09Ko00@0l?l0
0P2Fo`001000ogP00?oB09Ko002Fo`020?3o00@0ok@000<0??l00?mJ003oFP000`3oFP030?ooo`80
00001@3oool001/0oooo00<000000?ooo`3oool00P3oool00`3`o`00U_l00?3o00020?3o000409Ko
0000oah0UP3o09H0o`800?mh00@0??l00?3o003`o`00l?l01`3o]00L0?mJ0080ok@000<0l?l0003o
7P3o00000P00oah0102Fo`00l?l009Ko003`o`02003o7P<0l?l0202Fo`000`0lo`000=;o003odP02
003odP03003oN00lo`00??l00080??l02@2Fo`0303co0004001ho`00ogP00?lN003o7P80??l01000
oah3003oN0800?oB00<00=;o001ho`007_l00P3o000209H0o`03003Bo`00om800?oB00<00?mh1000
oah403co0003003oN000oah0?03o0080??l01`2Fo`050?3o000509Ko000lo`000?lN003o7P00ogP0
0P2Fo`001P3`o`00U_l009Ko002Fo`00o`0003co00800?mh00<001ko003odP007_l00P00oah00`00
N?l0U_l009Ko00030?3o00T0ok@0803oFP030?nd00070?3o0000ogP0U_l009Ko0000oah0U_l003co
00020?3o000409Ko0000ogP00?lN003odP80U_l000<0l?l00?nd003o]0002@3o]0040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00<0ok@00?3o003`o`000P3`
o`001@0lo`000?lN001ho`00N?l00?mh0080U_l00`3`o`070?nd01/0oeX02@3o]0080?3o00800?mh
1@3`o`00102Fo`00??l003co0000om820?l0]003001ho`00ogP00?oB0080??l00P2Fo`0303co00@0
U_l00`0lo`000`00oah001ko003o7P03003o7P06003oN000oah00?lN003o7P00ogP00=;o0`00om80
0`00d_l007So000No`020?l0FP030?l00000N?l00=;o00800=;o00<007So003odP00ogP02000oah0
0`00ogP00=;o03co000203co00h0U_l00`0lo`0609Ko0007003oN0007_l001ko000No`00d_l0o`00
003o7P0309Ko0003003oN02Fo`00l?l00080U_l02@3o]00P0?mJ00@0ok@000H0U_l00?3o003`o`00
l?l009Ko0000ogP303co0003003oN0007_l00=;o0080??l00P3`o`030?nd00030?3o003o]000ok@0
00800?mh00<0ok@009Ko003oool00`3oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`80ok@00P2Fo`000`3`o`00U_l009Ko0003003odP05003o7P2Fo`00l?l00?3o
002Fo`001P3`o`020?nd01X0oeX03P3o]00;0?3o0080U_l000H0??l0003oN000ogP00?mh09H0o`00
d_l7003o7P@0U_l00`0lo`001000oah0o`1J003Bo`00d_l2003o7P03003oN000om800?oB00<00?mh
00<00=;o0?l0]03o0;@00P00N?l01P0l0?l0o`1J0?l0FP3o0000o`1J001ho`800=;o00@00?oB003o
N000ogP0UP3o0P00om83003o7P800=;o00<0?03o003o7P00oah00P0lo`0609Ko000303co002Fo`00
U_l00080U_l000<00?lN09Ko002Fo`000`0lo`000`00oah00?oB003o7P02003o7P0309H0o`0lo`00
0?lN0080??l000<00?mh03co002Fo`00102Fo`000`3o00000?lN0?3o00020?3o00P0ok@07`3oFP08
0?nd0080l?l000H0U_l003co000lo`00?03o003Bo`3o0003003oN0<0l?l00P2Fo`000`00d_l0l?l0
0?3o0002003Bo`030?3o003o]000oooo00<0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3oool20?nd0080U_l000<0l?l009Ko002Fo`000`00om801@00oah0U_l00?3o
003`o`00U_l000H0l?l00P3o]00J0?mJ00h0ok@02`3`o`0209Ko000603co0000ogP00?mh003oN02F
0?l00=;o1`00oah409Ko00<0??l000@00?lN0?l0FP00d_l00=;o0P00oah00`00ogP00?oB003odP03
003oN003003Bo`3o0;@0o`2d008007So00H0?03o0?l0FP3o05X0o`000?l0FP00N?l2003Bo`04003o
dP00ogP00?mh09H0o`800?oB0`00oah2003Bo`0303`0o`00oah00?lN0080??l01P2Fo`000`0lo`00
U_l009Ko000209Ko0003003o7P2Fo`00U_l000<0??l000<00?lN003odP00oah00P00oah00`2F0?l0
??l0003o7P0203co0003003oN00lo`00U_l000@0U_l000<0o`00003o7P3`o`000P3`o`080?nd01l0
oeX0203o]0020?3o000609Ko000lo`00??l003`0o`00d_l0o`000`00ogP30?3o0080U_l000<00=;o
0?3o003`o`000P00d_l00`3`o`00ok@00?ooo`030?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo0P3o]0040?3o000609Ko0000oah00?lN09H0o`00ogP0??l00P00
om801000N?l0??l00?3o003`o`070?nd01L0oeX0403o]00:0?3o000309Ko000lo`000?lN00<0??l0
00H00?oB003o7P0lo`00??l0003oN000om83003oN004003o7P0lo`00??l003co00800?lN00<0??l0
003o7P00oah00P007_l3003oN08007So00@00?oB003oN000om800?oB0`00d_l01`00N?l0UP3o0?l0
003o0000l03o000No`00N?l00P00d_l3003odP06000No`00d_l00=;o003oN000oah00?mh0P00d_l0
0`00oah0??l003co000203co00H0U_l000<0??l009Ko002Fo`000P2Fo`000`0lo`000?lN03co0002
003o7P800?oB00<00=;o000No`0lo`000P0lo`0409Ko000303co0000oah0U_l000@0l?l0100lo`02
0?3o00L0ok@07`3oFP080?nd00<0l?l00`00oah00`00d_l0?03o003Bo`02001ho`03003o7P00om80
??l00080?03o00<00?oB03co003`o`000`3`o`000`3o]000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo0P3o]0030?3o000609Ko000lo`0007So
001ho`3o05X00?lN102Fo`020?3o00T0ok@05@3oFP0C0?nd00P0l?l000<0U_l00?l0]00lo`000`2F
o`001`00oah0U_l009Ko002Fo`00??l0003o7P0l0?l00P3o0002003o7P80??l00P00N?l00`00oah0
0=;o003oN004003odP07003oN000d_l00=;o000No`00om800=;o003odP03003Bo`07001ho`007_l0
UP3o09H0o`3o0000UP3o000No`02003Bo`0403`0o`00om800=;o003Bo`@00?mh00@001ko003oN000
ogP00?lN1@0lo`0309Ko0080??l000<00?mh03co002Fo`000`0lo`02003odP<0UP3o00<00?oB003o
7P00ogP0102Fo`030?3o000309Ko00007_l0l?l000@0l?l000<0U_l00?3o002Fo`000P2Fo`001@0l
o`00U_l009Ko002Fo`00l?l00080ok@000<0l?l00?mJ003oFP007@3oFP090?nd00080?3o002Fo`00
U_l009Ko000lo`000=;o000No`0lo`0409Ko00050?3o002Fo`00U_l00?3o002Fo`001@3o]0040?oo
o`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00L0ok@00?3o003`
o`00l?l0003o7P0lo`00U_l00080??l000<00?oB003o7P2Fo`00103`o`0;0?nd01<0oeX0503o]007
0?3o000409Ko0000om80U_l003co00P0U_l000P00?lN003odP00ogP00?mh03co0000ogP007So003o
7PD00?oB0P00N?l00`2F0?l00=;o001ho`02003Bo`03000No`00om800=;o00<00=;o00<001ko09H0
o`0l0?l00`3o0000202F0?l001ko001ho`00N?l001ko003Bo`00N?l00=;o0P007_l00`00om8007So
003odP03003oN0800?lN1@0lo`001P00oah0??l003co0000ogP00?oB03co00800?lN00<00=;o000N
o`00om800P00ogP01000d_l00?lN03co002Fo`0203co00H0l?l000<0U_l00?3o003`o`002P3`o`06
0?nd01l0oeX0203o]0020?3o000709Ko000lo`00??l0003o7P3o000007So03co000209Ko00<0l?l0
0P3o]0000`3`o`00U_l00?nd00030?nd00030?mJ003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool001/0oooo00<000000?ooo`3oool00P3oool0102Fo`00??l003co000lo`030?3o0080U_l0
00<00?lN0?l00000om800P2Fo`000`3`o`00ok@00?nd000;0?nd0100oeX0603o]0030?3o0080U_l0
00@0??l009Ko002Fo`00l?l0202Fo`002000oah0??l0003o7P00oah0??l0003o7P0lo`000?mh0P00
d_l20?l0FP04000No`0l0?l0?03o0?00o`8007So0P0l0?l010007_l00=;o001ho`00N?l2003Bo`03
001ho`007_l001ko0080?03o00<0UP3o0?l0FP3o00000P3`0?l0100l0?l001ko0?l00000N?l209H0
o`03001ho`3o00000=;o00<00?oB00H00?mh003odP00oah00?lN03co0000om82003o7P800?oB00<0
o`00001ho`00oah00P00oah203co0006003o7P0lo`00??l003co002F0?l0??l00`2Fo`070?3o0003
003o7P3`o`00l?l00080l?l03`3o]00L0?mJ00030?3o003o]000ok@000@0ok@01@3`o`0209Ko0004
003o7P00N?l00?lN03co00800?lN0P3`o`050?nd00030?3o003o]000ok@00080oeX0103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`0409Ko000lo`00??l003co
00<0l?l00P2Fo`000`00oah0o`00003odP0209Ko00030?3o003o]000ok@000/0ok@0403oFP0H0?nd
00<0l?l00P2Fo`00100lo`00U_l009Ko003`o`0809Ko0008003o7P0lo`000?lN003o7P0lo`000?lN
03co0000ogP2003Bo`80o`1J00@001ko03`0o`0l0?l0l03o0P00N?l203`0o`04000No`00d_l007So
001ho`800=;o00<007So000No`007_l00P0l0?l00`2F0?l0o`1J0?l000020?00o`0403`0o`007_l0
o`00001ho`80UP3o00<007So0?l00000d_l00`00om801P00ogP00?oB003o7P00oah0??l0003odP80
0?lN0P00om800`3o000007So003o7P02003o7P80??l000H00?lN03co000lo`00??l009H0o`0lo`03
09Ko00L0l?l000<00?lN0?3o003`o`000P3`o`0?0?nd01`0oeX000<0l?l00?nd003o]000103o]005
0?3o0080U_l000@00?lN001ho`00oah0??l00P00oah20?3o00D0ok@000<0l?l00?nd003o]0000P3o
FP040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo103o]003
0?3o0080??l000<0U_l00?l0]02Fo`000`3`o`0=0?nd0080l?l000<0ok@00?mJ003oFP002P3oFP0I
0?nd0080l?l000<0U_l00?3o003`o`00203`o`0309Ko0003003oN02Fo`00U_l000<0U_l00P0lo`00
1P00oah00?mh003oN000ogP0?03o000No`80UP3o00<0o`000?00o`2F0?l00P3`0?l0103o0;@0o`00
000No`00N?l203`0o`03001ho`007_l001ko008001ko0P0l0?l00`2F0?l0o`1J0?l0FP020?l00004
0?l0]03`0?l0o`000?l00080o`2d00H0?03o0?l0]03o0;@007So09H0o`007_l3001ho`03003Bo`00
ogP00?oB00800?lN00<00?mh003o7P00ogP00`2Fo`0203co00<0U_l000<0??l0003oN00lo`000P2F
o`0:0?3o0140ok@0703oFP020?nd0080l?l000<00?mh0?3o003`o`000P3`o`000`00om80U_l009Ko
000203co0004003oN03`0?l00?lN09Ko00<0l?l02@3o]0020?mJ00@0oooo00<000000?ooo`3oool0
0`3oool001/0oooo00<000000?ooo`3oool00P3oool60?nd000609Ko003`o`00l?l00?3o0000oah0
U_l00`3`o`0<0?nd00030?3o003o]000ok@000H0ok@00P3oFP040?nd00030?3o003o]000ok@001P0
ok@03@3`o`02003o7PL0U_l00P0lo`02003o7P03001ho`00ogP00?oB0080l03o00<0?03o0?l0]02F
0?l00P3o05X0103o0000l03o0?l0000l0?l209H0o`H001ko00P0l03o000No`3o0000o`0003`0o`2F
0?l0o`0003`0o`<0o`1J00D0l03o09H0o`007_l001ko001ho`02003Bo`800?lN1`0lo`000`00d_l0
U_l009Ko000309Ko000603co002Fo`00U_l009Ko000lo`000?mh0`2Fo`080?3o01@0ok@06P3oFP06
0?nd00@0l?l000<00?oB03co0000om800P00d_l01000N?l00=;o003o7P2Fo`030?3o00L0ok@0103o
FP040?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3oool60?nd00@0l?l000H00?lN
03co0000oah00?lN09Ko003`o`0;0?nd00030?3o003o]000ok@002L0ok@03`3`o`0709Ko00@0??l0
00<00?lN003oN000d_l00`00N?l0203`0?l007So0?l0FP3o05X0?03o0?l0]03o0000o`1J0P2F0?l0
0`3o000001ko000No`02000No`<007So0P3o05X01000N?l001ko0?l0FP00N?l2000No`03001ho`0l
0?l007So00<00?oB0P00ogP2003o7P80??l000H00?lN09Ko002Fo`00U_l003co0000om8509Ko0003
03co002Fo`00U_l000<0U_l000<0??l009Ko002Fo`001`3`o`0F0?nd01P0oeX02@3o]0040?3o0004
09Ko000lo`00??l00?l0]0<00?lN0`2Fo`000`3`o`00ok@00?nd00040?nd00@0oeX00`3oool20000
00D0oooo000K0?ooo`030000003oool0oooo0080oooo1`3o]0020?3o000303co0000oah0??l000@0
l?l02@3o]0000`3`o`00U_l00?nd000?0?nd0003003o7P3o]000ok@001L0ok@03`3`o`0709Ko0080
??l00P00oah2003oN003003Bo`00om800?oB00800?oB00L00=;o0?00o`3`0?l007So000No`0l0?l0
UP3o0080o`0000<0UP3o03`0o`0l0?l00P007_l00`00N?l00=;o003Bo`0203`0o`800=;o00L001ko
003Bo`00d_l00=;o003odP00N?l00=;o00800?oB00<00?lN0?l0FP00oah00P0lo`000`00oah0??l0
09Ko000509Ko000303co002Fo`00U_l000<0U_l0103`o`0509Ko00D0l?l0603o]00E0?mJ00/0ok@0
103`o`001@2Fo`00??l003co0000N?l00?oB0080U_l00P0lo`000`00oah0U_l00?3o00050?nd00@0
oeX0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`L0ok@0
0`3`o`000`2Fo`000?mh0?3o00040?3o00H0ok@00P3`o`000`00om80ok@00?nd000?0?nd00<0l?l0
5`3o]00?0?3o00H0U_l00P0lo`03003oN003000No`00ogP00?mh008007So00<00?mh003odP3o0000
0P00om801000d_l007So001ho`007_l209H0o`030?l0003`0?l001ko00<001ko1@00d_l00`00om80
01ko001ho`02003odP03003oN000om800?oB008007So0P00oah403co00/0U_l02P3`o`000`2Fo`00
0?lN0?3o00030?3o01X0ok@04P3oFP0>0?nd00030?3o002Fo`000?oB00800?lN00@007So09Ko003`
o`00l?l00P2Fo`030?3o0080??l000<00?lN0?nd003o]000103oFP040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo1`3o]0030?3o000309Ko0000ogP0l?l000@0
l?l01P3o]0020?3o0003003odP3o]000ok@000l0ok@00`3`o`0G0?nd00l0l?l01P2Fo`0203co00<0
0?mh00<001ko003oN000ogP00P00N?l00`00ogP00?oB0?l00002003odP04003Bo`00N?l007So000N
o`80UP3o00<0o`000?00o`007_l00`007_l5003Bo`03003odP007_l007So00800?oB00<00?mh003o
dP00om800P00N?l2003o7P@0??l02`2Fo`0:0?3o000309Ko0000oah0l?l000<0l?l06P3o]00B0?mJ
00h0ok@000<0l?l009Ko0000om800P00oah01000N?l0U_l00?3o003`o`0209Ko00<0l?l00P0lo`00
0`00oah0ok@00?nd00040?mJ00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3oool70?nd00<0l?l000@0U_l0003o7P0lo`00??l00P2Fo`020?3o0080U_l00`3`o`02
003oN0030?3o003o]000ok@00100ok@00P00oahG0?nd00l0l?l00`2Fo`0203co0004003Bo`00ogP0
0=;o003Bo`8001ko00<00?lN003oN000oah00P00oah00`00ogP0?03o003odP02003odP0409H0o`00
d_l00=;o0?l00080?03o00<0o`0009H0o`0l0?l00P00N?l2003Bo`<00?oB00@00=;o003odP00om80
0=;o1@00ogP20?l00003003odP00oah0??l000<0??l02P2Fo`0>0?3o0080U_l0703o]00?0?mJ0100
ok@00`3`o`02003oN00303co002Fo`00U_l000<0l?l0203o]0040?mJ00@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3oool60?nd00<0l?l00P2Fo`03003oN00403co
002Fo`00l?l00?3o00800?lN00<0l?l009Ko000lo`000P3`o`0C0?nd0080U_l000<0l?l00?nd003o
]0004`3o]00@0?3o00D0U_l00P00oah01@0lo`000?mh003o7P00oah0??l000@00?lN00<007So003o
dP00ogP00P00ogP2003odP04003Bo`00N?l0?03o03`0o`80o`2d00<0UP3o001ho`00N?l00P00d_l3
003odP<00?mh00<001ko003oN000ogP00`00oah2000No`030?00o`00ogP00?lN0080UP3o00<0??l0
09Ko002Fo`001P2Fo`0B0?3o0200ok@01`3oFP050?nd000309Ko003o]000ok@000`0ok@00`3`o`02
003o7P0409Ko003`o`00l?l00?3o00X0ok@0103oFP040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo1@3o]0050?3o000409Ko0000oah00?oB003odP80??l00P2F
o`0203co0003003o7P2Fo`000?lN0080l?l04`3o]0020?3o000303co003`o`00ok@001<0ok@0403`
o`0709Ko00H0??l01@00oah3003oN004003odP00N?l007So000No`<0o`0000<0o`2d0?00o`007_l0
0P007_l0100l0?l007So003odP00om84003oN08001ko1P00oah01000d_l0o`00003o7P00oah203co
00H0U_l04`3`o`0L0?nd00030?3o003o]000ok@000h0ok@000<0l?l00?nd003o]0002`3o]0000`3`
o`00??l009Ko0002003Bo`0309Ko003`o`00l?l000/0ok@0103oFP040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo0P3o]0080?3o000803co0000oah0l03o0?00
o`00oah0U_l003co0000oah2003odP03003o7P3`o`00l?l00080l?l04`3o]00309Ko0080l?l04@3o
]00@0?3o00X0U_l01P0lo`04003o7P04003oN000om800?oB003odP800=;o00<007So000No`007_l0
0P3o0;@00`007_l007So001ho`02003Bo`<007So00<00?oB003oN000ogP00`00oah00`00d_l00?lN
003o7P07003o7P03000No`0lo`00??l000D0U_l04`3`o`0K0?nd00030?3o003o]000ok@000l0ok@0
0`3`o`090?nd00@0l?l000<0U_l0003odP00om800P0lo`000`3`o`00ok@00?nd00090?nd00@0oeX0
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`80ok@0203`
o`00200lo`000?lN0?00o`3`0?l00?lN09Ko000lo`000?lN0P00om800`00oah0l?l00?3o00020?3o
01<0ok@00`2Fo`020?3o0140ok@0403`o`0:09Ko00H0??l01000oah01000ogP00?oB003odP00om82
003Bo`03001ho`007_l001ko0080o`2d00<001ko001ho`00N?l00P00d_l3001ho`03003odP00ogP0
0?mh00<00?lN00<00=;o003o7P00oah01`00oah00`007_l0??l003co000509Ko01<0l?l06`3o]000
0`3`o`00ok@00?nd000?0?nd00<0l?l02@3o]0040?3o000309Ko0000om800?oB0080??l000<0l?l0
0?nd003o]0002@3o]0040?mJ00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3oool00`00ogP0U_l00?3o00030?3o000303co002Fo`00U_l00080U_l000@00?lN000N
o`007_l00?oB0P00oah01P0lo`00U_l009Ko002Fo`00??l00?3o01D0ok@00P3`o`00102Fo`00??l0
0?3o003`o`0?0?nd00@0l?l000<00?oB0?3o003`o`002@3`o`0;09Ko00D0??l01@00oah4003oN003
003odP00d_l001ko0080?03o00<0o`2d0?l0002F0?l00P3o00000`007_l00?oB003odP04003oN0D0
0?lN1P0lo`001@00oah0??l003co0000om80??l000@00?lN00<0??l009Ko003`o`00403`o`0M0?nd
0003003o7P3o]000ok@00100ok@00P2Fo`000`3`o`00ok@00?nd00050?nd00D0l?l00`2Fo`030?3o
00d0ok@00P3oFP040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo00L0l?l0003o7P2Fo`00U_l003co00007_l007So00800?lN00<0?03o001ho`007_l00P0l0?l0
1000om800?lN09Ko002Fo`050?3o01D0ok@00`3`o`0209Ko000403co003`o`00l?l00?3o00/0ok@0
1P3`o`00100lo`00U_l009Ko002Fo`050?3o00d0U_l0100lo`02003o7P800?oB1@00ogP01000om80
0=;o003Bo`00N?l2000No`80o`2d00H0UP3o001ho`00N?l00=;o001ho`00d_l4003oN0D00?lN1P0l
o`000`00oah0??l003co000809Ko01<0l?l06@3o]0030?3o0180ok@00P3`o`000`2Fo`00l?l00?3o
00030?3o0003001ho`3`o`00l?l000@0U_l000<0??l009Ko002Fo`000`3`o`0=0?nd0080oeX0103o
ool00`000000oooo0?ooo`030?ooo`00203oool2000000@0oooo0P0000030?ooo`D000000`3oool0
0`000000oooo0?ooo`020?ooo`050?nd003`o`00??l003co003`o`00102Fo`000`0lo`00U_l003co
0002003odP04003Bo`00oah0??l009Ko00D0l?l05@3o]0030?3o0003003oN00lo`00l?l000<0l?l0
00@0U_l00?3o003`o`00l?l0103o]00:0?3o0080U_l000<00?lN09Ko002Fo`001P2Fo`02003odPP0
U_l000H0??l0003o7P00oah00?mh003Bo`00ogP3003Bo`04003odP007_l00?oB003odP800=;o00L0
07So000No`3`0?l0l03o0?l0]03o0000UP3o00<001ko00<00=;o003odP00ogP00P00ogP00`0l0?l0
0?mh003o7P02003o7P03000No`0lo`00??l000D0??l02P2Fo`0C0?3o01T0ok@00P0lo`000`3`o`00
ok@00?nd000B0?nd00040?3o0000ogP0U_l009Ko0080l?l000<0U_l00?3o003`o`000P3`o`000`00
oah0??l0003Bo`0409Ko00030?3o003o]000ok@000`0ok@000<0oeX00?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool20?nd00<0l?l000@0l03o0?3o003`o`00l?l00P2Fo`00
1@00om800?lN003o7P00d_l0??l00080U_l01@3`o`0E0?nd00@0l?l000D00?lN09Ko003`o`00l?l0
09Ko000D0?3o000409Ko000lo`000?lN09Ko0080??l00`2Fo`0303co00H0U_l01@0lo`02003o7P<0
0?oB00@00?mh000No`00om800?oB0P00d_l01`2F0?l0o`000?l0003o0000o`1J0?00o`3o0;@00`3o
00001P007_l007So003odP00om800=;o003odP@00?mh0P00oah503co00/0U_l04`3`o`0H0?nd0003
0?3o002Fo`00U_l001H0ok@000<0l?l009Ko000lo`000P2Fo`000`00om80l?l00?3o000309Ko0005
003o7P2F0?l0??l003co0000oah00`3`o`0:0?nd0080l?l000<0ok@00?mJ003oool00`3oool00`00
0000oooo0?ooo`030?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo0P0000030?ooo`80ok@00`3`o`00103`0?l0l?l00?3o003`o`0209Ko0005003odP00oah0
0?lN003Bo`0lo`000P2Fo`050?3o01D0ok@0103`o`001@00oah0U_l00?3o003`o`00U_l001@0l?l0
00@0U_l003co0000oah0U_l00P0lo`0309Ko00<0??l01P2Fo`0503co00800?lN0`00om801000ogP0
01ko003odP00om82003Bo`0709H0o`3o0000o`000?l0003o05X0l03o0?l0]0030?l00006000No`00
N?l00?oB003odP00d_l00?oB1000ogP2003o7PD0??l02`2Fo`0C0?3o01P0ok@000<0l?l009Ko002F
o`005P3o]0000`3`o`00U_l003co000209Ko0003003odP3`o`00l?l000<0U_l000D00?lN09H0o`0l
o`00??l0003o7P030?3o00X0ok@00P3`o`000`3o]000oeX00?ooo`020?ooo`8000001@3oool00003
0?ooo`0000000000008000000P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool40?nd000309Ko003`o`00l?l000<0l?l00P2Fo`02001h
o`040?l00000d_l0??l0003oN080??l000<0U_l00?3o003`o`005@3o]0040?3o0080??l00P00oah0
0`2Fo`00l?l00?3o000C0?3o000303co002Fo`000?mh00800?lN00<0??l009Ko000lo`000P00ogP0
0`3o0;@0??l009Ko000209Ko00P0??l01000oah4003oN004003odP00d_l0UP3o0?l00080UP3o00<0
o`0009H0o`007_l00P007_l00`00N?l00?oB003Bo`02003odP04003Bo`00om8001ko0?l0FP800=;o
00<00?mh003o7P00oah0100lo`0<09Ko0180l?l05`3o]000103`o`00U_l00?3o003`o`0F0?nd0003
09Ko003`o`00U_l000<00?lN00@0U_l003co002Fo`00U_l00P00oah01000d_l0??l003co002Fo`06
0?3o00D0ok@00P3`o`040?nd00@0oooo00<000000?ooo`3oool00`3oool000L0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo1@3o]005
0?3o0005003o7P0lo`000=;o003Bo`007_l00P00oah00`00d_l0U_l009Ko00030?3o01D0ok@00`3`
o`000`2Fo`000?lN0?l0]00209Ko01H0l?l00P2Fo`03003oN00303`0o`0lo`000?lN00800?oB1P0l
o`000`00oah0??l003co000403co00D00?lN0`00ogP2003odP07003Bo`00N?l0UP3o09H0o`3o0000
l03o000No`02003Bo`0309H0o`00d_l00?oB00800?mh00@00?oB003oN000d_l00?oB0P00ogP5003o
7P80??l0302Fo`0B0?3o000309Ko003o]000ok@001<0ok@00P3`o`000`00d_l0l?l00?3o000F0?nd
00<0l?l00P3o0;@00`0lo`000=;o003o7P0203co0003003o7P00om800?oB0080??l00P2Fo`000`3`
o`00U_l00?3o00040?3o00800?oB00<0l?l00?nd003o]000103o]0040?ooo`030000003oool0oooo
00<0oooo00080?ooo`8000002P3oool2000000D0oooo00<000000?ooo`3oool00P3oool50?nd00@0
l?l01@0lo`001000om800?lN09Ko002Fo`070?3o0180ok@01@3`o`000`2Fo`000?mh09Ko000209Ko
00D0l?l000<0U_l00?3o003`o`003@3`o`000`2Fo`000?mh09Ko000209Ko000303co0000oah001ko
0080o`0000<00?oB001ho`0lo`000`0lo`000`00om80??l003co000403co00D00?lN0`00om801000
N?l00?oB003Bo`00N?l203`0o`030?l0000l0?l007So00800=;o0P00om85003oN0D00?lN1P0lo`0;
09Ko000403co002Fo`00U_l009Ko00`0l?l000<0??l00?3o003`o`000P3`o`0B0?nd00<0l?l000@0
??l009Ko003`o`00l?l05`3o]000103`o`00U_l00?3o003`o`0209Ko00<0??l000<0UP3o000No`3`
0?l00P00oah303co0006003oN00lo`00??l0003Bo`2Fo`00??l00P3`o`070?nd00@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool60?nd000309Ko003`o`00l?l0
0080l?l00`2Fo`000`0lo`000?lN09Ko00090?3o0140ok@01P3`o`000`2Fo`000?oB003odP0209Ko
00<0l?l000<0U_l0003o7P3`o`003`3`o`0509Ko000703co0000om8007So001ho`3`0?l00?oB003o
7P0203co0003003o7P3o05X00?lN00@0??l00P00oah5003oN0800?oB00@007So000No`00N?l001ko
0P2F0?l00`3o0000l03o000No`04003Bo`04003odP00ogP00?mh003oN0D00?lN1`0lo`0:09Ko0003
03co002Fo`00U_l000@0U_l01@3`o`0409Ko000303co003`o`00l?l000@0l?l03`3o]0050?3o0004
003oN03`o`00l?l00?3o01L0ok@01@3`o`0209Ko0080??l000<00?mh0?l0FP00ogP0100lo`001`00
oah0??l009Ko002Fo`00l?l009Ko003`o`002@3o]0040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo1P3o]0060?3o00<0U_l000<00?lN09Ko003`o`00203`o`0@
0?nd00L0l?l000H0U_l003co000lo`00??l0003o7P2Fo`02003oN080??l0403`o`0409Ko000303co
0000oah00?mh00@00?mh00D00?oB003o7P00oah00?mh0?00o`07003o7P800=;o00<001ko003oN000
ogP00`00om800`00d_l007So03`0o`020?l0FP030?l0003`0?l0UP3o008007So00<00=;o0?l0]000
d_l00`00ogP5003o7PP0??l0202Fo`000`0lo`000?lN09Ko000909Ko00@0??l000<0U_l00?3o003`
o`001`3`o`0;0?nd000409Ko003`o`00l?l00?3o0080U_l000<0??l0003o7P3`o`000P3`o`0G0?nd
00H0l?l000H0U_l0003Bo`00d_l00?mh03`0o`00ogP203co0080U_l000@0l?l009Ko002Fo`00U_l0
0P3`o`0:0?nd00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3o
ool60?nd00H0l?l00`2Fo`000`00oah0U_l00?3o00080?3o0100ok@01`3`o`001P2Fo`00??l003co
000lo`000?lN09Ko00800?mh0P0lo`0@0?3o00@0U_l000<0??l0003o7P00ogP01000ogP01@00om80
0?lN003o7P00ogP0l03o00L00?lN0P00d_l00`007_l00?mh003oN003003odP03003Bo`00N?l0?03o
0080o`1J00<0o`000?00o`2F0?l00P00N?l00`00d_l0o`2d003Bo`03003oN0D00?lN200lo`0809Ko
000303co0000oah0U_l000T0U_l0100lo`000`2Fo`00l?l00?3o00070?3o00/0ok@000@0U_l00?3o
003`o`00l?l00P2Fo`000`0lo`000?lN0?3o00020?3o01L0ok@01P3`o`001P2Fo`000=;o003Bo`00
ogP0?03o003oN080??l00P2Fo`00103`o`00U_l009Ko002Fo`020?3o00X0ok@0103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`H0ok@01P3`o`0309Ko0003001h
o`2Fo`00U_l000L0l?l000<0U_l00?3o003o]0003@3o]0080?3o000609Ko000lo`00??l0003Bo`0l
o`00U_l00`00oah00`2Fo`00l?l00?3o000>0?3o0080U_l00P0lo`000`00oah0??l003co000203co
0003003oN000oah00?mh00800?lN00<00=;o000No`00om800`00oah00`00om800?lN003o7P02003o
N0<00?oB0P00d_l01000om8007So001ho`0l0?l20?l0]0030?l0003o0;@007So00800=;o0P00om84
003oN0D00?lN2`0lo`0209Ko000303co0000oah00?lN0080??l01@2Fo`001P0lo`00U_l009Ko000l
o`000?lN003odP<0U_l03P3`o`030?nd00X0l?l000<00=;o09Ko002Fo`000P3`o`0G0?nd00D0l?l0
0P2Fo`02003o7P03003oN000om80??l00080??l000<0U_l00?3o003`o`00103`o`0;0?nd00@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool60?nd00H0l?l00`2F
o`000`00oah0??l003co000209Ko0080l?l000<0U_l0003o7P00oah01@3`o`090?nd00@0l?l000<0
U_l00?3o003`o`000P3`o`0209Ko0080??l000<007So003o7P00oah00P0lo`0309Ko00l0l?l01@2F
o`0703co00800?lN00@00=;o0?00o`00om800?oB0P3o0;@00`00om800?mh003oN002003oN003003o
dP00d_l00=;o0080o`1J0P00d_l01`3`0?l0UP3o0?l0]03o0;@0o`0009H0o`0l0?l00P007_l00`00
d_l00?oB003odP02003oN003003odP00ogP0?03o00<00?lN1`0lo`000`00om80??l003co000203co
0007003o7P0lo`00??l003co0000om800?lN03co000309Ko000603co0000ogP0??l003co0000oah0
0?mh0P2Fo`0H0?3o000309Ko003`o`00l?l00080U_l000<00?oB0?3o003`o`000P3`o`0G0?nd0080
l?l00`2Fo`001`0lo`000?lN003o7P00oah0?03o003odP0lo`000`2Fo`050?3o00`0ok@0103oool0
0`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`D0ok@01`3`o`0209Ko
000303co0000ogP00?lN00@0U_l000<00?lN09Ko003`o`002@3`o`030?nd00P0l?l00P00oah209Ko
0007003odP0lo`00??l003co0000d_l0?03o003o7P0203co00<0U_l03`3`o`0909Ko00<0??l00P00
oah01000N?l00?lN003o7P00oah2003oN003003odP00d_l00=;o00<007So00<0l03o000No`00N?l0
0P00N?l00`3`0?l001ko03`0o`020?00o`030?l0000l0?l001ko00<007So00H00=;o003odP00d_l0
0=;o03`0o`00om85003o7PD0??l000<00?mh003o7P0lo`000`0lo`001@00ogP0??l003co000lo`00
o`2d00800?lN0P0lo`000`00oah00?mh001ho`0203co00<0U_l06P3`o`001@00ogP0??l0003o7P00
oah007So00D0l?l05P3o]0040?3o00<0U_l00P0lo`000`00om800?mh003o7P02003odP0309Ko003`
o`00l?l000<0l?l0303o]0040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooo1@3o]0000`3`o`00U_l00?3o00020?3o00@0U_l000@0??l0003oN0007_l00?lN0P00
d_l00`0lo`00U_l00?3o000G0?3o0080U_l000L00?mh03co0000oah00?lN003oN03`0?l00?mh0080
??l0102Fo`0=0?3o00/0U_l000@0??l0003o7P00oah00?lN0P0lo`02003o7P800?mh00<00?lN003o
N000ogP00P00d_l20?l000030?00o`0l0?l0?03o0080UP3o00D001ko09H0o`3o0;@0o`2d0?l00002
09H0o`<001ko1000d_l00`00om800?mh003o7P09003o7P03003oN000oah0??l000<0??l000<00?mh
003o7P00om800P00om801@00ogP00?oB003Bo`00d_l00?lN0080??l00P00oah309Ko0140l?l00P00
oah70?3o000609Ko000lo`0001ko000No`0lo`00U_l00`3`o`000`0lo`00ok@00?nd000C0?nd00L0
l?l000H0U_l0003o7P00oah00=;o03co002Fo`0203co000309Ko000lo`00U_l000<0l?l0303o]004
0?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo1@3o]0000`3`
o`00U_l00?3o00020?3o00@0U_l000@0??l0003oN0007_l00?lN0P00d_l00`0lo`00U_l00?3o000G
0?3o0080U_l000L00?mh03co0000oah00?lN003oN03`0?l00?mh0080??l0102Fo`0=0?3o00/0U_l0
00@0??l0003o7P00oah00?lN0P0lo`02003o7P800?mh00<00?lN003oN000ogP00P00d_l20?l00003
0?00o`0l0?l0?03o0080UP3o00D001ko09H0o`3o0;@0o`2d0?l0000209H0o`<001ko1000d_l00`00
om800?mh003o7P09003o7P03003oN000oah0??l000<0??l000<00?mh003o7P00om800P00om801@00
ogP00?oB003Bo`00d_l00?lN0080??l00P00oah309Ko0140l?l00P00oah70?3o000609Ko000lo`00
01ko000No`0lo`00U_l00`3`o`000`0lo`00ok@00?nd000C0?nd00L0l?l000H0U_l0003o7P00oah0
0=;o03co002Fo`0203co000309Ko000lo`00U_l000<0l?l0303o]0040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`8000000`3oool50?nd00@0l?l00P2Fo`001`00oah00?oB003odP3o00000?mh
001ho`0lo`00102Fo`0I0?3o00<0U_l00P0lo`000`00ogP001ko003oN003003o7P0303co002Fo`00
U_l00080U_l02P3`o`0<09Ko00L0??l01@00oah01P00ogP001ko000No`00d_l0o`0009H0o`80o`1J
0P3o00001P3o0;@0UP3o09H0o`2F0?l0l03o0?l000<0o`1J00<0?03o000No`3`0?l00P00d_l2003o
dP05003oN000oah00?lN003o7P00om800P00oah2003odP03003o7P00om800?lN0080UP3o0P00oah0
1`00ogP007So001ho`00N?l0o`00001ho`00ogP00P00oah00`0lo`00U_l009Ko000209Ko0003001h
o`2Fo`00l?l00140l?l00P0lo`070?3o000409Ko0000oah00?lN003o7P80U_l0103`o`0E0?nd00L0
l?l00`2Fo`000`2F0?l0??l009Ko00060?3o00h0ok@00`3oool2000000D0oooo000K0?ooo`030000
003oool0oooo0080oooo103o]0070?3o00@0U_l000<00?lN0?l0000lo`000`2Fo`0<0?3o000309Ko
003`o`00l?l000/0l?l00`2Fo`0203co0003003o7P00om80UP3o00800?lN00<0??l009Ko002Fo`00
102Fo`070?3o00h0U_l0200lo`04003o7P04001ho`00om800?oB0?00o`8007So0`0l0?l20?l0]0<0
UP3o00<0?03o09H0o`2F0?l00P3o00000`3o05X0o`000?l0]0020?l0]003001ho`00om800?mh00<0
0?mh00<00?oB003oN000ogP00`00om802000N?l00=;o003oN000ogP0l03o003Bo`3o05X007So0P00
om800`00ogP0?03o003o7P0203co00L0U_l04P3`o`020?l0000309Ko003`o`00l?l000<0l?l00P2F
o`001000oah0U_l009Ko002Fo`060?3o01<0ok@0203`o`0309Ko0003003o7P2Fo`00U_l000H0l?l0
3P3o]0040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo0P3o
]00:0?3o00<0U_l000<0l03o003Bo`0lo`000P0lo`000`2Fo`00l?l00?3o00090?3o0080U_l03P3`
o`0209Ko00800?lN00<00?oB003o7P0l0?l00P00oah00`0lo`00U_l009Ko000;09Ko0080??l0302F
o`0803co00800?mh00<00?oB000No`00N?l01000om801P3o05X007So001ho`3`0?l0?03o0?l000<0
l03o00<001ko03`0o`007_l00`0l0?l209H0o`80o`0000@007So000No`00d_l00?oB0`0l0?l01`00
d_l00?oB0?00o`3`0?l007So000No`3`0?l00P00om83003o7P06003oN000oah00?lN003o7P00om80
0?mh0P00oah609Ko01<0l?l00P2Fo`000`00ogP0??l009Ko000409Ko000403co0000oah0??l003co
00P0l?l0403o]00:0?3o00<0U_l000<00?lN09Ko003`o`001P3`o`0>0?nd00@0oooo00<000000?oo
o`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool<0?3o00@0U_l00P0lo`0309Ko00/0
l?l00P2Fo`0>0?3o00D0U_l000<0??l0003o7P0lo`000P0lo`0509Ko000303co002Fo`00U_l000L0
U_l000<0??l009Ko002Fo`002@2Fo`0803co00@00?lN00D0o`00003oN000ogP00?mh003odP03003B
o`04001ho`0l0?l0o`000?l00080?03o00<001ko001ho`00N?l00P3o00000`00d_l0?03o003Bo`04
003odP@00?mh00<007So003oN000oah00P00d_l3003oN0<00?lN0P0lo`03003o7P80??l000@001ko
003o7P00oah0??l01@2Fo`0C0?3o00<0??l000<0?03o03co002Fo`000P2Fo`0303co0080U_l0203`
o`0209Ko00d0ok@0103`o`000`007_l0l?l00?3o00030?3o0080U_l00P00oah00`0lo`00U_l009Ko
00080?3o00`0ok@0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?ooo`030?l0003`o`00l?l000/0l?l00P2Fo`0203co00@0U_l02@3`o`000`2Fo`00??l009Ko000>
0?3o00H0U_l000<00?oB003Bo`00d_l00P0lo`0209Ko00<0??l02@2Fo`0203co00X0U_l000<00?lN
03co000lo`00100lo`05003o7P@00?mh0P00om82003Bo`04001ho`0l0?l0o`000?00o`80?03o00<0
UP3o001ho`00d_l00`007_l01000om8001ko003odP00om82003oN0@00?lN00<00?mh003o7P00oah0
0P00ogP2003o7P03003Bo`00om800?oB00T0??l00P00oah00`0l0?l0??l009Ko000309Ko01<0l?l0
0`2Fo`002000ogP00?lN09Ko002Fo`00??l0003o7P3o00000?lN0P00om800`2Fo`00l?l00?3o0004
0?3o000403co003`o`00l?l00?3o00/0ok@01P3`o`00100lo`00U_l003co000lo`0209Ko000603co
0000ogP00?mh003Bo`0lo`00U_l0203`o`0<0?nd00@0oooo00<000000?ooo`3oool00`3oool001/0
oooo00<000000?ooo`3oool00P3oool00`3o0000l?l00?3o000;0?3o0080U_l00P0lo`0409Ko00T0
l?l000<0U_l003co002Fo`003P3`o`0609Ko0003003odP00d_l00=;o0080??l00P2Fo`0303co00T0
U_l00P0lo`0:09Ko0003003o7P0lo`00??l000@0??l01@00oah4003oN0800?oB0P00d_l01000N?l0
?03o0?l0003`0?l203`0o`0309H0o`00N?l00=;o00<001ko00@00?oB000No`00om800?oB0P00ogP4
003o7P03003oN000oah00?lN00800?mh0P00oah00`00d_l00?oB003odP0903co00800?lN00<0?03o
03co002Fo`000`2Fo`0C0?3o00<0U_l000P00?mh003o7P2Fo`00U_l003co0000oah0o`00003o7P80
0?oB00<0U_l00?3o003`o`00103`o`00100lo`00l?l00?3o003`o`0;0?nd00H0l?l000@0??l009Ko
000lo`00??l00P2Fo`001P0lo`000?mh003oN000d_l0??l009Ko00P0l?l0303o]0040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo303`o`0309Ko000303co0000
oah0?03o00800?mh0`2Fo`070?3o0080U_l000<0o`2d09Ko003`o`003@3`o`0609Ko000403co0000
ogP00?mh003oN0D0??l02`2Fo`000`3`0?l0??l009Ko000709Ko00<0??l00P00d_l3003o7P03003o
N000oah00?lN00800?lN00@00?mh001ho`00N?l001ko1000N?l203`0o`050?l0002F0?l001ko000N
o`00N?l00P00d_l2003odP03003Bo`00om800?oB008007So0P00om8;003o7P03003oN000oah00?lN
00@0??l00P00oah203co00@0U_l01@0lo`0C0?3o0080U_l00P0lo`001`00oah00?mh003oN00lo`00
0?oB003Bo`0lo`00102Fo`030?3o0080U_l01P3`o`060?nd00X0l?l000@0U_l0003o7P00oah00?mh
0P0lo`02001ho`030?00o`0lo`00U_l000<0U_l00P3`o`000`2Fo`00l?l00?3o000<0?nd00@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool00`3`o`000?oB0?3o
00090?3o00@0U_l000@0??l0001ho`0lo`00??l01@2Fo`030?3o00<0U_l000<00?lN003oN02Fo`00
0P2Fo`0<0?3o00D0U_l00P0lo`02003oN004003odP00oah00?mh003o7P80??l02`2Fo`000`0lo`00
0?mh03co000<03co0004003oN000om800?lN003Bo`800?mh00<00?lN003oN000ogP00P00ogP2003o
dP04000No`00N?l007So09H0o`<0o`000P0l0?l00`00N?l00=;o003odP03003odP800?mh0P00d_l0
0`00om800?mh003o7P04003o7PH0??l000<00?lN003odP00om80100lo`0=09Ko01<0l?l0102Fo`00
1P00ogP00?lN003o7P3o000001ko003odP@0??l000D0U_l0003oN02F0?l0UP3o09Ko000;0?3o0003
09Ko003`o`00l?l000X0l?l00P2Fo`0203co0006003o7P3o0000o`000?00o`007_l0l03o0P00oah0
0`0lo`00U_l00?3o00040?3o00/0ok@0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?ooo`040?3o002Fo`00U_l009Ko00P0l?l0102Fo`00100lo`000=;o003o7P00
oah;09Ko000303co0000ogP0U_l00080U_l02`3`o`000`2Fo`000=;o09Ko000303co000709H0o`00
oah00?mh003oN03o00000?mh000No`0303co00/0U_l000<0??l0003o7P2F0?l0300lo`02003o7P06
003oN00l0?l00?oB003odP00ogP00?oB0`00ogP2003odP07003Bo`00N?l007So000No`3o05X0o`2d
09H0o`02000No`0303`0o`007_l00=;o00800=;o0`00ogP2003Bo`03003oN000om800?mh00<00?lN
2P0lo`000`00oah0??l003co000?09Ko0140l?l01@2Fo`001`0lo`000?lN003o7P00d_l0UP3o000N
o`00oah00`00ogP01000oah0??l009Ko002Fo`0<0?3o000309Ko003`o`00l?l000X0l?l0102Fo`00
1@00oah0o`000?l00000om80??l000@0U_l01`3`o`0:0?nd00@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3oool01@3`o`00U_l0003Bo`00d_l0U_l000H0l?l01@2F
o`000`0lo`000?lN03co000303co0003003odP2Fo`00U_l000<0U_l00P00oah00`0lo`000?lN03co
000409Ko00T0l?l0102Fo`0203co00800?mh00H00?lN003oN000ogP007So003odP00oah303co00/0
U_l00`00ogP303co0003003o7P0lo`00??l000H0??l00P00oah01`00ogP00?oB003Bo`00d_l0o`2d
003Bo`007_l00P00N?l00`00om8007So003Bo`02000No`80o`2d00@0l03o000No`00N?l007So0P00
d_l010007_l00=;o003Bo`00om84003oN0H00?lN2`0lo`000`00oah0U_l009Ko000>09Ko0140l?l0
00<0??l009Ko002Fo`000P2Fo`001P0lo`000?lN003o7P00om8007So003oN0<0??l000<0U_l003co
002Fo`003P3`o`000`2Fo`00l?l00?3o000<0?3o000309Ko000lo`000?oB0080o`2d00<00?lN09Ko
002Fo`000P2Fo`090?3o00T0ok@0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`050?3o002Fo`000=;o003Bo`2Fo`001P3`o`0509Ko000303co0000oah0??l0
00<0??l000<00?oB09Ko002Fo`000`2Fo`02003o7P0303co0000oah0??l000@0U_l02@3`o`0409Ko
0080??l00P00ogP01P00oah00?mh003oN000N?l00?oB003o7P<0??l02`2Fo`03003oN0<0??l000<0
0?lN03co000lo`001P0lo`02003o7P07003oN000om800=;o003Bo`3o0;@00=;o000No`02001ho`03
003odP00N?l00=;o008001ko0P3o0;@0103`0?l001ko001ho`00N?l2003Bo`04000No`00d_l00=;o
003odP@00?mh1P00oah;03co0003003o7P2Fo`00U_l000h0U_l04@3`o`000`0lo`00U_l009Ko0002
09Ko000603co0000oah00?lN003odP00N?l00?mh0`0lo`000`2Fo`00??l009Ko000>0?3o000309Ko
003`o`00l?l000`0l?l000<0U_l003co0000om800P3o0;@00`00oah0U_l009Ko000209Ko00T0l?l0
2@3o]0040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00<0
l?l009Ko000lo`000P0lo`0709Ko00<0??l000<00?lN03co0000ogP00P00ogP00`0lo`000=;o03co
000509Ko0080??l000@00?mh000No`0lo`00??l00P2Fo`000`0lo`00U_l009Ko00050?3o00P0U_l0
0`0lo`02003o7P04003odP00N?l0UP3o003oN080??l02P2Fo`0303co0005003oN000oah00?lN003o
7P00ogP02@0lo`02003o7P@00?mh0P00d_l203`0o`03003Bo`00N?l007So008001ko00@0?03o0?l0
002F0?l0?03o0P007_l00`00d_l00?oB003odP03003odP03003Bo`00ogP00?lN00D00?lN3P0lo`0A
09Ko00l0l?l0102Fo`02003o7P03003Bo`00oah00?lN008007So0P0lo`0409Ko000303co003`o`00
l?l000`0l?l00P2Fo`0=0?3o0080U_l000<0??l0003Bo`00d_l00P0lo`000`2Fo`00l?l00?3o000;
0?3o000303co003o]000ok@000<0ok@000<0l?l00?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`006`3oool2000000<0oooo00H0l?l009Ko002Fo`00U_l0000No`0lo`0809Ko000403co0000
7_l00?lN003odP<00=;o00<00?lN03co002Fo`000`2Fo`0303co00800?mh00<00?lN03co002Fo`00
1`2Fo`000`0lo`00U_l009Ko000809Ko0080??l00`00ogP00`2F0?l00?lN03co000303co00T0U_l0
0`0lo`001000oah0l03o0?00o`00N?l2003o7PL0??l01000oah4003oN0<00?oB00<007So0?l0]03o
05X00P2F0?l0103`0?l0o`0003`0o`007_l2001ho`03003Bo`00om800?oB00@00?mh1`00oah=03co
01<0U_l03@3`o`0609Ko0080??l00P00oah0103`0?l00=;o003o7P0lo`0409Ko00l0l?l00P2Fo`0;
0?3o00@0U_l000<00?lN003odP00om800`2Fo`0D0?3o00<0oooo0P0000050?ooo`006`3oool00`00
0000oooo0?ooo`020?ooo`070?3o002Fo`00U_l009Ko000lo`000?lN03co0002003oN0D0U_l00P0l
o`001`00oah00?oB03`0o`0l0?l00?mh003o7P0lo`000P00ogP503co0003000No`00ogP0??l000T0
U_l000<0??l009Ko002Fo`002@2Fo`0303co0003003o7P00ogP00?oB00D0??l01P2Fo`0303co0003
003Bo`00ogP00?oB008001ko00<00=;o003oN000d_l01`0lo`06003o7P<00?mh0P00om800`0l0?l0
01ko0?00o`020?l000040?l0]03o05X0o`1J03`0o`8001ko00<007So003odP00om801@00ogP6003o
7Pd0??l05@2Fo`080?3o00X0U_l000@0??l0003odP00om800=;o0`00oah203co0080U_l03`3`o`00
102Fo`000?mh09Ko002Fo`090?3o00800?lN00<0U_l003co0000oah00P00om8309Ko00/0l?l00P0l
o`070?3o00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool0
0`3`o`00U_l009Ko000209Ko00800?mh0P00oah00`0lo`00U_l009Ko000403co0007003o7P00om80
UP3o09H0o`00ogP00?lN003oN00403co00@00?lN0P0lo`0909Ko000303co002Fo`00U_l000T0U_l0
100lo`000`00oah00?mh003o7P02003o7P`0??l00P00oah2003oN0030?l00000ogP00?lN00d00?lN
0P00ogP3003odP03003Bo`00N?l0?03o0080o`1J00@0o`2d09H0o`3o0;@0o`1J0P3`0?l00`0l0?l0
0?oB003odP05003oN0D00?lN00<00?oB003o7P00oah02`0lo`0M09Ko0080??l0202Fo`000`0lo`00
0?lN003o7P02003o7P0303co002Fo`00U_l000<0U_l03`3`o`001@2Fo`00??l003co000lo`00U_l0
00L0l?l0102Fo`001`0lo`000?lN003oN000ogP00?lN03co002Fo`002`3`o`0209Ko00L0l?l0103o
ool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030?3o002Fo`00
U_l00080U_l00P00ogP2003o7P0303co002Fo`00U_l000@0??l000L00?lN003odP2F0?l0UP3o003o
N000oah00?mh00@0??l01000oah203co00T0U_l000<0??l009Ko002Fo`002@2Fo`0403co0003003o
7P00ogP00?lN00800?lN300lo`02003o7P800?mh00<0o`00003oN000oah03@00oah2003oN0<00?oB
00<00=;o001ho`0l0?l00P3o05X0103o0;@0UP3o0?l0]03o05X20?00o`0303`0o`00om800?oB00D0
0?mh1@00oah00`00om800?lN003o7P0;03co01d0U_l00P0lo`0809Ko000303co0000oah00?lN0080
0?lN00<0??l009Ko002Fo`000`2Fo`0?0?3o000509Ko000lo`00??l003co002Fo`001`3`o`0409Ko
000703co0000oah00?mh003oN000oah0??l009Ko000;0?3o0080U_l01`3`o`040?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00<0U_l003co000lo`000P0lo`02
003odP800?mh1@0lo`001000oah007So003oN000om820?l00003001ho`3o00000?lN00@0??l000@0
0?mh001ho`00N?l00?lN0P0lo`0909Ko0003003o7P0lo`00U_l000T0U_l00`0lo`001000oah00?mh
03`0o`00d_l2003o7Pd0??l000<00?lN003oN000ogP00P00ogP8003o7P04003oN000om800?lN003o
7P<00?mh00<0?03o003Bo`00d_l00P00d_l020007_l0UP3o0?l0FP3o05X0UP3o03`0o`3o0;@0?03o
1000N?l00`00d_l00?oB003odP02003odPD00?mh00<0?03o003o7P00oah00P00oah:03co0180U_l0
00<00?lN09Ko002Fo`002P2Fo`000`00oah0U_l009Ko000409Ko000403co0000ogP00?oB003odP80
??l01P2Fo`0?0?3o000309Ko000lo`00U_l000<0U_l01@3`o`0609Ko00<00?lN1@2Fo`080?3o00<0
U_l01`3`o`040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo
102Fo`0203co0003003oN000om800?oB00800?lN100lo`000`00oah00?mh003Bo`020?l00003003B
o`00ogP00?lN00800=;o0P00oah01P3`0?l00?lN003o7P00oah00?oB003o7PT0U_l00P0lo`0909Ko
00@0??l000@00?lN003oN0007_l00?mh0P00oah503co0003003o7P0lo`00??l000D0??l01000oah0
103`0?l00?mh003odP00om85003o7P03003oN03o00000?mh00@00?mh00<00?oB003Bo`00N?l00P00
N?l01P3o05X0l03o0?l0003o0000?03o000No`8007So0P00d_l00`00om8007So003Bo`030?l00007
003odP00ogP00?oB003odP00ogP00?oB003oN003003o7P03003oN000oah00?lN00P0??l04@2Fo`02
03co00`0U_l00P0lo`0509Ko0080??l00P00ogP203co00H0U_l03`3`o`00102Fo`00??l0003odP00
om8<09Ko000403co003o00000?lN003o7PD0U_l01`3`o`00102Fo`000?lN09Ko002Fo`070?3o00@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool509Ko00@0??l0
00<00?oB003Bo`00ogP01000oah00`00om8007So09H0o`0209H0o`800?oB0P00ogP00`00om80o`00
003o7P02003o7P<0??l0202Fo`0503co00L0U_l01@0lo`000`00oah00?mh003oN002003o7PD0??l0
00<00?mh003odP0lo`001@0lo`03003o7P800?oB00<007So003oN000ogP01@00oah2003oN003001h
o`00om800?mh00800?mh0P00om82003Bo`03001ho`2F0?l0o`000080o`2d00@001ko001ho`00N?l0
0=;o0P00N?l5003odP03001ho`00d_l007So0080o`2d00@007So03`0o`00om800?mh0P00om800`00
7_l00?lN003o7P02003oN003003o7P00d_l00?lN00@0??l03`2Fo`000`0lo`0007So09Ko000=09Ko
00<0??l00P00om800`0lo`000?lN003o7P02003odP80??l01`2Fo`0=0?3o00<0U_l00P00oah00`0l
o`00U_l009Ko000509Ko0004003o7P0lo`00??l003co00800?lN0`0lo`0209Ko0080??l0202Fo`00
0`0lo`00U_l009Ko00070?3o00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3oool609Ko00<0??l000<00?oB003Bo`00om800P00ogP01000oah00=;o003odP00N?l2
03`0o`0309H0o`00N?l0UP3o008007So00<00?oB003o7P00oah01P0lo`0509Ko00<0??l000<00?oB
003oN00lo`000P0lo`0509Ko00H0??l00P00oah01000d_l00?lN003o7P00oah203co00800?lN00<0
07So003o7P0lo`001@0lo`03003o7P800?mh00@0o`00003odP00om800?mh1000oah01000ogP00?oB
003Bo`00d_l3003odP@00=;o0P0l0?l0103o05X0UP3o09H0o`007_l2003Bo`<00?oB0`00ogP3003o
dP800?mh0P00N?l00`0l0?l001ko000No`03003odP03003Bo`00ogP00?mh00800?mh00<00?lN03co
000lo`00100lo`0>09Ko000303co0000N?l0??l000h0U_l000<0??l0003oN000ogP00P00ogP00`0l
o`000?lN003Bo`02003oN003003o7P0lo`00U_l000D0U_l000<0??l00?3o003`o`002@3`o`0509Ko
0080??l000<00?lN03co0000oah01@2Fo`001P0lo`000=;o003Bo`0lo`000?lN003Bo`800?lN0P0l
o`000`00oah0U_l009Ko000609Ko000303co003o0;@0U_l00080U_l01`3`o`040?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo1P2Fo`0403co0005003o7P00om80
0?mh003oN000d_l00P00N?l01P007_l0o`2d0?l0]03o0;@0o`000?00o`8001ko00<00?mh003o7P00
oah03P0lo`02003o7PP0??l000<00?mh03co000lo`000`0lo`02003o7P03003odP00oah00?lN00<0
0?lN0P00ogP00`00d_l00?lN003o7P02003o7P0303co0000oah00?lN00@00?lN0P00ogP3003odPH0
0?mh00L00?oB000No`00d_l00=;o003odP00d_l0o`00008007So00<001ko0?l0002F0?l00`00N?l0
0`2F0?l00=;o003odP02003odPD00?mh00<00?oB003oN000ogP00`00ogP00`00om800?mh003o7P02
003o7P030?l00000oah00?lN00X0??l02`2Fo`0303co0003001ho`0lo`00U_l000h0U_l000L0??l0
003oN000d_l00=;o003odP00ogP001ko00800?oB00<00?lN03co000lo`000`0lo`000`00d_l0U_l0
09Ko000209Ko00P0l?l01@2Fo`0303co00030?l00000om80??l000D0U_l000H0??l0003o7P00oah0
0?oB003oN03o00020?00o`800?mh00<0??l009Ko002Fo`000`2Fo`001@00ogP0U_l009Ko0000ogP0
??l000<0U_l01`3`o`040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo
0080oooo1P2Fo`0403co0005003o7P00om800?mh003oN000d_l00P00N?l01P007_l0o`2d0?l0]03o
0;@0o`000?00o`8001ko00<00?mh003o7P00oah03P0lo`02003o7PP0??l000<00?mh03co000lo`00
0`0lo`02003o7P03003odP00oah00?lN00<00?lN0P00ogP00`00d_l00?lN003o7P02003o7P0303co
0000oah00?lN00@00?lN0P00ogP3003odPH00?mh00L00?oB000No`00d_l00=;o003odP00d_l0o`00
008007So00<001ko0?l0002F0?l00`00N?l00`2F0?l00=;o003odP02003odPD00?mh00<00?oB003o
N000ogP00`00ogP00`00om800?mh003o7P02003o7P030?l00000oah00?lN00X0??l02`2Fo`0303co
0003001ho`0lo`00U_l000h0U_l000L0??l0003oN000d_l00=;o003odP00ogP001ko00800?oB00<0
0?lN03co000lo`000`0lo`000`00d_l0U_l009Ko000209Ko00P0l?l01@2Fo`0303co00030?l00000
om80??l000D0U_l000H0??l0003o7P00oah00?oB003oN03o00020?00o`800?mh00<0??l009Ko002F
o`000`2Fo`001@00ogP0U_l009Ko0000ogP0??l000<0U_l01`3`o`040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo1P2Fo`0503co00<00?lN00@00?mh09H0o`0l
0?l0o`000P3o0;@00`2F0?l0?03o03`0o`02003odP03001ho`00om800?lN00800?lN0`0lo`000`00
7_l0??l003co000303co00800?mh00<00?lN003odP007_l00P00oah00`00ogP0??l003co000403co
0003003oN00lo`00??l00080??l00P00oah01000d_l00?oB003odP00d_l2003o7P800?mh00<007So
003oN000oah00`00oah00`00om800?lN003o7P03003o7P05003oN000om80o`000?l00000om800P00
ogP2003odP800?mh00@00?oB003Bo`007_l001ko0P00d_l01P00N?l0?03o03`0o`3`0?l0o`00001h
o`8001ko0P00d_l01000N?l001ko003odP00om85003oN00303`0o`00ogP00?mh00<00?mh00<00=;o
003oN000oah01000oah>03co00H0U_l00P0lo`02003o7P03003oN00lo`00??l000l0U_l0100lo`00
0`00oah001ko0?l0FP02000No`040?00o`007_l00?mh03`0o`800?lN1`2Fo`050?3o00D0U_l000L0
0?oB003o7P00oah00?lN003odP00ogP00?oB0080??l00P2Fo`001`00om80??l003co000lo`000?lN
003oN03o00000P00om800`00oah0??l003co000509Ko00<00?lN00<00=;o03co002Fo`000P2Fo`07
0?3o00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool509Ko
00H0??l000L00?mh003odP00om8001ko003odP2F0?l007So00<0l03o00D0o`00003Bo`00om800?oB
003oN005003o7P03003oN0007_l0??l000L0??l000<00?oB003Bo`0l0?l00P00ogP00`00oah0??l0
03co000403co0003003oN000oah00?lN00<00?lN00L001ko0?l0]0007_l001ko003oN000om800?mh
00800?oB00<00?mh003o7P00oah00`00oah00`00ogP00?lN003o7P03003o7P800?mh0P00om800`3o
05X00?oB001ho`02003Bo`@00?oB0P00d_l00`007_l0?03o0?00o`0209H0o`80o`0000<007So003B
o`00d_l00P00om801@00d_l00?oB001ho`00N?l00?oB00@00?mh1P00oah2003oN0@00?lN6@0lo`00
0`3`0?l0o`0003co000?09Ko00@0??l000<00?lN003odP3o00000P00d_l01000oah0??l0003o7P0l
o`0D09Ko0006003o7P0lo`00??l0003oN000N?l00?lN0P0lo`001000d_l0??l003co0000ogP3003o
7P05003odP3o0;@00?oB003odP00oah0100lo`00102Fo`00??l003co0000oah203`0o`03003oN000
d_l0U_l000<0U_l01P3`o`040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooo00@0??l009Ko002Fo`00U_l00P0lo`001000oah0??l003co000lo`04003o7P800?mh
00L00?oB001ho`3o0000o`000?00o`00N?l001ko008007So00<00=;o003oN000oah00P00oah00`00
ogP00?oB003oN00803co0003003o7P00ogP0o`0000<00?lN1P0lo`001000oah00?oB09H0o`2F0?l2
003o7P07003oN000om80o`2d0?l0]00l0?l00?oB003oN0020?l0]00303`0o`00ogP00?lN00<00?lN
0P00ogP3003o7P<00?mh0P00om82001ho`<00=;o0P00om82003Bo`<0UP3o0P3`0?l20?l0000309H0
o`007_l0o`2d008001ko0`00om84003oN003003odP00ogP00?lN00P00?lN00@00?mh003o7P00oah0
0?lN400lo`000`00oah0??l003co000303co00D00?lN0P0lo`0?09Ko0080??l00P00oah00`00ogP0
?03o003Bo`02003o7P<0??l02`2Fo`0203co00T0U_l00P00d_l00`0lo`000?lN003odP03003o7P80
??l000H00?lN000No`007_l00?mh003odP3o0;@2003odP03003oN0007_l0??l000D0??l00`00ogP3
03co00@0U_l01@3`o`040?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3oool00`0l
o`000?lN03co000403co00800=;o1@00oah01000ogP00=;o001ho`007_l30?l0]00403`0o`00d_l0
0?oB003odP<00?mh0P00om800`3o00000?mh003o7P0603co00<00?lN00<00?mh003Bo`00oah00P00
oah503co00800?lN00<0l03o09H0o`2F0?l00`00ogP01P00d_l0l03o0?00o`2F0?l0o`2d003Bo`80
0?oB0`00ogP2003o7P800?mh0P00om83003oN0070?l00000om800?oB003odP00N?l0l03o001ho`02
003Bo`03001ho`00d_l0UP3o00<007So00<0?03o0?l0003o05X00P3o0;@00`007_l007So003Bo`03
003Bo`03001ho`00ogP00?mh00@00?mh3P00oah@03co0003003o7P0lo`00??l000@0??l000@00?lN
09H0o`2F0?l00?lN0P0lo`0?09Ko00@0??l000<00?lN003odP00N?l00`00ogP203co00/0U_l00P00
om8909Ko00@0??l000@00?oB003Bo`00d_l00?lN0P0lo`03003o7P03003odP3`0?l0o`2d0080?03o
00<00?mh003o7P0lo`000`0lo`000`3o00000=;o003o7P0303co00/0U_l00`3oool2000000D0oooo
000K0?ooo`030000003oool0oooo0080oooo00<0??l0003o7P0lo`00100lo`02003Bo`D00?lN00@0
0?mh003Bo`00N?l001ko0`3o0;@0100l0?l00=;o003odP00om83003oN0800?oB00<0o`00003oN000
oah01P0lo`03003o7P03003oN000d_l00?lN00800?lN1@0lo`02003o7P030?00o`2F0?l0UP3o00<0
0?mh00H00=;o0?00o`3`0?l0UP3o0?l0]000d_l2003odP<00?mh0P00oah2003oN0800?oB0`00ogP0
1`3o00000?oB003odP00om8007So0?00o`00N?l00P00d_l00`00N?l00=;o09H0o`03001ho`0303`0
o`3o0000o`1J0080o`2d00<001ko001ho`00d_l00`00d_l00`00N?l00?mh003oN004003oN0h00?lN
400lo`000`00oah0??l003co000403co0004003o7P2F0?l0UP3o003o7P80??l03`2Fo`0403co0003
003o7P00om8007So00<00?mh0P0lo`0;09Ko00800?oB2@2Fo`0403co0004003odP00d_l00=;o003o
7P80??l00`00oah00`00om80l03o0?l0]00203`0o`03003oN000oah0??l000<0??l000<0o`00003B
o`00oah00`0lo`0;09Ko00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3oool2003o7PD0??l00P00ogP00`00N?l00?oB003odP04003oN007003odP00N?l0?03o03`0
o`3o0000l03o003Bo`02001ho`800?oB0`00d_l01000om800?mh003o7P00oah503co00<00?lN00<0
0?mh003odP00oah00P00oah00`00ogP0??l003co000203co00<00?lN0P00ogP01000d_l00?oB003o
dP00N?l20?00o`030?l0]03o05X00=;o00800?oB1P00ogP00`00N?l0?03o003odP03003oN003003o
dP00N?l001ko008001ko00<0o`0009H0o`00N?l00P00N?l00`00d_l007So0?00o`02000No`0309H0
o`3o0000o`2d0080o`000`3`0?l4003odPH00?mh3000oahB03co0003003oN000oah0??l000<0??l0
00D00?lN003oN000om800?oB003o7P0303co00d0U_l01@0lo`000`00oah00?mh003o7P0503co00/0
U_l00P0lo`0909Ko00<0??l000@001ko003o7P00N?l007So0P00ogP01000oah007So003oN000ogP2
001ho`040?l0FP00d_l00=;o003Bo`D00?lN0P00om8403co00/0U_l0103oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`03003oN000oah0??l000@0??l00P00oah0
0`00ogP00?oB003Bo`02003Bo`800?oB00L0l03o000No`3o05X0o`1J0?l0000l0?l001ko00<00=;o
00<007So003odP00ogP00P00ogP:003o7P800?mh00@007So003Bo`00d_l00?mh2000oah3003oN003
003odP00N?l0o`1J0080o`0000<0l03o000No`00d_l00P00om800`00d_l0l03o003oN003003oN003
003odP3o05X00?oB00<00?mh0P00om82003Bo`030?l0]02F0?l0o`2d0080o`000`007_l00`3o05X0
o`2d0?l0]0020?l0000609H0o`0l0?l0?03o09H0o`00N?l00=;o1000om86003oN0`00?lN4P0lo`03
003o7P80??l00P00oah00`3o05X00?lN003o7P0403co00d0U_l01@0lo`000`00oah00?oB003odP05
03co00/0U_l00P00om800`0lo`00U_l009Ko000609Ko00D0??l00P00oah00`00ogP00=;o003oN004
003odP06001ho`3o0;@007So001ho`00d_l0o`000`00ogP0100l0?l00?mh003o7P00ogP203co00`0
U_l0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`03003o
dP00oah0??l000@0??l01000oah01P00ogP00?oB003odP00om8007So0?l000<0l03o0P3o0;@00`3`
0?l007So001ho`02003odP<00?mh2`00oah00`00ogP00?oB0?l0FP02003oN0@00?lN0P00d_l3003o
7P<00?mh00<00?oB003Bo`00N?l00P0l0?l00`3o05X0UP3o003Bo`02003Bo`03000No`2F0?l00?oB
00<00?mh00<00?oB001ho`2F0?l00`00om82003Bo`8007So00<0?03o09H0o`3o00000P2F0?l0100l
0?l0l03o03`0o`3`0?l20?l000030?l0]02F0?l0l03o00@007So00@0o`1J001ho`00N?l0?03o0P00
om85003oN0`00?lN4P0lo`000`00oah00?mh003oN003003o7P800?mh0P00oah603co00X0U_l0100l
o`02003o7P03003oN000N?l00?lN00D0??l02P2Fo`001@0lo`000?mh003oN000oah0??l000L0U_l0
1@0lo`03003o7P03003oN000d_l001ko00<007So00@001ko0?l0000l0?l0?03o0P00N?l01@007_l0
0?oB003odP00ogP00?lN00D0??l01`2Fo`0303co000309Ko003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool01000ogP00?lN003o7P00oah203co
00D00?lN1000ogP00`00om80l03o03`0o`020?00o`030?l0]00l0?l0?03o00<007So00<00?oB003o
N000ogP00P00ogP3003o7P800?mh1P00oah01000ogP0UP3o003oN000ogP4003o7PL00?mh00@00?oB
003Bo`00d_l007So0P007_l00`3o0000?03o001ho`020?00o`03003Bo`00om800?oB00@00?oB00<0
07So003Bo`00om800P00om82001ho`800=;o00<007So09H0o`3o00000P3`0?l0102F0?l0l03o0?l0
003o00020?00o`030?l000007_l007So00800=;o00<007So003Bo`00d_l00P007_l0103`0?l00=;o
003Bo`00om82003Bo`<00?mh2`00oahB03co0003003o7P00om80o`0000<00?mh00@0UP3o003Bo`00
oah00?lN1`0lo`0609Ko00H0??l000D00?mh003odP00om800?mh0?l00003003oN0800?lN00<0??l0
09Ko002Fo`00202Fo`0303co0003003oN000oah0??l000D0U_l0200lo`000`00oah00?mh003odP03
09H0o`030?l0002F0?l0l03o0080UP3o00<0?03o0?l0FP00om800`00oah603co00H0U_l000D0??l0
003o7P00oah0??l009Ko00040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooo00@00?mh003o7P00oah00?lN0P0lo`05003o7P@00?mh00<00?oB0?00o`0l0?l00P3`
0?l00`3o0;@0?03o03`0o`03001ho`03003odP00ogP00?mh00800?mh0`00oah2003oN0H00?lN00@0
0?mh09H0o`00ogP00?mh1000oah7003oN004003odP00d_l00=;o001ho`8001ko00<0o`0003`0o`00
N?l00P3`0?l00`00d_l00?oB003odP04003odP03001ho`00d_l00?oB00800?oB0P00N?l2003Bo`03
001ho`2F0?l0o`000080l03o00@0UP3o0?00o`3o0000o`000P3`0?l00`3o000001ko001ho`02003B
o`03001ho`00d_l00=;o008001ko00@0l03o003Bo`00d_l00?oB0P00d_l3003oN0/00?lN4P0lo`00
0`00oah00?oB0?l00003003oN00409H0o`00d_l00?lN003o7PL0??l01P2Fo`0603co0005003oN000
om800?oB003oN03o00000`00ogP2003o7P0303co002Fo`00U_l000P0U_l00`0lo`000`00ogP00?lN
03co000509Ko00P0??l000<00?lN003oN000om800`2F0?l00`3o0000UP3o0?00o`0209H0o`0303`0
o`3o05X00?oB00<00?lN1P0lo`0609Ko000503co0000oah00?lN03co002Fo`00103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`03000No`00ogP00?lN00<00?lN
00<0?03o003o7P00oah00P00oah4003oN003003odP00d_l007So0080l03o00<0o`1J09H0o`007_l0
0P00d_l2003odPD00?mh00D00?lN003oN000om800?oB003oN004003o7P800?mh00@0l03o003oN000
ogP00?mh0P00oah3003oN003003Bo`00om800?mh00800?mh00@00?oB001ho`3`0?l007So0P3o0;@0
0`3o05X0o`00000No`02001ho`03003Bo`00om800?oB008001ko0P00om800`00d_l0UP3o003Bo`03
003Bo`060?l0]000N?l007So0?l0000l0?l0o`1J0P3o0;@0103`0?l0o`2d0?l0003o05X203`0o`<0
01ko0`00d_l2003odP8007So00@00=;o000No`2F0?l007So0P00om83003oN0/00?lN400lo`04003o
7P06003oN000N?l007So000No`2F0?l00?oB0P00oah2003oN0800?lN400lo`02003o7P03003oN00l
0?l00?mh0080o`1J00@00?lN03co000lo`00??l0202Fo`0203co00800?lN00<00?oB03co000lo`00
2`0lo`03003o7P03003oN000om800?oB00<001ko00<0o`0003`0o`00N?l00P00N?l01@00om800=;o
003Bo`00d_l00?mh00L0??l0102Fo`0203co00800?lN00<0??l009Ko003oool00`3oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`03000No`00ogP00?lN00<00?lN
1P00ogP2001ho`<00=;o00H007So03`0o`0l0?l0o`0003`0o`00N?l3003Bo`04000No`00d_l00?oB
003odP@00?mh0P007_l00`00ogP00=;o003o7P04003oN003000No`00om800?oB00@00?mh0P00d_l0
0`3`0?l00=;o003oN002003oN0800?oB00L00=;o001ho`0l0?l0?03o0?l0FP2F0?l001ko00<007So
0P00d_l20?l000<00=;o00<0o`00001ho`00N?l00P00N?l010007_l0?03o03`0o`0l0?l20?l00080
o`1J00@0l03o0?l0]03o0000l03o0P007_l00`0l0?l007So000No`0203`0o`03003Bo`00om800?oB
0080?03o00<00?oB003Bo`007_l00`007_l00`3o05X00?oB003oN003003oN0P00?lN400lo`04003o
7P06003oN000om800?oB001ho`3`0?l007So0P3o05X00`00d_l00?mh003o7P0A03co00800?lN0P00
N?l00`00ogP00?lN003o7P0703co0080U_l00P0lo`000`00oah0??l003co0002003o7P04003odP0l
o`00??l0003o7PD0??l00P00oah00`00N?l00?lN003o7P04003o7P07003oN000om800=;o003Bo`00
7_l0o`0003`0o`02001ho`800?oB00<00?mh003o7P00oah00P00oah403co0003003oN00lo`00??l0
00D0??l00P3o0;@203co00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3oool00`3`0?l00?mh003o7P03003o7P04003oN03o0000o`00003odP800?mh0P00om801000
d_l007So000No`0l0?l20?00o`030?l0003`0?l007So008007So00<001ko09H0o`00d_l00P00om83
003oN004003odP3`0?l0l03o003odP800?mh0P00N?l2003oN005003Bo`00om800?oB003oN000om80
0P00ogP2003odP800=;o1@00om80103o05X001ko000No`007_l20?l0]0<0?03o00<0l03o003Bo`00
d_l00P0l0?l01000N?l00=;o000No`3o0;@20?l00003000No`3o0;@0?03o0080o`0000<0o`2d0?l0
003o00000`2F0?l00`3o05X0o`000?l00002000No`03001ho`00d_l00=;o00<00=;o0P00om83003o
N003003odP00d_l00?oB00<00?oB00@0l03o003odP00om800?oB0`00ogP5003o7P03003oN000oah0
0?lN00d0??l01@00oah01P00ogP00?oB003odP2F0?l001ko003oN0@00?lN2P0lo`000`00ogP0??l0
03co000503co00<00?lN00<00?oB003o7P0lo`001`0lo`000`00om80??l003co000303co000709H0
o`00oah00?lN003o7P3o00000?lN003odP0803co00<00?mh0`00oah00`00ogP007So0?l0FP02001h
o`03000No`3o05X0o`2d008001ko0P00d_l00`00om800?lN003o7P03003o7P03003oN000om800?oB
00H0??l00P00oah2003oN080??l0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`03000No`00om800?mh00@00?mh0P00N?l00`00d_l00?mh003oN003003odP80
0=;o00D0?03o0?l0]03o0;@0o`2d09H0o`03001ho`0303`0o`00d_l00?oB00800?oB0`00ogP01000
om8007So001ho`00d_l2003oN0@00?oB00L007So000No`007_l00?oB000No`00om800?mh00800?oB
00<00=;o03`0o`00om800P00om801000N?l00=;o003Bo`00N?l2000No`030?l0]03`0?l0?03o0080
01ko00<007So03`0o`00N?l00P2F0?l01000N?l001ko000No`3o0;@20?l0000309H0o`3o05X0o`00
00<0o`0000<0UP3o03`0o`0l0?l00P0l0?l00`3`0?l0o`000?l0]00209H0o`030?00o`007_l00=;o
00@00?oB1@00ogP2003odP<00?mh00D00=;o003oN000N?l007So003odP02003Bo`800?oB00<0UP3o
003oN000oah01000oah;03co00D00?lN00L00?oB09H0o`00N?l007So0?l0]000om800?mh00<00?lN
2`0lo`000`00om80??l003co000503co00800?mh0`00om82003o7Pd0??l000H00?lN003odP00om80
l03o003oN000oah803co0003003o7P00d_l0?03o00800?oB0`00ogP01P00om800=;o003Bo`007_l0
o`1J0?l0008007So0P00om85003oN004003odP00ogP00?lN003o7PH0??l000H00?oB003oN000d_l0
0=;o003oN000oah40?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo0P00om82003oN003003odP00ogP00?mh00800?oB0P00N?l01`00om80UP3o09H0o`00om800=;o
0?00o`007_l00P3o05X00`2F0?l0?03o001ho`03003Bo`H00?oB0P00d_l209H0o`03003odP00ogP0
0?mh00800?oB00<0o`2d003Bo`3o05X00P007_l01000N?l00=;o003odP00N?l2003odP03003Bo`3`
0?l00=;o00<00=;o00<001ko001ho`0l0?l00P0l0?l00`3o0000l03o0?00o`02000No`0303`0o`00
7_l007So00@001ko00<0?03o0?00o`3o00001P3o00000`3o05X0o`00000No`0209H0o`80?03o00D0
o`000?l0FP2F0?l0UP3o001ho`02003Bo`<00?oB3@00ogP2003odP<00?mh2P00oah903co00L00?lN
00H00?mh003Bo`00d_l001ko003odP00N?l2003oN003003o7P0lo`00??l000T0??l00P00oah503co
00<00?lN0P00ogP3003o7P@0??l00P00oah703co00<00?lN00@007So003odP00ogP00?lN1`0lo`00
0`00d_l00?mh003odP02003odP04003Bo`00om800?oB000No`800=;o00<001ko0?l0002F0?l00P00
N?l00`00d_l00?oB003oN002003Bo`03003oN03`0?l00=;o00<00?lN1P0lo`001P00oah00?mh003o
dP00om800?lN03co00@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?ooo`800?oB
0P00ogP00`00om800?mh003oN002003odP8007So00L00?oB09H0o`2F0?l00?oB003Bo`3`0?l001ko
0080o`1J00<0UP3o03`0o`00N?l00`00d_l6003odP800=;o0P2F0?l00`00om800?mh003oN002003o
dP030?l0]000d_l0o`1J008001ko00@007So003Bo`00om8007So0P00om800`00d_l0l03o003Bo`03
003Bo`03000No`00N?l0?03o0080?03o00<0o`000?00o`3`0?l00P007_l00`0l0?l001ko001ho`04
000No`0303`0o`3`0?l0o`0000H0o`0000<0o`1J0?l000007_l00P2F0?l203`0o`050?l0003o05X0
UP3o09H0o`00N?l00P00d_l3003odPd00?mh0P00om83003oN0X00?lN2@0lo`07003o7P06003oN000
d_l00=;o000No`00om8007So0P00ogP00`00oah0??l003co000903co00800?lN1@0lo`03003o7P80
0?mh0`00oah403co00800?lN1`0lo`03003o7P04001ho`00om800?mh003o7PL0??l000<00=;o003o
N000om800P00om801000d_l00?oB003odP007_l2003Bo`03000No`3o0000UP3o008007So00<00=;o
003odP00ogP00P00d_l00`00ogP0l03o003Bo`03003o7PH0??l000H00?lN003oN000om800?oB003o
7P0lo`030?ooo`8000001@3oool001/0oooo00<000000?ooo`3oool00P3oool01@00om800=;o003o
dP00om8007So00800?mh0P00om800`00N?l00=;o003odP02003Bo`04000No`00d_l007So03`0o`80
o`0000<0l03o09H0o`0l0?l00P00N?l00`007_l00?oB003odP05003odP03003Bo`00N?l007So00D0
0?oB00<00=;o001ho`3o00000P3o0;@0102F0?l00=;o003Bo`007_l2003Bo`H007So0`0l0?l20?00
o`030?l0002F0?l0?03o008001ko0P0l0?l01@007_l0o`1J0?l0FP3o0;@0l03o0080o`000P3o05X0
0`3o0000l03o03`0o`0203`0o`8001ko1000N?l00`2F0?l0?03o0?l0FP020?00o`0309H0o`007_l0
07So00800=;o0P00om8;003oN2000?lN00D00?mh003odP00om800?oB003oN004003o7P/0??l000<0
0?lN003odP00oah01000oah00`00ogP00?lN003o7P02003oN0L00?lN0P00ogP703co00<00?lN00@0
0?oB003oN000oah00?lN1@0lo`04003o7P<00?mh00@00?oB003Bo`00d_l007So0P007_l00`0l0?l0
o`2d09H0o`0203`0o`03001ho`00d_l00=;o0080o`2d00<00?oB003oN000ogP00`00oah503co0080
0?lN0`00ogP00`00oah0??l00?ooo`030?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000
003oool0oooo0080oooo00<007So0?l00000d_l00P00d_l01P00om8007So003odP00om800=;o001h
o`<00=;o00@0UP3o001ho`2F0?l0o`000P3o05X00`0l0?l001ko000No`02001ho`<00=;o0P0l0?l0
1000d_l00?oB003odP00d_l2001ho`800?oB00<001ko003Bo`00d_l00P00N?l01`2F0?l0o`2d0?l0
]00l0?l001ko003Bo`007_l00`00N?l0202F0?l0o`00000No`007_l0UP3o03`0o`3o05X0o`2d0P3o
00000`3o0;@0UP3o03`0o`0303`0o`040?l0FP2F0?l0l03o0?00o`80o`0000L0o`1J0?l0002F0?l0
UP3o0?l0FP3`0?l0UP3o00<007So00L0o`2d001ho`00d_l00=;o000No`00N?l0?03o00<0o`0000<0
01ko003Bo`00d_l00P00N?l00`3o00000?oB003oN005003oN1d00?lN00<00?mh003o7P00oah01@00
oah00`00ogP00=;o003Bo`02003oN0D00?lN2@0lo`02003o7P<00?mh00@0o`2d003o7P00oah00?mh
0P2F0?l00`00om80UP3o003odP02003oN0800?lN00<0o`00003oN000oah00P00oah603co00<00?lN
0P00ogP<003o7P<00?mh0P00om801000N?l0o`000?l0003o00020?l0]080l03o00<001ko003Bo`00
om800`00om800`00ogP00?lN003o7P03003o7P03003Bo`0lo`000?lN00<00?lN0`00ogP2003o7P@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool0100l0?l0o`00
0?00o`3`0?l2003Bo`060?l0]000d_l00=;o001ho`2F0?l0o`000P00N?l010007_l0o`000?00o`3o
000209H0o`03000No`00N?l007So00@00=;o00@007So03`0o`0l0?l007So0`00d_l2000No`800=;o
00H0UP3o001ho`00N?l007So000No`2F0?l20?l0]00403`0o`007_l001ko03`0o`8001ko00<0UP3o
03`0o`3o00000P2F0?l0103o0;@0o`000?l0003o00020?00o`0309H0o`0l0?l0?03o00<0?03o00<0
UP3o0?l0FP3o00000`3o00001`0l0?l0UP3o000No`007_l0UP3o0?l0000l0?l00P00N?l00`00d_l0
01ko000No`04003Bo`8001ko0P3o00000`007_l00=;o003odP03003odP800=;o1000ogPO003o7P03
003oN000oah00?lN00<00?lN0P00ogP2003odP800?mh1@00oah903co00800?lN00@00?mh000No`00
7_l00?mh0P00oah3003oN003003Bo`3o05X00?oB00800?mh0P00oah01P00ogP0o`00003oN000ogP0
UP3o003o7P@0??l000<00?lN003oN000ogP00P00ogP00`007_l00=;o003oN004003o7P03003oN000
oah00?lN00<00?lN0`00ogP00`00om800=;o003Bo`02000No`0309H0o`3o0000UP3o008001ko0P00
N?l00`00om800?mh003oN002003oN0X00?lN00<007So003Bo`00om800P00om800`00oah0oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00@001ko
0?l0FP0l0?l0?03o0P00N?l01P0l0?l007So001ho`00N?l0UP3o0?00o`80?03o00@0UP3o0?l0003o
0000l03o0P0l0?l00`3o0;@0?03o000No`02001ho`03003Bo`00N?l007So008001ko0P00d_l01@00
7_l007So03`0o`0l0?l0UP3o008007So0P007_l00`0l0?l001ko09H0o`020?l000<0?03o00@0UP3o
0?l0]03o0;@0o`1J1@3o00000`3`0?l0UP3o0?l0000203`0o`030?l0000l0?l001ko0080UP3o00<0
o`2d0?00o`3o00000P3o05X00`2F0?l0?03o000No`03001ho`03000No`2F0?l007So00D00=;o0`00
om82001ho`06003Bo`007_l001ko0?l000007_l00?oB2000ogPP003o7P<00?mh0P00oah2003oN005
003Bo`0l0?l0?03o003odP00ogP01000oah00`00ogP00?lN03co000503co00<00?lN00<00?mh0?l0
0000om800P00om83003oN080?03o00<0l03o03`0o`00d_l00P00om801000ogP00?oB003Bo`0l0?l:
003o7P<00?mh00<0o`2d003oN000oah01000oah3003oN0800?lN00<00?mh0?00o`3`0?l00`00om80
0`007_l0?03o03`0o`030?l0008001ko00<00=;o003odP00om801000ogP4003o7P03003oN000oah0
0?lN00<00?lN00@00?mh03`0o`00om800?oB0P00oah40?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo00@001ko0?l0FP0l0?l0?03o0P00N?l01P0l0?l007So001h
o`00N?l0UP3o0?00o`80?03o00@0UP3o0?l0003o0000l03o0P0l0?l00`3o0;@0?03o000No`02001h
o`03003Bo`00N?l007So008001ko0P00d_l01@007_l007So03`0o`0l0?l0UP3o008007So0P007_l0
0`0l0?l001ko09H0o`020?l000<0?03o00@0UP3o0?l0]03o0;@0o`1J1@3o00000`3`0?l0UP3o0?l0
000203`0o`030?l0000l0?l001ko0080UP3o00<0o`2d0?00o`3o00000P3o05X00`2F0?l0?03o000N
o`03001ho`03000No`2F0?l007So00D00=;o0`00om82001ho`06003Bo`007_l001ko0?l000007_l0
0?oB2000ogPP003o7P<00?mh0P00oah2003oN005003Bo`0l0?l0?03o003odP00ogP01000oah00`00
ogP00?lN03co000503co00<00?lN00<00?mh0?l00000om800P00om83003oN080?03o00<0l03o03`0
o`00d_l00P00om801000ogP00?oB003Bo`0l0?l:003o7P<00?mh00<0o`2d003oN000oah01000oah3
003oN0800?lN00<00?mh0?00o`3`0?l00`00om800`007_l0?03o03`0o`030?l0008001ko00<00=;o
003odP00om801000ogP4003o7P03003oN000oah00?lN00<00?lN00@00?mh03`0o`00om800?oB0P00
oah40?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00L001ko
0?l0FP2F0?l0UP3o000No`3`0?l001ko00<0?03o00@0l03o0?l0FP3o05X0o`1J0`3o00000`3`0?l0
?03o03`0o`07001ho`<0?03o00@007So000No`00N?l0?03o0P3o000203`0o`04000No`3o0000o`00
09H0o`80o`000P3o05X00`2F0?l0l03o0?l0FP030?l000030?l0]03`0?l0l03o0080o`0000@0UP3o
0?l000007_l0o`000P007_l00`2F0?l0l03o000No`0203`0o`0309H0o`3o0;@0l03o00<0?03o00<0
07So0?00o`00N?l01000d_l00`00N?l00=;o003Bo`02003odP07003Bo`00om800?oB003odP00N?l0
0=;o003odP0203`0o`03001ho`00om800?oB00L00?mh8P00oah01`00ogP00=;o003oN000ogP007So
003oN000om800P3o0;@00`00om800?mh003oN002003oN003003odP00oah00?lN00/00?lN0P00ogP0
1000om80UP3o003oN000ogP2003odP03000No`3o00000=;o00800?oB00@00=;o001ho`00om800?mh
3000oah01000ogP007So003oN000ogP4003o7P03003oN00l0?l0?03o00D00?mh00@00?oB09H0o`00
N?l00=;o0P007_l20?l0000603`0o`00N?l007So003Bo`00om800=;o0P00om800`00N?l00?mh003o
N003003oN0030?l0]000oah00?lN00<00?lN00@00?mh003odP00ogP00?mh0P00oah40?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00<0UP3o0?l0002F0?l00`2F
0?l00`3`0?l0o`000?l000020?l000040?l0]03o05X0o`1J09H0o`80?03o00<0UP3o000No`007_l0
1`00N?l01`0l0?l0UP3o09H0o`00N?l0?03o000No`0l0?l00P3o000209H0o`030?00o`3o0000o`00
0080o`0000@0o`2d0?l0FP3o05X0l03o0P3o00000`3`0?l0o`000?l0000203`0o`040?l0]03o0000
o`00000No`8007So00<0l03o001ho`00N?l00P00N?l303`0o`0309H0o`3o0000l03o008001ko1000
N?l2003Bo`03003odP00d_l007So00800=;o0`00om82003oN003003odP00N?l00=;o00@00?oB00<0
01ko003odP00ogP01P00ogPS003o7P<00?oB00<0?03o000No`00d_l00P3o05X00`00N?l001ko000N
o`02003oN0h00?lN0P00ogP01000d_l0o`1J003Bo`00om82001ho`03000No`3o05X0?03o008007So
00@0o`2d003odP00ogP00?mh1@00oah2003oN0D00?lN00<00?mh003Bo`00om800`00ogP00`00oah0
0?mh000No`03003Bo`@00?mh00@00?oB003Bo`00N?l001ko0P3o00000`3o05X0o`000?00o`04001h
o`030?l00000om800?oB00@00?mh0`00om801000ogP00?lN003o7P00oah2003oN005000No`00d_l0
0=;o003oN000oah0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?ooo`80o`000P3`0?l00`3o05X0o`000?l0FP020?l0000309H0o`0l0?l0UP3o0080o`000P0l0?l0
1000N?l001ko03`0o`0l0?l7001ho`03000No`0l0?l0?03o0080?03o0P3o0;@50?l00080l03o00<0
o`2d03`0o`0l0?l00P0l0?l0103`0?l0o`1J09H0o`0l0?l2000No`8007So00<0?03o0?00o`3`0?l0
0P00N?l01`00d_l001ko001ho`00N?l00=;o001ho`007_l00P0l0?l00`3o0;@0o`000?00o`0203`0
o`04001ho`00d_l00=;o001ho`@00?oB0`00N?l00`00om800?mh003oN003003oN003001ho`00ogP0
0?mh00800?mh00<00?oB003Bo`00d_l00P00om83003oN2D00?lN00H00?mh003odP00om800?mh003o
dP00d_l20?l0]003001ho`00om800?mh00800?mh1`00oah00`0l0?l00?lN003o7P04003o7P@00?mh
00L00?oB000No`3o05X0o`1J0?00o`3o0;@0o`000080?03o00<00=;o003odP00ogP00`00ogP2003o
7P04003oN0007_l001ko003oN0800?lN0`00ogP00`00om800=;o003oN005003oN0800=;o00<007So
003odP00om800P00N?l2003odP07003Bo`00N?l0?03o03`0o`3o0000l03o09H0o`03001ho`0403`0
o`00d_l00?oB003odP@00?mh0P00N?l00`00d_l00?mh003oN004003oN005003Bo`00om800?oB003o
N000d_l0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`80
UP3o0P3`0?l00`3o0000UP3o03`0o`0203`0o`8001ko00@0?03o0?l0FP3o05X0?03o0P00N?l01000
7_l0?03o03`0o`3o0006001ho`05000No`3o0000o`000?l0003o0;@00P3o00020?00o`030?l0002F
0?l0?03o008001ko00<0o`1J000No`3`0?l00P2F0?l00`3`0?l0o`2d000No`03001ho`03000No`00
d_l00=;o008007So0`00d_l0103o00000=;o003Bo`00d_l4000No`0309H0o`3o0000?03o008001ko
0P00N?l2003odP800=;o0`00om8203`0o`03003odP00ogP00?mh00<00?mh00<00?oB003oN000ogP0
0P00ogP00`00om800=;o000No`03003Bo`0309H0o`00d_l00?lN02D00?lN1000ogP01P00om80?03o
03`0o`00d_l00?oB003oN0T00?lN0P00ogP5003o7P@00?mh00L00=;o09H0o`3o0000o`0009H0o`3o
05X001ko008007So00@00=;o003odP00om800?oB1000ogP01000om800=;o003Bo`00om85003oN003
003odP00d_l00=;o00<00?oB0P00ogP2003odP030?00o`00d_l00?oB00800?oB0P00d_l01`00N?l0
l03o03`0o`0l0?l0o`0009H0o`007_l00P00N?l2003Bo`@00?oB0P00ogP01000om800=;o003Bo`00
om84003oN0800?oB00D007So000No`007_l00=;o003odP040?ooo`030000003oool0oooo00<0oooo
000D0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`80UP3o0P3`0?l00`3o0000UP3o03`0
o`0203`0o`8001ko00@0?03o0?l0FP3o05X0?03o0P00N?l010007_l0?03o03`0o`3o0006001ho`05
000No`3o0000o`000?l0003o0;@00P3o00020?00o`030?l0002F0?l0?03o008001ko00<0o`1J000N
o`3`0?l00P2F0?l00`3`0?l0o`2d000No`03001ho`03000No`00d_l00=;o008007So0`00d_l0103o
00000=;o003Bo`00d_l4000No`0309H0o`3o0000?03o008001ko0P00N?l2003odP800=;o0`00om82
03`0o`03003odP00ogP00?mh00<00?mh00<00?oB003oN000ogP00P00ogP00`00om800=;o000No`03
003Bo`0309H0o`00d_l00?lN02D00?lN1000ogP01P00om80?03o03`0o`00d_l00?oB003oN0T00?lN
0P00ogP5003o7P@00?mh00L00=;o09H0o`3o0000o`0009H0o`3o05X001ko008007So00@00=;o003o
dP00om800?oB1000ogP01000om800=;o003Bo`00om85003oN003003odP00d_l00=;o00<00?oB0P00
ogP2003odP030?00o`00d_l00?oB00800?oB0P00d_l01`00N?l0l03o03`0o`0l0?l0o`0009H0o`00
7_l00P00N?l2003Bo`@00?oB0P00ogP01000om800=;o003Bo`00om84003oN0800?oB00D007So000N
o`007_l00=;o003odP040?ooo`030000003oool0oooo00<0oooo000C0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool2000No`80UP3o00<0o`2d03`0o`007_l00`007_l0
1@00d_l007So09H0o`2F0?l007So00800=;o0`007_l00`00N?l00=;o003Bo`02001ho`03000No`3o
0;@0?03o0080l03o0`3o00001@3o0;@0?03o03`0o`3o0000UP3o00<007So00<0o`00001ho`00N?l0
0P0l0?l20?l0]005000No`2F0?l00=;o003Bo`00N?l00P00om83003Bo`800?oB00<00=;o003odP00
om800P00d_l01P00N?l001ko000No`2F0?l0o`0009H0o`80l03o0P00d_l4003odP800?mh00D00?oB
000No`007_l00=;o003odP09003oN003003odP3o0000?03o00800?oB0`00ogPV003o7P<00?mh00H0
0?oB003Bo`0l0?l0?03o003Bo`00om83003oN0L00?lN00<00?mh003odP00ogP01000ogP2003Bo`<0
0?oB00H00=;o000No`007_l0?03o0?l0002F0?l203`0o`800=;o00<007So003odP00ogP00`00ogP0
0`00om8007So001ho`03003oN08001ko00@00?oB003Bo`2F0?l00?oB0P00N?l00`00d_l00?oB003o
dP02003odP800=;o00L00?oB003Bo`00d_l001ko001ho`2F0?l001ko0080UP3o00<0o`1J09H0o`0l
0?l00P3`0?l00`00N?l001ko003odP05003odP06003Bo`2F0?l0UP3o001ho`00om8001ko0P00om80
0`007_l00=;o000No`02001ho`0309H0o`00om80oooo00<0oooo00<000000?ooo`3oool00`3oool0
01<0oooo00@000000?ooo`3oool00000103oool2000000<0oooo00<00=;o03`0o`3o05X00P3o05X0
1@007_l00=;o003Bo`00d_l001ko00800=;o0P3o0003003Bo`03001ho`007_l001ko00<00=;o0`00
N?l01P007_l0?03o0?l0003o0000o`2d09H0o`80?03o0P00N?l203`0o`04000No`00d_l00=;o000N
o`800=;o0P00N?l0100l0?l0o`00000No`00d_l5003odP<007So1P00om801000d_l001ko09H0o`2F
0?l20?l000070?00o`0l0?l0?03o03`0o`00N?l00=;o000No`04003oN006003odP0l0?l0?03o001h
o`00ogP00?oB0P00ogP3003o7P06003oN000N?l007So003oN000om800=;o0P00om83003oN2P00?lN
0`00ogP3003odP@00?mh1P00oah2003oN004003Bo`00ogP00?mh003odP@00?mh00@00=;o000No`00
d_l00=;o0P00N?l00`3`0?l0o`0003`0o`02000No`04001ho`3`0?l00=;o003odP<00?mh0P00om82
003Bo`03003odP00ogP00?mh00800=;o00@007So003Bo`3o0000?03o0P00N?l2003odP05003Bo`00
om800?oB003Bo`0l0?l00`00d_l01000N?l0?03o000No`2F0?l20?l0FP0309H0o`007_l001ko0080
01ko1@00d_l010007_l00?oB003odP00d_l20?00o`800?oB00D00=;o003odP00om800=;o001ho`03
0?l000800=;o0`3oool2000000D0oooo000C0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00P3oool2003Bo`<0o`0000D007So003Bo`00om800?oB003Bo`02003odP80l03o00@0
0=;o003odP00om8001ko1@00d_l4000No`0709H0o`3o05X0o`1J09H0o`007_l0?03o001ho`03003B
o`0503`0o`00d_l00?oB003odP00d_l00P00om82001ho`0403`0o`3o00000=;o001ho`800=;o0P00
ogP00`00om800=;o003Bo`02003odP800?mh0P00om800`00d_l0l03o001ho`02000No`0303`0o`3o
0000l03o008007So0P00d_l00`007_l00=;o003oN003003oN004003odP00ogP00?mh003Bo`800?mh
1P00oah4003oN0<00?oB0`00ogPX003o7P<00?mh0P00om800`00d_l00?oB003oN002001ho`04003o
N000oah00?lN003o7P800?mh00<00?oB003oN000N?l00P0l0?l00`00om800?mh003oN002003oN003
000No`00d_l007So00<0?03o00<0l03o0?l0003o00000P2F0?l00`007_l00=;o003odP05003odP<0
07So1@00om801000d_l001ko0?l0000l0?l2001ho`800=;o00@001ko003Bo`00d_l001ko0P0l0?l2
001ho`80?03o00H0UP3o0?l0]03o0000o`0003`0o`007_l3001ho`<00=;o0P007_l01000N?l00=;o
003Bo`00d_l20?l000800=;o00D001ko003Bo`00d_l00=;o000No`030?l0FP0303`0o`00d_l0oooo
00<0oooo00<000000?ooo`3oool00`3oool001<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?ooo`07003odP2F0?l007So001ho`007_l00=;o000No`02003odP03000No`00
om8007So0080UP3o00<00=;o003odP00om801000om801`007_l007So0?00o`3`0?l0?03o09H0o`3o
05X00P2F0?l010007_l0UP3o001ho`007_l2003Bo`03003odP00d_l00=;o00@00?oB00L00=;o001h
o`00N?l00?oB09H0o`00d_l00?oB008001ko0`00ogP2001ho`04003odP00ogP00?mh003oN0800?oB
00<007So003Bo`00d_l00P0l0?l00`2F0?l0o`0003`0o`02000No`04003Bo`00om800?oB003odP80
0=;o1@00ogP00`00om800?mh003o7P06003o7P<00?mh00H00?oB003Bo`0l0?l0?03o003Bo`00om83
003oN2H00?lN0`00ogP2003odP0303`0o`3o00000?oB00T00?mh00D00?oB003Bo`007_l001ko003o
dP02003oN0@00?oB0P00d_l20?00o`0309H0o`3o0000UP3o008001ko00@007So003Bo`00d_l00?oB
0P00d_l2003odP<00=;o0P00om801@00N?l00=;o003Bo`2F0?l001ko0080o`2d0P0l0?l2001ho`06
0?l00000N?l007So001ho`2F0?l0o`000P0l0?l0103o0;@0o`000?l0003o00020?00o`0303`0o`3o
0;@001ko008007So0P00d_l01000N?l001ko000No`007_l2003Bo`05001ho`2F0?l0UP3o001ho`00
d_l010007_l0100l0?l0o`2d09H0o`2F0?l2000No`@0oooo00<000000?ooo`3oool00`3oool001@0
oooo0P0000050?ooo`030000003oool0oooo0080oooo00D00?oB003Bo`007_l001ko001ho`02003o
dP@00?mh00@00?oB003Bo`00d_l00?oB0P00ogP4003odP800=;o0P00N?l00`007_l0UP3o0?l00002
03`0o`040?00o`00N?l00=;o003Bo`<00?oB00@00=;o0?00o`00om800?oB0P00ogP3003odP800=;o
00<00?oB003oN000ogP00`00ogP01000om800=;o003Bo`00om83003oN0@00?oB00H00=;o001ho`00
N?l001ko0?l0FP2F0?l20?l0000309H0o`00d_l00?mh00<00?mh1@00oah2003oN0T00?lN00<00?mh
003odP00d_l00P0l0?l00`00om800?mh003oN002003oN2H00?lN00<00=;o09H0o`00d_l00P00d_l0
0`007_l00=;o003odP04003oN003003odP00ogP00?mh00<00?mh00<00?oB03`0o`0l0?l00`00om82
003Bo`800?oB0P00N?l2000No`0303`0o`3o0000UP3o00@001ko0P00d_l20?l000<00=;o0P00N?l2
003Bo`07000No`00N?l007So001ho`007_l0o`2d0?00o`0209H0o`030?00o`007_l0o`1J008001ko
00<0?03o09H0o`3o00000P3`0?l20?l000050?l0]03o0000o`000?l000007_l01P00N?l0103o0000
?03o03`0o`007_l2001ho`0403`0o`3o05X0o`1J03`0o`8001ko0`0l0?l0102F0?l0o`000?00o`3`
0?l209H0o`@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool0
1@00om800=;o000No`007_l007So00800?oB1000ogP01000om800=;o003Bo`00om82003oN0@00?oB
0P00d_l2001ho`03000No`2F0?l0o`000080?03o00@0l03o001ho`00d_l00=;o0`00om801000d_l0
l03o003odP00om82003oN0<00?oB0P00d_l00`00om800?mh003oN003003oN004003odP00d_l00=;o
003odP<00?mh1000om801P00d_l007So001ho`007_l0o`1J09H0o`80o`0000<0UP3o003Bo`00ogP0
0`00ogP5003o7P800?mh2@00oah00`00ogP00?oB003Bo`0203`0o`03003odP00ogP00?mh00800?mh
9P00oah00`00d_l0UP3o003Bo`02003Bo`03000No`00d_l00?oB00@00?mh00<00?oB003oN000ogP0
0`00ogP00`00om80?03o03`0o`03003odP800=;o0P00om82001ho`8001ko00<0?03o0?l0002F0?l0
10007_l2003Bo`80o`000`00d_l2001ho`800=;o00L001ko001ho`00N?l007So000No`3o0;@0l03o
0080UP3o00<0l03o000No`3o05X00P007_l00`0l0?l0UP3o0?l000020?00o`80o`0000D0o`2d0?l0
003o0000o`00000No`06001ho`040?l0000l0?l0?03o000No`8007So00@0?03o0?l0FP3o05X0?03o
0P007_l303`0o`0409H0o`3o0000l03o0?00o`80UP3o103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?ooo`05003Bo`00ogP00?oB003odP00d_l01P00ogP00`00d_l0
07So001ho`04003oN0800?oB00<00=;o03`0o`00N?l00P00N?l00`2F0?l0l03o0?l0000203`0o`04
001ho`00d_l00?oB003odP8007So0P00om800`00N?l00=;o003Bo`06003oN003003Bo`00om800?mh
00800?mh0P00oah01000ogP001ko000No`00ogP2003o7P@00?mh00L00?oB003Bo`0l0?l0?03o0?l0
003o0;@0l03o0080o`1J00<001ko003odP00ogP00`00ogP6003o7P0303`0o`00oah00?lN00D00?lN
0`00ogP01`00om8007So0?l0]03o0;@00=;o003odP00ogP00P00om800`00ogP00?lN003o7P0S003o
7P<00?mh0P00om82003Bo`03003odP00ogP00?mh00800?mh00<007So003oN000ogP00`00ogP01000
om8007So001ho`00N?l4003odP04001ho`00d_l00=;o001ho`80?03o00<0l03o0?l0003o0;@00P0l
0?l010007_l007So003Bo`00N?l2000No`03003Bo`00N?l007So0080l03o00<0?03o001ho`00N?l0
0P007_l0100l0?l0UP3o0?l0FP3`0?l403`0o`030?l0]03`0?l0l03o00D0o`000P3o0;@403`0o`03
000No`00N?l007So00D007So0P0l0?l010007_l007So03`0o`0l0?l20?l0000309H0o`0l0?l0UP3o
0080o`0000<0o`1J0?l0003o05X00P3`0?l20?l000@0oooo00<000000?ooo`3oool00`3oool001/0
oooo00<000000?ooo`3oool00P3oool01@00oah00?mh003Bo`00d_l001ko00800?mh0`00oah01000
ogP00?oB003odP00om84003oN0800?oB00<0o`00001ho`00N?l00P00N?l00`3`0?l0o`000?l0FP02
0?l00004000No`00N?l00=;o003odP@00?mh0`00d_l00`007_l00?mh003o7P03003oN003003odP00
d_l00?mh00D00?lN0P00ogP4003o7P<00?mh00L00?oB0?l0]000N?l007So03`0o`3o05X001ko0080
07So00@00?oB003Bo`3o05X00=;o0P00ogP>003o7P800?mh0P007_l01P00N?l0o`1J0?l0FP00d_l0
01ko03`0o`<00?oB8`00oah7003oN003003odP007_l00?oB00<00?oB00<00=;o001ho`00om800P00
ogP3003odP800=;o00<007So003Bo`00om800P00d_l4001ho`8001ko00<0l03o0?l0002F0?l00`0l
0?l3001ho`80l03o0P00N?l010007_l0o`000?l0003o0;@203`0o`80o`0000@0l03o0?l0003o0000
l03o0P3o05X00`3o0;@0o`000?l000020?l000030?00o`2F0?l0UP3o0080o`0000@0?03o000No`0l
0?l007So0P2F0?l00`0l0?l007So001ho`05001ho`8001ko00@0UP3o03`0o`0l0?l0UP3o0P3o05X0
0`3o0;@0o`000?l000020?l000030?00o`2F0?l0UP3o0080UP3o00<0o`0009H0o`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`800?lN0P00ogP00`00
om800?mh003o7P04003o7P030?l0]000ogP00?mh00<00?mh00H007So003odP00om800=;o003odP00
d_l2001ho`0303`0o`3o0000o`00008001ko00@00=;o001ho`2F0?l00?oB1@00ogP203`0o`03003o
N000oah00?lN00800?lN0P00ogP00`00N?l00?mh003o7P0:003o7P800?mh00<00?oB001ho`00d_l0
0P00om800`00d_l0o`00000No`02003odP800?mh00@0UP3o003odP00ogP00?mh3@00oah00`00om80
0?mh003oN002003oN006003odP3o0;@0o`2d003odP00ogP007So0P00ogP00`00d_l00?mh003o7P0Q
003o7PL00?mh0P00om801P00N?l0?03o03`0o`00om800=;o001ho`<00?oB00<00=;o003odP00om80
0P00d_l00`00N?l00=;o003Bo`02003Bo`03001ho`3`0?l007So00<0?03o00<0l03o0?l0]02F0?l0
0P0l0?l010007_l0l03o09H0o`007_l20?l00003000No`3o0000UP3o0080o`000P3`0?l01`3o0;@0
o`000?l0003o0000o`1J0?00o`2F0?l00P3o05X20?l0000409H0o`3o0000o`00000No`80?03o0P3o
0000100l0?l007So000No`00N?l303`0o`L007So0P0l0?l0103`0?l0o`000?l0003o00030?l0FP07
0?00o`0l0?l0?03o03`0o`007_l0l03o000No`0209H0o`030?l0FP007_l0oooo00<0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool2003o7P800?oB00<0?03o003o
N000oah01000oah00`00ogP00?lN003o7P02003o7P@00?mh0P00om800`00d_l001ko000No`030?l0
0080?03o00@001ko003odP00om800?oB0P3`0?l00`00ogP00?lN003o7P03003oN0D00?lN00<00?mh
0?l0]000ogP00P00ogP9003o7P80?03o00<00=;o003odP00ogP00P00om800`00d_l0?03o0?00o`02
03`0o`<00?mh0`00om800`3o00000?mh003o7P02003o7PH0??l000<00?lN003oN000oah00`00oah0
1@00ogP00?oB03`0o`0l0?l00=;o00800?mh0P00oah3003oN2000?lN2000ogP00`00om8001ko0?l0
0002000No`03003Bo`00N?l007So00<00?oB1@00d_l00`00N?l0UP3o000No`03001ho`03000No`0l
0?l0UP3o0080o`1J00<0o`000?00o`3o0;@00P2F0?l010007_l0?03o0?l0000l0?l20?l0000309H0
o`3`0?l0o`0000@0o`0000@0o`1J0?l0]03o0;@0UP3o0`0l0?l20?l0000309H0o`007_l0?03o0080
01ko0P00N?l01@2F0?l0?03o03`0o`00N?l001ko00800=;o0P007_l2001ho`06003Bo`00N?l007So
000No`0l0?l0o`2d0P0l0?l0103`0?l0o`000?l0002F0?l203`0o`030?00o`2F0?l007So008007So
00<0?03o001ho`00N?l00P0l0?l00`3o05X001ko0?ooo`030?ooo`030000003oool0oooo00<0oooo
000K0?ooo`030000003oool0oooo0080oooo0P00oah2003odP0303`0o`00ogP00?lN00@00?lN00<0
0?mh003o7P00oah00P00oah4003oN0800?oB00<00=;o000No`007_l00`3o000203`0o`04000No`00
om800?oB003odP80l03o00<00?mh003o7P00oah00`00ogP5003o7P03003oN03o0;@00?mh00800?mh
2@00oah203`0o`03003Bo`00om800?mh00800?oB00<00=;o03`0o`3`0?l00P0l0?l3003oN0<00?oB
00<0o`00003oN000oah00P00oah603co0003003o7P00ogP00?lN00<00?lN00D00?mh003odP0l0?l0
?03o003Bo`02003oN0800?lN0`00ogPP003o7PP00?mh00<00?oB000No`3o00000P007_l00`00d_l0
07So001ho`03003odPD00=;o00<007So09H0o`007_l00`00N?l00`007_l0?03o09H0o`020?l0FP03
0?l0003`0?l0o`2d0080UP3o00@001ko03`0o`3o0000?03o0P3o00000`2F0?l0l03o0?l000040?l0
00040?l0FP3o0;@0o`2d09H0o`<0?03o0P3o00000`2F0?l001ko03`0o`02000No`8007So00D0UP3o
03`0o`0l0?l007So000No`02003Bo`8001ko0P00N?l01P00d_l007So001ho`007_l0?03o0?l0]080
?03o00@0l03o0?l0003o0000UP3o0P0l0?l00`3`0?l0UP3o001ho`02001ho`0303`0o`00N?l007So
0080?03o00<0o`1J000No`3oool00`3oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`06003o7P00om800?oB003odP00d_l007So2P00oah4003oN003003odP00N?l0
07So008001ko00<0UP3o0?l0002F0?l00P007_l2003Bo`04003odP00ogP00?mh003oN0D00?lN00<0
0?mh003o7P00oah00P00oah00`00ogP00=;o000No`04003oN003003o7P0lo`00??l00080??l000<0
0?lN09H0o`00ogP00P3o00000`00ogP00?lN003o7P02003oN003003odP3o05X00=;o00<00?mh0P00
oah01000ogP001ko000No`00ogP2003o7PT0??l01@00oah2003oN0800?oB0P00ogP5003o7P03003o
N000oah00?lN01d00?lN1000ogP2003Bo`@00?oB00@00=;o000No`3o0000o`000P007_l4003Bo`80
01ko00H00=;o001ho`00N?l0?03o0?l0002F0?l2000No`0309H0o`0l0?l0o`0000<0o`0000<0o`1J
09H0o`0l0?l0100l0?l00`2F0?l0l03o0?l000030?l000060?l0]02F0?l0UP3o0?l0000l0?l0UP3o
0P007_l0100l0?l001ko000No`0l0?l20?l0]00309H0o`007_l007So008007So00<0UP3o003Bo`00
d_l00P007_l3003Bo`04001ho`0l0?l0?03o001ho`@00=;o0P00N?l01`007_l0UP3o09H0o`3o0000
l03o0?l000007_l00P00N?l00`3o0000UP3o001ho`02003Bo`030?l0]000d_l00=;o0080l03o00<0
o`0003`0o`3oool00`3oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?ooo`800?lN0`00ogP4003o7P0303co0000d_l00?lN00@00?lN00<00?mh003odP00om800P00om80
1000d_l001ko0?00o`3`0?l20?l0]0<0o`0000<007So003odP00om800`00ogP<003o7P800?mh0`00
oah603co00800?lN0P00ogP00`3o00000?lN003o7P02003oN003003odP2F0?l00?oB0080UP3o00@0
0?mh003o7P00oah0o`2d0`00ogP2003o7PT0??l01@00oah2003oN0800=;o00<00?mh003o7P00oah0
1@00oah00`00ogP00?lN003o7P0K003o7PH00?mh00@00?oB0?l00000N?l007So0P00d_l01`007_l0
o`000?l0003o0000?03o001ho`007_l00P00d_l00`00N?l0o`2d001ho`02001ho`0309H0o`3`0?l0
o`1J0080UP3o00@0o`000?l0FP3o0000o`000P3`0?l00`2F0?l0o`1J03`0o`0303`0o`0309H0o`3o
0;@0o`000080o`2d00<0o`1J03`0o`2F0?l00P007_l00`3o0000UP3o001ho`02001ho`04000No`00
d_l001ko03`0o`80o`2d00<0UP3o001ho`00N?l00P00d_l00`007_l00?oB003odP02001ho`04003B
o`00om800?oB003Bo`80?03o0`00d_l2001ho`8001ko00L0?03o0?l0FP3o05X0o`0009H0o`00N?l0
UP3o00<00=;o00H007So003Bo`00om800?oB001ho`00om83003Bo`030?l00000N?l0oooo00<0oooo
00<000000?ooo`3oool00`3oool001/0oooo0P0000030?ooo`0303co0000oah00?mh00800?mh0P00
oah503co00<00?lN0P00ogP00`00om80o`2d0?l0]002003Bo`06001ho`0l0?l0?03o09H0o`3o0;@0
?03o0P007_l01000N?l00=;o003Bo`00om83003oN0@00?lN1@0lo`02003o7P03003oN000om800?lN
00800?lN1`0lo`000`00ogP00?lN003o7P06003o7P800?mh0P00oah00`00ogP00?lN003o7P03003o
7P03003odP00oah0??l000X0??l01000oah01@00ogP00?oB003odP00om800?mh02000?lN2`00ogP2
003odP800=;o00<007So000No`2F0?l00P3`0?l00`3o05X0?03o09H0o`04001ho`8001ko0`0l0?l0
103`0?l0o`000?l0FP3o05X20?l000050?00o`3o0;@0o`1J0?l0FP007_l00P0l0?l2000No`0403`0
o`2F0?l0o`000?00o`@0?03o1P00N?l2003Bo`04000No`00d_l00=;o09H0o`80o`2d00<0o`00001h
o`00d_l01@00om82001ho`03003Bo`00om800?oB00D00?oB00H001ko001ho`00N?l0?03o09H0o`3`
0?l20?l0000403`0o`00N?l00=;o000No`800=;o00<00?oB003Bo`00N?l00P00om82003oN005001h
o`00om800?oB003Bo`00om800`3oool2000000D0oooo000K0?ooo`030000003oool0oooo0080oooo
00H0??l0003o7P00om800?oB003oN000oah603co00<00?lN00<00=;o0?00o`00ogP00P00d_l00`00
ogP00?oB003Bo`02001ho`0309H0o`3o000001ko00800=;o00@001ko003odP00om800=;o0`00om80
0`00ogP00=;o03co000603co0004003o7P00ogP00?oB001ho`<00?lN1`0lo`000`00oah0??l003co
000303co00<00?lN0P00ogP3003o7PD0??l00P00oah;03co0006003o7P00ogP00?mh001ho`00om80
01ko0P00d_l00`00ogP00?lN003o7P05003o7PT0??l02P00oah3003oN0800?oB3@00ogP3003odP80
0=;o00D007So09H0o`2F0?l0o`1J0?l0000203`0o`80UP3o00<001ko0?l0003o05X01`3o00000`3`
0?l0?03o000No`03000No`03001ho`007_l0?03o008001ko0P3`0?l01P3o0000?03o03`0o`0l0?l0
07So000No`@00=;o00P0l03o003Bo`00om800?oB001ho`00om800=;o001ho`8001ko00<0o`1J003B
o`3o0;@00P00om82003oN003003odP2F0?l0UP3o00800=;o1P00om83003Bo`03001ho`0l0?l0UP3o
0080o`1J00@001ko0?00o`00d_l00?oB0P2F0?l00`00om8007So001ho`02003odP800?mh00<00?oB
003oN000ogP00P00om840?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo
0080oooo00H0??l0003o7P00om800?oB003oN000oah603co00<00?lN00<00=;o0?00o`00ogP00P00
d_l00`00ogP00?oB003Bo`02001ho`0309H0o`3o000001ko00800=;o00@001ko003odP00om800=;o
0`00om800`00ogP00=;o03co000603co0004003o7P00ogP00?oB001ho`<00?lN1`0lo`000`00oah0
??l003co000303co00<00?lN0P00ogP3003o7PD0??l00P00oah;03co0006003o7P00ogP00?mh001h
o`00om8001ko0P00d_l00`00ogP00?lN003o7P05003o7PT0??l02P00oah3003oN0800?oB3@00ogP3
003odP800=;o00D007So09H0o`2F0?l0o`1J0?l0000203`0o`80UP3o00<001ko0?l0003o05X01`3o
00000`3`0?l0?03o000No`03000No`03001ho`007_l0?03o008001ko0P3`0?l01P3o0000?03o03`0
o`0l0?l007So000No`@00=;o00P0l03o003Bo`00om800?oB001ho`00om800=;o001ho`8001ko00<0
o`1J003Bo`3o0;@00P00om82003oN003003odP2F0?l0UP3o00800=;o1P00om83003Bo`03001ho`0l
0?l0UP3o0080o`1J00@001ko0?00o`00d_l00?oB0P2F0?l00`00om8007So001ho`02003odP800?mh
00<00?oB003oN000ogP00P00om840?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003o
ool0oooo0080oooo00H00?lN003oN000d_l00=;o003oN000om8603co00800?lN00<00?mh003odP00
ogP01000ogP2003odP8007So00<0o`000?l0FP007_l00P00d_l01000om800?mh003oN000ogP2003o
dP0303`0o`00d_l00?lN00P0??l000<00?lN003oN03`0?l00P00om800`00oah0??l003co000;03co
00800?lN0`00om82003oN0L0??l000<00?oB03co000lo`002@0lo`03003o7P03003oN000om80o`2d
008007So00<0UP3o003odP00oah01000oah;03co00D00?lN00@00?mh09H0o`00om800?oB0P00d_l0
1@00om8007So001ho`00ogP00=;o00<00?mh0P00om85003oN0@00?oB00<00=;o000No`3`0?l00P2F
0?l00`3o0;@0o`000?00o`0403`0o`0309H0o`3o0000o`000080o`0000D0o`1J09H0o`3o0000o`00
0?l0]002000No`06001ho`2F0?l0UP3o001ho`0l0?l007So0P007_l0100l0?l0l03o0?l0]0007_l2
001ho`800=;o00H007So003odP00om800?oB03`0o`00d_l2003odP04003oN000om8001ko003odP80
01ko00<007So003odP00om800P00om82003oN004003Bo`00N?l007So003odP<00?mh0`00om800`00
d_l0?03o001ho`02001ho`0509H0o`3o0;@0o`2d0?l0]00l0?l00P00d_l3003odP800?mh00<00=;o
001ho`00N?l01@00ogP00`00om8001ko0?ooo`030?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo0P0lo`02003oN0800?lN1P0lo`02003odP03003oN000oah00?lN
00<00?lN00<00?oB003Bo`00d_l00P007_l00`3o0;@0o`1J000No`02001ho`030?l0FP00N?l00?mh
00<00?lN0`00ogP803co0003003odP00oah0o`0000<00?lN00<0UP3o03co000lo`000`0lo`000`00
om80??l003co000603co0003003o7P00om800?lN00800?lN1`0lo`000`00ogP0??l003co000803co
00@00?lN00<00?mh000No`2F0?l00P00om800`00ogP00?lN003o7P03003o7Pd0??l00P00oah00`00
ogP00?lN003o7P03003o7P<00?mh0`00om800`3`0?l00?oB003odP02003odP03003Bo`00om800?mh
00800?mh0P00om85003Bo`03001ho`007_l001ko0080o`0000@0o`1J09H0o`2F0?l0UP3o0P3o0000
1P3o0;@0o`000?l0000l0?l0o`2d000No`80o`0000@0o`2d000No`00d_l007So0P0l0?l2003Bo`04
0?00o`0l0?l0?03o03`0o`80o`2d0`007_l00`3o05X00?oB003odP03003odP800=;o0P00om82003o
N005003odP00ogP00?oB003odP00d_l00P00ogP2001ho`800?mh00@00?oB0?00o`3`0?l00?oB0`00
ogP2003odP03003Bo`2F0?l001ko00<007So00P0l03o0?l0003`0?l0l03o03`0o`007_l007So003B
o`800?oB0P00ogP01000om80o`000?l00000ogP4003o7P03003oN03`0?l0oooo00<0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool203co0080o`2d1`0lo`000`00
ogP0??l003co000203co00@00?lN00<00?mh003odP00om800P00N?l00`0l0?l0o`00000No`02003B
o`03003odP00ogP00?lN00D00?lN00<007So003o7P00oah01@0lo`001000oah0??l003co0000om82
003o7P80??l000<00?lN03co000lo`000P2Fo`0703co00800?lN00<00?mh001ho`00N?l00P00oahA
03co0003003o7P00ogP00=;o0080o`1J00<007So0?00o`00N?l00P00om800`00ogP00?lN003o7P02
003o7Q00??l02000oah4003oN003003odP3o05X001ko00<001ko00@00=;o003odP0l0?l0?03o0P00
om801P00d_l0?03o03`0o`007_l007So03`0o`8001ko00@0l03o0?l0003o0;@0l03o0P3o05X20?l0
00<0?03o00<001ko001ho`00N?l00P00N?l0103o00000=;o003Bo`00d_l20?l000800=;o0`00N?l0
10007_l0UP3o0?l0FP0l0?l2001ho`03003Bo`00om800?oB00<00?mh00@00=;o0?00o`00d_l00=;o
1000ogP2003odP03000No`00ogP00?mh00800?mh00<00?lN003Bo`00ogP00P007_l4003oN0800?oB
00<00=;o000No`00d_l00P00d_l00`00N?l0?03o0?l0000203`0o`04001ho`00d_l00=;o003Bo`80
07So1P00ogP4003o7P03003oN0007_l0oooo00<0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3oool0102Fo`00??l0003o7P00oah203co00@0U_l01`0lo`001@00ogP0
0=;o003Bo`00d_l00?oB00<007So00<0?03o0?l000007_l00P007_l2003odP04003oN000oah00?lN
003o7Pd0??l000<00?oB003o7P00oah00P0lo`0709Ko00@0??l000H00?lN0?l0FP3o05X00?mh03`0
o`00ogP2003o7Q00??l00P00oah2003oN0800?lN00<00?oB09H0o`007_l00P00N?l00`00ogP00?lN
003o7P02003o7Q00??l02`00oah3003oN0800?oB00@007So09H0o`007_l00=;o0P00N?l2003odP<0
0=;o0`007_l203`0o`040?l0FP3o0000o`2d0?00o`80o`2d00<0o`1J03`0o`3o00000P00N?l00`3o
0;@00=;o003Bo`02003Bo`0409H0o`00d_l00?oB003odP8001ko0P00om801`00d_l007So001ho`00
7_l0o`000?l0FP3o0;@00P00N?l00`3`0?l007So003odP03003oN003003odP00d_l00?mh00800?mh
0P00oah3003oN0030?00o`00ogP00?mh00@00?lN00D00?mh003odP00om800?mh003o7P05003oN080
0?oB0P00d_l00`007_l0UP3o0?l0FP020?00o`03001ho`00d_l00?oB00@00?mh1000oah00`0l0?l0
0?lN003o7P02003o7P03003oN0007_l0oooo00<0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3oool01@2Fo`00??l0003o7P00oah0??l000H0U_l01P0lo`03003o7P03
003odP3o05X0?03o0080UP3o00<0l03o09H0o`3o00000`2F0?l00`00om800?mh003o7P0803co00D0
U_l000<0??l0003o7P00ogP00`0lo`0:09Ko000303co0000oah00?lN00<00?mh00D0o`00003oN000
om800?oB003oN00603co00H0U_l01`0lo`02003o7P03003Bo`2F0?l00?mh00800?mh00<0o`00003o
dP00oah04P0lo`0;003o7P<00?mh0P00d_l01000om800=;o003Bo`3`0?l2000No`800=;o00H007So
003Bo`00d_l007So000No`3o00020?00o`80o`0000L0l03o09H0o`3`0?l0l03o0?l0002F0?l007So
00800=;o0P00N?l3003odP03003Bo`00N?l00?oB00D00?oB00L00=;o0?00o`3`0?l007So03`0o`3o
000001ko008007So0P00d_l00`00om800?mh003oN005003oN0@00?lN0P00ogP00`2F0?l00?mh003o
7P05003o7P800?mh0`00oah4003oN004003odP00N?l007So001ho`80?03o00H0o`2d0?00o`3`0?l0
?03o0?00o`00om84003oN0D00?lN0P0lo`03003o7P03003oN03oool0oooo0080oooo00<000000?oo
o`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool01@2Fo`00??l0003o7P00oah0??l0
00H0U_l01P0lo`03003o7P03003odP3o05X0?03o0080UP3o00<0l03o09H0o`3o00000`2F0?l00`00
om800?mh003o7P0803co00D0U_l000<0??l0003o7P00ogP00`0lo`0:09Ko000303co0000oah00?lN
00<00?mh00D0o`00003oN000om800?oB003oN00603co00H0U_l01`0lo`02003o7P03003Bo`2F0?l0
0?mh00800?mh00<0o`00003odP00oah04P0lo`0;003o7P<00?mh0P00d_l01000om800=;o003Bo`3`
0?l2000No`800=;o00H007So003Bo`00d_l007So000No`3o00020?00o`80o`0000L0l03o09H0o`3`
0?l0l03o0?l0002F0?l007So00800=;o0P00N?l3003odP03003Bo`00N?l00?oB00D00?oB00L00=;o
0?00o`3`0?l007So03`0o`3o000001ko008007So0P00d_l00`00om800?mh003oN005003oN0@00?lN
0P00ogP00`2F0?l00?mh003o7P05003o7P800?mh0`00oah4003oN004003odP00N?l007So001ho`80
?03o00H0o`2d0?00o`3`0?l0?03o0?00o`00om84003oN0D00?lN0P0lo`03003o7P03003oN03oool0
oooo0080oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool0102F
o`00??l003co000lo`0709Ko00D0??l000D00?lN003oN000om800?oB000No`02001ho`80?03o00<0
o`00000No`00N?l00P00N?l00`007_l00=;o003oN003003o7PD0??l01`2Fo`001@0lo`000?lN003o
N000ogP0??l000X0U_l01@0lo`000`00oah007So003oN002003o7P@0??l02P2Fo`0603co00800?lN
0P00ogP3003o7P800?mh00<00?lN03co000lo`00400lo`0<003o7PD00?mh0P00om80100l0?l007So
001ho`3o05X4001ho`030?00o`2F0?l0o`2d0080o`0000@0l03o03`0o`3`0?l0?03o0P2F0?l00`3o
0000UP3o03`0o`02001ho`800=;o0`00om800`2F0?l007So003odP03003oN003003odP2F0?l001ko
00<00=;o00<0UP3o0?l0FP0l0?l00P00N?l00`00d_l00?oB003oN002003oN0<00?lN0P00d_l4003o
7P800?mh00<0o`1J003odP00ogP02`00oah3003oN0800?oB0P00N?l00`3`0?l0o`2d0?l0]0030?00
o`030?l00000N?l00?oB00800?oB00<00?mh003o7P00oah00P00oah503co0003003o7P00om80oooo
00<0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool<09Ko0080
??l000@00?mh003o7P00ogP0?03o0`00ogP01P3o00000=;o001ho`00N?l0o`2d001ho`@00?oB00<0
0?mh003Bo`00ogP00P00oah503co00P0U_l000<0??l0003odP00om802`2Fo`0503co00800?oB00<0
0?lN03co000lo`000`0lo`0=09Ko00@0??l00P00oah00`3o05X00?lN003o7P0203co00<00?lN4P0l
o`0<003o7PH00?mh1000om800`00d_l007So09H0o`0203`0o`0309H0o`3o0000o`000080o`2d00@0
o`1J000No`007_l001ko0P3o00000`3o0;@0UP3o0?l0]002003Bo`800?oB0`00ogP00`00om80o`1J
003odP04003oN0080?00o`00d_l00?oB003odP00d_l001ko0?00o`3o00020?l0FP03001ho`00om80
0?mh00800?mh2000oah01000ogP00=;o003Bo`00N?l2003oN0X00?lN0`00ogP00`00om8007So003B
o`02003Bo`03000No`0l0?l0o`000080o`1J00@001ko0?00o`00om800?oB0`00d_l01000om800?mh
003o7P00oah503co0003003o7P00ogP0oooo00<0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3oool;09Ko00@0??l00P00om85003o7P<00=;o00<0o`1J001ho`00N?l0
0P00ogP01000N?l00?lN003oN000ogP2001ho`03003o7P007_l0??l00080??l02@2Fo`0203co00/0
U_l01@0lo`000`00oah00?mh003o7P0503co00d0U_l00`0lo`001@00oah00?oB003odP00ogP00?lN
00@0??l000<00?lN003oN00lo`004@0lo`0<003o7PH00?mh1000om830?00o`80o`0000<0o`2d0?l0
002F0?l00P007_l00`3`0?l007So003Bo`03001ho`0309H0o`3o000001ko008001ko00<007So003o
dP00ogP00P00ogP00`00om80?03o001ho`06003oN0800?oB00@00=;o0?l0FP3o0;@0l03o0P00N?l2
003odP03003Bo`00ogP00?mh00<00?lN100lo`001P00ogP00?lN003o7P00oah00?oB003oN0<00?lN
1@0lo`02003o7P03003oN000om800=;o00800=;o0P00om82001ho`03003Bo`3`0?l0o`000080?03o
00<007So003odP00ogP00`00ogP2003odP03001ho`00ogP00?mh00D0??l00P00oah40?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo2`2Fo`0303co0003003o7P00
d_l0o`0000@0??l000L00?lN003oN00l0?l0?03o0?l0]03`0?l00?oB00<00?lN0P0lo`001000oah0
0=;o003Bo`00om8403co00T0U_l00P00om8;09Ko0080??l00`00ogP00`00N?l00?oB003o7P0403co
00l0U_l00P0lo`001000oah0UP3o09H0o`00oah603co0003003o7P0lo`00??l000h0??l03P00oah6
003oN003001ho`00d_l00=;o00800=;o00L007So000No`3o0;@0o`2d0?l0FP3o0000?03o00<007So
00<0UP3o003Bo`00N?l00P00d_l00`00N?l0l03o001ho`03003odP040?l00000ogP00?mh003oN080
0?oB0P00ogP2003o7P<00?mh0P00om801000d_l0o`2d09H0o`3`0?l2003Bo`<00?mh0P2F0?l00`3`
0?l00?lN003o7P0503co00<00?lN00<00=;o003oN000oah00P00oah603co0003003o7P00ogP0o`00
00800?oB0`00ogP2003odP03003Bo`0l0?l0o`2d0080o`2d00@001ko001ho`00d_l00?mh1@00oah2
003Bo`D0??l000<00?lN03co003oool00`3oool00`000000oooo0?ooo`030?ooo`006`3oool20000
00<0oooo2`2Fo`0303co0003003o7P00d_l0o`0000@0??l000L00?lN003oN00l0?l0?03o0?l0]03`
0?l00?oB00<00?lN0P0lo`001000oah00=;o003Bo`00om8403co00T0U_l00P00om8;09Ko0080??l0
0`00ogP00`00N?l00?oB003o7P0403co00l0U_l00P0lo`001000oah0UP3o09H0o`00oah603co0003
003o7P0lo`00??l000h0??l03P00oah6003oN003001ho`00d_l00=;o00800=;o00L007So000No`3o
0;@0o`2d0?l0FP3o0000?03o00<007So00<0UP3o003Bo`00N?l00P00d_l00`00N?l0l03o001ho`03
003odP040?l00000ogP00?mh003oN0800?oB0P00ogP2003o7P<00?mh0P00om801000d_l0o`2d09H0
o`3`0?l2003Bo`<00?mh0P2F0?l00`3`0?l00?lN003o7P0503co00<00?lN00<00=;o003oN000oah0
0P00oah603co0003003o7P00ogP0o`0000800?oB0`00ogP2003odP03003Bo`0l0?l0o`2d0080o`2d
00@001ko001ho`00d_l00?mh1@00oah2003Bo`D0??l000<00?lN03co003oool00P3oool2000000D0
oooo000K0?ooo`030000003oool0oooo0080oooo1@3`o`0409Ko00<0??l00`00ogP603co0007000N
o`00ogP00?oB003odP3o0;@00?oB003oN002000No`03003o7P0lo`00??l000<00?lN00<00?oB003o
7P0lo`000P00d_l909Ko0080??l02`2Fo`0303co00800?lN00<00=;o03`0o`00ogP00P00oah203co
00l0U_l00P0lo`05003o7PD0??l000<00?lN03co000lo`003P0lo`03003o7P03003oN000oah00?lN
00L00?lN00<00?mh003odP00ogP00`00ogP3003odP8001ko00<0o`2d000No`2F0?l00P3o00020?00
o`<0UP3o0P00d_l2003odP<00=;o0P00N?l2003odP<00?mh0`00oah2003oN0@00?lN00P00?mh03`0
o`3o0;@0o`2d003oN000om80?03o0?l0]0800?oB00<00?mh003o7P00oah00P2F0?l00`00om800?lN
03co000503co00<00?lN00<0o`00003oN000oah0200lo`000`00ogP00?oB003oN003003o7P07003o
N000d_l007So001ho`007_l007So0?00o`020?l00004001ho`00om800?mh003oN0@00?lN0`0lo`00
0`00oah0??l003co000309Ko000303co003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
01/0oooo00<000000?ooo`3oool00P3oool60?3o00@0U_l000D00=;o003oN00l0?l0?03o003o7P02
03co000309Ko000lo`00??l00080??l000D00?lN003odP00om80o`2d003odP03003o7P04003oN00l
o`00??l0003Bo`80??l000<00?lN001ho`00ogP00P0lo`000`00oah0U_l009Ko000A09Ko0080??l0
00<00?lN03co0000oah00P00d_l00`3o00000?oB003o7P0403co00l0U_l000<0??l00?l0003`0?l0
6@0lo`04003o7P800?mh1P00oah4003oN005003odP00N?l007So003odP00d_l00P00om82003Bo`03
001ho`3o0000o`000080UP3o00<0l03o03`0o`007_l00P00d_l4003odP800=;o00<007So003odP3o
05X00P00om82003oN0D00?lN00<00?mh003o7P00oah00`00oah01`00ogP00?oB003odP00ogP00?oB
003oN0007_l00P3o0;@00`007_l00?lN003o7P03003o7P03003oN00lo`00??l000@0??l000H00?lN
003oN000ogP0?03o003Bo`00om8803co0003000No`00ogP00?lN00@00?lN00D00?mh003odP00om80
0=;o0?l000030?00o`04001ho`2F0?l00?oB000No`800?oB00<00?mh03co000lo`00100lo`0509Ko
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool70?3o00<0
U_l000<0??l0003Bo`00oah00P00oah509Ko0080??l000H00?lN003odP00om80o`00003oN000oah3
03co0003003odP2Fo`00U_l00080??l000<00?oB003oN000om800`00oah00`00om80U_l009Ko0003
09Ko00D0l?l01`2Fo`001P00oah0?03o03`0o`00ogP001ko0?00o`8001ko00<0o`1J000No`00oah0
100lo`0?09Ko0080??l000<00?mh003o7P00oah00P0lo`0609Ko00h0??l01@00oah00`00ogP00=;o
003oN004003oN00303`0o`00ogP00?mh00<00?mh0P00om8010007_l007So003Bo`00d_l2000No`03
001ho`3o0000l03o0080?03o00<007So003Bo`00d_l00P007_l01000d_l00?oB003oN000ogP2003o
dP800?mh00D00?oB0?l0003o00000?oB003oN005003o7P03003odP00oah00?lN00800?lN00@00?mh
001ho`00ogP00?mh0P00oah01000d_l00?oB003Bo`00d_l2003o7P@0??l000<00?mh03co000lo`00
100lo`001P00ogP00?lN003o7P007_l00?oB003o7P800?mh1@0lo`0010007_l0??l003co000lo`03
003o7P04003odP00N?l00?oB003odP80?03o00L0UP3o0?l0]03o0;@0o`0003`0o`2F0?l00?mh00<0
0?lN1@0lo`0609Ko00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0
0P3oool70?3o00<0U_l000D0??l0003oN02Fo`00U_l0003oN00509Ko000303co0000ogP00?mh0080
l03o00<0o`00003oN000om800P00oah00`0lo`00U_l009Ko000309Ko000303co0000om80o`0000<0
??l01@2Fo`080?3o00@0U_l000<00=;o03co000lo`000`0lo`001P00oah00?oB003odP007_l00?mh
003odP800=;o00<00?mh03co002Fo`003P2Fo`000`0lo`0007So03co000203co00/0U_l02P0lo`02
003o7P060?l00000oah00?lN003o7P00ogP00?oB1@00ogP00`00om800?mh003oN003003oN0<00?oB
00<00=;o09H0o`00N?l00P00N?l00`2F0?l0o`00000No`02001ho`030?l00000d_l00?oB00800=;o
00<001ko003odP00ogP01@00ogP3003odP800?mh1P00oah00`0lo`000?lN003o7P02003o7P03003B
o`00ogP00?mh00@00?lN0P00om82003o7PD0??l000<00?mh03co000lo`001P0lo`02003o7Ph0??l0
0P00oah01@00ogP001ko000No`3`0?l0o`0000<0o`2d00@001ko001ho`00N?l00=;o0P00ogP00`00
om800?lN03co000303co00H0U_l0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`L0l?l00`2Fo`001@0lo`000?mh09Ko002Fo`000?mh00D0U_l000<0??l0003o
N000ogP00P3`0?l00`3o00000?mh003odP02003o7P0303co002Fo`00U_l000<0U_l000<0??l0003o
dP3o00000`0lo`0509Ko00P0l?l0102Fo`000`00d_l0??l003co000303co0006003o7P00om800?oB
000No`00ogP00?oB0P00d_l00`00ogP0??l009Ko000>09Ko000303co0000N?l0??l00080??l02`2F
o`0:03co00800?lN00H0o`00003o7P00oah00?lN003oN000om85003oN003003odP00ogP00?mh00<0
0?mh0`00om800`00d_l0UP3o001ho`02001ho`0309H0o`3o000001ko008007So00<0o`00003Bo`00
om800P00d_l00`007_l00?oB003oN005003oN0<00?oB0P00ogP6003o7P0303co0000oah00?lN0080
0?lN00<00=;o003oN000ogP01000oah2003odP800?lN1@0lo`000`00ogP0??l003co000603co0080
0?lN3P0lo`02003o7P05003oN0007_l001ko0?00o`3o00000`3o0;@010007_l007So001ho`00d_l2
003oN003003odP00oah0??l000<0??l01P2Fo`040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo1`3`o`0309Ko00030?l0]00lo`00U_l000L0U_l000<00?lN03co
000lo`000P00oah00`00d_l00?lN03co0002003Bo`0303co002Fo`00U_l000<0U_l000<00?lN03co
0000oah00P0lo`0509Ko00/0l?l000<0??l009Ko002Fo`00102Fo`001`0lo`000?lN003oN000ogP0
0=;o003o7P0lo`001000ogP00`0lo`00U_l009Ko000<09Ko000303co0000N?l0??l000h0U_l01P0l
o`000`00oah00?mh003oN002003oN004003Bo`00om800?oB003odP8001ko00<0?03o001ho`00N?l0
0P00ogP3003odP<00?mh0`00om82003Bo`04000No`2F0?l0UP3o0?l0FP80?03o1000d_l3003odP80
0=;o00<00?oB003oN000oah00`00oah01000ogP00?oB003odP3o0002003oN0<00?lN1P0lo`001000
oah007So003o7P00oah203co00800?lN0P00d_l2003o7PH0??l01@2Fo`0303co0003003oN000om80
??l00080??l01@2Fo`0603co00800?lN00H00?oB001ho`00N?l0UP3o001ho`2F0?l203`0o`04001h
o`00om800=;o003o7P800?mh00<00?oB003Bo`00om800`0lo`0609Ko00@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3oool70?3o0080U_l000<0??l009Ko002Fo`00
1P2Fo`0203co0080U_l00`0lo`02003o7P<0??l000<00?lN09Ko002Fo`001@2Fo`000`0lo`000?lN
003o7P0309Ko00d0l?l01`2Fo`0203co00800?oB0P00oah00`0lo`000?oB003odP0303co00h0U_l0
00<007So03co002Fo`003P2Fo`0403co0003003o7P00d_l00?lN00800?mh0P00oah01`007_l00?oB
003odP00ogP00?oB03`0o`00N?l00P3o0;@00`00N?l00=;o001ho`05003odP8007So00@00=;o001h
o`00N?l001ko0P3o0;@00`3o0000UP3o001ho`02003Bo`800?oB0`00ogP01000om8007So003oN000
ogP5003o7P800?mh00<007So003odP00om800`00oah603co0003003odP00ogP0??l000@0??l000D0
0?lN003oN000ogP00?mh003o7P0503co00L0U_l01@0lo`0809Ko00<0??l00`00oah0103o00000?oB
003oN000ogP2003odP<0UP3o00<007So003odP00oah00`00oah00`00ogP00=;o003odP0403co00D0
U_l0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`L0l?l0
0P2Fo`000`00oah0U_l00?3o00060?3o00D0U_l00P00oah00`3o0000??l009Ko000;09Ko00800?oB
00<0??l009Ko003`o`003P3`o`0609Ko0080??l00P00ogP203co00D0U_l00P0lo`0<09Ko0080??l0
4@2Fo`0803co00800?lN00L00?mh003o7P00oah00?lN003oN000om800?mh00800?oB00<00?mh003o
dP3o00000P3o00000`00d_l007So003odP02003Bo`8007So00H001ko03`0o`3o0000o`000?00o`3o
05X3001ho`03003Bo`00om800?mh00@00?mh00<0o`00003oN000oah01000oah2003odP03003oN03`
0?l00?lN00<00?lN1`0lo`000`00oah0??l003co000303co0006003o7P00ogP00?mh000No`00ogP0
0?lN100lo`0909Ko0080??l02@2Fo`000`00oah00?oB003o7P02003o7P030?00o`00oah00?lN0080
0=;o00<00?lN003oN000d_l00P3o00000`00d_l00?mh003o7P0403co00800?lN0P00om800`00ogP0
??l003co000409Ko00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0
0P3oool70?3o00<0U_l0203`o`0509Ko00<00?lN1P2Fo`050?3o00@0U_l000<0??l009Ko003`o`00
3P3`o`0609Ko0080??l00P00om800`00ogP0??l009Ko000509Ko0003003o7P2Fo`00U_l000X0U_l0
00<00?lN09Ko002Fo`00402Fo`0:03co00@00?lN00<0?03o003oN000ogP00`00ogP4003odP03003B
o`00N?l007So008007So00@0?03o0?l0]00l0?l0UP3o0P3o05X00`2F0?l001ko003Bo`03003Bo`04
03`0o`00ogP00?mh003oN0800?lN00<00?oB003oN000oah01`00oah4003oN003003o7P0lo`00??l0
00/0??l000H00?lN003Bo`00d_l0?03o003oN000oah303co00X0U_l000<0??l0003o7P2Fo`00202F
o`0203co0004003o7P00N?l007So003oN0@0??l000<00?lN0?l00000N?l00P3o00001000om800?mh
001ho`00oah503co00800?mh0P00om8403co000309Ko003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3oool70?3o0080U_l02`3`o`000`2Fo`00??l0
003o7P02003oN003003o7P0lo`00U_l000<0U_l01`3`o`001@2Fo`00??l003co000lo`00U_l000l0
l?l01@2Fo`000`0lo`000?lN003o7P02003o7P0303co002Fo`00U_l000H0U_l00P0lo`0M09Ko00/0
??l00P00oah00`00om800?lN003o7P03003o7PD00?mh0P00om801`0l0?l0l03o0?00o`3o05X0o`2d
09H0o`3o0;@00P3o05X00`0l0?l007So003Bo`03003odP800?mh3P00oah01000ogP0o`00003oN000
ogP2003o7P`0??l00`00oah00`00ogP00?lN03co000303co00/0U_l000<0??l009Ko002Fo`001`2F
o`0203co00@00?lN100lo`000`00ogP00?lN003oN00209H0o`03003odP00oah0??l000<0??l00P2F
o`000`0lo`000?lN003o7P02003oN0@0U_l000<0l?l00?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`L0l?l00P2Fo`0;0?3o000309Ko000lo`00
0?lN00800?mh00<00?lN03co002Fo`000`2Fo`070?3o000509Ko000lo`00??l003co002Fo`003`3`
o`0509Ko000303co0000oah00?lN00800?lN00<0??l009Ko002Fo`001P2Fo`0203co01d0U_l02`0l
o`02003o7P03003odP00oah00?lN00<00?lN1@00ogP2003odP0703`0o`3`0?l0l03o0?l0FP3o0;@0
UP3o0?l0]0020?l0FP0303`0o`00N?l00=;o00<00?oB0P00ogP>003o7P04003oN03o00000?mh003o
N0800?lN300lo`03003o7P03003oN000oah0??l000<0??l02`2Fo`000`0lo`00U_l009Ko000709Ko
0080??l01000oah403co0003003oN000oah00?mh0080UP3o00<00?oB003o7P0lo`000`0lo`0209Ko
000303co0000oah00?lN00800?mh102Fo`000`3`o`00oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo000K0?ooo`8000000`3oool70?3o0080??l02`3`o`0309Ko00800?oB00<00?lN03co002F
o`000P00oah90?3o0080U_l000<00?mh09Ko003`o`003P3`o`0209Ko000303co0000oah00?lN0080
0?lN00@00=;o003odP00om80??l02P2Fo`080?3o01D0U_l03@0lo`06003o7PD00?mh0P00om801000
N?l001ko000No`0l0?l20?l0FP060?l0]03o0000o`000?00o`007_l0?03o0P00om83003oN0H00?lN
1`0lo`000`00d_l00?mh003Bo`02000No`03003odP00ogP00=;o00<0??l01P2Fo`0503co0003003o
dP00ogP00?lN00<0??l02`2Fo`000`0lo`00U_l009Ko000709Ko000303co0000ogP001ko00D0??l0
0P00ogP00`0lo`000?lN003oN00203`0o`04003odP00oah0??l003co00D0U_l00P00ogP00`0lo`00
0?lN03co000309Ko00040?3o003oool0oooo0?ooo`8000001@3oool001/0oooo00<000000?ooo`3o
ool00P3ooolD0?3o00<0U_l00P00om800`00oah0U_l009Ko000209Ko00/0l?l00P2Fo`0?0?3o00<0
U_l00P0lo`000`00oah00=;o0?00o`02003o7P80??l01P2Fo`0=0?3o01<0U_l03@0lo`07003o7P@0
0?mh0P00om801`00d_l007So001ho`007_l0?03o0?l0003`0?l00P2F0?l00`3o05X0o`2d001ho`03
003odP@00?mh1000oah703co00800?lN00@007So0?00o`3`0?l00?lN0`0lo`0909Ko00@0??l000<0
0?lN09H0o`00ogP00P00ogP203co00X0U_l000<0??l009Ko002Fo`001P2Fo`00100lo`000?lN003o
N000ogP303co00@0U_l000<0??l0003o7P00d_l00P00d_l01000om800?lN000No`0lo`0809Ko0003
03co00007_l0U_l00080U_l000<0l?l00?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?ooo`030?3o003o]000ok@000<0ok@000<0??l00?3o003`o`00
2`3`o`000`2Fo`00??l003co0002003Bo`0303co002Fo`00U_l000d0l?l00P2Fo`0>0?3o000403co
002Fo`00U_l009Ko00<0??l00P00N?l2003o7P03003Bo`00oah00?lN00@0U_l03`3`o`0A09Ko00h0
??l01P00oah00`00ogP00=;o003odP04003odP07003Bo`007_l001ko03`0o`2F0?l0o`0003`0o`02
000No`8007So00<00=;o03`0o`0l0?l00P00d_l4003oN0800?lN2@0lo`001@00ogP00?lN003o7P00
oah00?mh00<0??l02P2Fo`001P0lo`000?mh003oN02F0?l007So003odP800?lN0`0lo`0809Ko00D0
l?l00P2Fo`000`0lo`00U_l009Ko000203co0004000No`00ogP0??l003co00D0U_l000<0??l0003B
o`0lo`000`00ogP00`0lo`000?lN03co000203co00L0U_l00`0lo`000`2Fo`00l?l00?ooo`030?oo
o`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo2@3o]0090?3o00@0
U_l000H00?lN0?l0]03o0;@00?oB03co002Fo`0>0?3o000309Ko003`o`00l?l000`0l?l000<0U_l0
03co002Fo`000`0lo`000`00ogP007So003odP02003o7P0303co002Fo`00U_l00080U_l000<0??l0
0?3o003`o`003`3`o`0@09Ko0003003o7P0lo`00??l000T0??l01P00oah4003oN004003odP00d_l0
0=;o000No`800=;o0P00N?l010007_l0l03o0?l0]03o0;@2000No`03003Bo`00N?l00?oB008007So
00<001ko003Bo`3o0;@00P00d_l01000om800?mh003o7P00oah803co0004003o7P0lo`00??l003co
00<00?mh2`2Fo`0303co0003003o7P00om8007So00800?mh00<00?lN003oN000ogP00P0lo`0409Ko
00T0l?l0102Fo`000`0lo`000?lN03co0002003o7PD0U_l000<00?oB03co000lo`000P0lo`000`00
oah0??l009Ko000409Ko00H0l?l000D0U_l0003Bo`00d_l0U_l00?3o00040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo2@3o]0090?3o00@0U_l000H00?lN0?l0
]03o0;@00?oB03co002Fo`0>0?3o000309Ko003`o`00l?l000`0l?l000<0U_l003co002Fo`000`0l
o`000`00ogP007So003odP02003o7P0303co002Fo`00U_l00080U_l000<0??l00?3o003`o`003`3`
o`0@09Ko0003003o7P0lo`00??l000T0??l01P00oah4003oN004003odP00d_l00=;o000No`800=;o
0P00N?l010007_l0l03o0?l0]03o0;@2000No`03003Bo`00N?l00?oB008007So00<001ko003Bo`3o
0;@00P00d_l01000om800?mh003o7P00oah803co0004003o7P0lo`00??l003co00<00?mh2`2Fo`03
03co0003003o7P00om8007So00800?mh00<00?lN003oN000ogP00P0lo`0409Ko00T0l?l0102Fo`00
0`0lo`000?lN03co0002003o7PD0U_l000<00?oB03co000lo`000P0lo`000`00oah0??l009Ko0004
09Ko00H0l?l000D0U_l0003Bo`00d_l0U_l00?3o00040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo2P3o]0070?3o00@0U_l000D0??l0003odP3o0000o`00003o
7P0409Ko00`0l?l000<0U_l00?3o003`o`002P3`o`0209Ko000403co0000oah00?mh003oN0800?lN
00<001ko09H0o`00d_l00P00oah00`0lo`00U_l009Ko000309Ko0140l?l03`2Fo`0203co0003003o
7P0lo`00??l000P0??l00`00oah00`00ogP00?oB003oN002003Bo`<00?mh0`00d_l020007_l0?03o
000No`007_l0UP3o0?l0]03o05X001ko0P00N?l00`00d_l00?oB003odP03003oN006003odP00ogP0
0?oB003odP0l0?l00?mh0P00oah<03co000309H0o`00oah0??l000/0U_l00`0lo`000`007_l00?mh
0?l00002003oN003003o7P2F0?l0??l00080??l000<0U_l0003Bo`2Fo`002`3`o`0309Ko0003003o
N00lo`00U_l000X0U_l00P00oah00`00d_l0??l009Ko000309Ko00P0l?l00`2Fo`000`3`o`00oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo2`3o
]0050?3o000709Ko000lo`000?lN003o7P3`0?l001ko0?00o`020?l00003003o7P0lo`00??l00080
U_l0303`o`000`2Fo`00l?l00?3o00090?3o000509Ko002F0?l0UP3o003oN02Fo`00100lo`000`00
om8001ko0?l00002003o7P03003oN02Fo`00U_l00080U_l04`3`o`0=09Ko00@0??l00P00om800`00
oah0??l003co000403co00D00?lN00@00?mh003odP00d_l00=;o0P00ogP4003odP04003Bo`00N?l0
?03o03`0o`<0o`0000@0UP3o001ho`00N?l001ko0P00om84003oN007003o7P00ogP00?mh003Bo`00
oah00?oB003oN00=03co0003003oN00lo`00U_l000X0U_l000H0??l0003o7P00oah00?mh003o7P00
om82003oN080??l01@2Fo`0<0?3o00<0U_l000<00?mh003o7P2Fo`000P2Fo`030?3o00D0U_l00P0l
o`000`00N?l0??l009Ko000309Ko00X0l?l000<00?oB0?3o003oool00`3oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo``0ok@00P3`o`000`2Fo`00l?l00?3o0004
09Ko000403co003`0?l007So001ho`80??l000@00?mh003o7P00oah0U_l02P3`o`060?nd00H0l?l0
0P2Fo`030?3o00<0U_l00P0lo`000`00d_l00?oB03co0002003oN003003o7P0lo`00??l00080U_l0
4`3`o`0503co00@0U_l00P0lo`02003o7P@0??l00P00oah00`00ogP00?lN003o7P09003o7P800?oB
0P00N?l2003odP03003Bo`00om800?oB00800=;o00D007So000No`007_l0UP3o0?l0000203`0o`@0
07So00@001ko001ho`00N?l00?mh1000oah01000ogP00?lN003o7P00oah2003Bo`<0??l0202Fo`00
0`0lo`00l03o09Ko000:09Ko00D0??l00`00ogP00`0lo`00U_l009Ko000409Ko00h0l?l000@0U_l0
0?l0]02Fo`00U_l01`3`o`0309Ko00800?mh00<0?03o003o7P0lo`000`2Fo`0<0?3o00@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool<0?nd00P0l?l000<0U_l0
03co0000d_l00P00ogP00`0lo`00U_l009Ko000203co000309Ko000lo`00l?l000D0l?l02`3o]003
0?3o000303co003`o`00l?l000@0l?l000L0U_l0003odP00oah00?lN0?l00000oah0??l00080U_l0
00<00?lN003oN02Fo`000P2Fo`0C0?3o00@0U_l000@0??l003`0o`00oah00?lN2@0lo`02003odP03
003Bo`00oah00?lN00800?mh0P00oah00`00ogP00?lN003o7P02003o7P800?mh0P00om800`007_l0
0?oB000No`02000No`03003Bo`00N?l0UP3o0080?03o00@0l03o0?l0000l0?l007So0P00d_l2003o
dP@00?mh1@00oah603co0003003o7P2Fo`00U_l000P0U_l00P0lo`0909Ko0080??l00`2Fo`0203co
00800=;o00<00?oB09Ko002Fo`00102Fo`0>0?3o000309Ko000lo`00U_l000T0l?l0102Fo`0203co
0080U_l03@3`o`000`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo000K0?ooo`03
0000003oool0oooo0080oooo303o]0080?3o000309Ko000lo`000=;o00800?mh00<0??l009Ko002F
o`000P0lo`000`2Fo`00??l00?3o00050?3o00/0ok@00`3`o`000`0lo`00l?l00?3o00040?3o0007
09Ko0000om800?lN003o7P3o00000?lN03co000209Ko0003003o7P00ogP0U_l00080U_l04`3`o`04
09Ko000403co000l0?l00?lN003o7PT0??l00P00om800`00d_l00?lN003o7P02003oN0800?lN00<0
0?mh003o7P00oah00P00oah2003oN0800?oB00<001ko003odP007_l00P007_l00`00d_l007So09H0
o`0203`0o`040?00o`3o0000?03o001ho`800=;o0P00om84003oN0D00?lN1P0lo`000`00oah0U_l0
09Ko000809Ko0080??l02@2Fo`0203co00<0U_l00P0lo`02003Bo`03003odP2Fo`00U_l000@0U_l0
3P3`o`000`2Fo`00??l009Ko00090?3o00@0U_l00P0lo`0209Ko00d0l?l000<0o`000?ooo`3oool0
0P3oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo``0ok@0203`
o`0209Ko000303co0000oah00?lN0080U_l01@3`o`000`007_l0l?l00?3o00020?3o00d0ok@00P2F
o`080?3o000309Ko000lo`00??l00080??l00`2Fo`000`0lo`00?03o03co000203co01<0l?l01@2F
o`00100lo`000?lN003o7P007_l203co00<00?lN0P0lo`03003o7P<00?mh0P00d_l00`00oah00?mh
001ho`04003oN0@00?oB00<00=;o03`0o`00d_l00P3o0002001ho`03000No`0l0?l0?03o0080o`00
00<0?03o001ho`00d_l00P00d_l01@00om800?mh003oN000ogP0o`0000@00?lN200lo`0;09Ko0003
03co002Fo`00U_l000L0U_l000<0??l009Ko002Fo`000`2Fo`0303co0003003o7P0lo`00U_l000@0
U_l03P3`o`0209Ko00/0l?l00`2Fo`0203co00@0U_l0303`o`040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo3P3o]0070?3o000309Ko0000oah0U_l00080U_l0
2P3`o`0@0?nd00P0l?l000@0??l0003o7P00oah0??l01@2Fo`00100lo`000?mh09Ko002Fo`0C0?3o
00H0U_l00P00oah00`00ogP00?oB003o7P02003o7P04003oN000oah00?lN003o7P800?oB00<0l03o
000No`00N?l00P3`0?l00`00om800=;o03`0o`0203`0o`04003odP00d_l001ko001ho`80o`000P2F
0?l303`0o`03000No`0l0?l001ko00<0l03o00<0o`0003`0o`3`0?l00P00N?l00`3o05X00?oB003o
dP02003odP03001ho`007_l00?oB00800?mh200lo`0<09Ko0080??l03@2Fo`001P0lo`000?lN003o
7P0l0?l00?lN003odP800?lN0P2Fo`0>0?3o0080U_l02`3`o`001P2Fo`00??l003co000lo`000=;o
0?00o`<0U_l02P3`o`020?nd00@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?oo
o`h0ok@01P3`o`0209Ko0004003o7P2Fo`00U_l009Ko00P0l?l04`3o]0060?3o0080U_l00P00oah2
09Ko00D0l?l000<0U_l00?l0003o00004P3`o`0709Ko0080??l000<00?lN03`0o`00ogP00P00om80
1000N?l0o`1J003Bo`3`0?l2003oN003003Bo`00N?l00?oB00800?oB0P00ogP00`00om800?mh003o
N002003oN003003odP00N?l0o`2d0080o`2d00@0o`000?l0FP3o0000o`000P2F0?l0100l0?l0UP3o
09H0o`2F0?l20?l0]0<0?03o0P00N?l0103`0?l00?oB003odP00N?l4003o7PP0??l03P2Fo`070?3o
00H0U_l000H0??l0003o7P00oah0UP3o003odP00oah203co00<0U_l03@3`o`000`2Fo`00l?l00?3o
000:0?3o00<0U_l000<0??l00?l00000oah0102Fo`070?3o00@0ok@00`3oool2000000D0oooo000K
0?ooo`030000003oool0oooo0080oooo3P3o]0060?3o000309Ko000lo`00UP3o00<0U_l01`3`o`0E
0?nd00@0l?l00P2Fo`03003o7P0309Ko003`o`00l?l000D0l?l00P0lo`0B0?3o000309Ko0000N?l0
U_l000<0U_l000H0??l0003o7P00oah00?mh001ho`3o0003001ho`03003oN000oah00?lN0080UP3o
00<00?lN003odP00oah00P00om82003o7P05003odP00oah00?lN003o7P00ogP00P00om82003Bo`03
0?00o`007_l0?03o00<0o`1J00<0o`000?00o`2F0?l00P2F0?l00`3o0;@0o`000?l000020?l0FP03
09H0o`3o00000=;o008001ko00<00?mh003o7P00oah00`00oah703co00`0U_l02P3`o`0409Ko0007
03co0000oah00?lN003o7P00ogP001ko003oN00203co00<0U_l06@3`o`0409Ko000403co0000N?l0
0?mh0?l000800?oB00<00?lN09Ko002Fo`00103`o`050?nd00@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3oool<0?nd00<0l?l000<0U_l003co002Fo`000P0lo`00
0`2Fo`00??l0003Bo`02003o7P0309Ko003`o`00l?l000D0l?l05@3o]0001`0lo`00l?l00?3o003`
o`00U_l003co00007_l00P0lo`000`2Fo`00l?l00?3o00050?3o00800?lN4@3`o`0309Ko00800?lN
0P0lo`001@00oah00=;o003Bo`00om800?mh00<00?oB00<00?lN003oN00lo`000`0lo`000`00oah0
0?mh003o7P09003o7P03003oN000om800=;o00<00=;o0`007_l209H0o`050?l0003o0;@0o`2d09H0
o`007_l00P2F0?l203`0o`030?00o`3o0000o`0000800=;o0P00ogP00`00oah00?mh003oN002003o
7P80??l00`00oah00`0lo`00U_l009Ko000909Ko00`0l?l01@2Fo`0203co0003003oN03`0?l00?mh
00800?lN00@0??l0003oN02Fo`00U_l0603`o`00202Fo`00??l0003Bo`00d_l00?lN000No`00ogP0
??l0102Fo`030?3o000309Ko003`o`00ok@000@0ok@0103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?ooo``0ok@00`3`o`000`2Fo`00??l009Ko000203co000309Ko
000lo`000=;o00800?lN00<0U_l00?3o003`o`001@3`o`0E0?nd000703co003`o`00l?l00?3o002F
o`00??l0000No`0203co000309Ko003`o`00l?l000D0l?l00P00oahA0?3o00<0U_l00P00oah203co
0005003o7P00d_l00=;o003odP00ogP00`00om800`00oah00?mh03co000303co0003003o7P00ogP0
0?lN00T00?lN00<00?mh003odP00d_l00`00d_l3000No`80UP3o00D0o`000?l0]03o0;@0UP3o000N
o`0209H0o`80?03o00<0l03o0?l0003o00000P00d_l2003oN003003o7P00ogP00?mh00800?lN0P0l
o`03003o7P0303co002Fo`00U_l000T0U_l0303`o`0509Ko0080??l000<00?mh0?00o`00ogP00P00
oah0100lo`000?mh09Ko002Fo`0H0?3o000809Ko000lo`000=;o003Bo`00oah001ko003oN00lo`04
09Ko00<0l?l000<0U_l00?3o003o]000103o]0040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo303o]0050?3o000609Ko0000om800?oB003o7P00ogP00?oB0P0l
o`0309Ko00@0l?l05P3o]0050?3o0005001ho`00oah0??l003co0000ogP06P3`o`0309Ko0080??l0
00<007So003oN000oah00P0lo`02003o7P050?l0]00lo`00??l003co0000ogP0100lo`000`00oah0
0?mh03co000403co00D00?lN00H00?oB03`0o`00d_l00=;o003odP00d_l3001ho`03000No`0l0?l0
o`000080l03o00<0?03o000No`3`0?l00`00N?l00`007_l0l03o001ho`02001ho`800=;o00<00?oB
003oN000ogP00`00oah00`00N?l00?lN003o7P0303co00T0U_l03`3`o`0309Ko0080??l000<00?lN
03`0o`00d_l00`0lo`000`00om80U_l009Ko0002003o7PP0l?l00`3o]00:0?3o000309Ko0000oah0
U_l000<0U_l000<00?lN003oN00lo`000P2Fo`070?3o00D0ok@0103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?ooo``0ok@01@3`o`0309Ko000303co0000om80?03o
00<00?lN00@0??l009Ko002Fo`00U_l00P3`o`0G0?nd00@0l?l000<00?oB09Ko003`o`000P3`o`00
0`2Fo`00l?l00?3o000F0?3o0080U_l000H00?mh003o7P0lo`00??l0003oN00lo`0309Ko000303co
0000oah00?oB00<0??l000<00?lN03co000lo`000P0lo`000`00om80??l003co000503co00<00?lN
00<0?03o003oN000om800P00ogP2003odP06003Bo`007_l001ko03`0o`2F0?l0o`000P3o0;@0102F
0?l0l03o003Bo`00d_l20?l0FP800=;o00<00?oB003oN000ogP00P00ogP00`00om80o`2d0?l0]002
003odP040?00o`00d_l00?lN003o7PL0??l01@2Fo`0?0?3o00<0U_l00P0lo`02003o7P03001ho`0l
o`00??l00080U_l0103`o`000`2Fo`00l?l00?3o00020?3o00T0ok@01@3`o`02003o7P0309Ko003`
o`00l?l00080U_l00P0lo`001000oah0U_l009Ko002Fo`060?3o00H0ok@0103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`/0ok@01P3`o`001P2Fo`00??l003co
000lo`000?oB003oN0800?lN0P2Fo`050?3o01L0ok@00P3`o`0209Ko0003003Bo`3`o`00l?l000P0
l?l00`3o]00>0?3o00<0U_l000<00?oB003o7P0lo`000P2Fo`000`0lo`00U_l009Ko000309Ko0080
??l00P00oah00`0lo`00U_l009Ko000;03co00D00?lN1000ogP2003odP800=;o00<007So0?l0]03o
00000P3o0;@0100l0?l007So001ho`00om82003Bo`<00?oB0P00ogP2003o7P07003odP00oah00?lN
003o7P00om8001ko003Bo`02003o7P03003oN000oah00?mh00@0??l000<00?lN03co000lo`000P2F
o`0@0?3o000709Ko0000oah00?lN003o7P2Fo`00??l0003Bo`0203co000309Ko003`o`00l?l000H0
l?l03P3o]0000`3`o`00U_l00?3o00060?3o0080U_l000@007So09Ko002Fo`00U_l01P3`o`060?nd
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool:0?nd0080
l?l00`2Fo`000`3`o`00U_l009Ko000203co0003003oN00l0?l00?mh00800=;o00<0U_l00?3o003`
o`00103`o`0G0?nd00<0l?l000<00?lN03co002Fo`00103`o`000`2Fo`00ok@00?nd00090?nd00T0
l?l000<0U_l003co000lo`000P0lo`0:09Ko0003003o7P0lo`00U_l000L0U_l0200lo`05003o7P<0
0?mh00<00=;o0?l0]000d_l00P00N?l00`2F0?l0l03o0?l000020?l0FP0303`0o`00N?l00=;o00<0
0?oB0P00ogP00`007_l00=;o003Bo`07003o7P050?00o`00ogP00?lN003o7P00om801@00ogP00`00
oah0??l009Ko000309Ko0100l?l00P0lo`02003oN00309Ko0000oah0??l00080??l000<0U_l00?3o
003`o`001@3`o`0@0?nd00T0l?l000<0U_l0003o7P2Fo`000P2Fo`060?3o00H0ok@0103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`X0ok@00P3`o`0309Ko0003
0?3o002Fo`00U_l00080??l000<00?mh03`0o`00ogP00P00d_l00`2Fo`00l?l00?3o00040?3o01L0
ok@00`3`o`000`00oah0??l009Ko00040?3o000309Ko003o]000ok@000T0ok@02@3`o`000`2Fo`00
??l003co000203co00X0U_l000<00?lN03co002Fo`001`2Fo`0803co00D00?lN0`00ogP00`00d_l0
o`2d003Bo`02001ho`0309H0o`3`0?l0o`000080o`1J00<0?03o001ho`00d_l00`00om82003oN003
000No`00d_l00=;o00L00?lN00D0l03o003oN000oah00?lN003odP05003oN003003o7P0lo`00U_l0
00<0U_l0403`o`0203co00800?mh00<0U_l0003o7P0lo`000P0lo`000`2Fo`00l?l00?3o00050?3o
0100ok@02@3`o`000`2Fo`000?lN09Ko000209Ko00H0l?l01P3o]0040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo2@3o]0000`3`o`00U_l00?3o000209Ko0003
03co0000oah0??l000<0??l000<00?mh0?l0FP00ogP00P0lo`0209Ko00D0l?l05`3o]0030?3o0003
003oN03`o`00l?l000<0l?l03`3o]0060?3o000303co002Fo`00U_l00080U_l01@3`o`0609Ko0003
03co002Fo`00U_l000P0U_l01`0lo`05003o7P<00?mh00<00?oB003Bo`00d_l00P00d_l00`007_l0
l03o0?l0000209H0o`04000No`00N?l001ko001ho`800?oB1@00ogP2003o7P@0??l000<00?lN0?l0
FP00oah00P0lo`000`00oah00?oB0?00o`02001ho`03003odP0lo`00U_l000@0U_l0403`o`000`00
oah0U_l00?3o00020?3o0080U_l00P00om800`2Fo`00l?l00?3o00040?3o0140ok@02@3`o`000`2F
o`000?lN03co000309Ko00@0l?l000<0U_l00?nd003o]000103o]0040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo1`3o]0020?3o000303co002Fo`000=;o0080
??l000@00?mh03co000lo`00??l00P00oah00`3`0?l001ko09H0o`0303co0080U_l00P3`o`000`2F
o`00l?l00?nd000F0?nd0080l?l000@0U_l003co003`o`00l?l04`3o]0040?3o000303co003`o`00
l?l000X0l?l00`2Fo`000`0lo`00U_l009Ko000909Ko00H0??l01@00oah5003oN0800?oB0P00d_l0
0`00N?l0?03o0?l0000203`0o`04001ho`00d_l00?oB001ho`<00?oB1@00oah603co0003003odP0l
o`00??l00080??l000L007So003odP3o0000o`00000No`00oah0??l000<0U_l000<00?mh09Ko003`
o`003P3`o`000`2Fo`00l?l00?3o00030?3o00<0U_l000<00?mh09Ko003`o`00103`o`0B0?nd00L0
l?l00P2Fo`000`00oah00?oB03co000403co00@0l?l01@3o]0040?ooo`030000003oool0oooo00<0
oooo00080?ooo`800000103oool2000000<0oooo1@0000030?ooo`030000003oool0oooo0080oooo
1P3o]0000`3`o`000?oB003odP050?3o000409Ko003`o`00U_l009Ko0080??l00P00om801P00oah0
??l003co0000oah00=;o03co0080o`2d0`3`o`0F0?nd0080l?l000<00=;o0?3o003`o`005@3o]000
0`2Fo`00l?l00?3o000@0?3o00`0U_l00P0lo`05003o7P800?mh00@00?oB003Bo`00ogP00?oB0P00
ogP00`00om800=;o09H0o`02003Bo`03000No`3`0?l0o`000080UP3o00@007So003Bo`00om800?oB
0`00ogP5003o7PH0??l000<00?lN03co000lo`00100lo`02003odP03003o7P0lo`00?03o00<00?mh
0P2Fo`0F0?3o0080U_l000<0o`2d003o7P2Fo`000`3`o`0E0?nd00<0l?l00P2Fo`001000d_l00?lN
003o7P007_l2003Bo`0303co0000oah0l?l000@0l?l01@3o]0040?ooo`030000003oool0oooo00<0
oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`@0ok@00P3`o`050?nd00H0l?l000@0U_l003co000lo`000=;o0P00oah209Ko
000303co002Fo`000?lN00800?lN00<0U_l00?3o002Fo`005P3o]0020?3o000309Ko003`o`00ok@0
01H0ok@04P3`o`0<09Ko00@0??l00P00oah01`00ogP00=;o003Bo`3o05X001ko003odP00d_l00P00
om800`00d_l00?oB001ho`03000No`0809H0o`3o0000UP3o09H0o`3o0000UP3o003Bo`00om84003o
N0@00?lN200lo`0309Ko000703co003o0;@00?mh003oN00lo`00U_l003co0002003o7P03003oN02F
o`00??l001D0l?l000<0U_l0003o7P00oah00P0lo`040?3o01D0ok@00P3`o`001`2Fo`00??l003co
0000ogP0??l0003Bo`3o00000P00N?l209Ko00D0l?l000<0U_l00?nd003o]0000P3o]0040?ooo`03
0000003oool0oooo00<0oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool2000000<0oooo103o]0020?3o00D0ok@01P3`o`00102Fo`00??l003co0000d_l2003o
7P80U_l000<0??l009Ko0000oah00P00oah00`2Fo`00l?l009Ko000F0?nd0080l?l000<0U_l00?3o
003o]0005P3o]00B0?3o00`0U_l0100lo`02003o7P07003oN000d_l00=;o0?l0FP007_l00?oB003B
o`02003odP03003Bo`00om8007So00<001ko00P0UP3o0?l0002F0?l0UP3o0?l0002F0?l00=;o003o
dP@00?mh1000oah803co00<0U_l000L0??l00?l0]000ogP00?mh03co002Fo`00??l000800?lN00<0
0?mh09Ko000lo`005@3`o`000`2Fo`000?lN003o7P0203co00@0l?l05@3o]0020?3o000709Ko000l
o`00??l0003oN00lo`000=;o0?l00002001ho`80U_l01@3`o`000`2Fo`00ok@00?nd00020?nd00<0
oooo0P0000050?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool0103oFP00ok@00?3o003`o`0:0?nd00<0l?l000D00?lN03co
000lo`00UP3o003o7P0309Ko0080l?l000H00?oB09Ko002Fo`00??l009Ko003`o`0F0?nd0080U_l0
00<0l?l00?nd003o]0005P3o]00C0?3o00/0U_l01@0lo`02003o7P@00?mh00H00?oB003Bo`00om80
0?oB001ho`007_l30?l000030?l0]03`0?l0o`1J00<0o`0000<0UP3o003Bo`00d_l00P00om800`00
7_l00?mh003odP02003odP800?lN1@0lo`0609Ko00<0??l00`2Fo`0203co000409Ko0000oah0??l0
09Ko01@0l?l000D0U_l00?3o003`o`00U_l0003o7P040?3o01D0ok@01@3`o`0209Ko000503co0000
d_l00?lN003o7P00om800P2Fo`030?3o00040?00o`3`o`00l?l00?3o0080ok@0103oool00`000000
oooo0?ooo`030?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`3oFP00ok@00?nd000<0?nd00030?3o002Fo`00U_l00080
U_l000<00=;o03co0000oah0103`o`000`2Fo`00l?l00?3o000209Ko0003003oN03`o`00ok@001<0
ok@000<0l?l003co000lo`006@3o]00C0?3o00X0U_l01`0lo`001P007_l00?lN003o7P00oah00?mh
03`0o`<00?mh00<00?oB003Bo`007_l00P007_l00`2F0?l0o`000?l0]0020?00o`04000No`00N?l0
0=;o003Bo`800?oB00<001ko003odP00d_l00P00d_l00`00ogP00=;o003oN002003o7P0303co002F
o`00U_l000H0U_l00P00om8809Ko0003003o7P2Fo`00U_l000T0l?l01@3o]0030?3o000309Ko003`
o`00l?l00080l?l000<0??l0003oN03`o`000P3`o`0E0?nd00D0l?l000@0U_l003co0000oah00=;o
0P00om800`0lo`00U_l003co000409Ko00050?3o000lo`00??l00?3o003o]000103oool00`000000
oooo0?ooo`030?ooo`00203oool2000000X0oooo0P0000050?ooo`030000003oool0oooo0080oooo
0P3oFP0=0?nd00<0l?l00P2Fo`000`0lo`00U_l009Ko000209Ko0080l?l000<007So0?3o003`o`00
0`3`o`000`2Fo`00l?l00?3o000B0?nd00<0l?l06@3o]00C0?3o00P0U_l00P0lo`000`00oah0??l0
03co000403co00D00?lN1000ogP00`00d_l007So003Bo`02001ho`0309H0o`3o0;@0o`2d008001ko
00@007So003Bo`00d_l00?oB1@00ogP2003odP800?lN100lo`0=09Ko00D0l?l00`2Fo`000`0lo`00
l?l00?3o00040?3o00/0ok@00`3`o`000`0lo`00U_l009Ko00030?3o01D0ok@01@3`o`0209Ko0007
003o7P00om80?03o03`0o`007_l007So03`0o`02003o7P03001ho`007_l0??l00080U_l000<00?lN
0?3o003oool00`3oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
o`80oeX03@3o]0030?3o00<0U_l01@3`o`070?nd00030?3o002Fo`00U_l00180ok@000<00?lN0?nd
003o]0006`3o]00A0?3o000309Ko000lo`000?lN00<00?lN00D0??l0003odP0lo`00??l0003o7P06
03co00D00?lN1000ogP2003odP06000No`3o0000o`0009H0o`3o0000o`2d0P0l0?l00`007_l00=;o
003odP04003oN0D00?lN1@0lo`0;09Ko00/0l?l000<00?oB0?3o003`o`000P3`o`0?0?nd0080l?l0
00@0??l009Ko003`o`00l?l05@3o]0000`3`o`00??l009Ko000209Ko000403co0000oah00?lN003o
dP8001ko00<00?lN09Ko002Fo`000P2Fo`000`0lo`00l?l00?3o00020?3o000309Ko0000ogP0oooo
00<0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool40?mJ00/0
ok@000<0l?l003co000lo`000P00om800`2Fo`00l?l00?3o00020?3o00T0ok@00`3`o`0A0?nd0003
0?3o003o]000ok@001T0ok@04`3`o`0509Ko0080??l000<001ko003o7P00oah01`00oah01000d_l0
0?lN003o7P00oah2003oN004003odP00N?l007So001ho`800=;o0P00N?l00`007_l0o`2d0?l0]002
000No`03001ho`00d_l00=;o00<00?oB00<00?mh003o7P00oah00P00oah603co00X0U_l0403`o`0A
0?nd0080l?l00`2Fo`0C0?nd00@0l?l000L00?lN003odP00om800?lN03co002Fo`000?lN0080l03o
00<00?lN03co003`o`001`3`o`020?nd00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3oool40?mJ00/0ok@000<0l?l003co000lo`000P00om800`2Fo`00l?l00?3o
00020?3o00T0ok@00`3`o`0A0?nd00030?3o003o]000ok@001T0ok@04`3`o`0509Ko0080??l000<0
01ko003o7P00oah01`00oah01000d_l00?lN003o7P00oah2003oN004003odP00N?l007So001ho`80
0=;o0P00N?l00`007_l0o`2d0?l0]002000No`03001ho`00d_l00=;o00<00?oB00<00?mh003o7P00
oah00P00oah603co00X0U_l0403`o`0A0?nd0080l?l00`2Fo`0C0?nd00@0l?l000L00?lN003odP00
om800?lN03co002Fo`000?lN0080l03o00<00?lN03co003`o`001`3`o`020?nd00@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool40?mJ00/0ok@00P3`o`001P2F
o`000=;o003Bo`2Fo`00??l00?3o00d0ok@000<0l?l00?nd003o]0003P3o]0000`3`o`00ok@00?nd
000J0?nd01<0l?l01P2Fo`0203co00800?lN00<0o`00003Bo`00oah01@00oah2000No`@00?mh0P00
om800`00N?l0?03o000No`02000No`030?00o`3o0;@0o`000080o`0000@001ko001ho`00N?l00?oB
0`00ogP5003o7PH0??l01`2Fo`0@0?3o01@0ok@000@0l?l003co003`o`00l?l04`3o]0020?3o0003
003o7P2Fo`000?lN0080??l00P2Fo`0203co00800?oB00<00?lN09Ko003`o`00103`o`050?nd00@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool40?mJ00X0ok@0
0`3`o`000`2Fo`000?lN003o7P030?3o00h0ok@000<0U_l00?nd003o]0000`3o]0070?mJ0200ok@0
4P3`o`0809Ko000603co002F0?l0UP3o003o7P00ogP0l03o0P007_l3003o7P800?mh00@001ko003o
N000ogP00?mh0`00om82003Bo`8007So00<0UP3o0?l0]03o0;@00P0l0?l01000N?l00=;o003odP00
om83003oN003003odP00N?l00?lN00<00?lN00D0??l0003o7P00oah00?mh03co0002003o7PD0U_l0
403`o`0E0?nd00030?3o002Fo`00U_l001<0ok@00P3`o`000`0lo`00U_l00?3o0002003o7P80l?l0
00<0U_l003co0000ogP00P00ogP209Ko00<0l?l01P3o]0040?ooo`030000003oool0oooo00<0oooo
000K0?ooo`030000003oool0oooo0080oooo103oFP080?nd00<0l?l00P2Fo`000`0lo`000?mh003o
N0030?3o0100ok@03`3oFP0L0?nd0080U_l03P3`o`0:09Ko00@0??l000@00?lN003odP3o0000o`00
1@00ogP01000d_l00?oB003odP00d_l3003odP800=;o0P00N?l00`0l0?l0UP3o0?l0000203`0o`04
0?l00000d_l00=;o09H0o`<00?oB00<0?03o003oN000oah00P00oah01000ogP00?lN000No`007_l2
003Bo`04003oN000d_l0??l003co00<0U_l03`3`o`0G0?nd00800?lN4P3o]0000`3`o`000?mh003o
N0030?3o0080U_l00P3`o`0209Ko0080??l000<00?lN09Ko003`o`000P3`o`070?nd00@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool40?mJ0080ok@000<00?lN
03co000lo`000`3`o`0209Ko0080l?l000L0U_l0001ho`00oah00?lN003odP2Fo`00l?l000h0ok@0
4P3oFP0J0?nd00@0l?l000<00?lN09Ko003`o`002@3`o`0;09Ko00@0??l00P00oah2001ho`800?oB
00H00?mh003odP00om8007So000No`00om85003Bo`@001ko00D0l03o0?l0002F0?l0UP3o000No`02
001ho`06003Bo`00om800?oB0?l00000om800?mh0P00N?l2003oN004000No`00ogP00?mh003oN080
??l01P2Fo`0?0?3o01L0ok@00`3`o`0A0?nd0003003odP3`o`00l?l000H0ok@01@3`o`000`00ogP0
U_l00?3o00020?3o00L0ok@0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo
0?ooo`020?ooo`@0oeX00P3o]0000`00oah0??l003co00030?3o0080U_l00P3`o`001`2Fo`0007So
003o7P00oah00?oB09Ko003`o`003P3o]00B0?mJ01X0ok@0103`o`000`00oah0U_l00?3o00090?3o
00/0U_l0100lo`02003o7P8007So0P00om801P00ogP00?oB003odP00N?l001ko003odPD00=;o1000
7_l01@3`0?l0o`0009H0o`2F0?l001ko008007So00H00=;o003odP00om80o`00003odP00ogP2001h
o`800?mh00@001ko003oN000ogP00?mh0P0lo`0609Ko00l0l?l05`3o]0030?3o0140ok@000<00?oB
0?3o003`o`001P3o]0050?3o0003003oN02Fo`00l?l00080l?l01`3o]0040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`8000000`3oool40?mJ00D0ok@000<0l?l009Ko0000oah00P0lo`0209Ko
0005003odP00N?l0??l003co002Fo`00103`o`0;0?nd01D0oeX0603o]0050?3o00D0U_l0103`o`05
09Ko000303co002Fo`00U_l000@0U_l000L0??l0003o7P0lo`00??l0003o7P3o05X00?lN00800?oB
00<00=;o001ho`00om800`00d_l00`007_l00=;o003Bo`0203`0o`800=;o00<007So000No`007_l0
0P0l0?l01`2F0?l0o`000?l0002F0?l0?03o000No`00N?l00P3`0?l00`00d_l00?oB003odP02003o
dP03003Bo`00ogP00?mh00800?lN0P0lo`0709Ko00l0l?l06@3o]0000`00oah0ok@00?nd000>0?nd
000309Ko003`o`00ok@000P0ok@0103`o`000`0lo`000?lN03co00020?3o00L0ok@00`3oool20000
00D0oooo000K0?ooo`030000003oool0oooo0080oooo103oFP060?nd00040?3o002Fo`00U_l009Ko
00<00?lN00@0o`2d03co000lo`00U_l0103`o`090?nd01P0oeX05P3o]0070?3o0080U_l000<0??l0
09Ko002Fo`000`2Fo`000`0lo`00U_l009Ko000309Ko0003003odP0lo`00U_l00080U_l000<00?lN
03co000lo`000P00oah2003oN0<00?oB00<007So03`0o`00N?l00P007_l01000N?l0o`1J000No`00
N?l20?l0FP<007So10007_l01`3o0000UP3o09H0o`3o05X0o`000?l0]00l0?l00P3o05X00`00N?l0
l03o001ho`02001ho`03003Bo`00ogP00?lN00@0??l01`2Fo`0?0?3o02T0ok@000<0l?l00?nd003o
]0002@3o]0001P3`o`00U_l0003o7P00oah0??l0003o7P@0l?l01P3o]0040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo103oFP070?nd00<0l?l000@0U_l0003o
7P00d_l007So0P00d_l00`00om80??l0003odP040?3o00H0ok@06P3oFP0D0?nd00P0l?l00`2Fo`00
0`00ogP0??l009Ko000209Ko000303co002Fo`00U_l000<0U_l000<00=;o03co000lo`001@0lo`02
003o7P800=;o00D007So000No`007_l0UP3o0?00o`030?l0FP0403`0o`3o0000UP3o03`0o`80o`00
00<001ko0?00o`007_l01@007_l209H0o`0403`0o`3o0000l03o0?l00080o`1J00<0UP3o0?l0]00l
0?l00P3`0?l00`00om800?mh001ho`02003o7P80??l01`2Fo`02003o7Pd0l?l06P3o]0000`3`o`00
ok@00?nd00020?nd0080oeX0203o]0000`3`o`00ok@00?nd000:0?nd00<0l?l000<0U_l0003o7P3`
o`000P3`o`000`2Fo`00ok@00?nd00040?nd00@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3oool20?mJ00T0ok@00`3`o`00102Fo`000?lN0?00o`00ogP203co0080
U_l000<00?oB0?3o003`o`000P3`o`000`00ogP0l?l00?3o00020?nd01`0oeX04@3o]00:0?3o0080
U_l000<0??l0003oN00lo`000`2Fo`0203co00<0U_l000<00?mh003o7P00ogP00P00oah00`00om80
0?mh003Bo`03001ho`03000No`2F0?l007So0080o`2d00<0?03o0?l0]03o0;@00P3o0000103`0?l0
o`2d0?l0003o00020?l0FP0309H0o`0l0?l0?03o00@001ko00L007So03`0o`0l0?l007So000No`3o
0000o`2d0080l03o00<0UP3o0?00o`3o00000P2F0?l00`007_l0?03o003oN002003oN003003o7P0l
o`00??l000D0U_l000@00?mh09Ko002Fo`00U_l02P3`o`000`2Fo`00l?l00?3o000I0?nd00`0oeX0
00<0ok@00?3o003`o`003@3o]0030?3o000309Ko003o0;@0U_l00080??l00`3`o`040?nd00@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool20?mJ0080ok@000<0
l?l00?nd003o]0000`3o]0020?3o00800?lN00@0??l0003o7P00N?l00?lN0P2Fo`050?3o00H0ok@0
00<0l?l00?mJ003oFP006P3oFP0?0?nd00@0l?l000<00?lN0?3o003`o`001@3`o`0309Ko000303co
002F0?l0??l00080??l000<00?lN03co000lo`000`00oah01000N?l0o`00003odP00om82003o7P06
003odP0lo`000?lN003o7P00om800?mh0`00om800`00d_l0o`00001ho`0209H0o`04001ho`3o0000
01ko03`0o`80l03o00<0o`000?l0FP2F0?l00P0l0?l2000No`03001ho`00d_l00=;o008007So00@0
0=;o000No`0l0?l0?03o0P00N?l0103`0?l0?03o03`0o`007_l20?l0FP800=;o00@00?mh03co0000
oah0??l00P00oah00`0lo`000?lN09Ko000709Ko00040?3o002Fo`00U_l003co0080U_l00`3`o`0H
0?nd0100oeX03@3o]0001P3`o`00U_l009Ko0000om80o`00003o7P80U_l00`3`o`0303co000309Ko
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3o
ool20?mJ0080ok@000<0l?l00?nd003o]0000`3o]0020?3o00800?lN00@0??l0003o7P00N?l00?lN
0P2Fo`050?3o00H0ok@000<0l?l00?mJ003oFP006P3oFP0?0?nd00@0l?l000<00?lN0?3o003`o`00
1@3`o`0309Ko000303co002F0?l0??l00080??l000<00?lN03co000lo`000`00oah01000N?l0o`00
003odP00om82003o7P06003odP0lo`000?lN003o7P00om800?mh0`00om800`00d_l0o`00001ho`02
09H0o`04001ho`3o000001ko03`0o`80l03o00<0o`000?l0FP2F0?l00P0l0?l2000No`03001ho`00
d_l00=;o008007So00@00=;o000No`0l0?l0?03o0P00N?l0103`0?l0?03o03`0o`007_l20?l0FP80
0=;o00@00?mh03co0000oah0??l00P00oah00`0lo`000?lN09Ko000709Ko00040?3o002Fo`00U_l0
03co0080U_l00`3`o`0H0?nd0100oeX03@3o]0001P3`o`00U_l009Ko0000om80o`00003o7P80U_l0
0`3`o`0303co000309Ko003oool0oooo0080oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3oool00`3oFP00ok@00?nd00020?nd000409Ko003`o`00ok@00?nd00<0l?l0
0P2Fo`00100lo`0007So0?l00000oah203co000309Ko003`o`00l?l000P0ok@07P3oFP070?nd00`0
l?l000<0U_l00?3o003`o`00103`o`0203co000409Ko000lo`000?lN003Bo`800?mh00<00?oB000N
o`00d_l00P00oah00`0lo`000?oB003oN00203co0003003o7P0lo`00??l000<0??l00P00oah3003o
N003003odP00N?l00?oB008001ko00@00=;o001ho`00d_l001ko0P00N?l00`007_l0UP3o0?l00002
0?l0000303`0o`2F0?l001ko00@00=;o00L00?oB000No`00d_l00=;o001ho`00d_l0UP3o008007So
1@00om801000oah007So003oN00lo`02003oN003003odP00oah0U_l000L0U_l000@0??l009Ko0000
om80U_l01`3`o`0D0?nd01<0oeX02`3o]0040?3o000309Ko0000oah00?oB0080??l000<0U_l003co
0000oah00`3`o`000`3o]000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo000K0?ooo`03
0000003oool0oooo0080oooo1@3o]0001@2Fo`00l?l009Ko002Fo`00l?l000@0U_l000@0??l0000N
o`00d_l0??l00`2Fo`000`3`o`00ok@00?nd00070?nd01h0oeX00P3`o`020?nd00050?3o002Fo`00
U_l009Ko000lo`000`2Fo`000`3`o`00U_l00?3o00040?3o0003000No`2Fo`00l?l00080l?l0102F
o`000`00ogP00?lN003odP0309H0o`800?oB0`0lo`000`2Fo`00??l0003oN00203co00<0U_l01@0l
o`001000oah00?mh003oN0007_l4003oN0800=;o00L00?oB03`0o`00d_l00=;o000No`2F0?l0o`00
0080UP3o00<001ko001ho`00d_l00P00d_l01000om800=;o003odP007_l2003Bo`03003oN000om80
0?oB00800?oB00<00?mh003Bo`00oah00P00N?l203co00800?lN0P3o00000`0l0?l00?lN03co0003
09Ko0007003o7P2Fo`00U_l009Ko000lo`00o`2d09Ko00080?3o01<0ok@05@3oFP090?nd0080l?l0
102Fo`001P00oah0o`1J001ho`00N?l0??l009Ko00<0l?l00P3o]0040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo00<0ok@00?3o003`o`000P3`o`001`0lo`00
0?oB03`0o`0l0?l0??l0003odP00oah00P00N?l00`00d_l0?03o003Bo`03003o7P<0l?l0203o]00N
0?mJ00P0ok@00P3`o`0403co00@0l?l000<0U_l0003o7P0lo`00102Fo`0303co0004000No`00d_l0
0?oB003odP800?lN00<0??l0003o7P0lo`00102Fo`000`0lo`00U_l009Ko000409Ko00@0??l000H0
0?lN003Bo`00d_l00?mh003o7P00ogP2003Bo`04000No`00om800?oB003odP800=;o00<007So000N
o`3`0?l00P3o00000`2F0?l007So003Bo`02003Bo`800?oB00@00?mh003odP00N?l007So0`00ogP2
000No`800?lN00<0??l0003o7P00oah00`0lo`001P00oah00?mh003oN000ogP00?oB003oN080??l0
00<00?lN003odP0lo`000P0lo`000`00oah0??l009Ko000:0?3o0100ok@05`3oFP070?nd0080l?l0
00L0??l0001ho`00om800?oB03co0000ogP0UP3o00800?lN00<0U_l00?3o003`o`000P3`o`020?nd
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool0103o]000
l?l0003Bo`00d_l20?3o0003003Bo`2Fo`00U_l000<0l?l00`00ogP00`3o00000=;o03`0o`0203co
000309Ko003`o`00l?l000P0ok@07P3oFP090?nd00<0l?l000<00?lN0?l0002Fo`00102Fo`001`0l
o`000?mh03co000lo`000?lN03co002F0?l00`00oah00`00om800?lN03co000203co0080U_l000<0
0?lN09Ko002Fo`000P2Fo`000`0lo`00U_l009Ko000409Ko0080??l00P00oah00`0l0?l00=;o003B
o`03003o7P800?oB00@0UP3o003oN000ogP00?oB0P00d_l00`00N?l0o`1J0?l000020?l0FP0303`0
o`00N?l007So0080o`2d00@00=;o003oN000ogP00?mh0P00om800`00ogP00?lN003o7P02003Bo`03
0?l0FP00oah0??l00080??l0102Fo`07003o7P03003Bo`2F0?l00?mh00800?mh00<0??l009Ko002F
o`002`3`o`0>0?nd01X0oeX00P3o]0060?3o000509Ko003`o`00l?l009Ko0000oah00`00om8209Ko
00030?3o002Fo`00U_l00080ok@0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`040?nd003`o`000=;o003Bo`80l?l000<00=;o09Ko002Fo`000`3`o`03003o
N0030?l00000d_l0?03o0080??l000<0U_l00?3o003`o`00203o]00N0?mJ00T0ok@00`3`o`000`00
oah0o`0009Ko000409Ko000703co0000ogP0??l003co0000oah0??l009H0o`03003o7P03003odP00
oah0??l00080??l00P2Fo`000`00oah0U_l009Ko000209Ko000303co002Fo`00U_l000@0U_l00P0l
o`02003o7P0303`0o`00d_l00=;o00<00?lN0P00om80102F0?l00?mh003oN000om82003Bo`03001h
o`3o05X0o`000080o`1J00<0?03o001ho`00N?l00P3o0;@01000d_l00?mh003oN000ogP2003odP03
003oN000oah00?lN00800=;o00<0o`1J003o7P0lo`000P0lo`0409Ko00L00?lN00<00=;o09H0o`00
ogP00P00ogP00`0lo`00U_l009Ko000;0?3o00h0ok@06P3oFP020?nd00H0l?l000D0U_l00?3o003`
o`00U_l0003o7P03003odP80U_l000<0l?l009Ko002Fo`000P3o]0040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo00@0U_l00?nd0000ogP00?mh0P3o]000103`
o`00ok@00?nd003o]0020?3o0080??l000<00=;o000No`00ogP00`0lo`000`00ogP0U_l00?3o0002
0?3o000309Ko003o]000ok@00080ok@07`3oFP0:0?nd0080U_l000<0l?l009Ko0000ogP00`2Fo`00
0`00oah0o`00003Bo`03000No`03003oN02Fo`00U_l000@0U_l00`0lo`0>09Ko00<0??l000<00=;o
003oN000oah01`00oah00`00ogP00?oB001ho`03003Bo`07001ho`3o0000o`1J0?l0FP007_l007So
003Bo`03003odP03003Bo`00ogP00?lN00800?lN00<00?mh003o7P00oah00P00oah00`007_l00?lN
03co000203co00@0U_l00`0lo`0209Ko0080??l000<00?oB003oN000N?l00P3o0;@01000om80??l0
03co002Fo`050?3o00800?mh203`o`090?nd01/0oeX01`3o]0030?3o0080U_l000D00?mh001ho`00
N?l00?lN03co00040?3o00030?nd003oool0oooo0080oooo00<000000?ooo`3oool00`3oool001/0
oooo0P0000030?ooo`/0ok@000L0l?l009Ko002Fo`000?oB003o7P00ogP0U_l00080l?l000<0??l0
09Ko0000oah00P2Fo`000`00ogP0l?l00?nd00020?nd01l0oeX02P3o]0030?3o0080U_l000H007So
003o7P00oah001ko003odP007_l2003oN00303co003o0000U_l00080U_l000@0l?l009Ko002Fo`00
0?mh0P00oah00`0lo`00U_l00?3o00040?3o00L0U_l00P0lo`000`0l0?l00?lN003oN00403co00@0
0?lN0`00ogP2003odP03003Bo`2F0?l0UP3o0080o`0000<001ko001ho`00d_l00P00om83003oN0@0
0?lN0P0lo`02003o7P03003oN000N?l0??l00080??l02@2Fo`0403co0006003oN000om800?oB003o
dP00d_l0??l0202Fo`030?3o0006003o7P3`o`00l?l009Ko003`o`00U_l00P00oah00`3o00000?lN
0?3o00020?nd01`0oeX01`3o]0030?3o000303co0000ogP00?mh0080UP3o00<00?lN09Ko003`o`00
0P3`o`000`2Fo`00l?l00?ooo`020?ooo`8000001@3oool001/0oooo00<000000?ooo`3oool00P3o
ool50?mJ000303co003o]000ok@00080ok@00P3`o`0209Ko0004003odP00ogP0U_l009Ko00@0l?l0
00@0U_l0000No`007_l0l?l0103o]00O0?mJ00X0ok@00`3`o`000`2Fo`00o`00003oN002001ho`03
03`0o`00ogP00?oB008001ko00<0??l009Ko003`o`001@3`o`00102Fo`00??l003co002Fo`090?3o
00<0U_l000@00?mh03co000lo`000?lN1P0lo`04003o7P<00?mh0P00d_l00`00N?l001ko09H0o`02
0?l0000309H0o`007_l007So00800?oB0`00ogP4003o7P@0??l000<00?mh03co0000N?l00P0lo`09
09Ko0080??l00P2Fo`000`00N?l0??l003co000303co00060?l0002Fo`00U_l003co002Fo`000?lN
0`2Fo`020?3o000409Ko000l0?l0?03o03co0080l?l01`3o]00L0?mJ00P0ok@00`3`o`001@2Fo`00
0?oB000No`007_l00?oB00800?lN0`0lo`000`2Fo`00oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo1`3oFP030?nd000609Ko0000oah0U_l009Ko
00007_l00?oB0P3`o`040?nd000509Ko003`o`00l?l00?l0003`o`000`3o]00O0?mJ00T0ok@00`3`
o`00102Fo`000=;o003o7P2F0?l2003Bo`800?mh0`2Fo`000`00d_l0U_l00?3o00050?3o00<0U_l0
2`3`o`000`0lo`00U_l009Ko000409Ko00D0??l000<00?lN001ho`00N?l00P00ogP2003odP800=;o
00<0UP3o0?l0FP3o0;@00P3o0;@00`3`0?l0o`0009H0o`02000No`03003Bo`007_l00?mh00<00?mh
00<00?lN03co000lo`000P0lo`000`00oah0??l003co0002003o7P@0U_l01@3`o`0409Ko000303`0
o`2Fo`00U_l000@0U_l00P0lo`000`3`0?l00?lN003o7P0209Ko00040?l0002Fo`00U_l0003Bo`80
??l00P3`o`080?nd01d0oeX01P3o]0040?3o000609Ko0000d_l0?03o03`0o`00d_l00?oB102Fo`00
0`3`o`00oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo
0080oooo1`3oFP030?nd000609Ko0000oah0U_l009Ko00007_l00?oB0P3`o`040?nd000509Ko003`
o`00l?l00?l0003`o`000`3o]00O0?mJ00T0ok@00`3`o`00102Fo`000=;o003o7P2F0?l2003Bo`80
0?mh0`2Fo`000`00d_l0U_l00?3o00050?3o00<0U_l02`3`o`000`0lo`00U_l009Ko000409Ko00D0
??l000<00?lN001ho`00N?l00P00ogP2003odP800=;o00<0UP3o0?l0FP3o0;@00P3o0;@00`3`0?l0
o`0009H0o`02000No`03003Bo`007_l00?mh00<00?mh00<00?lN03co000lo`000P0lo`000`00oah0
??l003co0002003o7P@0U_l01@3`o`0409Ko000303`0o`2Fo`00U_l000@0U_l00P0lo`000`3`0?l0
0?lN003o7P0209Ko00040?l0002Fo`00U_l0003Bo`80??l00P3`o`080?nd01d0oeX01P3o]0040?3o
000609Ko0000d_l0?03o03`0o`00d_l00?oB102Fo`000`3`o`00oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo1`3oFP050?nd0080U_l000@00?lN
0?3o000lo`00l?l0103o]0001P3`o`00ok@00?nd003`o`000?mh09Ko00<0ok@07P3oFP020?nd0003
0?3o003o]000ok@000<0ok@000H0l?l003co003`o`00l?l009Ko000l0?l2003o7P800?oB00<0??l0
09Ko002Fo`00102Fo`060?3o00<0U_l02`3`o`0809Ko00<0??l000L00?lN001ho`00d_l00=;o03`0
o`00om800=;o00<00?oB00<007So03`0o`2F0?l00P3o00000`007_l007So09H0o`03003odP03003B
o`00om80?03o00800?mh00<00?lN03co000lo`000P0lo`0809Ko00P0l?l00P2Fo`001000om80U_l0
09Ko002Fo`020?3o000609Ko0000ogP00?mh003o7P007_l00?oB0P00oah203co0003003o7P2Fo`00
l?l00080l?l02@3o]00M0?mJ00D0ok@00P3`o`02001ho`03003odP0lo`000?mh00800?mh00<00=;o
03co002Fo`000`3`o`000`3o]000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo2@3oFP030?nd00800?lN00@0l?l00?nd003o]0000?oB203o]002
0?3o00<0ok@07P3oFP030?nd00L0l?l00P0lo`0209Ko0006003o7P2Fo`00U_l009Ko000l0?l0??l0
103`o`000`00N?l0l?l00?3o00040?3o0003003oN03`o`00l?l000/0l?l0202Fo`0303co0004003o
7P00ogP00?lN003o7P@00?mh0P00om800`00d_l007So09H0o`020?l000030?00o`007_l00?oB0080
0?oB0P00ogP00`00oah00?mh003o7P04003o7PT0U_l02P3`o`000`2Fo`000?oB0?3o00050?3o0080
U_l000<00?mh003o7P00ogP00P3`0?l2003odP80U_l00`3`o`090?nd01d0oeX00`3o]0000`0lo`00
U_l00?3o000303co000309Ko003`o`00U_l000800?oB00<0o`1J03co002Fo`000P3`o`020?nd00@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool90?mJ0080ok@0
00@0l?l0003o7P00oah0l?l01P3o]0020?mJ00@0ok@000@0U_l00?nd003o]000ok@07@3oFP050?nd
00060?3o0000oah00?lN09Ko000lo`000?oB0P2Fo`020?3o000603co003`o`00l?l00?3o000lo`00
U_l02`3`o`000`2Fo`00l?l00?3o000;0?3o00P0U_l01@0lo`04003o7P800?mh0P007_l00`00d_l0
07So03`0o`020?l0000303`0o`00N?l00=;o00800?oB00@00?mh003o7P00oah00?lN1@0lo`0909Ko
00/0l?l000<0??l00?3o003`o`00103`o`0209Ko0003003odP2Fo`000?lN00800?lN00<0?03o001h
o`00oah00`2Fo`000`3`o`00ok@00?nd00070?nd01d0oeX0103o]0000`3`o`000?mh03co00020?3o
000309Ko003`o`00??l00080U_l000<007So03co002Fo`000P3`o`020?nd00@0oooo00<000000?oo
o`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool90?mJ0080ok@000@0U_l003`0o`0l
0?l0U_l00`3o]0080?mJ0080ok@00P0lo`000`3o]000oeX00?mJ000K0?mJ00D0ok@000H0l?l009Ko
002Fo`000?oB003oN02Fo`060?3o0080U_l000<00?mh003o7P3`o`00103`o`040?nd0100l?l000<0
??l009Ko002Fo`001@2Fo`0503co00@00?lN0P00ogP20?l00003001ho`007_l0o`2d0080o`0000<0
?03o001ho`00d_l00P00d_l2003oN0800?lN1@0lo`0909Ko00/0l?l000<0l03o0?3o003`o`00103`
o`02003Bo`<0U_l00P0lo`001000oah00?oB0?l0FP0lo`040?3o00P0ok@07@3oFP040?nd000309Ko
0000om80l?l000@0ok@000H0l?l009Ko002Fo`0001ko003o7P2Fo`02003o7P030?3o003o]000oooo
00<0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool70?mJ00@0
ok@000<0l?l009Ko002Fo`000`3o]00:0?mJ00<0ok@000<0U_l00?mJ003oFP006`3oFP000`3`o`00
ok@00?nd00020?nd00050?3o0000N?l007So03co002Fo`000`3`o`030?nd00<0l?l000<0U_l00?3o
003`o`000P3`o`090?nd00d0l?l00P2Fo`00100lo`00U_l009Ko002Fo`0703co00800?lN00@00?oB
003oN000ogP00?mh0P00om800`00d_l007So03`0o`020?l0000303`0o`3o00000=;o008007So00@0
0?mh003odP00om800?lN1@0lo`02001ho`H0U_l000<0??l00?3o003`o`002@3`o`000`2Fo`00l?l0
0?3o00080?3o000309Ko0000oah00?lN0080U_l00P00oah309Ko0080l?l0103o]0000`0lo`00ok@0
0?nd000M0?mJ00070?nd000lo`00??l009Ko003`o`00ok@0003odP040?nd00060?3o002Fo`00U_l0
09Ko00007_l0l?l0103o]0040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooo1`3oFP040?nd00030?3o002Fo`00U_l000<0ok@02P3oFP030?nd000309Ko003oFP00
oeX001/0oeX000<0l?l00?nd003o]0000P3o]0001@3`o`0007So001ho`0lo`00U_l000<0l?l00`3o
]0030?3o000309Ko003`o`00l?l00080l?l02@3o]00=0?3o0080U_l000@0??l009Ko002Fo`00U_l0
1`0lo`02003o7P04003odP00ogP00?mh003oN0800?oB00<00=;o001ho`0l0?l00P3o00000`0l0?l0
o`00003Bo`02001ho`04003oN000om800?oB003o7PD0??l00P00N?l609Ko000303co003`o`00l?l0
00T0l?l000<0U_l00?3o003`o`00203`o`000`2Fo`000?lN003o7P0209Ko00800?lN0`2Fo`020?3o
00@0ok@000<0??l00?nd003o]0007@3oFP001`3o]000??l003co002Fo`00l?l00?nd0000om80103o
]0001P3`o`00U_l009Ko002Fo`0001ko0?3o00@0ok@0103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?ooo`L0oeX00P3o]0020?3o000309Ko003`o`00l?l00080ok@0
303oFP020?nd00030?3o003oFP00oeX001X0oeX00P3o]0030?3o000309Ko000lo`00l?l00080l?l0
00<0o`1J03co003o]0001@3o]0020?3o0080??l000<0l?l00?nd003o]0002`3o]00:0?3o00<0U_l0
00<00?lN03co000lo`000`0lo`02003Bo`80??l000L00?oB003o7P00oah00?lN003Bo`3o00000?oB
008007So00<00=;o001ho`0l0?l00P3o05X00`2F0?l001ko09H0o`02003Bo`0309H0o`00ogP00?lN
00<00?lN0P0lo`000`00oah0??l003co000303co00800?lN0P2Fo`0A0?3o000309Ko003`o`00l?l0
0080l?l000L0??l0003oN000ogP0U_l00?3o0000oah0l?l00080U_l000<0o`0009Ko002Fo`000P3`
o`000`00ogP0ok@00?nd00020?nd01d0oeX000@0ok@00?3o003`o`00U_l01`3o]0001P3`o`00ok@0
0?nd003`o`00??l00?3o00@0ok@0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`H0oeX0103o]000100lo`00o`000?3o003`o`020?nd00h0oeX000<0ok@00?mJ
003oFP006P3oFP020?nd0080l?l000<007So03co003`o`000`3o]0000`2Fo`00ok@00?nd00070?nd
0003003o7P3`o`00ok@000h0ok@01P3`o`0309Ko000403co002Fo`00??l003co00800?lN00<00?mh
03co000lo`002000oah00`00ogP00?oB000No`03001ho`07000No`2F0?l0l03o0?00o`3o0000l03o
09H0o`0203`0o`03001ho`00om800?mh00<00?mh0P00oah00`00ogP0??l003co000203co00<00?lN
0P2Fo`000`00ogP0l?l00?3o00080?3o00L0ok@0103`o`000`00oah00?mh003oN0070?3o00@00?lN
00<0l?l00?nd003o]0000`3o]00K0?mJ0080ok@00P00ogP30?nd00<0oeX01P3o]0000`3`o`000?lN
0?nd00030?nd00@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?ooo`@0oeX000<0
U_l00?nd003`o`000`3`o`0203co0080l?l00P3o]00>0?mJ0080ok@06P3oFP020?nd00050?3o000l
o`00??l00?3o000lo`003P3o]0000`0lo`00ok@00?nd000>0?nd00@0l?l000<0U_l0003o7P0lo`00
0P00ogP01000d_l0o`2d003odP0l0?l20?l000030?l0FP3o0;@0l03o0080o`0000<0UP3o001ho`0l
0?l00P007_l2001ho`0309H0o`3o0000l03o0080l03o00H0o`0009H0o`2F0?l0UP3o0?l0]00l0?l3
09H0o`04000No`00N?l00?oB003odP<00=;o00@0o`2d000No`00om800?oB0P007_l00`00d_l00?mh
003oN00203co0080U_l0203`o`0;0?nd0080l?l00P2Fo`000`3`o`00ok@00?nd00030?nd0003003o
7P2Fo`000?oB00800?lN00<0l?l00?nd003o]0000`3o]00K0?mJ00050?nd002Fo`00ok@00?nd003`
o`001`3oFP040?nd000409Ko0000om80l?l00?3o0080ok@00`3oool2000000D0oooo000K0?ooo`03
0000003oool0oooo0080oooo00L0oeX009Ko003`o`00l?l00?nd00007_l0l?l00080U_l000<00?lN
003odP0lo`000P3`o`020?nd00l0oeX000<0ok@00?mJ003oFP005`3oFP020?nd00040?3o0000oah0
l?l00?3o0100ok@000<0l?l00?nd003o]0003P3o]0050?3o00@0U_l000@0??l009Ko000lo`00??l0
0P00oah00`00ogP0??l003co0005003o7P<00?mh00<00?oB001ho`3o0;@00P007_l00`0l0?l0UP3o
0?l000020?l0]08001ko00D0l03o001ho`00N?l00=;o003oN007003o7P80??l00P00oah01`00ogP0
0?oB003odP0lo`0001ko003oN00lo`000P2Fo`050?3o00d0ok@000@0l?l009Ko002Fo`00l?l01P3o
]0001`0lo`00l?l009Ko002Fo`000?mh0?3o002Fo`000P3`o`000`3o]000oeX00?mJ000I0?mJ0004
0?nd002Fo`00ok@00?nd00T0oeX00P3`o`000`3o]000l?l003co00040?nd00@0oooo00<000000?oo
o`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool01`3oFP00U_l00?3o003`o`00ok@0
000No`3`o`000P2Fo`000`00oah00?oB03co00020?3o0080ok@03`3oFP000`3o]000oeX00?mJ000G
0?mJ0080ok@000@0l?l0003o7P3`o`00l?l0403o]0000`3`o`00ok@00?nd000>0?nd00D0l?l0102F
o`00100lo`00U_l003co000lo`02003o7P03003oN00lo`00??l000D00?lN0`00ogP00`00om8007So
0?l0]002000No`0303`0o`2F0?l0o`000080o`2d0P007_l01@3`0?l007So001ho`00d_l00?mh00L0
0?lN0P0lo`02003o7P07003oN000om800?oB03co00007_l00?mh03co000209Ko00D0l?l03@3o]000
103`o`00U_l009Ko003`o`060?nd000703co003`o`00U_l009Ko0000ogP0l?l009Ko00020?3o0003
0?nd003oFP00oeX001T0oeX000@0ok@009Ko003o]000ok@02@3oFP020?3o00030?nd003`o`00??l0
00@0ok@0103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`H0
oeX00`3o]0000`0lo`00UP3o09Ko000203co000309Ko003o]000oeX000h0oeX000<0l?l00?mJ003o
FP005`3oFP00103o]000l?l009Ko003o]00203co00h0ok@00P3`o`0B0?nd00P0l?l00`2Fo`000`00
oah0??l003co000303co0080o`0000<00?lN03co0000ogP00`00oah00`00ogP00=;o003odP03001h
o`07000No`3o0;@0o`000?l0003o0;@007So000No`03003odP03003Bo`00oah00?lN00800?lN0P0l
o`000`00oah0??l003co000203co0005003Bo`2Fo`00U_l009Ko000lo`001`2Fo`0?0?nd00<0U_l0
1`3o]0001`00om80l?l00?nd003o]000l?l0003oN02Fo`00103o]00J0?mJ0080ok@02`3oFP040?nd
00050?3o0000om800?oB0?3o003o]000103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?ooo`L0oeX00P3`o`000`2Fo`00UP3o0?3o00020?nd000309Ko0000d_l0ok@0
00h0oeX000<0ok@00?mJ003oFP005@3oFP020?nd000303co003`o`00ok@000<0ok@02`3oFP0F0?nd
00X0l?l01P2Fo`0703co00800?lN00<00?mh003odP00om800`00om800`3o000007So09H0o`020?00
o`03000No`00d_l00?oB00@00?mh00<00?lN003odP0lo`001P0lo`0209Ko000303co002Fo`00U_l0
0080U_l01`3`o`0@0?nd0080o`2d1`3o]0000`3`o`00ok@00?nd00020?nd00030?l0FP2Fo`00l?l0
0080l?l000<0ok@00?mJ003oFP00603oFP000`00N?l0oeX00?mJ000<0?mJ00030?nd003`o`00U_l0
0080UP3o00<0l?l00?nd003oool00`3oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?ooo`L0oeX00P3o]0030?3o00H0ok@0903oFP000`3o]000l?l00?3o00030?nd0100
oeX000<0l?l00?nd003o]0004@3o]00:0?3o00L0U_l01P0lo`04003o7P800?mh0P00d_l00`00N?l0
01ko0?l000020?l0FP0309H0o`00N?l0o`2d0080o`2d00@00?oB003o7P00oah00?lN1@0lo`0809Ko
00P0l?l0403o]0020?3o00h0ok@00`2Fo`020?nd01T0oeX000<0ok@00?mJ003oFP00303oFP020?nd
000509Ko0000N?l007So09Ko003`o`00103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?ooo`L0oeX00P3o]0000`00ogP0ok@00?nd00050?mJ00030?nd003oFP00oeX0
00L0oeX0303o000>0?mJ00030?nd000lo`00ok@00080ok@04`3oFP0C0?nd00/0l?l01`2Fo`0503co
00@00?lN00L00?mh003odP0l0?l0?03o003Bo`00N?l0UP3o0080o`2d00<001ko003Bo`00om800`00
ogP3003o7P@0??l0202Fo`090?3o0200ok@00`3`o`000`2Fo`00ok@00?nd000W0?mJ0080ok@000D0
U_l0001ho`00N?l0??l009Ko00040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003o
ool0oooo0080oooo1`3oFP020?nd0003003oN03o]000ok@000D0oeX000<0ok@00?mJ003oFP001`3o
FP0<0?l000h0oeX000<0ok@003co003o]0000P3o]00C0?mJ01<0ok@02`3`o`0709Ko00D0??l01000
oah01`00ogP00?oB03`0o`0l0?l00=;o001ho`2F0?l00P3o0;@00`007_l00=;o003odP03003oN0<0
0?lN100lo`0809Ko00T0l?l0803o]0030?3o000309Ko003o]000ok@002L0oeX00P3o]0001@2Fo`00
07So001ho`0lo`00U_l000@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3oool60?mJ00<0ok@000<0l?l00?nd003oFP001P3oFP020?nd00<0oeX0503o000:0?mJ0003
003o7P3o]000oeX001L0oeX0403o]00<0?3o00L0U_l0100lo`000`00oah00?mh003oN002003o7P80
0?mh0P00om800`00d_l0?03o03`0o`020?l0000303`0o`00N?l00=;o00<00?oB00<00?mh003odP00
ogP00`00om8203co00L0U_l02@3`o`0B0?nd00030?3o003o]000ok@000X0oeX01@3o]0000`0lo`00
ok@00?mJ000F0?mJ00030?nd003oFP00oeX000/0oeX00P3o]0000`3`o`000?lN0?3o0002003odP03
09Ko003o]000oooo00<0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0
0P3oool40?mJ00<0ok@00`2Fo`000`3o]000oeX00?mJ00070?mJ00030?nd003o0000o`0001L0o`00
1P3oFP000`3`o`00oeX00?mJ000I0?mJ00d0ok@00`3`o`000`2Fo`00l?l00?3o00070?3o00L0U_l0
100lo`000`00ogP0o`00003odP02003odP03003oN000d_l00?oB00800?oB00<007So000No`0l0?l0
0P3o05X00`3o0;@0o`1J03`0o`03000No`800?oB00<00?mh003o7P00oah00`0lo`0709Ko00/0l?l0
4@3o]00@0?mJ0080ok@000<0??l00?nd003o]0005@3oFP000`3o]000oeX00?mJ000;0?mJ0080l?l0
00<0ok@00?3o003o]0000P00oah00`0lo`00ok@00?ooo`030?ooo`030000003oool0oooo00<0oooo
000K0?ooo`030000003oool0oooo0080oooo00<0o`000?mJ003oFP000P3oFP000`3o]000l?l0003o
7P02003o7P030?3o003oFP00oeX000L0oeX06`3o00030?mJ0080ok@07@3oFP0;0?nd00D0l?l000<0
??l00?3o003`o`001@3`o`0209Ko0080??l00`2Fo`000`00oah0??l003co000303co0007003o7P00
N?l007So0?l00000om80o`00000No`020?00o`<0o`000P3o0;@00`2F0?l001ko001ho`02003odP80
0?mh0P00oah:03co00<0U_l01`3`o`00100lo`00l?l00?3o003`o`0=0?nd01D0oeX000@0ok@0000N
o`007_l0ok@03`3oFP060?l000`0oeX000<0l03o0?nd003o]0000P3oFP030?nd000309Ko003o]000
oooo00<0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool00`3o
0000oeX00?mJ00030?mJ00030?3o0000ogP00?mh0080ok@000<0??l00?mJ003oFP000`3oFP0O0?l0
00030?mJ003o]000oeX001h0oeX02@3o]0070?3o0003003o7P2Fo`00U_l000P0U_l000D0??l0003o
7P00oah0??l0003o7P0503co00<00?lN0`00ogP01P00N?l00?oB003odP00N?l001ko03`0o`80o`00
00<0?03o000No`00d_l00P00om82003oN0@00?lN0`0lo`03003o7P0303co002Fo`00U_l000<0U_l0
1@3`o`000`0lo`00l?l00?3o00030?3o00/0ok@05`3oFP020?nd0003003o7P3oFP00oeX000T0oeX0
3`3o00060?mJ000309Ko003oFP00oeX000@0oeX00P3o]0000`3`o`00ok@00?ooo`030?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo00<0o`000?mJ003oFP000`3o
FP00100lo`00l?l00?3o003o]0020?mJ0080ok@00P3oFP0Q0?l00240oeX0103o]0000`3`o`00U_l0
09Ko000209Ko00@0??l00P00oah01000om80??l003co0000oah809Ko0080??l000<00?mh000No`0l
o`00100lo`04003o7P<00?mh0P00om800`00d_l007So03`0o`020?l0000309H0o`00N?l00=;o0080
01ko00@0l03o003oN000d_l00?mh1000oah01@00ogP0?03o03`0o`00oah0??l000X0U_l000<00?mh
0?3o003`o`00103`o`0:0?nd01X0oeX000<0l?l00?mJ003oFP001P3oFP0C0?l000/0oeX00P3o]000
0`3`o`00U_l00?ooo`030?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3oool00`3o
0000oeX00?mJ00030?mJ000403co003`o`00l?l00?nd0080oeX00P3o]0020?mJ0240o`008@3oFP04
0?nd00030?3o002Fo`00U_l00080U_l0100lo`02003o7P04003odP0lo`00??l0003o7PP0U_l00P0l
o`000`00ogP001ko03co000403co00@00?lN0`00ogP2003odP03003Bo`00N?l0?03o0080o`0000<0
UP3o001ho`00d_l00P007_l0103`0?l00?mh003Bo`00ogP4003o7P05003oN00l0?l0?03o003o7P0l
o`002P2Fo`000`00ogP0l?l00?3o00040?3o00X0ok@06P3oFP000`3`o`00oeX00?mJ00060?mJ01<0
o`002`3oFP020?nd00030?3o002Fo`00oooo0080oooo0P0000050?ooo`006`3oool00`000000oooo
0?ooo`020?ooo`030?l0003oFP00oeX00080oeX000@0ok@00?3o003o]000ok@01P3oFP0S0?l00200
oeX01@3o]0050?3o00@0U_l000H00=;o03`0o`00om800?oB03co002Fo`0303co00@0U_l00P0lo`00
0`00N?l00=;o003o7P08003o7P800?mh1000om801`00d_l007So03`0o`0l0?l0o`000?l0FP00d_l0
0`00om800`00ogP00=;o003oN003003o7P0403`0o`2F0?l007So001ho`80??l01`2Fo`0203co0080
0?lN00H0??l009Ko002Fo`00??l009Ko0000ogP30?3o00H0ok@0703oFP000`3o]000oeX00?mJ0002
0?mJ01T0o`00203oFP030?nd000309H0o`3oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
01/0oooo00<000000?ooo`3oool00P3oool01`3o0000oeX00?mJ003oFP00ok@009Ko00007_l00P3o
]0050?mJ02@0o`00803oFP090?nd00030?3o002Fo`00l?l00080l?l000L0U_l003co0000oah00?lN
03co0000om800?lN0080??l00`2Fo`0303co0003003o7P00ogP00?mh00@00?lN00<0o`00003oN000
ogP00P00ogP00`00om8007So003Bo`02003Bo`03001ho`007_l0o`000080o`0000<0?03o0?l0]000
d_l00P00d_l00`00om800=;o003oN003003oN0800=;o0P00oah203co0004003o7P2Fo`00U_l009Ko
00<0??l00P3o0;@00`00om800=;o003oN00309Ko00030?3o002Fo`00U_l000<0U_l000<00?lN0?3o
003o]0000P3o]00M0?mJ0080ok@000<0oeX00?l0003o00006P3o00060?mJ0080ok@000<0l?l003`0
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`03
0?l0003oFP00oeX00080oeX000<0ok@00?3o003o]0000P3o]0020?mJ02P0o`007P3oFP0;0?nd00<0
l?l000H00?lN09Ko000lo`00??l009Ko000lo`03003oN0H0??l000<00?lN001ho`007_l00P00ogP2
003o7P03003oN000om800?oB00<00?mh00H0o`2d000No`007_l007So000No`00N?l2000No`0303`0
o`3o000001ko008001ko00@00=;o001ho`00om800?oB0P0l0?l2003odP<00?lN00<0??l0003o7P0l
o`000`0lo`000`00ogP0o`0003co000209Ko0080??l000<0U_l00?3o003`o`000`3`o`080?nd0200
oeX07P3o00040?mJ00030?nd003oFP00oeX00080ok@0103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?ooo`030?l0003oFP00oeX00080oeX00P3o]0040?mJ02T0o`00
7P3oFP0;0?nd00L0l?l000<0U_l003co000lo`000P0lo`000`007_l0??l0003o7P05003o7P03003o
N000om800?oB00<00?mh0P3o00000`00om800?mh003odP03003odP03001ho`00d_l00=;o008007So
00<0?03o000No`3o0;@00P3`0?l0100l0?l0o`2d003Bo`00d_l2001ho`03000No`00om800?mh0080
0?oB00<00?lN001ho`00oah00P00oah0100l0?l0??l003co000lo`0409Ko0004003oN03`o`00l?l0
0?3o00X0ok@07P3oFP0R0?l000H0oeX000<0ok@00?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030?l0003oFP00oeX00080oeX00P3o]0040?mJ
02T0o`007P3oFP0;0?nd00L0l?l000<0U_l003co000lo`000P0lo`000`007_l0??l0003o7P05003o
7P03003oN000om800?oB00<00?mh0P3o00000`00om800?mh003odP03003odP03001ho`00d_l00=;o
008007So00<0?03o000No`3o0;@00P3`0?l0100l0?l0o`2d003Bo`00d_l2001ho`03000No`00om80
0?mh00800?oB00<00?lN001ho`00oah00P00oah0100l0?l0??l003co000lo`0409Ko0004003oN03`
o`00l?l00?3o00X0ok@07P3oFP0R0?l000H0oeX000<0ok@00?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`070?l0003oFP00oeX00?mJ003o]000
o`000?nd00040?mJ02X0o`007@3oFP0=0?nd00D0l?l00`2Fo`0303co000303`0o`00ogP00?mh0080
0?lN00<007So003oN000ogP00P00d_l00`00N?l00?oB003odP02001ho`H00?oB0`00d_l4001ho`<0
?03o0P3o0;@01@2F0?l0?03o0?00o`3`0?l007So00@00?oB00<00?mh003odP00om800P00oah203co
0080U_l01`3`o`0;0?nd01d0oeX0903o00050?mJ00030?nd003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool00`3o0000oeX00?mJ00020?mJ0003
0?3o003oFP00oeX00080oeX0:`3o000L0?mJ00h0ok@01@3`o`0309Ko00800?lN00@00=;o003odP3o
0;@00?oB0P00ogP00`0l0?l00?mh003Bo`0209H0o`800=;o00<00?oB003Bo`00d_l01000d_l2001h
o`<00=;o0P00N?l2003Bo`<007So00@0o`1J03`0o`3o0000o`000P3`0?l203`0o`06003Bo`00om80
0?oB003odP2F0?l0o`2d0P00ogP01000oah0U_l009Ko002Fo`070?3o00/0ok@07@3oFP0U0?l000@0
oeX000<0U_l00?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo
0?ooo`020?ooo`040?l0003oFP00l?l00?3o0080ok@00`3oFP0]0?l001/0oeX03P3o]0030?3o00<0
U_l000L0??l0003o7P0lo`00??l0003o7P00om80o`0000<00=;o00<007So003Bo`00d_l00P3`0?l0
0`007_l007So001ho`020?l0]004000No`00N?l007So003Bo`8001ko0`00d_l3003odP@00=;o00@0
07So003Bo`00N?l001ko0P3o00000`3o0;@0o`000?l00003000No`0409H0o`00d_l00?lN003o7P<0
??l000<0U_l00?3o003`o`000`3`o`0=0?nd01`0oeX09`3o00020?nd0080oeX0103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooo`040?l0003oFP00oeX00?mJ0080
ok@000<0U_l00?l0003o0000;@3o000J0?mJ00d0ok@00`3`o`001P2Fo`000?lN03co000lo`00U_l0
03co00<00?lN00@007So000No`0l0?l0?03o0P007_l203`0o`060?00o`3o0000o`000?l0003o0;@0
o`1J0P3o00000`2F0?l0o`00000No`03001ho`<00=;o1`00om801000N?l00?oB003odP00N?l203`0
o`8007So00H0UP3o0?l0003o0000l03o000No`3`0?l2001ho`03003o7P00om800?mh00H0U_l00P3`
o`0<0?nd01/0oeX0:@3o00020?mJ00@0oooo00<000000?ooo`3oool00`3oool000P0oooo0P000004
0?ooo`8000000`3oool4000000@0oooo00<000000?ooo`3oool00P3oool0103o0000oeX00?mJ003o
FP020?nd000309Ko003o0000o`0002d0o`006P3oFP0=0?nd00<0l?l000H0U_l0003o7P0lo`00??l0
09Ko000lo`03003o7P04001ho`007_l0?03o03`0o`8001ko0P0l0?l01P3`0?l0o`000?l0003o0000
o`2d0?l0FP80o`0000<0UP3o0?l000007_l00`00N?l3003Bo`L00?oB00@007So003odP00om8007So
0P0l0?l2001ho`0609H0o`3o0000o`000?00o`007_l0l03o0P00N?l00`00oah00?oB003oN00609Ko
0080l?l0303o]00K0?mJ02T0o`000P3oFP040?ooo`030000003oool0oooo00<0oooo00070?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`050?l0003oFP000?lN003o7P0lo`000P3oFP0_0?l001X0oeX000<0ok@00?3o003o]0002P3o]004
0?3o000609Ko00007_l001ko003o7P00ogP007So0P00d_l0103o0000l03o0?l0000l0?l20?l00080
l03o00@0o`1J000No`007_l0o`000P007_l20?l0]00403`0o`3o0000o`1J03`0o`D007So0P00d_l0
0`00om800?mh003oN003003odP03003oN000om800=;o00800=;o0`00om82003Bo`0309H0o`3o0000
o`2d008007So00@0?03o003o7P00oah0??l00P00oah00`2Fo`00l?l00?3o00020?3o00`0ok@06`3o
FP0Y0?l00080oeX0103oool00`000000oooo0?ooo`030?ooo`001`3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`060?l0003oFP00oeX00?mJ003o]000
oeX0<03o000I0?mJ00<0ok@00P2Fo`000`00oah0ok@00?nd00050?nd00D0l?l000H0U_l0003o7P00
oah00?mh0?l000007_l20?l0]004001ho`007_l00=;o03`0o`8001ko00<00=;o001ho`00d_l00P00
N?l00`2F0?l00=;o003Bo`020?l00004003Bo`00N?l001ko0?l00080l03o00<0o`00001ho`00N?l0
0P3`0?l00`00om800?mh003oN003003odP800?mh00H00?oB003oN000ogP00?mh000No`00ogP2003B
o`030?00o`00N?l00=;o008007So00@0l03o003Bo`00ogP001ko0P0lo`000`2Fo`00l?l00?3o0002
0?3o00/0ok@000<0l?l00?nd003oFP00603oFP0[0?l000040?mJ003oool0oooo0?ooo`8000001@3o
ool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?`0oooo00<000000?ooo`3oool00`3oool000L0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?`0oooo00<000000?ooo`3oool0
0`3oool000P0oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo03/0oooo00D000000?ooo`3oool0oooo000000050?ooo`006`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?oo
o`3oool0000000D0oooo000K0?ooool000000@0000050?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.252245, -0.243364, \
0.00162679, 0.00162679}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mandelbrot Set", "Section"],

Cell[BoxData[
    \(TraditionalForm\`\(mandelbrotC = 
        Compile[{x, y, 
            lim}, \[IndentingNewLine]Module[{z, 
              ct = 0}, \[IndentingNewLine]z = 
              x + I\ y; \[IndentingNewLine]While[
              Abs[z] < 2.0 && ct < lim, \[IndentingNewLine]z = 
                z^2 + \((x + 
                      I\ y)\); \[IndentingNewLine]\(++ct\)]; \
\[IndentingNewLine]ct]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(gr22 = 
        DensityPlot[
          mandelbrotC[x, y, 90], \[IndentingNewLine]{x, \(-2.5\), 
            1. }, {y, \(-1.5\), 1.5}, PlotPoints \[Rule] 200, Mesh -> False, 
          ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.706044 0.274725 0.5 0.320513 [
[.01923 -0.0125 -12 -9 ]
[.01923 -0.0125 12 0 ]
[.15659 -0.0125 -6 -9 ]
[.15659 -0.0125 6 0 ]
[.29396 -0.0125 -12 -9 ]
[.29396 -0.0125 12 0 ]
[.43132 -0.0125 -6 -9 ]
[.43132 -0.0125 6 0 ]
[.56868 -0.0125 -12 -9 ]
[.56868 -0.0125 12 0 ]
[.70604 -0.0125 -3 -9 ]
[.70604 -0.0125 3 0 ]
[.84341 -0.0125 -9 -9 ]
[.84341 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -24 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .17949 -12 -4.5 ]
[-0.0125 .17949 0 4.5 ]
[-0.0125 .33974 -24 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66026 -18 -4.5 ]
[-0.0125 .66026 0 4.5 ]
[-0.0125 .82051 -6 -4.5 ]
[-0.0125 .82051 0 4.5 ]
[-0.0125 .98077 -18 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-2.5)] .01923 -0.0125 0 1 Mshowa
.15659 0 m
.15659 .00625 L
s
[(-2)] .15659 -0.0125 0 1 Mshowa
.29396 0 m
.29396 .00625 L
s
[(-1.5)] .29396 -0.0125 0 1 Mshowa
.43132 0 m
.43132 .00625 L
s
[(-1)] .43132 -0.0125 0 1 Mshowa
.56868 0 m
.56868 .00625 L
s
[(-0.5)] .56868 -0.0125 0 1 Mshowa
.70604 0 m
.70604 .00625 L
s
[(0)] .70604 -0.0125 0 1 Mshowa
.84341 0 m
.84341 .00625 L
s
[(0.5)] .84341 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.0467 0 m
.0467 .00375 L
s
.07418 0 m
.07418 .00375 L
s
.10165 0 m
.10165 .00375 L
s
.12912 0 m
.12912 .00375 L
s
.18407 0 m
.18407 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.23901 0 m
.23901 .00375 L
s
.26648 0 m
.26648 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.3489 0 m
.3489 .00375 L
s
.37637 0 m
.37637 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45879 0 m
.45879 .00375 L
s
.48626 0 m
.48626 .00375 L
s
.51374 0 m
.51374 .00375 L
s
.54121 0 m
.54121 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62363 0 m
.62363 .00375 L
s
.6511 0 m
.6511 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.73352 0 m
.73352 .00375 L
s
.76099 0 m
.76099 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.81593 0 m
.81593 .00375 L
s
.87088 0 m
.87088 .00375 L
s
.89835 0 m
.89835 .00375 L
s
.92582 0 m
.92582 .00375 L
s
.9533 0 m
.9533 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-1.5)] -0.0125 .01923 1 0 Mshowa
0 .17949 m
.00625 .17949 L
s
[(-1)] -0.0125 .17949 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(-0.5)] -0.0125 .33974 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .66026 m
.00625 .66026 L
s
[(0.5)] -0.0125 .66026 1 0 Mshowa
0 .82051 m
.00625 .82051 L
s
[(1)] -0.0125 .82051 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1.5)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05128 m
.00375 .05128 L
s
0 .08333 m
.00375 .08333 L
s
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .21154 m
.00375 .21154 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .46795 m
.00375 .46795 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .59615 m
.00375 .59615 L
s
0 .62821 m
.00375 .62821 L
s
0 .69231 m
.00375 .69231 L
s
0 .72436 m
.00375 .72436 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .85256 m
.00375 .85256 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.15659 .99375 m
.15659 1 L
s
.29396 .99375 m
.29396 1 L
s
.43132 .99375 m
.43132 1 L
s
.56868 .99375 m
.56868 1 L
s
.70604 .99375 m
.70604 1 L
s
.84341 .99375 m
.84341 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.0467 .99625 m
.0467 1 L
s
.07418 .99625 m
.07418 1 L
s
.10165 .99625 m
.10165 1 L
s
.12912 .99625 m
.12912 1 L
s
.18407 .99625 m
.18407 1 L
s
.21154 .99625 m
.21154 1 L
s
.23901 .99625 m
.23901 1 L
s
.26648 .99625 m
.26648 1 L
s
.32143 .99625 m
.32143 1 L
s
.3489 .99625 m
.3489 1 L
s
.37637 .99625 m
.37637 1 L
s
.40385 .99625 m
.40385 1 L
s
.45879 .99625 m
.45879 1 L
s
.48626 .99625 m
.48626 1 L
s
.51374 .99625 m
.51374 1 L
s
.54121 .99625 m
.54121 1 L
s
.59615 .99625 m
.59615 1 L
s
.62363 .99625 m
.62363 1 L
s
.6511 .99625 m
.6511 1 L
s
.67857 .99625 m
.67857 1 L
s
.73352 .99625 m
.73352 1 L
s
.76099 .99625 m
.76099 1 L
s
.78846 .99625 m
.78846 1 L
s
.81593 .99625 m
.81593 1 L
s
.87088 .99625 m
.87088 1 L
s
.89835 .99625 m
.89835 1 L
s
.92582 .99625 m
.92582 1 L
s
.9533 .99625 m
.9533 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .17949 m
1 .17949 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .5 m
1 .5 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .82051 m
1 .82051 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05128 m
1 .05128 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .46795 m
1 .46795 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .72436 m
1 .72436 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .85256 m
1 .85256 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00E4FF00FFEC00
FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00E4FF0085FF00B5FF00
E4FF0085FF00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFEC00FFEC00E4FF0056FF00
00FF0756FF00E4FF00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF0085FF00
00ADFF85FF00E4FF00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00B5FF00
00FF0756FF00B5FF00E4FF00FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00B5FF00
00FF070F00FF00FFC4E4FF00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00B5FF00
00FF07FF000000FF0785FF00B5FF00E4FF00E4FF00E4FF00E4FF00B5FF00E4FF00FFBD00
FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00B5FF00
00FF0700FF95FC00FF00FF07B5FF00B5FF00E4FF00E4FF00B5FF0000FF66B5FF00FFEC00
FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00B5FF00
85FF0056FF0000FF3700FF0785FF0085FF0085FF0056FF0056FF0000FFF400ADFFFFEC00
FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00B5FF00
85FF0085FF0000FF37FF00A527FF0056FF0000FF0700FFC4004EFF27FF00B5FF00FFEC00
FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00B5FF00
B5FF0085FF0027FF0000FF6600FFC400FF376E00FF00FF3700FF07B5FF00E4FF00FFEC00
FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00B5FF00
B5FF0085FF0027FF0000FF0700DCFF00FFF400FF3756FF0085FF00B5FF00E4FF00FFEC00
FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00E4FF00B5FF00
B5FF0056FF0027FF0000FF37FF000000FF6627FF0056FF0085FF00E4FF00E4FF00FFEC00
FFEC00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00E4FF00E4FF00E4FF00B5FF00B5FF00
85FF0056FF0027FF00007EFFFF000000ADFF27FF0056FF0085FF00B5FF00E4FF00E4FF00
FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0085FF00
56FF0000FF3700FF6600FFC4FF000000FFC400FF3727FF0085FF00B5FF00E4FF00E4FF00
FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00B5FF0085FF0085FF0056FF00
00FF956E00FF00ADFF0F00FFFF0000FF000000FFC400FFC485FF00B5FF00B5FF00E4FF00
E4FF00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00B5FF0000FF6627FF0056FF0027FF00
00FF0700FFC49D00FFFF0000FF0000FC00FFFF000000ADFF56FF0085FF00B5FF00B5FF00
E4FF00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00B5FF0085FF0000FF37007EFF00FF0700FF07
00FF37007EFFFF0000FF0000FF0000FF0000004EFF00FF3727FF0056FF0085FF0056FF00
85FF00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFEC00FFEC00FFEC00E4FF0085FF0000FF956E00FF007EFF0F00FF00FF6600FF95
FF0000007EFFFF00A5FF0000FF0000FF000000ADFF00FF9500FF0727FF0000FF9500DCFF
56FF00E4FF00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00
FFEC00FFEC00FFEC00E4FF00E4FF0056FF0000DCFF00FFC400FFF4007EFF0F00FF00DCFF
FF0000FF0000FF0000FF0000FF0000FF0000FF00003F00FF00FF9500FF66FC00FF00FF37
85FF00B5FF00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00
FFEC00FFEC00FFEC00E4FF00B5FF0085FF0056FF0000FF0700FFC4FF0000FF0000CC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000ADFF00FFC43F00FFFF0000
27FF00B5FF00E4FF00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0085FF0027FF00CC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFC00FF00FF66
00FF37B5FF00E4FF00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
FFEC00E4FF00E4FF00E4FF00B5FF00B5FF0085FF0027FF0000FF66007EFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007627FF00
85FF00B5FF00E4FF00E4FF00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
E4FF00E4FF00E4FF00E4FF00B5FF00B5FF0085FF0000FF66CC00FF0F00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003F00FF00FF6627FF00
85FF00B5FF00E4FF00E4FF00E4FF00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00
E4FF00E4FF00E4FF00B5FF00B5FF00B5FF0056FF006E00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00009D00FF004EFF00DCFF
85FF00B5FF00E4FF00E4FF00E4FF00FFEC00FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00
FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00
E4FF00E4FF00E4FF00B5FF00B5FF0085FF0056FF0000FF66FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF37
85FF00B5FF00B5FF00E4FF00E4FF00E4FF00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00
E4FF00E4FF00B5FF00B5FF0085FF0085FF0056FF0000FF0700DCFF9D00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF9500FF07
56FF00B5FF00B5FF00B5FF00E4FF00E4FF00E4FF00FFEC00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00
FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00
E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00
E4FF00B5FF00B5FF0085FF0085FF0056FF0056FF0027FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D4FC00FF27FF00
56FF0085FF00B5FF00B5FF00B5FF00E4FF00E4FF00E4FF00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00FF8D00FF8D00
FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00
E4FF00E4FF00B5FF00B5FF00FF000085FF00B5FF00B5FF00B5FF00B5FF00B5FF00B5FF00
B5FF0085FF0085FF0085FF0056FF0056FF0027FF0000FF0700FF66FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000DCFF00FF3727FF00
56FF0085FF0085FF0085FF0085FF00B5FF00B5FF00E4FF00E4FF00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00E4FF00E4FF0000FFC4E4FF00FFEC00FFBD00FFBD00FF8D00
FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC0000FF0727FF00
00FF3785FF0085FF0056FF009D00FFFF000085FF00B5FF00B5FF00B5FF00B5FF0085FF00
27FF0027FF0027FF0056FF0056FF0027FF0000FF0700FF0700FF6600FFF4FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A500FFC400FF3700FF07
27FF0056FF0056FF0085FF0085FF0056FF0000FFC485FF00B5FF00E4FF00E4FF00E4FF00
FFEC00FFEC00E4FF00E4FF00E4FF00B5FF0085FF0056FF00B5FF00FFEC00FFBD00FF8D00
FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00B5FF00FF0000
00FFC400FF07FF00D400FF66FF000000FF3756FF0085FF0085FF0085FF0085FF0056FF00
001FFF3F00FF00FFF400FF0700FF0700FF6600FF6600FF6600FF9500FFC4007EFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004600ADFF00FFC400FF9500FF37
00FF37FC00FF00FF0727FF0027FF0000FF370F00FF27FF00B5FF00B5FF00E4FF00E4FF00
E4FF00E4FF00E4FF00E4FF00E4FF00B5FF0056FF0000DCFF85FF00FFEC00FFEC00FFBD00
FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00B5FF0056FF00
007EFFFF0000FF0000FF000000FFF400FF3727FF0056FF0085FF0056FF0056FF0000FF07
004EFFFF0000FF000000FF6600DCFFFF0000004EFF3F00FF001FFFFF0000FF00009D00FF
FF0017FF0000FF0000FF0000FF0000FF0000FF00179D00FF0F00FF3F00FF00ADFFFF0000
00FFC4FF0000FF000000FF0700FF37FF0000FF007600DCFF56FF00B5FF00B5FF00B5FF00
E4FF00E4FF00E4FF00B5FF00B5FF0085FF0000FF3700FF07B5FF00E4FF00FFEC00FFBD00
FFBD00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00B5FF0085FF00
00FF0700FFF4FF0000001FFF00FFF400FF6600FF95FF007627FF0027FF0027FF0000FF95
0F00FFFF0000FF0076FF0017007EFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0F00FFFF00003F00FF00FF95001FFFCC00FFFF0000FF000000FF0785FF0085FF00B5FF00
B5FF00B5FF00B5FF0085FF0085FF0056FF00007EFF00FF66B5FF00E4FF00FFEC00FFBD00
FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF0027FF00
00FF953F00FF004EFFFF0000FF0000FF0000CC00FFFF000000FF9500FF0700FF0700FF66
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0F00FFFF0000FF0000FF000000FFF400FF0756FF0085FF0085FF00
56FF0000FF0700FF0756FF0056FF0027FF0000FF6600FFF456FF00B5FF00E4FF00FFBD00
FFBD00FFBD00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF00FF0000
FF00A500FF950F00FFFF0000FF0000FF00A5FF0000FF000000FFC400FF66FF007600ADFF
004EFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000ADFF00FF3727FF0056FF0056FF00
00FF07FC00FF0F00FF007EFF27FF0000FF07FF000000DCFF00FF3700FF0756FF00FFEC00
FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF0056FF00
27FF0000FF37007EFFFF0000FF0000FF0000FF0000FF0000FF000000FFC4FF00D4FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00D400DCFFFF000000FFC400FF0727FF00
00FF3700ADFFCC00FF00FFC49D00FFCC00FF00FFF40F00FF00FFC456FF00B5FF00FFEC00
FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF0085FF00
56FF0000FF9500ADFFFF0000FF0000FF0000FF0000FF0000FF0000004EFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FC00FF00FF3700FF66
FF0000CC00FFFF0000FF0000FF0000FF00D4FF000000DCFF00FFF485FF00E4FF00FFEC00
FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0085FF00
56FF0000FF95FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF400FFC4
FF0000FF0000FF0000FF0000FF0000FF0000004EFF00FF6600DCFF9D00FFE4FF00FFEC00
FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0085FF00
56FF0000FF950F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0017007EFF
FF0000FF0000FF0000FF0000FF0000FF0000FC00FF27FF0056FF00B5FF00FFEC00FFEC00
FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0085FF0085FF00
56FF0000FF0700FF95FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00009D00FF
FF0000FF0000FF0000FF0000FF0000FF000000FF9527FF0085FF00B5FF00FFEC00FFEC00
FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00B5FF00B5FF00B5FF0085FF0056FF00
27FF0000FF0700FF6600DCFF6E00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000F00FFB5FF00E4FF00FFEC00FFEC00
FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF0085FF0027FF0027FF0027FF00
27FF0000FF3700FFF4001FFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00A527FF00B5FF00E4FF00FFEC00FFEC00
FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF0085FF0056FF00FF007600FFC400FF37
00FF37FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00A527FF0085FF00B5FF00E4FF00FFEC00FFEC00
FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00E4FF00E4FF00B5FF0000FF6600FF37FC00FFFF004600FFF400FF95
00FF95FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000007EFF00FF9500FF0756FF0085FF00B5FF00E4FF00E4FF00FFEC00
FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00E4FF00E4FF00E4FF0085FF0027FF0000ADFFFF00009D00FF0F00FFFF0000
00ADFFFF0017FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFF400FF0727FF0085FF00B5FF00E4FF00E4FF00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00E4FF00E4FF00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
E4FF00E4FF00E4FF00E4FF00B5FF0085FF0027FF006E00FFFF0000FF0000FF0000FF0000
FF00D4FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF6600FF6685FF00B5FF00E4FF00E4FF00E4FF00
FFEC00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFEC00E4FF0000FF07B5FF00E4FF00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00
E4FF00E4FF00E4FF00B5FF00B5FF0085FF0056FF0000FF3700ADFFFF0046FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000001FFFFC00FF27FF0085FF00B5FF00B5FF00E4FF00
FFEC00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFEC00E4FF0056FF000F00FF56FF00
B5FF00E4FF00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00
E4FF00E4FF00B5FF00B5FF00B5FF0085FF0056FF0000FF0700FF95FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000027FF0085FF0085FF00B5FF00B5FF00
B5FF00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00B5FF0056FF0000FF37
85FF00B5FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00
B5FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00
E4FF00E4FF00B5FF00B5FF00B5FF0085FF0056FF0000FF0700FF6600DCFFFF00D4FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFF400FF0727FF0085FF0085FF0056FF00
00FF95E4FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00B5FF0000FF07007EFF
85FF00B5FF00B5FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF0085FF00
27FF00B5FF00B5FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00
E4FF00B5FF00B5FF00B5FF0085FF0056FF0000FF07FF00D400FF95FC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF6600DCFF00FF0727FF0000FF37
004EFFE4FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00B5FF0027FF0000FF37
56FF00B5FF00B5FF00B5FF00E4FF00E4FF00E4FF00E4FF00B5FF00B5FF00B5FF0027FF00
00ADFF56FF00B5FF00B5FF00B5FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF00
B5FF00B5FF00B5FF00B5FF0085FF0027FF00CC00FF0F00FF00ADFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000001FFF9D00FFFF000000FF3700DCFF
27FF00B5FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF0000FF666E00FF00FF66
56FF0085FF0085FF0085FF00B5FF00B5FF00B5FF00B5FF00B5FF0085FF0056FF00FF0000
00FF3756FF0085FF0085FF00B5FF00B5FF00B5FF00E4FF00E4FF00B5FF00B5FF00B5FF00
B5FF00B5FF00B5FF0085FF0056FF0000ADFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000001FFFCC00FF
00FF3785FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF0085FF0056FF003F00FF
00FF0727FF0056FF0056FF0056FF0000FF6685FF0085FF0085FF0085FF0027FF00004EFF
00FF6627FF0056FF0085FF0085FF0085FF00B5FF00B5FF00B5FF00B5FF00B5FF00B5FF00
B5FF0085FF0085FF0085FF0027FF0000FF95FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF37B5FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00B5FF0056FF0000FFF4
00FF9500FF9500FF9500FF0700FF3700FF3727FF0085FF0085FF0056FF0000FF0700FFF4
004EFFFF0046FF000056FF0056FF0056FF000F00FF56FF0085FF0085FF0085FF0085FF00
85FF0085FF0085FF0056FF0027FF0000FF3700FFC4FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF4FF0000
27FF00E4FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00E4FF00B5FF00B5FF0056FF00
00FF3700FF66FF0076007EFFFF0000FC00FF00FF3700FF6627FF0027FF0000FF0700FF66
00DCFFFF00006E00FF00FF0700FF0700ADFFFC00FF56FF0056FF0085FF0085FF0085FF00
85FF0085FF0056FF0056FF0027FF0000FFC4004EFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000056FF00
B5FF00E4FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0056FF00
27FF0000FF0700FFF4004EFFFF0017007EFF00FFF400FF9500FF3700FF0700FF3700FF95
00DCFFCC00FFFF00D400FFC400FF669D00FF00FFC427FF0027FF0056FF0085FF0085FF00
85FF0056FF0056FF0056FF0000FF37FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC400FF0756FF00B5FF00
E4FF00FFEC00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0085FF00
56FF0027FF0000FF6600FFF4FF00A5FF0000CC00FFFF000000FF95FF00A500FF9500ADFF
FF0000FF0000FF000000ADFF00FFC400ADFFFF000000FF9500FF0700FF0756FF0056FF00
56FF0056FF0027FF0027FF0000FF37FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000001FFF00FF0785FF00B5FF00
E4FF00FFEC00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00E4FF00B5FF00B5FF0085FF00
56FF0000FF0700FF3700ADFFFF0000FF0000FF0000FF000000DCFF004EFFFF0000FC00FF
FF0000FF0000FF00003F00FFFF0017FF0017FF0000FF000000FFF4FF000000FF0727FF00
27FF0027FF0027FF0000FF0700FF6600ADFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0756FF0085FF00
E4FF00FFEC00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00B5FF0085FF0085FF00
56FF00FC00FF00FF95FF0000FF0000FF0000FF0000FF00003F00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00003F00FF004EFFFF000000FF3700FF07
27FF0027FF0000FF0700FF0700FF95FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF6627FF0000FF37
B5FF00FFEC00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00B5FF0085FF0085FF00
27FF0000FF9500DCFF001FFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF4007EFF
00FF3700FF0700FF0700FF3700FFF4FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF660F00FF
B5FF00FFEC00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF0085FF0056FF00
27FF0000FF3700FF95FF0046FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00006E00FF00ADFF
00FF6600FF3700FF3700FF6600FFF4FF0076FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000004EFF00FF37
B5FF00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFEC00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF0056FF0056FF0027FF00
00FF0700FF3700FFC400ADFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF007600FF9500FF6600FF95FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FC00FF00FF37
E4FF00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFEC00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF0085FF0000FF07007EFF00FF37
00FFC400FFF4004EFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFC400FF9500FFC4FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000ADFF00FF3756FF00B5FF00
E4FF00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFEC00E4FF00B5FF00B5FF00B5FF00B5FF00B5FF0085FF0085FF0027FF0000DCFFFF0000
FF0000FF0000FF00D4FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000ADFF00FFF400DCFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0785FF00E4FF00
FFEC00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00
E4FF0027FF0085FF00B5FF00B5FF0085FF0085FF0085FF0056FF0027FF0000FF3700FFC4
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000ADFF00ADFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003F00FF00FF3756FF00E4FF00
FFEC00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00
B5FF0085FF00FC00FF56FF0085FF0085FF0085FF0085FF0056FF0027FF0000FF3700FF95
FC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000001FFF004EFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FC00FF85FF00E4FF00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00
B5FF0085FF00007EFF00FF9556FF0056FF0056FF0056FF0027FF0027FF0000FFC400FFF4
6E00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000F00FF00FFC4B5FF00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00
B5FF0085FF0000FF37007EFF00FF0727FF0000FF07FF000000FF3700FF3700FFC4FC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000004EFF00FF3785FF00E4FF00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00B5FF00
B5FF0085FF0027FF0000FF6600FFC400FF3700FF37007EFF00FF6600FF6600FF950F00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0076FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000B5FF00E4FF00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF5E00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF00
85FF0085FF0027FF0000FF37FF000000FFF400FFF4FF000000DCFF00DCFF00DCFF9D00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FF00FF3785FF00E4FF00FFEC00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00E4FF00E4FF00E4FF00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF0085FF00
85FF0085FF0027FF0000FF37001FFFFF0000FF0046FF0000FF00466E00FF004EFFFF00A5
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000056FF00B5FF00E4FF00FFEC00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00
FFEC00FFEC00FFEC00FFEC00E4FF00B5FF0085FF00E4FF00E4FF00E4FF00E4FF00E4FF00
FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00B5FF00E4FF00B5FF00B5FF0056FF0085FF00
56FF0000FF3700FF3700FF6600ADFFFF0000FF0000FF0000FF0000FF0000FF0017FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000027FF00B5FF00E4FF00E4FF00FFEC00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8D00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00
FFEC00FFEC00FFEC00E4FF00E4FF0085FF0027FF00B5FF00E4FF00E4FF00E4FF00B5FF00
B5FF00B5FF0085FF00B5FF00B5FF00B5FF00B5FF0085FF0085FF0056FF0000FF3727FF00
27FF0000FF37007EFF00FFF4FF00D4FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0785FF00B5FF00E4FF00E4FF00FFEC00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFBD00FFBD00FFBD00FFBD00FFEC00E4FF00FFEC00
FFEC00FFEC00E4FF00E4FF00E4FF0056FF0000FFF400FFF485FF0085FF00B5FF00B5FF00
85FF0085FF0000FF0785FF0085FF00B5FF0085FF0085FF0056FF0027FF0000DCFF00FF37
00FF3700FF3700ADFFCC00FFFF0076FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF3756FF0085FF00B5FF00E4FF00E4FF00FFEC00FFEC00
FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFEC00E4FF00B5FF00B5FF00B5FF00E4FF00B5FF00
85FF0085FF00B5FF0085FF0056FF0000ADFFFF000000FFC427FF0056FF0056FF0000FF66
56FF0000FF0700ADFF00FF0700FF0700FF0727FF0000FF0700FF3700FF950F00FF00FFF4
007EFF00DCFF3F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000F00FF00FF3727FF0085FF00B5FF00B5FF00E4FF00E4FF00FFEC00FFEC00
FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFEC00E4FF00B5FF00B5FF00B5FF00E4FF00B5FF00
85FF0085FF00B5FF0085FF0056FF0000ADFFFF000000FFC427FF0056FF0056FF0000FF66
56FF0000FF0700ADFF00FF0700FF0700FF0727FF0000FF0700FF3700FF950F00FF00FFF4
007EFF00DCFF3F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000F00FF00FF3727FF0085FF00B5FF00B5FF00E4FF00E4FF00FFEC00FFEC00
FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFBD00FFBD00FFBD00FFBD00FFEC00E4FF00FFEC00
FFEC00FFEC00E4FF00E4FF00E4FF0056FF0000FFF400FFF485FF0085FF00B5FF00B5FF00
85FF0085FF0000FF0785FF0085FF00B5FF0085FF0085FF0056FF0027FF0000DCFF00FF37
00FF3700FF3700ADFFCC00FFFF0076FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF3756FF0085FF00B5FF00E4FF00E4FF00FFEC00FFEC00
FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8D00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00
FFEC00FFEC00FFEC00E4FF00E4FF0085FF0027FF00B5FF00E4FF00E4FF00E4FF00B5FF00
B5FF00B5FF0085FF00B5FF00B5FF00B5FF00B5FF0085FF0085FF0056FF0000FF3727FF00
27FF0000FF37007EFF00FFF4FF00D4FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0785FF00B5FF00E4FF00E4FF00FFEC00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00
FFEC00FFEC00FFEC00FFEC00E4FF00B5FF0085FF00E4FF00E4FF00E4FF00E4FF00E4FF00
FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00B5FF00E4FF00B5FF00B5FF0056FF0085FF00
56FF0000FF3700FF3700FF6600ADFFFF0000FF0000FF0000FF0000FF0000FF0017FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000027FF00B5FF00E4FF00E4FF00FFEC00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00E4FF00E4FF00E4FF00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF0085FF00
85FF0085FF0027FF0000FF37001FFFFF0000FF0046FF0000FF00466E00FF004EFFFF00A5
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000056FF00B5FF00E4FF00FFEC00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF5E00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF00
85FF0085FF0027FF0000FF37FF000000FFF400FFF4FF000000DCFF00DCFF00DCFF9D00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CC00FF00FF3785FF00E4FF00FFEC00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00B5FF00
B5FF0085FF0027FF0000FF6600FFC400FF3700FF37007EFF00FF6600FF6600FF950F00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0076FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000B5FF00E4FF00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00
B5FF0085FF0000FF37007EFF00FF0727FF0000FF07FF000000FF3700FF3700FFC4FC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000CC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000004EFF00FF3785FF00E4FF00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00
B5FF0085FF00007EFF00FF9556FF0056FF0056FF0056FF0027FF0027FF0000FFC400FFF4
6E00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000F00FF00FFC4B5FF00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00
B5FF0085FF00FC00FF56FF0085FF0085FF0085FF0085FF0056FF0027FF0000FF3700FF95
FC00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000001FFF004EFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FC00FF85FF00E4FF00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00
E4FF0027FF0085FF00B5FF00B5FF0085FF0085FF0085FF0056FF0027FF0000FF3700FFC4
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000ADFF00ADFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003F00FF00FF3756FF00E4FF00
FFEC00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFEC00E4FF00B5FF00B5FF00B5FF00B5FF00B5FF0085FF0085FF0027FF0000DCFFFF0000
FF0000FF0000FF00D4FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000ADFF00FFF400DCFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0785FF00E4FF00
FFEC00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFEC00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF0085FF0000FF07007EFF00FF37
00FFC400FFF4004EFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000000FFC400FF9500FFC4FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000ADFF00FF3756FF00B5FF00
E4FF00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFEC00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF0056FF0056FF0027FF00
00FF0700FF3700FFC400ADFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF007600FF9500FF6600FF95FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FC00FF00FF37
E4FF00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF0085FF0056FF00
27FF0000FF3700FF95FF0046FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00006E00FF00ADFF
00FF6600FF3700FF3700FF6600FFF4FF0076FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000004EFF00FF37
B5FF00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00B5FF0085FF0085FF00
27FF0000FF9500DCFF001FFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF4007EFF
00FF3700FF0700FF0700FF3700FFF4FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF660F00FF
B5FF00FFEC00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00B5FF0085FF0085FF00
56FF00FC00FF00FF95FF0000FF0000FF0000FF0000FF00003F00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00003F00FF004EFFFF000000FF3700FF07
27FF0027FF0000FF0700FF0700FF95FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF6627FF0000FF37
B5FF00FFEC00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00E4FF00B5FF00B5FF0085FF00
56FF0000FF0700FF3700ADFFFF0000FF0000FF0000FF000000DCFF004EFFFF0000FC00FF
FF0000FF0000FF00003F00FFFF0017FF0017FF0000FF000000FFF4FF000000FF0727FF00
27FF0027FF0027FF0000FF0700FF6600ADFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF0756FF0085FF00
E4FF00FFEC00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0085FF00
56FF0027FF0000FF6600FFF4FF00A5FF0000CC00FFFF000000FF95FF00A500FF9500ADFF
FF0000FF0000FF000000ADFF00FFC400ADFFFF000000FF9500FF0700FF0756FF0056FF00
56FF0056FF0027FF0027FF0000FF37FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000001FFF00FF0785FF00B5FF00
E4FF00FFEC00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0056FF00
27FF0000FF0700FFF4004EFFFF0017007EFF00FFF400FF9500FF3700FF0700FF3700FF95
00DCFFCC00FFFF00D400FFC400FF669D00FF00FFC427FF0027FF0056FF0085FF0085FF00
85FF0056FF0056FF0056FF0000FF37FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFC400FF0756FF00B5FF00
E4FF00FFEC00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00E4FF00B5FF00B5FF0056FF00
00FF3700FF66FF0076007EFFFF0000FC00FF00FF3700FF6627FF0027FF0000FF0700FF66
00DCFFFF00006E00FF00FF0700FF0700ADFFFC00FF56FF0056FF0085FF0085FF0085FF00
85FF0085FF0056FF0056FF0027FF0000FFC4004EFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000056FF00
B5FF00E4FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00B5FF0056FF0000FFF4
00FF9500FF9500FF9500FF0700FF3700FF3727FF0085FF0085FF0056FF0000FF0700FFF4
004EFFFF0046FF000056FF0056FF0056FF000F00FF56FF0085FF0085FF0085FF0085FF00
85FF0085FF0085FF0056FF0027FF0000FF3700FFC4FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF4FF0000
27FF00E4FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF0085FF0056FF003F00FF
00FF0727FF0056FF0056FF0056FF0000FF6685FF0085FF0085FF0085FF0027FF00004EFF
00FF6627FF0056FF0085FF0085FF0085FF00B5FF00B5FF00B5FF00B5FF00B5FF00B5FF00
B5FF0085FF0085FF0085FF0027FF0000FF95FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
00FF37B5FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF0000FF666E00FF00FF66
56FF0085FF0085FF0085FF00B5FF00B5FF00B5FF00B5FF00B5FF0085FF0056FF00FF0000
00FF3756FF0085FF0085FF00B5FF00B5FF00B5FF00E4FF00E4FF00B5FF00B5FF00B5FF00
B5FF00B5FF00B5FF0085FF0056FF0000ADFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000001FFFCC00FF
00FF3785FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00B5FF0027FF0000FF37
56FF00B5FF00B5FF00B5FF00E4FF00E4FF00E4FF00E4FF00B5FF00B5FF00B5FF0027FF00
00ADFF56FF00B5FF00B5FF00B5FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF00
B5FF00B5FF00B5FF00B5FF0085FF0027FF00CC00FF0F00FF00ADFFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000001FFF9D00FFFF000000FF3700DCFF
27FF00B5FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00B5FF0000FF07007EFF
85FF00B5FF00B5FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00B5FF0085FF00
27FF00B5FF00B5FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00
E4FF00B5FF00B5FF00B5FF0085FF0056FF0000FF07FF00D400FF95FC00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF6600DCFF00FF0727FF0000FF37
004EFFE4FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00B5FF0056FF0000FF37
85FF00B5FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00
B5FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00
E4FF00E4FF00B5FF00B5FF00B5FF0085FF0056FF0000FF0700FF6600DCFFFF00D4FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000000FFF400FF0727FF0085FF0085FF0056FF00
00FF95E4FF00FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFEC00E4FF0056FF000F00FF56FF00
B5FF00E4FF00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00
E4FF00E4FF00B5FF00B5FF00B5FF0085FF0056FF0000FF0700FF95FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000027FF0085FF0085FF00B5FF00B5FF00
B5FF00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFEC00E4FF0000FF07B5FF00E4FF00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00
E4FF00E4FF00E4FF00B5FF00B5FF0085FF0056FF0000FF3700ADFFFF0046FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000001FFFFC00FF27FF0085FF00B5FF00B5FF00E4FF00
FFEC00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00E4FF00E4FF00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
E4FF00E4FF00E4FF00E4FF00B5FF0085FF0027FF006E00FFFF0000FF0000FF0000FF0000
FF00D4FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF6600FF6685FF00B5FF00E4FF00E4FF00E4FF00
FFEC00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00E4FF00E4FF00E4FF0085FF0027FF0000ADFFFF00009D00FF0F00FFFF0000
00ADFFFF0017FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FFF400FF0727FF0085FF00B5FF00E4FF00E4FF00FFEC00
FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00E4FF00E4FF00B5FF0000FF6600FF37FC00FFFF004600FFF400FF95
00FF95FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000007EFF00FF9500FF0756FF0085FF00B5FF00E4FF00E4FF00FFEC00
FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF0085FF0056FF00FF007600FFC400FF37
00FF37FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00A527FF0085FF00B5FF00E4FF00FFEC00FFEC00
FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF0085FF0027FF0027FF0027FF00
27FF0000FF3700FFF4001FFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00A527FF00B5FF00E4FF00FFEC00FFEC00
FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00B5FF00B5FF00B5FF0085FF0056FF00
27FF0000FF0700FF6600DCFF6E00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000F00FFB5FF00E4FF00FFEC00FFEC00
FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0085FF0085FF00
56FF0000FF0700FF95FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00009D00FF
FF0000FF0000FF0000FF0000FF0000FF000000FF9527FF0085FF00B5FF00FFEC00FFEC00
FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0085FF00
56FF0000FF950F00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0017007EFF
FF0000FF0000FF0000FF0000FF0000FF0000FC00FF27FF0056FF00B5FF00FFEC00FFEC00
FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0085FF00
56FF0000FF95FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFF400FFC4
FF0000FF0000FF0000FF0000FF0000FF0000004EFF00FF6600DCFF9D00FFE4FF00FFEC00
FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF0085FF00
56FF0000FF9500ADFFFF0000FF0000FF0000FF0000FF0000FF0000004EFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FC00FF00FF3700FF66
FF0000CC00FFFF0000FF0000FF0000FF00D4FF000000DCFF00FFF485FF00E4FF00FFEC00
FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF0056FF00
27FF0000FF37007EFFFF0000FF0000FF0000FF0000FF0000FF000000FFC4FF00D4FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00D400DCFFFF000000FFC400FF0727FF00
00FF3700ADFFCC00FF00FFC49D00FFCC00FF00FFF40F00FF00FFC456FF00B5FF00FFEC00
FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF00FF0000
FF00A500FF950F00FFFF0000FF0000FF00A5FF0000FF000000FFC400FF66FF007600ADFF
004EFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000000ADFF00FF3727FF0056FF0056FF00
00FF07FC00FF0F00FF007EFF27FF0000FF07FF000000DCFF00FF3700FF0756FF00FFEC00
FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00E4FF00B5FF0027FF00
00FF953F00FF004EFFFF0000FF0000FF0000CC00FFFF000000FF9500FF0700FF0700FF66
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000CC00FF0F00FFFF0000FF0000FF000000FFF400FF0756FF0085FF0085FF00
56FF0000FF0700FF0756FF0056FF0027FF0000FF6600FFF456FF00B5FF00E4FF00FFBD00
FFBD00FFBD00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00B5FF0085FF00
00FF0700FFF4FF0000001FFF00FFF400FF6600FF95FF007627FF0027FF0027FF0000FF95
0F00FFFF0000FF0076FF0017007EFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0F00FFFF00003F00FF00FF95001FFFCC00FFFF0000FF000000FF0785FF0085FF00B5FF00
B5FF00B5FF00B5FF0085FF0085FF0056FF00007EFF00FF66B5FF00E4FF00FFEC00FFBD00
FFBD00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00B5FF0056FF00
007EFFFF0000FF0000FF000000FFF400FF3727FF0056FF0085FF0056FF0056FF0000FF07
004EFFFF0000FF000000FF6600DCFFFF0000004EFF3F00FF001FFFFF0000FF00009D00FF
FF0017FF0000FF0000FF0000FF0000FF0000FF00179D00FF0F00FF3F00FF00ADFFFF0000
00FFC4FF0000FF000000FF0700FF37FF0000FF007600DCFF56FF00B5FF00B5FF00B5FF00
E4FF00E4FF00E4FF00B5FF00B5FF0085FF0000FF3700FF07B5FF00E4FF00FFEC00FFBD00
FFBD00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00B5FF00FF0000
00FFC400FF07FF00D400FF66FF000000FF3756FF0085FF0085FF0085FF0085FF0056FF00
001FFF3F00FF00FFF400FF0700FF0700FF6600FF6600FF6600FF9500FFC4007EFFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF004600ADFF00FFC400FF9500FF37
00FF37FC00FF00FF0727FF0027FF0000FF370F00FF27FF00B5FF00B5FF00E4FF00E4FF00
E4FF00E4FF00E4FF00E4FF00E4FF00B5FF0056FF0000DCFF85FF00FFEC00FFEC00FFBD00
FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC0000FF0727FF00
00FF3785FF0085FF0056FF009D00FFFF000085FF00B5FF00B5FF00B5FF00B5FF0085FF00
27FF0027FF0027FF0056FF0056FF0027FF0000FF0700FF0700FF6600FFF4FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A500FFC400FF3700FF07
27FF0056FF0056FF0085FF0085FF0056FF0000FFC485FF00B5FF00E4FF00E4FF00E4FF00
FFEC00FFEC00E4FF00E4FF00E4FF00B5FF0085FF0056FF00B5FF00FFEC00FFBD00FF8D00
FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00
E4FF00E4FF00B5FF00B5FF00FF000085FF00B5FF00B5FF00B5FF00B5FF00B5FF00B5FF00
B5FF0085FF0085FF0085FF0056FF0056FF0027FF0000FF0700FF66FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000DCFF00FF3727FF00
56FF0085FF0085FF0085FF0085FF00B5FF00B5FF00E4FF00E4FF00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00E4FF00E4FF0000FFC4E4FF00FFEC00FFBD00FFBD00FF8D00
FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00
E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00E4FF00
E4FF00B5FF00B5FF0085FF0085FF0056FF0056FF0027FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D4FC00FF27FF00
56FF0085FF00B5FF00B5FF00B5FF00E4FF00E4FF00E4FF00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00FF8D00FF8D00
FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00
FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00E4FF00E4FF00
E4FF00E4FF00B5FF00B5FF0085FF0085FF0056FF0000FF0700DCFF9D00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF9500FF07
56FF00B5FF00B5FF00B5FF00E4FF00E4FF00E4FF00FFEC00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00
FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00
FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00E4FF00
E4FF00E4FF00E4FF00B5FF00B5FF0085FF0056FF0000FF66FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF37
85FF00B5FF00B5FF00E4FF00E4FF00E4FF00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00E4FF00
E4FF00E4FF00E4FF00B5FF00B5FF00B5FF0056FF006E00FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00009D00FF004EFF00DCFF
85FF00B5FF00E4FF00E4FF00E4FF00FFEC00FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
E4FF00E4FF00E4FF00E4FF00B5FF00B5FF0085FF0000FF66CC00FF0F00FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00003F00FF00FF6627FF00
85FF00B5FF00E4FF00E4FF00E4FF00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00
FFEC00E4FF00E4FF00E4FF00B5FF00B5FF0085FF0027FF0000FF66007EFFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF007627FF00
85FF00B5FF00E4FF00E4FF00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00FFEC00
FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0085FF0027FF00CC00FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000CC00FFFC00FF00FF66
00FF37B5FF00E4FF00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00
FFEC00FFEC00FFEC00E4FF00B5FF0085FF0056FF0000FF0700FFC4FF0000FF0000CC00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000ADFF00FFC43F00FFFF0000
27FF00B5FF00E4FF00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00
FFEC00FFEC00FFEC00E4FF00E4FF0056FF0000DCFF00FFC400FFF4007EFF0F00FF00DCFF
FF0000FF0000FF0000FF0000FF0000FF0000FF00003F00FF00FF9500FF66FC00FF00FF37
85FF00B5FF00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFEC00FFEC00FFEC00E4FF0085FF0000FF956E00FF007EFF0F00FF00FF6600FF95
FF0000007EFFFF00A5FF0000FF0000FF000000ADFF00FF9500FF0727FF0000FF9500DCFF
56FF00E4FF00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00B5FF0085FF0000FF37007EFF00FF0700FF07
00FF37007EFFFF0000FF0000FF0000FF0000004EFF00FF3727FF0056FF0085FF0056FF00
85FF00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00B5FF0000FF6627FF0056FF0027FF00
00FF0700FFC49D00FFFF0000FF0000FC00FFFF000000ADFF56FF0085FF00B5FF00B5FF00
E4FF00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00B5FF0085FF0085FF0056FF00
00FF956E00FF00ADFF0F00FFFF0000FF000000FFC400FFC485FF00B5FF00B5FF00E4FF00
E4FF00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00B5FF00B5FF0085FF00
56FF0000FF3700FF6600FFC4FF000000FFC400FF3727FF0085FF00B5FF00E4FF00E4FF00
FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00E4FF00E4FF00E4FF00B5FF00B5FF00
85FF0056FF0027FF00007EFFFF000000ADFF27FF0056FF0085FF00B5FF00E4FF00E4FF00
FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00E4FF00B5FF00
B5FF0056FF0027FF0000FF37FF000000FF6627FF0056FF0085FF00E4FF00E4FF00FFEC00
FFEC00FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00B5FF00
B5FF0085FF0027FF0000FF0700DCFF00FFF400FF3756FF0085FF00B5FF00E4FF00FFEC00
FFEC00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00E4FF00B5FF00
B5FF0085FF0027FF0000FF6600FFC400FF376E00FF00FF3700FF07B5FF00E4FF00FFEC00
FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00E4FF00B5FF00
85FF0085FF0000FF37FF00A527FF0056FF0000FF0700FFC4004EFF27FF00B5FF00FFEC00
FFEC00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00B5FF00
85FF0056FF0000FF3700FF0785FF0085FF0085FF0056FF0056FF0000FFF400ADFFFFEC00
FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00B5FF00
00FF0700FF95FC00FF00FF07B5FF00B5FF00E4FF00E4FF00B5FF0000FF66B5FF00FFEC00
FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00B5FF00
00FF07FF000000FF0785FF00B5FF00E4FF00E4FF00E4FF00E4FF00B5FF00E4FF00FFBD00
FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00FFEC00B5FF00
00FF070F00FF00FFC4E4FF00FFEC00FFEC00FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF00B5FF00
00FF0756FF00B5FF00E4FF00FFEC00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFBD00FFEC00FFEC00E4FF0085FF00
00ADFF85FF00E4FF00FFEC00FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00FFEC00FFEC00E4FF0056FF00
00FF0756FF00E4FF00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00E4FF0085FF00B5FF00
E4FF0085FF00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00E4FF00FFEC00
FFEC00FFEC00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FFBD00FFBD00
FFBD00FFBD00FFBD00FFBD00FFBD00FFBD00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00
FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF8D00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00FF5E00
FF5E00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00FF2F00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3oool4000000<0oooo0P00
00040?ooo`8000006P3oool4000001X0oooo1@0000020?ooo`800000103oool2000001/0oooo1@00
000I0?ooo`800000103oool2000000@0oooo0P00000I0?ooo`800000703oool2000000@0oooo0P00
00040?ooo`8000006P3oool5000000@0oooo000K0?ooo`030000003oool0oooo00T0oooo00@00000
0?ooo`3oool000006@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`3oool00000703oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000005`3oool010000000oooo0?ooo`00000J0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000006`3oool00`000000oooo0?ooo`040?ooo`00703o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0603o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool0
00006P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0103oool001D0oooo100000040?ooo`030000003oool0oooo00P0oooo0P00000D0?ooo`@0
0000103oool00`000000oooo0?ooo`0C0?ooo`@00000103oool00`000000oooo0?ooo`080?ooo`80
00005@3oool4000000@0oooo00<000000?ooo`3oool04P3oool400000080oooo00@000000?ooo`3o
ool000002@3oool2000001P0oooo00@000000?ooo`3oool000006P3oool010000000oooo0?ooo`00
00090?ooo`800000703oool00`000000oooo0?ooo`040?ooo`006`3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool00000703oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0603oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo01L0oooo00@000000?ooo`3oool000006P3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool0
01`0oooo0P00000:0?ooo`<000006P3oool2000001`0oooo0P00000:0?ooo`<000006`3oool20000
01/0oooo0P00000:0?ooo`<00000603oool2000001`0oooo0P00000:0?ooo`<000006P3oool20000
00H0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo000K0?ooool000001@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0080oooo0@0000010?ooo`001`3oool500000080oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`002@3oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3oool0
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`800000o`3oool10?oo
o`8000000@3oool000030?ooo`000000000000800000103oool00`000000oooo0?ooo`080?ooo`80
00001@3oool00`000000oooo0?ooo`020?oooe<0o`00YP3o;`050?ooo`4000000@3oool000T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
DP3o002W0?l_00D0oooo0@0000010?ooo`00203oool2000000X0oooo0`0000040?ooo`030000003o
ool0oooo0080ooooDP3o002W0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`02
0?oooe80o`00Y`3o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooomA0?l0
0:P0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080ooooD03o002Y0?l_00D0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooodh0o`00Z`3o;`050?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool00P3ooom>0?l00:/0obl01@3oool100000040oooo000K
0?ooo`8000000`3ooom=0?l00:`0obl0103oool200000040oooo000K0?ooo`030000003oool0oooo
0080ooooC03o002]0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oood/0
o`00[P3o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooom90?l00;00obl0
1@3oool100000040oooo000K0?ooo`030000003oool0oooo0080ooooB@3o002`0?l_00D0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`020?ooodT0o`00/03o;`050?ooo`4000000@3oool0
01/0oooo00<000000?ooo`3oool00P3ooom80?l00;40obl01@3oool100000040oooo000K0?ooo`03
0000003oool0oooo0080ooooA`3o000o0?l_0140oeh0HP3o;`050?ooo`4000000@3oool001/0oooo
0P0000030?ooodH0o`00=P3o;`0U0?mN05P0obl0103oool200000040oooo000K0?ooo`030000003o
ool0oooo0080ooooAP3o000f0?l_02D0oeh0F03o;`050?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool00P3ooom60?l00300obl0<@3oGP1B0?l_00D0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`020?oood@0o`00;@3o;`0k0?mN04d0obl01@3oool100000040oooo000K0?ooo`03
0000003oool0oooo0080oooo@`3o000[0?l_0480oeh0B@3o;`050?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool00P3ooom30?l002L0obl0B@3oGP160?l_00D0oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`020?oood<0o`009`3o;`190?mN04H0obl01@3oool100000040oooo000K
0?ooo`030000003oool0oooo0080oooo@P3o000T0?l_0500oeh0@`3o;`050?ooo`4000000@3oool0
01/0oooo0P0000030?oood40o`008`3o;`1F0?mN03l0obl0103oool200000040oooo000K0?ooo`03
0000003oool0oooo0080oooo@@3o000P0?l_05/0oeh0?@3o;`050?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool00P3ooolo0?l00200obl0G`3oGP0k0?l_00D0oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`020?ooocl0o`00803o;`1O0?mN03/0obl01@3oool100000040oooo000K
0?ooo`030000003oool0oooo0080oooo?P3o000N0?l_0400oeh04P3oS@0C0?mN03P0obl01@3oool1
00000040oooo000K0?ooo`030000003oool0oooo0080oooo?P3o000L0?l_03d0oeh0703oS@0@0?mN
03H0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo?@3o000J0?l_03d0
oeh03P3oS@0:0?nm00X0ohd03`3oGP0d0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`020?ooocd0o`006@3o;`0l0?mN00d0ohd00`3o_@000`3To`00on`00?o/00020?o/00H0okd0
2`3oS@0?0?mN0380obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo?@3o
000I0?l_03`0oeh03@3oS@030?nm00030>Co003ok000on`00080on`01P3o_@0;0?n=00l0oeh0<P3o
;`050?ooo`4000000@3oool001/0oooo0P0000030?oooc`0o`005`3o;`0l0?mN00l0ohd00`3o_@00
0`3To`00QOl00;Go00020>Co000308Go003ok000okd000D0okd03@3oS@0=0?mN0340obl0103oool2
00000040oooo000K0?ooo`030000003oool0oooo0080oooo>`3o000G0?l_03/0oeh0403oS@020?nm
00<0on`000L0i?l005Ko0000o`L00?l705Ko003To`00on`000L0okd0303oS@0?0?mN02h0obl01@3o
ool100000040oooo000K0?ooo`030000003oool0oooo0080oooo>`3o000E0?l_03X0oeh04P3oS@03
0?nm00<0on`000H0i?l008Go0000[Ol00:go08Go003To`040?o/00D0okd03@3oS@0>0?mN02d0obl0
1@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo>@3o000E0?l_03/0oeh04@3o
S@050?nm00<0on`000L0i?l00;Go0000o`L00?l705Ko002eo`00i?l000D0on`0103o_@0>0?n=00l0
oeh0:P3o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oooli0?l001D0obl0
>`3oGP0A0?n=00D0okd00`3ok0001`3To`00]Ol0003o1`00o`L0E_l00;Go003To`001@3ok0040?nm
00h0ohd03`3oGP0Z0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooocT0
o`00503o;`0i0?mN01<0ohd01P3o_@040?o/00060;Go0000o`L00?l700l0o`00ol@0i?l0203ok002
0?nm00h0ohd03`3oGP0Y0?l_00D0oooo0@0000010?ooo`004`3oool5000000<0oooo00<000000?oo
o`3oool00P3ooolh0?l001<0obl0>P3oGP0C0?n=00L0okd0103ok0001P2eo`000?l7003o1`3o0000
0?l708Go0080]Ol01@3To`000`2eo`00i?l00?nm00020?nm00d0ohd03`3oGP0X0?l_00D0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo>03o000A
0?l_03X0oeh05@3oS@070?nm00@0on`000H0]Ol0003o1`00o`L00?nE0?`0o`00o`L30;Go0080i?l0
0P2eo`000`00ofH0]Ol00?o/00020?nm00h0ohd03`3oGP0W0?l_00D0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`030?ooo`8000000`3ooolg0?l00140obl0>@3oGP0F0?n=00P0okd00`3o
k0001`3To`00]Ol008Go0025o`00E_l0003o=`00o`L01025o`0305Ko0003003om000[Ol0on`000<0
okd03`3oS@0?0?mN02D0obl0103oool200000040oooo000=0?ooo`@00000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo=`3o000A0?l_03T0oeh05P3oS@080?nm00<0on`0
00L0i?l00;Go0025o`00QOl005Ko0000ocL00?l700@0QOl00`1Fo`000`00oo@00:go0?o/00030?nm
00l0ohd03`3oGP0U0?l_00D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo=`3o000@0?l_03T0oeh05@3oS@090?nm00@0on`000<0i?l00;Go0025
o`000P25o`001`00ocL0o`2U02Oo000Wo`00E_l0003o1`00ol@00P00C_l00`0Wo`00]Ol00?o/0002
0?o/0080okd03`3oS@0?0?mN02@0obl01@3oool100000040oooo000D0?ooo`8000001@3oool00`00
0000oooo0?ooo`020?ooocH0o`00403o;`0i0?mN01H0ohd02@3o_@030?o/0080i?l00`2eo`000`25
o`009ol0003oIP02003oa003003o=`1^0?l00?lg00800?l700<0]Ol00>Co003ok0000P3ok0020?nm
0100ohd0403oGP0R0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooocH0
o`003P3o;`0h0?mN01P0ohd02P3o_@030?o/0080i?l00`2eo`000`25o`009ol0003o1`02003Lo`03
003om000ocL0E_l00080QOl000<0]Ol00>Co003ok0000P3ok0030?nm0100ohd04@3oGP0P0?l_00D0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooc@0o`003`3o;`0h0?mN01P0ohd0
2P3o_@020?o/00@0i?l00`2eo`000`1Fo`009ol0003o=`020?l00003003oIP0Wo`00E_l00080QOl0
0P3To`040?o/00@0okd0403oS@0@0?mN01l0obl01@3oool100000040oooo000K0?ooo`030000003o
ool0oooo0080oooo=03o000?0?l_03P0oeh0603oS@0:0?nm0080on`0103To`030;Go000305Ko000W
o`000?lg0080o`0000<00?mV02Oo001Fo`000P25o`020>Co00@0on`0103o_@0@0?n=0100oeh07`3o
;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooold0?l000h0obl0>03oGP0I
0?n=00X0okd000<0on`00>Co003To`000P3To`020;Go0080QOl000<0E_l002Oo0000O_l00P3o0000
0`00[Ol09ol005Ko000208Go00030;Go003To`00i?l000<0on`01@3o_@0?0?n=0140oeh07P3o;`05
0?ooo`4000000@3oool001/0oooo0P0000030?oooc<0o`003P3o;`0h0?mN01T0ohd02P3o_@020?o/
00<0i?l00P2eo`001P25o`00E_l005Ko0000ocL00?mV003oa080o`0000<00?o4003o=`0Wo`000P25
o`000`2eo`00i?l00>Co00030?o/00H0okd03`3oS@0@0?mN01h0obl0103oool200000040oooo000K
0?ooo`030000003oool0oooo0080oooo<`3o000<0?l_03T0oeh0603oS@0:0?nm00<0on`00P3To`02
0;Go0080QOl000H0E_l0003oU@00oiD0KP3o002]o`0?0?l30?l000800?o40P25o`020;Go00<0i?l0
00<0on`00?nm003o_@001@3o_@0?0?n=0100oeh07@3o;`050?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool00P3ooolc0?l000/0obl0>03oGP0I0?n=00X0okd00`3ok0020>Co00060;Go0000
ofH00?mV02Oo001Fo`009ol00P00o`L00`00ol@0W@3o0?l000020?l000030?`0o`3o00000:go0080
E_l000<0QOl00;Go002eo`000P3To`020?o/00L0okd03`3oS@0A0?mN01/0obl01@3oool100000040
oooo000K0?ooo`030000003oool0oooo0080oooo<`3o000;0?l_03P0oeh06@3oS@0:0?nm00<0on`0
0P3To`001P2eo`000?mV003oIP0Wo`00E_l002Oo00800?l700<00?o409d0o`3o00000P3o00000`3l
0?l0o`00002]o`0205Ko000308Go002eo`00]Ol00080i?l00P3ok0070?nm00l0ohd04@3oGP0K0?l_
00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooc80o`002`3o;`0h0?mN01T0
ohd02P3o_@040?o/00030>Co002eo`00QOl000800?lg00<007ko003o1`00o`L00P00ocL00`00O_l0
o`000?l000030?l00007001>o`00ocL09ol002Oo001Fo`00QOl005Ko000208Go0080on`02@3o_@0=
0?n=0180oeh06P3o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolb0?l0
00/0obl0=`3oGP0I0?n=00X0okd00`3ok0020>Co000308Go0000oiD0KP3o008007ko00<03`3o003o
IP00oiD00P3o00000`00O_l0o`2U0?l000030?l00007002]o`00oiD00?l7003o1`0Wo`000?nE003L
o`0205Ko00030>Co003ok000on`000X0okd03@3oS@0A0?mN01T0obl01@3oool100000040oooo000K
0?ooo`030000003oool0oooo0080oooo<@3o000;0?l_03L0oeh0603oS@090?nm00D0on`00`3To`00
0`1Fo`000=co003oa002003om003001no`0?0?l00=co00T0o`0000H0?`3o003oU@00oiD00?mV0?`0
o`00ocL208Go00030;Go003ok000on`000/0okd0303oS@0B0?mN01P0obl01@3oool100000040oooo
000K0?ooo`030000003oool0oooo0080oooo<@3o000:0?l_03H0oeh06@3oS@090?nm00H0on`000H0
i?l00;Go002eo`00QOl005Ko0000o`L2003oa080o`0000<0c03o0?l0003o0000203o0002002]o`03
003oa00o0?l0o`0000809ol000<0]Ol00>Co003ok0000P3ok00;0?nm00/0ohd04@3oGP0H0?l_00D0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooc40o`002P3o;`0f0?mN01T0ohd0
2@3o_@060?o/00060>Co002eo`00]Ol008Go001Fo`000?l70P00ol@20?l000030<`0o`3o0000o`00
00P0o`000P00[Ol00`00ol@0?`3o0?l0000202Oo00030;Go003To`00on`00080on`02`3o_@0;0?n=
0140oeh0603o;`050?ooo`4000000@3oool001/0oooo0P0000030?oooc40o`00203o;`0g0?mN01T0
ohd01`3o_@080?o/0080i?l00`2eo`001025o`009ol00<`0o`3<0?l?0?l000030<`0o`3l0?l00?mV
00800?lg00<0]Ol00>Co003ok0000`3ok00<0?nm00X0ohd04P3oGP0F0?l_00@0oooo0P0000010?oo
o`006`3oool00`000000oooo0?ooo`020?ooobl0o`002P3o;`0f0?mN01T0ohd01P3o_@090?o/00<0
i?l00`2eo`001@25o`009ol0003oIP00ofH007ko00l0o`0000D0o`1f02Oo0025o`00QOl00;Go0002
0>Co00@0on`0303o_@090?n=01<0oeh05@3o;`050?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool00P3oool_0?l000T0obl0=P3oGP0G0?n=00H0okd02P3ok0050>Co00<0]Ol000D0QOl0003o
IP3<0?l0c03o00l0o`0>0?l0000303l0o`00ofH09ol00080QOl000<0]Ol00>Co003To`000P3To`03
0?o/00d0okd0203oS@0C0?mN01@0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo
0080oooo;P3o00090?l_03D0oeh0603oS@060?nm00X0on`01@3To`040;Go000305Ko001^0?l0o`00
0100o`0000<0W@3o001>o`00g?l00P25o`000`2eo`00i?l00>Co00020>Co00H0on`02`3o_@070?n=
01<0oeh0503o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool^0?l000T0
obl0=@3oGP0H0?n=00H0okd02P3ok0050>Co00@0]Ol000<0E_l006h0o`3o0000403o00000`2M0?l0
04ko003Lo`0208Go00030;Go003To`00i?l00080i?l01P3ok00;0?nm00L0ohd04`3oGP0D0?l_00D0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobh0o`00203o;`0e0?mN01P0ohd0
1@3o_@0;0?o/00H0i?l00`2eo`000`25o`00E_l0003oIP0C0?l00003003o=`25o`00QOl00080]Ol0
103To`070?o/00X0okd0203oS@0B0?mN01<0obl01@3oool100000040oooo000K0?ooo`030000003o
ool0oooo0080oooo;P3o00080?l_03@0oeh05P3oS@060?nm00X0on`0203To`020;Go00<0QOl000D0
E_l0003o1`00g?l00=co09d0o`0?0?l00004003oU@00o`L0E_l005Ko00<0]Ol0103To`0<0?o/00D0
okd01`3oS@0D0?mN0140obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo
;@3o00070?l_03D0oeh05@3oS@060?nm0080on`04@3To`020;Go00<0QOl00P1Fo`000`0Wo`00o`00
0?l0000?0?l000030?l0e03l0?l09ol00080E_l000<0QOl00;Go002eo`000P2eo`030>Co00l0on`0
0`3o_@060?n=01<0oeh04@3o;`050?ooo`4000000@3oool001/0oooo0P0000030?ooobd0o`001`3o
;`0c0?mN01D0ohd01`3o_@020?o/00@0i?l00P2eo`020?l0000308Go002eo`00]Ol000L0]Ol00`25
o`0305Ko000402Oo0000o`L00?mV003oIPl0o`0000<00=co003o=`0Wo`000P1Fo`0508Go0080]Ol0
0P3To`090?o/00<0i?l000<00?o40>Co003ok0000`3o_@050?n=01@0oeh0403o;`040?ooo`800000
0@3oool001/0oooo00<000000?ooo`3oool00P3oool]0?l000L0obl0<`3oGP0E0?n=00L0okd00P3o
k0040>Co0080]Ol00P3o00000`25o`00]Ol00;Go00070;Go00<0QOl00`1Fo`00100Wo`000?l7003o
IP00ofH?0?l00003003Lo`00ocL09ol00080E_l01@25o`020;Go0080i?l02@3ok0030>Co0003003o
a03To`00on`000<0okd01@3oS@0D0?mN0100obl01@3oool100000040oooo000K0?ooo`030000003o
ool0oooo0080oooo;@3o00060?l_03<0oeh0503oS@070?nm00<0on`000@00?l702Oo0000ocL00?lg
0P25o`001@1Fo`00W@3o09d0o`3o0000QOl000D0]Ol000<0QOl002Oo000Wo`000P0Wo`0305Ko0003
02Oo0000o`L00?l700800?mV00<00?od0?l0003o00002P3o00020?l0Y@03003oa000ocL00?l70080
9ol00P1Fo`0308Go000405Ko0000ol@0QOl00;Go00@0i?l00`3ok0030>Co0080]Ol000<0QOl005Ko
002eo`000P3ok0000`3o_@00ohd00?n=00040?n=01<0oeh0403o;`050?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool00P3oool]0?l000D0obl0<`3oGP0C0?n=00P0okd00`3ok0000`3To`00
]Ol00?l00002003oa003003o1`3o0=@00?mV0080o`0000<00?lg05Ko0025o`001025o`001@1Fo`00
01oo000Oo`0o0?l00?od00<00?l70`00ofH2003oU@03003oa000O_l0o`0000T0o`0000D0o`16002]
o`00[Ol00?o4003oU@03003o=`030?`0o`00o`L09ol000809ol000<00?lg00l0o`0Wo`000`2eo`08
0>Co0080]Ol000<0E_l0003Lo`25o`000`3ok0000`3o_@00ohd00?n=00030?n=01@0oeh03`3o;`05
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool/0?l000H0obl0<P3oGP0A0?n=
00X0okd0103ok0000`3To`00]Ol005Ko0002001no`<0o`000P00oo@00`00ocL09ol005Ko000208Go
0080E_l000<00?l7001>o`00C_l00P3o00001P00ofH00=co003Lo`3o000004ko03l0o`8001oo0P3o
00000`2M0?l0o`0G0?l05`060?l000070?l05`2M0?l03`3o00l0o`0o0?l00:go0?l00002003oa080
o`0000L00?l7003o=`00ocL0o`000?l0MP00g?l0E_l000@0]Ol0103To`020;Go0080QOl000<00?lg
003o1`2eo`000P3To`000`3ok000okd00?nm00040?n=01D0oeh03P3o;`050?ooo`4000000@3oool0
01/0oooo00<000000?ooo`3oool00P3oool/0?l000D0obl0<@3oGP0A0?n=00`0okd0103ok0000`3T
o`00]Ol008Go0002003o1`03003om03o000001oo00800?od00<00?mV003oU@3o07H0100Wo`001P00
oiD03`3o00l0o`3o0000o`1f0?l05`8007ko5`3o000200l0o`030?l0000o0?l00?nE008001oo00@0
c03o0?l0003o00000?l70`25o`050;Go0080QOl00P1Fo`000`00O_l00?mV0;Go00020>Co00030?o/
003o_@00okd000D0ohd0503oGP0>0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?oo
o`020?ooob`0o`001@3o;`0a0?mN0140ohd0303o_@040?o/00030>Co002eo`00QOl000800?l700<0
0?od0?l000007ol00P00oo@00`00ofH00?nE0?l0MP0402Oo0006003oU@0?0?l03`3o0?l0003o07H0
o`0G0P00O_lG0?l000803`3o00<0o`0003l0o`00oiD00P007ol0103<0?l0o`000?l00000o`L308Go
00D0]Ol00P25o`0205Ko0003001no`00ofH0]Ol00080i?l000<0on`00?nm003o_@001@3oS@0D0?mN
00h0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo;03o00050?l_0300
oeh03`3oS@0>0?nm00<0on`00`3To`001P2eo`009ol0003oU@00oiD0?`3o001>o`@0o`0000@0c03o
0?l00000oiD00?nE0P00o`L00`00ofH0o`000?l0000O0?l000030<`0o`0?0?l0o`0000<0o`0000@0
0?od003o1`1Fo`00E_l00P25o`00101Fo`000?l7003o1`00o`L205Ko00809ol000<00?mV003om01F
o`000P2eo`000`3To`00okd00?nm00020?nm00<0ohd05P3oGP0<0?l_00D0oooo0@0000010?ooo`00
6`3oool2000000<0oooo:P3o00050?l_0340oeh03P3oS@0>0?nm00D0on`00`3To`001P2eo`00o`00
0?l0Y@3o0:D00?nE00l0o`<0o`0000<0o`2U0?l0003o00000P00ol@00`00ofH0o`1f002]o`02001>
obD0o`0000@00:go003o=`0Wo`009ol00P1Fo`001P00o`L0o03o0?`0o`0?0?l007ko02Oo00800?l7
00<0o`00003Lo`00ocL00P00o`L00`1Fo`00on`00?nm00020?nm00D0ohd0503oGP0<0?l_00@0oooo
0P0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobX0o`001@3o;`0^0?mN00d0ohd04@3o
_@060?o/00<0i?l000H0]Ol005Ko000Wo`009ol0003o=`00O_l80?l00003003oa03o0=@0o`0002H0
o`0000<0o`3D003Lo`3o00000P00ol@00`00o`L09ol0003o=`02002]o`030<`0o`00ol@0W@3o0080
c03o00<00?od00l0o`00ol@00P1Fo`000`2eo`00on`00?nm00030?nm00@0ohd05@3oGP0;0?l_00D0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobX0o`00103o;`0^0?mN00/0ohd0
4`3o_@070?o/00<0i?l000H0]Ol008Go001Fo`00E_l0003oU@00[Ol80?l00003001>o`3o0000o`00
02T0o`000P3l0?l00`00ocL00?mV0?l000020<`0o`<0o`000P3o0=@00`3o00000=co003om00208Go
00030>Co003ok000okd000<0okd0103oS@0E0?mN00/0obl01@3oool100000040oooo000K0?ooo`03
0000003oool0oooo0080oooo:P3o00040?l_02h0oeh02`3oS@0C0?nm00L0on`00`3To`001P2eo`00
QOl005Ko001Fo`000?nE002]o`P0o`0000<004ko0?l0003o0000:@3o00020?`0o`03003o=`00ofH0
o`000080c03o0`3o00020?l0e0030?l00000g?l00?od0080QOl000<0i?l00?o/003o_@000`3o_@04
0?n=01D0oeh02`3o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolZ0?l0
00@0obl0;@3oGP0:0?n=01@0okd01`3ok0030>Co0080]Ol000@0QOl005Ko001Fo`000?nE=`3o0000
0`00oo@00?o40?l000070?l00003001>o`00ofH00=co0080W@3o00<0i?l00?o/003o_@000`3o_@05
0?n=01D0oeh02P3o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolY0?l0
00@0obl0;@3oGP080?n=01L0okd01`3ok0030>Co0080]Ol000D0QOl005Ko001Fo`000?nE00l0o`0f
0?l000030?l05`00O_l0o`0000L0o`0000<0o03o02Oo001Fo`000P2eo`020?o/00@0okd01@3oS@0E
0?mN00X0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo:@3o00040?l_
02X0oeh02@3oS@0H0?nm00L0on`00P3To`030;Go0080QOl00P1Fo`000`00o`L00?nE0?l0000f0?l0
000309d0o`3o0000o`0000H0o`0000<00?nE02Oo0025o`000P2eo`020?o/00D0okd0103oS@0E0?mN
00X0obl01@3oool100000040oooo00080?ooo`800000103oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo:@3o00040?l_02T0oeh01`3oS@0I0?nm00T0on`000<0i?l00;Go002e
o`000P2eo`001`25o`00E_l002Oo000Wo`000?l7003oIP00g?l00P1^0?ln0?l0000400l0o`2eo`00
i?l00>Co0080on`01@3o_@050?n=01D0oeh02@3o;`050?ooo`4000000@3oool000L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
:@3o00040?l_02T0oeh01`3oS@0I0?nm00T0on`000<0i?l00;Go002eo`000P2eo`001`25o`00E_l0
02Oo000Wo`000?l7003oIP00g?l00P1^0?ln0?l0000400l0o`2eo`00i?l00>Co0080on`01@3o_@05
0?n=01D0oeh02@3o;`050?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`020?ooo`8000000`3ooolY0?l000<0obl09`3oGP080?n=01X0okd02@3ok002
0>Co00030;Go0025o`00QOl000D09ol000<00?lg003om0007ol0?`3o00000`3o0:D09ol00;Go0002
0>Co00<0on`0103o_@050?n=01D0oeh02@3o;`040?ooo`8000000@3oool000030?ooo`0000000000
008000000P3oool010000000oooo0?ooo`0000090?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooobP0o`00103o;`0V0?mN00H0ohd06`3o_@090?o/00<0i?l000H0]Ol008Go001Fo`00E_l00?l0
MP00ol@3003o=d00o`000P3o0:D00`0Wo`00QOl00;Go00020>Co00<0on`0103o_@050?n=01L0oeh0
1`3o;`050?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo:03o00020?l_02H0oeh01`3oS@0J0?nm00X0on`0
0`3To`000`2eo`000?mV003o=`020?`0o`030?l0AP00oo@00?nE00800?nE?P3o00001`00O_l00?nE
003o1`00o`L0E_l008Go002eo`000`3To`020?o/00@0okd01P3oS@0F0?mN00L0obl01@3oool10000
0040oooo00080?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool00P3ooolX0?l00080
obl08`3oGP080?n=0080okd0203ok00@0?nm00/0on`0103To`000`25o`009ol0002]o`020?l00003
09d0o`0?0?l0o`0000800:go00<0o`0G0?l0003o0000?03o00001P00oo@00?l7003o1`0Wo`00QOl0
0;Go00<0i?l00P3ok0050?nm00D0ohd05P3oGP070?l_00D0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`020?ooobP0o`000P3o;`0S0?mN00P0ohd00P3o_@080?o/0100okd02`3ok0040>Co
000308Go000Wo`000:go0080o`0000<0W@3o00l0o`3o00000P00[Ol00`3o01L0o`000?l0000l0?l0
0006003om000o`L00?l702Oo0025o`00]Ol00`3To`020?o/00D0okd01@3oS@0F0?mN00L0obl01@3o
ool100000040oooo000K0?ooo`030000003oool0oooo0080oooo:03o00020?l_0240oeh0203oS@03
0?nm0080i?l0303ok0080?nm00`0on`0103To`020;Go000308Go000Wo`00KP3o00D0o`000P3o0=A0
0?l000<00?mV00<0QOl00;Go003To`000`3To`030?o/00<0okd01@3oS@0G0?mN00H0obl01@3oool1
00000040oooo000K0?ooo`030000003oool0oooo0080oooo:03o00000`3o;`00oeh00?mN000L0?mN
00X0ohd00P3o_@020?o/00030>Co0000o`L0]Ol00080i?l06`3ok0060>Co00<0]Ol000<0QOl005Ko
0000ocL00P00[Ol00`3o04H0o`000?l000120?l0008001oo00<0o03o02Oo0025o`000`2eo`00103T
o`00on`00?o/003ok0030?nm00L0ohd05@3oGP060?l_00D0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`020?ooobL0o`000P3o;`0J0?mN00d0ohd00`3o_@020?o/00030>Co001Fo`003`3o
0080E_l000<0]Ol00>Co003ok0004P3ok00;0>Co00@0]Ol000<0QOl005Ko0000o`L00P00oiE80?l0
000402Oo0025o`00QOl008Go00<0]Ol00P3ok0030?nm00L0ohd05@3oGP060?l_00D0oooo0@000001
0?ooo`006`3oool2000000<0oooo9`3o00020?l_01P0oeh03@3oS@040?nm00<0on`000<0i?l00;Go
001Fo`000P00ocL00`25o`00]Ol00>Co000<0>Co00030;Go003To`00i?l000h0i?l0102eo`000`25
o`00E_l0003o1`02003oIP03003Lo`3o0=@0o`0004@0o`0000<00?od003o1`0Wo`000`25o`001@1F
o`000?nE0>Co003To`00on`00080okd01`3oS@0F0?mN00D0obl0103oool200000040oooo000K0?oo
o`030000003oool0oooo0080oooo9`3o00020?l_01P0oeh03@3oS@040?nm00<0on`000<0i?l00;Go
001Fo`000P00ocL00`25o`00]Ol00>Co000<0>Co00030;Go003To`00i?l000h0i?l0102eo`000`25
o`00E_l0003o1`02003oIP03003Lo`3o0=@0o`0004@0o`0000<00?od003o1`0Wo`000`25o`001@1F
o`000?nE0>Co003To`00on`00080okd01`3oS@0F0?mN00D0obl01@3oool100000040oooo000K0?oo
o`030000003oool0oooo0080oooo9`3o00020?l_01@0oeh03`3oS@060?nm00<0on`000<0i?l00;Go
0000o`L00P00O_l00`25o`00]Ol00;Go00090>Co00040;Go0025o`00QOl002Oo0080]Ol03@3To`03
0;Go0080QOl000<0E_l0003o1`3o0=@00P00oiD00`3l0?l0o`000?l000150?l00007003oIP00g?l0
0?l7003o1`0Wo`000?lg001>o`020>Co00030?o/003o_@00okd000L0ohd05P3oGP050?l_00D0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobL0o`0000<0obl00?mN003oGP004@3o
GP0@0?n=00H0okd01@3ok0001@2eo`009ol0003o=`00ocL0E_l000@0]Ol01@3To`030;Go00809ol0
00<00:go05Ko002eo`000`2eo`070>Co00H0]Ol00P25o`000`0Wo`00c03o00l0o`02002]odP0o`00
00L001oo09d0o`3o0000o`00003o=`00g?l09ol00080]Ol000<0on`00?nm003o_@00203oS@0E0?mN
00D0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo9`3o00000`3o;`00
oeh00?mN000>0?mN0140ohd0203o_@040?o/00030>Co0000ofH0KP3o00800?mV00<0E_l008Go0025
o`000P25o`060;Go000608Go001Fo`00o`000?l00000ocL0E_l00`25o`030;Go00<0i?l01`2eo`00
1025o`00E_l005Ko0000[Om@0?l00003000Oo`3<0?l00?lg0080QOl000<0on`00?nm003o_@00203o
S@0E0?mN00D0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo9`3o0000
0`3o;`00oeh00?mN000<0?mN0180ohd02@3o_@040?o/00030>Co0025o`00E_l00080?`3o00<00?l7
02Oo001Fo`000`1Fo`000`00ofH0QOl008Go000308Go000602Oo0000C_l004ko003oIP0Wo`00E_l0
1025o`090;Go00<0QOl00P0Wo`000`00oiD0o`000?l0001@0?l00004003o=`2eo`00]Ol00?o/0080
okd0203oS@0F0?mN00@0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo
9`3o00000`3o;`00oeh00?mN000<0?mN0180ohd02@3o_@040?o/00030>Co0025o`00E_l00080?`3o
00<00?l702Oo001Fo`000`1Fo`000`00ofH0QOl008Go000308Go000602Oo0000C_l004ko003oIP0W
o`00E_l01025o`090;Go00<0QOl00P0Wo`000`00oiD0o`000?l0001@0?l00004003o=`2eo`00]Ol0
0?o/0080okd0203oS@0F0?mN00@0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo
0080oooo9@3o00020?l_00`0oeh0503oS@0:0?nm00@0on`000<0i?l00;Go001Fo`000P00oo@3003o
U@800?l70P00ocL01P0Wo`00QOl008Go0025o`00E_l0003o1`800?od00<004ko0?l0AP3o0000101F
o`000`0?0?l0E_l005Ko000808Go000505Ko000Wo`009ol0003o=`00ol@0C`3o00000`00oo@0o`00
02Oo00020>Co00030?o/003o_@00okd000P0ohd05P3oGP040?l_00D0oooo0@0000010?ooo`006`3o
ool2000000<0oooo9@3o00020?l_00/0oeh0503oS@0:0?nm00D0on`000<0i?l00;Go002eo`000P1F
o`000`00ocL00?mV0?l0MP02001no`030?l0003l0?l00?lg00800?mV0P0Wo`001P00o`L00?mV003o
IP00g?l0o`0006h0o`<00?l700<00:go0?`0o`1Fo`000P1Fo`0608Go0080E_l00P0Wo`000`00ol@0
04ko0?l0001?0?l0000505Ko002eo`00i?l00>Co003ok0000P3o_@080?n=01H0oeh0103o;`040?oo
o`8000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolU0?l00080obl0203oGP0E0?n=00`0
okd00`3ok0030>Co0080]Ol00P1Fo`000`0Wo`000?l7003om002001>o`030?l05`00O_l00?od0080
0?nE00<00?lg003o1`00ocL00P00oiD00`00g?l0c03o0?l0e002003oa003003oIP2M0?l00?o400<0
9ol000<0E_l008Go0025o`000P25o`0305Ko00800?lgCP3o00001P00ol@00?l7003o1`1Fo`00]Ol0
0>Co00<0on`00P3o_@090?n=01D0oeh0103o;`050?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool00P3ooolU0?l00080obl01`3oGP0E0?n=00d0okd00`3ok0030>Co0080]Ol00P25o`000`1F
o`009ol0003oIP02003om0030?l0Y@3o0000c03o0080o`0000<00?nE0?l0Y@00oiD00P00[Ol30?l0
00800:go00<00?o4002]o`3o00000P00oiD2003o1`D0E_l00P0Wo`02003o=dh0o`0000H001oo003o
1`00o`L0QOl00;Go003To`030?o/0080okd02@3oS@0G0?mN0080obl01@3oool100000040oooo000K
0?ooo`030000003oool0oooo0080oooo9@3o00020?l_00L0oeh05@3oS@0=0?nm00<0on`00`3To`02
0;Go0080QOl000<0E_l002Oo0000ofH00P00oo@00`3o0:D0o`000<`0o`020?l00003003oU@3o0:D0
0?nE00800:go0`3o0002002]o`03003oa000[Ol0o`0000800?nE0P00o`L505Ko00809ol00P00ocM>
0?l00006000Oo`00o`L00?l708Go002eo`00i?l00`3ok0020?nm00T0ohd05`3oGP020?l_00D0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobD0o`000P3o;`060?mN01D0ohd03P3o
_@020?o/00@0i?l00P2eo`0208Go000305Ko0000o`L00?lg00800:go1@3o00000`00g?l004ko0?l0
00020?`0o`<0o`000P0o0?l20?l05`<0o`0000<00?od0?l00000o`L01@0Wo`001000o`L00?mV003o
IP00[Om>0?l000800?l700<0E_l008Go003To`000`3ok0020?nm00T0ohd05`3oGP020?l_00D0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobD0o`001`3oGP0E0?n=00d0okd00`3o
k0050>Co00070;Go0025o`00QOl008Go001Fo`00o03o003oU@070?l0000303l0o`3o0000o`0000X0
o`000P0o0?l00`00C_l0o`00003o=`02003o1`809ol00P00o`L2003oUDl0o`000P00ofH00`0Wo`00
0?lg0;Go00030?o/0080okd02@3oS@0G0?mN0080obl01@3oool100000040oooo000K0?ooo`030000
003oool0oooo0080oooo9@3o00050?mN01D0ohd03`3o_@030?o/00D0i?l000L0]Ol008Go0025o`00
QOl002Oo0000oiD00=co008001oo5P3o00001000oo@007ko001no`00ocL2003o1`03003o=`00oo@0
0?od0540o`0000<00?mV00l0o`2eo`000`3ok0020?nm00T0ohd05`3oGP020?l_00D0oooo0@000001
0?ooo`006`3oool00`000000oooo0?ooo`020?ooobD0o`001@3oGP0E0?n=00h0okd00`3ok0060>Co
00070;Go0025o`00E_l005Ko000Wo`000?lg003oU@020?l0AQH0o`0000@0KP3o002]o`00[Ol00?mV
0P00ocL01000ofH00?od003om03o07I@0?l00003001>o`00ocL0]Ol00080on`00`3o_@090?n=01L0
oeh00P3o;`050?ooo`4000000@3oool001/0oooo0P0000030?ooobD0o`001@3oGP0E0?n=00h0okd0
0`3ok0060>Co00070;Go0025o`00E_l005Ko000Wo`000?lg003oU@020?l0AQH0o`0000@0KP3o002]
o`00[Ol00?mV0P00ocL01000ofH00?od003om03o07I@0?l00003001>o`00ocL0]Ol00080on`00`3o
_@090?n=01L0oeh00P3o;`040?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolU
0?l000@0oeh05@3oS@0?0?nm00030?o/003To`00i?l000D0i?l000<0]Ol005Ko001Fo`000P0Wo`00
0`00o`L00?lg003oa002002]oaT0o`0000@0o`1f003oU@00ofH00?nED`3o00000`3l0?l00?lg0>Co
00020?o/00<0okd02P3oS@0G0?mN00030?l_003oool0oooo00<0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`020?ooob@0o`0000@0obl00?mN003oGP00oeh05@3oS@0?0?nm00030?o/003T
o`00i?l000@0i?l00P2eo`000`25o`000?l7001no`02003o=`03003oa000oo@004ko01`0o`0000<0
0?o4003oU@00ol@0D03o00001P00[Ol00?lg003o=`1Fo`00]Ol00>Co0080on`00`3o_@0:0?n=01L0
oeh000<0obl00?ooo`3oool00`3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo
903o0000103o;`00oeh00?mN003oGP0D0?n=00l0okd000<0on`00>Co002eo`001@2eo`0308Go0003
02Oo0000g?l0o`0000<0o`0000<0o`3D0?l0003o00006P3o00000`00[Ol00?od003Lo`1A0?l00080
0?l700<0QOl00>Co003ok0000P3ok0030?nm00X0ohd05`3oGP000`3o;`00oooo0?ooo`030?ooo`40
00000@3oool001/0oooo00<000000?ooo`3oool00P3ooolT0?l000030?l_003oGP00oeh001@0ohd0
3@3o_@030?o/00030>Co000Wo`00QOl000<0]Ol01025o`000`1Fo`009ol0003o=`02003oa200o`00
0P00[Om@0?l0000503l0o`00ocL00?lg05Ko003To`000`3ok0030?nm00X0ohd05`3oGP000`3o;`00
oooo0?ooo`030?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolT0?l000030?l_
003oGP00oeh001@0ohd03@3o_@030?o/00030>Co000Wo`00QOl000<0]Ol01025o`000`1Fo`009ol0
003o=`02003oa200o`000P00[Om@0?l0000503l0o`00ocL00?lg05Ko003To`000`3ok0030?nm00X0
ohd05`3oGP000`3o;`00oooo0?ooo`030?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0
0P3ooolT0?l000<0oeh0503oS@080?nm00H0on`00P3To`000`2eo`00QOl00?`0o`0205Ko00D0QOl0
00<0E_l002Oo0000ocL00P00oiD00`3l0?l0o`000?l0000M0?l00003000Oo`00C_l0o`000500o`00
0P3l0?l00`25o`00i?l00?o/00050?nm00X0ohd05`3oGP000`3o;`00oooo0?ooo`030?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool00P3ooolT0?l000030?mN003oS@00ohd00180ohd01@3o
_@0:0?o/00<0i?l000<0]Ol008Go0000O_l00P00oiD505Ko00809ol000@00?o4003om000oo@0KP3o
803o00000`0?0?l0o`000?l0001>0?l0000400l0o`00ol@00?o40;Go0080on`01@3o_@0:0?n=01L0
oeh000<0obl00?ooo`3oool00`3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo
903o00000`3oGP00ohd00?n=000A0?n=00<0okd02`3ok0050>Co00030;Go0025o`000?lg008007ko
00<00?l702Oo0000o`L00P3o0002003o=`03003oa03l0?l0o03o0240o`0000<0c03o0?l0003o0000
C@3o00001@00C_l00?lg08Go0025o`00i?l00080on`01@3o_@0:0?n=01L0oeh000<0obl00?ooo`3o
ool00`3oool100000040oooo000K0?ooo`8000000`3ooolT0?l000030?mN003oS@00ohd00100ohd0
0P3o_@0;0?o/00D0i?l00`2eo`001@25o`009ol0003oIP00ofH00?o400800?lg0P00O_l2003oIP03
003oU@0?0?l03`3o0240o`0000<0o`1f0?l0003o0000C`3o00020;Go00030>Co003ok000on`000D0
okd02P3oS@0G0?mN00030?l_003oool0oooo0080oooo0P0000010?ooo`006`3oool00`000000oooo
0?ooo`020?ooob@0o`0000<0oeh00?n=003oS@00403oS@020?nm00/0on`01@3To`030;Go000508Go
000Wo`000?mV003oIP00ol@00P00ocL2001no`800?mV00<00?nE00l0o`0?0?l08@3o00000`3o07H0
o`000?l0001?0?l00080]Ol000<0i?l00?o/003ok0001@3o_@0:0?n=01L0oeh000<0obl00?ooo`3o
ool00`3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo903o00000`3oGP00ohd0
0?n=00030?n=00@0okd01P3oS@030?nm00`0on`01P3To`020;Go0080QOl000@09ol0003o=`00ocL0
o`000P00oo@20?l000<00=co0P2M0?m`0?l000030<`0o`00ocL0QOl00080i?l00`3ok0050?nm00X0
ohd05`3oGP000`3o;`00oooo0?ooo`030?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0
0P3ooolT0?l000<0ohd0303o_@000`3ok000i?l00>Co00020>Co00T0on`01`3To`000`2eo`00QOl0
08Go000208Go000602Oo0000ocL00?lg000Oo`3o0000o`160P3o00000`3o04H0KP3o001>o`020?l0
YG40o`0000@0E_l00;Go003To`00i?l00`3ok0050?nm00X0ohd05`3oGP000`3o;`00oooo0?ooo`03
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolT0?l000030?n=003o_@00okd0
00D0okd01P3ok000103To`00]Ol008Go0025o`060>Co00<0on`0103To`000`2eo`00i?l00>Co0002
0;Go000405Ko0025o`00QOl005Ko00800?lg0P00ofH00`00[Ol0o`000?l000040?l000030?l05`3o
0000o`000700o`0000<09ol00;Go003To`000P3To`030?o/00D0okd02P3oS@0G0?mN00030?l_003o
ool0oooo00<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooob@0o`0000<0ohd0
0?nm003o_@000`3o_@070?o/0080i?l000@0QOl002Oo000Wo`00]Ol0103To`030;Go000308Go002e
o`00]Ol000<0]Ol00`25o`000`1Fo`000?lg02Oo000202Oo0005003o=`00O_l00?od003om03o0=@0
M`3o0002003o1`0308Go002eo`00i?l00080i?l00`3ok0050?nm00X0ohd05`3oGP000`3o;`00oooo
0?ooo`030?ooo`4000000@3oool001@0oooo0P0000050?ooo`030000003oool0oooo0080oooo903o
00000`3oS@00okd00?nm00030?nm00L0on`00P3To`001025o`009ol002Oo002eo`040>Co00<0]Ol0
00<0QOl00;Go002eo`000`2eo`0308Go000305Ko0000ocL09ol000809ol000D00?lg001no`00oo@0
0?od0?l0e01g0?l000800?l700<0QOl00;Go003To`000P3To`030?o/00D0okd02P3oS@0G0?mN0003
0?l_003oool0oooo00<0oooo0@0000010?ooo`004`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo903o00050?nm00030?o/003To`00i?l000<0on`0103To`00101Fo`00
0?od003om000oo@208Go00<0]Ol00P25o`001@00o`L0QOl008Go0025o`00]Ol000<0QOl000<0E_l0
02Oo0000g?l01000ocL01000[Ol0c03o0<`0o`3o07If0?l00005003o=`1Fo`00E_l008Go002eo`00
0`3To`020?o/00H0okd02P3oS@0G0?mN00030?l_003oool0oooo00<0oooo0@0000010?ooo`004`3o
ool010000000oooo0?ooo`0000040?ooo`8000000`3ooolT0?l000030?o/003To`00i?l000<0]Ol0
0P3To`000`2eo`00QOl008Go00020;Go000308Go001Fo`000:go0080o`0000<00?o402Oo001Fo`00
0P1Fo`001000ofH0E_l0003o1`00[Ol4003o1`0602Oo0000o`L00?l7003o=`00oiD03`3o0P00oo@0
0`00O_l00=co03l0o`1g0?l0000300l0o`00ocL09ol00080QOl00P2eo`030>Co0080on`01P3o_@0:
0?n=01L0oeh000<0obl00?ooo`3oool00P3oool200000040oooo000C0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3ooolT0?l000030?o/003To`00i?l000<0]Ol00P3To`00
0`2eo`00QOl008Go00020;Go000308Go001Fo`000:go0080o`0000<00?o402Oo001Fo`000P1Fo`00
1000ofH0E_l0003o1`00[Ol4003o1`0602Oo0000o`L00?l7003o=`00oiD03`3o0P00oo@00`00O_l0
0=co03l0o`1g0?l0000300l0o`00ocL09ol00080QOl00P2eo`030>Co0080on`01P3o_@0:0?n=01L0
oeh000<0obl00?ooo`3oool00`3oool100000040oooo000C0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3ooolT0?l000D0okd000<0on`00>Co003To`000`3ok0040>Co0004
05Ko0000oo@00?od003om080QOl00`2eo`0208Go0005003o1`25o`00QOl008Go002eo`000`25o`00
0`1Fo`009ol0003Lo`04003o=`04002]o`3<0?l0c03o0?l0MWH0o`0000D00?lg05Ko001Fo`00QOl0
0;Go00030>Co0080on`01P3o_@0:0?n=01L0oeh000<0obl00?ooo`3oool00`3oool100000040oooo
000D0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooob@0o`001@3o_@000`3ok000i?l00>Co
00030?o/00@0i?l000@0E_l0003om000oo@00?od0P25o`030;Go0080QOl000D00?l708Go0025o`00
QOl00;Go000308Go000305Ko000Wo`000=co00@00?lg00@00:go0<`0o`3<0?l0o`1fMP3o00001@00
ocL0E_l005Ko0025o`00]Ol000<0i?l00P3ok0060?nm00X0ohd05`3oGP000`3o;`00oooo0?ooo`03
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolT0?l000030?n=003o_@00okd0
00<0okd01`3ok0020>Co000408Go000Wo`009ol00;Go00@0i?l00`2eo`000`25o`00]Ol00;Go0003
0;Go00<0QOl000<0E_l0003o=`0Wo`000P0Wo`001@00ocL007ko003om000oo@0o`3D07L0o`000P00
o`L00`25o`00]Ol00>Co00020>Co00<0on`01@3o_@0:0?n=01L0oeh000<0obl00?ooo`3oool00`3o
ool100000040oooo000K0?ooo`030000003oool0oooo0080oooo903o00000`3oS@00okd00?nm0005
0?nm00H0on`000@0i?l00;Go0025o`00QOl01P3To`030?o/00@0i?l000<0]Ol00>Co003To`000P2e
o`00101Fo`00QOl008Go001Fo`02003o=`800?mV00<00:go0?l0003o0000103o00000`3o01L0o`00
0?l0001`0?l0000302Oo002eo`00i?l00080i?l00`3ok0050?nm00X0ohd05`3oGP000`3o;`00oooo
0?ooo`030?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolT0?l000<0ohd0303o
_@000`3ok000i?l00>Co00020>Co00T0on`01`3To`000`2eo`00QOl008Go000208Go000602Oo0000
ocL00?lg000Oo`3o0000o`160P3o00000`3o04H0KP3o001>o`020?l0YG40o`0000@0E_l00;Go003T
o`00i?l00`3ok0050?nm00X0ohd05`3oGP000`3o;`00oooo0?ooo`030?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool00P3ooolT0?l000030?mN003oS@00ohd000<0ohd0103o_@060?n=00<0
okd0303ok0060>Co0080]Ol00P25o`00100Wo`000?lg003o=`3o0002003om080o`000`00g?l209d0
og00o`0000<0c03o003o=`25o`000P3To`030?o/00D0okd02P3oS@0G0?mN00030?l_003oool0oooo
00<0oooo0@0000010?ooo`006`3oool2000000<0oooo903o00000`3oGP00ohd00?n=00030?n=00@0
okd01P3oS@030?nm00`0on`01P3To`020;Go0080QOl000@09ol0003o=`00ocL0o`000P00oo@20?l0
00<00=co0P2M0?m`0?l000030<`0o`00ocL0QOl00080i?l00`3ok0050?nm00X0ohd05`3oGP000`3o
;`00oooo0?ooo`020?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolT0?l00003
0?mN003oS@00ohd00100ohd00P3o_@0;0?o/00D0i?l00`2eo`001@25o`009ol0003oIP00ofH00?o4
00800?lg0P00O_l2003oIP03003oU@0?0?l03`3o0240o`0000<0o`1f0?l0003o0000C`3o00020;Go
00030>Co003ok000on`000D0okd02P3oS@0G0?mN00030?l_003oool0oooo00<0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`020?ooob@0o`0000<0oeh00?n=003oS@004@3oS@030?nm00/0
on`01@3To`000`2eo`00QOl0003o=`02001no`03003o1`0Wo`000?l70080o`000P00ocL00`00ol@0
o03o0?`0o`0Q0?l000030<`0o`3o0000o`0004d0o`0000D004ko003o=`25o`00QOl00>Co00020?o/
00D0okd02P3oS@0G0?mN00030?l_003oool0oooo00<0oooo0@0000010?ooo`006`3oool00`000000
oooo0?ooo`020?ooob@0o`0000<0oeh00?n=003oS@004P3oS@050?nm00X0on`00`3To`000`2eo`00
QOl0001no`02003oU@D0E_l00P0Wo`001000ol@00?od003om01^0?lP0?l0000300l0o`3o0000o`00
04h0o`0000@03`3o003oa000ol@0]Ol00P3ok0050?nm00X0ohd05`3oGP000`3o;`00oooo0?ooo`03
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolT0?l000<0oeh0503oS@080?nm
00H0on`00P3To`000`2eo`00QOl00?`0o`0205Ko00D0QOl000<0E_l002Oo0000ocL00P00oiD00`3l
0?l0o`000?l0000M0?l00003000Oo`00C_l0o`000500o`000P3l0?l00`25o`00i?l00?o/00050?nm
00X0ohd05`3oGP000`3o;`00oooo0?ooo`030?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool00P3ooolT0?l000<0oeh0503oS@080?nm00H0on`00P3To`000`2eo`00QOl00?`0o`0205Ko00D0
QOl000<0E_l002Oo0000ocL00P00oiD00`3l0?l0o`000?l0000M0?l00003000Oo`00C_l0o`000500
o`000P3l0?l00`25o`00i?l00?o/00050?nm00X0ohd05`3oGP000`3o;`00oooo0?ooo`030?ooo`40
00000@3oool001/0oooo00<000000?ooo`3oool00P3ooolT0?l000030?l_003oGP00oeh001@0ohd0
3@3o_@030?o/00030>Co000Wo`00QOl000<0]Ol01025o`000`1Fo`009ol0003o=`02003oa200o`00
0P00[Om@0?l0000503l0o`00ocL00?lg05Ko003To`000`3ok0030?nm00X0ohd05`3oGP000`3o;`00
oooo0?ooo`030?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooolT0?l000040?l_
003oGP00oeh00?mN01@0ohd03`3o_@000`3ok000i?l00;Go00050;Go00<0QOl000<09ol0003Lo`3o
00000`3o00000`3o0=@0o`000?l0000J0?l00003002]o`00oo@00=co0540o`000P00o`L00`25o`00
i?l00?o/00020?o/00<0okd02P3oS@0G0?mN00030?l_003oool0oooo00<0oooo0@0000010?ooo`00
6`3oool00`000000oooo0?ooo`020?ooob@0o`0000@0obl00?mN003oGP00oeh05@3oS@0?0?nm0003
0?o/003To`00i?l000@0i?l00P2eo`000`25o`000?l7001no`02003o=`03003oa000oo@004ko01`0
o`0000<00?o4003oU@00ol@0D03o00001P00[Ol00?lg003o=`1Fo`00]Ol00>Co0080on`00`3o_@0:
0?n=01L0oeh000<0obl00?ooo`3oool00`3oool100000040oooo000K0?ooo`8000000`3ooolU0?l0
00@0oeh05@3oS@0?0?nm00030?o/003To`00i?l000D0i?l000<0]Ol005Ko001Fo`000P0Wo`000`00
o`L00?lg003oa002002]oaT0o`0000@0o`1f003oU@00ofH00?nED`3o00000`3l0?l00?lg0>Co0002
0?o/00<0okd02P3oS@0G0?mN00030?l_003oool0oooo0080oooo0P0000010?ooo`006`3oool00`00
0000oooo0?ooo`020?ooobD0o`00103oGP0E0?n=00l0okd000<0on`00>Co003To`001@3To`000`2e
o`00E_l005Ko000202Oo0003003o1`00ocL00?o400800:go6@3o0000103o07H00?nE003oIP00oiEC
0?l000030?`0o`00ocL0i?l00080on`00`3o_@0:0?n=01L0oeh000<0obl00?ooo`3oool00`3oool1
00000040oooo000K0?ooo`030000003oool0oooo0080oooo9@3o00050?mN01D0ohd03P3o_@030?o/
00H0i?l000L0]Ol008Go001Fo`00E_l002Oo0000ocL00?nE0080o`165P3o0000101^0?l00:go002]
o`00ofH2003o=`04003oIP00oo@00?od0?l0MU00o`0000<004ko003o=`2eo`000P3ok0030?nm00T0
ohd05`3oGP020?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobD0o`00
1@3oGP0E0?n=00l0okd00`3ok0050>Co00070;Go0025o`00QOl008Go000Wo`000?nE003Lo`02000O
oaH0o`0000@00?od001no`00O_l00?lg0P00o`L00`00ocL00?od003om01A0?l00003003oIP0?0?l0
]Ol000<0on`00P3o_@090?n=01L0oeh00P3o;`050?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool00P3ooolU0?l000L0oeh05@3oS@0=0?nm00<0on`01@3To`001`2eo`00QOl008Go0025o`00
E_l00?`0o`00oiD01`3o00000`0o0?l0o`000?l0000:0?l00080?`3o00<004ko0?l00000ocL00P00
o`L202Oo00800?l70P00oiE?0?l000800?mV00<09ol0003o=`2eo`000`3ok0020?nm00T0ohd05`3o
GP020?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobD0o`000P3o;`06
0?mN01D0ohd03P3o_@020?o/00@0i?l00P2eo`0208Go000305Ko0000o`L00?lg00800:go1@3o0000
0`00g?l004ko0?l000020?`0o`<0o`000P0o0?l20?l05`<0o`0000<00?od0?l00000o`L01@0Wo`00
1000o`L00?mV003oIP00[Om>0?l000800?l700<0E_l008Go003To`000`3ok0020?nm00T0ohd05`3o
GP020?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobD0o`000P3o;`06
0?mN01D0ohd03P3o_@020?o/00@0i?l00P2eo`0208Go000305Ko0000o`L00?lg00800:go1@3o0000
0`00g?l004ko0?l000020?`0o`<0o`000P0o0?l20?l05`<0o`0000<00?od0?l00000o`L01@0Wo`00
1000o`L00?mV003oIP00[Om>0?l000800?l700<0E_l008Go003To`000`3ok0020?nm00T0ohd05`3o
GP020?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobD0o`000P3o;`07
0?mN01D0ohd03@3o_@030?o/00<0i?l00P2eo`0208Go000305Ko000Wo`000?mV00800?od00<0o`2U
0?l0003<0?l00P3o00000`00oiD0o`2U003oU@02002]o`<0o`000P00[Ol00`00ol@00:go0?l00002
003oU@800?l71@1Fo`0202Oo00800?lgCP3o00001P007ol00?l7003o1`25o`00]Ol00>Co00<0on`0
0P3o_@090?n=01L0oeh00P3o;`050?ooo`4000000@3oool001/0oooo0P0000030?ooobD0o`000P3o
;`080?mN01D0ohd0303o_@030?o/00<0i?l00P2eo`0205Ko000302Oo0000o`L00?od008004ko00<0
o`0G001no`00oo@00P00oiD00`00ocL00?l7003o=`02003oU@03003Lo`3<0?l0o`3D00800?o400<0
0?mV09d0o`00ol@00`0Wo`000`1Fo`00QOl008Go000208Go00<0E_l00P00ocM>0?l00006003oa000
o`L00?l705Ko002eo`00i?l00`3ok0020?nm00T0ohd05@3oGP040?l_00@0oooo0P0000010?ooo`00
6`3oool00`000000oooo0?ooo`020?ooobD0o`000P3o;`0;0?mN01@0ohd02P3o_@050?o/00030>Co
002eo`00]Ol00080E_l000<00?lg003oIP3o07H00P00O_l00`3o0000o03o003o=`02003oIP809ol0
00H00?l7003oIP00ofH00=co0?l0001^0?l3003o1`03002]o`3l0?l0E_l00080E_l01P25o`0205Ko
00809ol000<00?o4001>o`3o0000C`3o00001@1Fo`00]Ol00>Co003To`00on`00080okd0203oS@0F
0?mN00@0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo9@3o00020?l_
00`0oeh0503oS@0:0?nm00@0on`000<0i?l00;Go001Fo`000P00oo@3003oU@800?l70P00ocL01P0W
o`00QOl008Go0025o`00E_l0003o1`800?od00<004ko0?l0AP3o0000101Fo`000`0?0?l0E_l005Ko
000808Go000505Ko000Wo`009ol0003o=`00ol@0C`3o00000`00oo@0o`0002Oo00020>Co00030?o/
003o_@00okd000P0ohd05P3oGP040?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?oo
o`020?ooobD0o`000P3o;`0<0?mN01@0ohd02P3o_@040?o/00030>Co002eo`00E_l000800?od0`00
oiD2003o1`800?lg00H09ol008Go0025o`00QOl005Ko0000o`L2003om003001>o`3o04H0o`0000@0
E_l000<03`3o05Ko001Fo`002025o`001@1Fo`009ol002Oo0000ocL00?o404l0o`0000<00?od0?l0
000Wo`000P3To`000`3ok000okd00?nm00080?n=01H0oeh0103o;`050?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool00P3ooolW0?l000030?l_003oGP00oeh000`0oeh04P3oS@090?nm00@0
on`000<0i?l008Go001Fo`000P0o0?l00`00o`L09ol005Ko000305Ko0003003oIP25o`00QOl000<0
QOl000H09ol0001>o`00C_l00?mV02Oo001Fo`0408Go00T0]Ol00`25o`0202Oo0003003oU@3o0000
o`000500o`0000@00?lg0;Go002eo`00on`00P3o_@080?n=01H0oeh0103o;`050?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool00P3ooolW0?l000030?l_003oGP00oeh000h0oeh04@3oS@08
0?nm00@0on`000<0i?l0003oIP1^0?l00P00ofH00`1Fo`00QOl008Go000208Go00H0]Ol000H0QOl0
05Ko003o0000o`00003o=`1Fo`0308Go00<0]Ol00`3To`070;Go000408Go001Fo`00E_l0002]oe00
o`0000<001oo0<`0o`00ocL00P25o`000`3ok000okd00?nm00080?n=01D0oeh01@3o;`050?ooo`40
00000@3oool001/0oooo00<000000?ooo`3oool00P3ooolW0?l000030?l_003oGP00oeh00140oeh0
403oS@060?nm00D0on`000D0]Ol002Oo0000ocL00?lg05Ko00040;Go00D0i?l00`2eo`0202Oo0003
002]o`1Fo`00]Ol000<0]Ol01`3To`060;Go0080QOl000<09ol00<`0o`0?0?l00P00[Om80?l00007
000Oo`2M0?l0o`000?l00000ocL00=co02Oo00020;Go00030?o/003o_@00okd000P0ohd05@3oGP05
0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobL0o`000P3o;`0D0?mN
00l0ohd01P3o_@030?o/00030>Co002eo`000?l7008007ko00<0QOl00;Go002eo`002@3To`00102e
o`00QOl008Go000Wo`020;Go00d0i?l00`2eo`0208Go000305Ko0000o`L0o`3D00800?nE00<0o03o
0?l0003o0000A@3o00001`00ofH00=co003o1`00o`L09ol0003o=`00C_l00P3To`000`3ok000okd0
0?nm00070?n=01H0oeh01@3o;`050?ooo`4000000@3oool001/0oooo0P0000030?ooobL0o`000P3o
;`0D0?mN00l0ohd01P3o_@030?o/00030>Co002eo`000?l7008007ko00<0QOl00;Go002eo`002@3T
o`00102eo`00QOl008Go000Wo`020;Go00d0i?l00`2eo`0208Go000305Ko0000o`L0o`3D00800?nE
00<0o03o0?l0003o0000A@3o00001`00ofH00=co003o1`00o`L09ol0003o=`00C_l00P3To`000`3o
k000okd00?nm00070?n=01H0oeh01@3o;`040?ooo`8000000@3oool001/0oooo00<000000?ooo`3o
ool00P3ooolW0?l00080obl0603oGP0=0?n=00@0okd00`3ok0000`3To`00]Ol005Ko0002003o=`03
08Go002eo`00i?l000`0i?l000<0]Ol00>Co003To`003P3To`040;Go000308Go001Fo`000?l70080
0?mV00<00=co0?l0e03o0000A03o00000`00oo@00?l702Oo000308Go000505Ko0000oiD0i?l00>Co
003ok0000P3o_@070?n=01H0oeh01@3o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool00P3ooolW0?l00080obl06P3oGP0=0?n=00<0okd00P3ok0000`3To`00E_l000l0o`0205Ko0003
0;Go003To`00on`00180on`02`3To`040;Go000308Go001Fo`000?l700800?nEB03o0000100Wo`00
QOl008Go0025o`030;Go0080on`00`3o_@070?n=01D0oeh01P3o;`050?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool00P3ooolX0?l000030?l_003oGP00oeh001`0oeh02P3oS@020?nm0080
on`000<0i?l0003o1`2eo`000P3To`0K0?o/00H0i?l00`2eo`000`25o`00E_l0003o=`02002]o`03
0?l0AP3o0000o`000480o`000P007ol00`3l0?l09ol008Go00030;Go00040>Co003ok000on`00?o/
00<0okd01`3oS@0E0?mN00H0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080
oooo:03o00020?l_0240oeh0203oS@030?nm0080i?l0303ok0080?nm00`0on`0103To`020;Go0003
08Go000Wo`00KP3o00D0o`000P3o0=A00?l000<00?mV00<0QOl00;Go003To`000`3To`030?o/00<0
okd01@3oS@0G0?mN00H0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo
:03o00020?l_0240oeh0203oS@030?nm0080i?l0303ok0080?nm00`0on`0103To`020;Go000308Go
000Wo`00KP3o00D0o`000P3o0=A00?l000<00?mV00<0QOl00;Go003To`000`3To`030?o/00<0okd0
1@3oS@0G0?mN00H0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo:03o
00020?l_02<0oeh0203oS@020?nm00P0on`0403o_@0;0?o/00@0i?l000<0QOl002Oo0000[Ol00P3o
00000`2M0?l03`3o0?l00002002]o`030?l05`3o0000o`0003`0o`0000H00?od003o1`00o`L09ol0
08Go002eo`030>Co0080on`01@3o_@050?n=01H0oeh01`3o;`050?ooo`4000000@3oool000P0oooo
0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool00P3ooolX0?l00080obl0
9P3oGP070?n=01X0okd02P3ok0030>Co00030;Go0000ofH00?lg0080o03o00<0o`16003om000oiD0
0P00oiDn0?l00007001no`00oiD00?l7003o1`1Fo`00QOl00;Go00030>Co0080on`0103o_@060?n=
01H0oeh01`3o;`050?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo:03o00040?l_02H0oeh01P3oS@0K
0?nm00T0on`00`3To`001P2eo`00QOl005Ko001Fo`00o`1f003oa0<00?lg@03o00020?l0Y@0302Oo
0025o`00]Ol00080i?l00`3ok0040?nm00D0ohd05`3oGP070?l_00D0oooo0@0000010?ooo`001`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo0P0000030?ooobT0o`00
0`3o;`0W0?mN00P0ohd06P3o_@090?o/0080i?l000<0]Ol008Go0025o`001@0Wo`000`00ocL00?od
000Oo`0o0?l000030?l0Y@0Wo`00]Ol00080i?l00`3ok0040?nm00D0ohd05@3oGP090?l_00@0oooo
0P0000010?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`8000001@3oool00`000000oooo
0?ooo`020?ooobT0o`000`3o;`0W0?mN00P0ohd06P3o_@090?o/0080i?l000<0]Ol008Go0025o`00
1@0Wo`000`00ocL00?od000Oo`0o0?l000030?l0Y@0Wo`00]Ol00080i?l00`3ok0040?nm00D0ohd0
5@3oGP090?l_00D0oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3ooolY0?l000@0obl0:@3oGP070?n=01T0okd0
2@3ok0000`3To`00]Ol00;Go00020;Go000708Go001Fo`009ol002Oo0000o`L00?mV003Lo`0206h0
och0o`0000@03`3o0;Go003To`00i?l00P3ok0050?nm00D0ohd05@3oGP090?l_00D0oooo0@000001
0?ooo`00203oool2000000X0oooo0`0000040?ooo`030000003oool0oooo0080oooo:@3o00040?l_
02X0oeh02@3oS@0H0?nm00L0on`00P3To`030;Go0080QOl00P1Fo`000`00o`L00?nE0?l0000f0?l0
000309d0o`3o0000o`0000H0o`0000<00?nE02Oo0025o`000P2eo`020?o/00D0okd0103oS@0E0?mN
00X0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo:@3o00040?l_02d0
oeh0203oS@0G0?nm00L0on`00`3To`020;Go000508Go001Fo`00E_l0003oU@0?0?l0=P3o00000`3o
01L007ko0?l000070?l000030?`0o`0Wo`00E_l00080]Ol00P3ok0040?nm00D0ohd05@3oGP0:0?l_
00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobX0o`00103o;`0]0?mN00X0
ohd0503o_@070?o/00<0i?l00P2eo`001025o`00E_l005Ko0000oiDg0?l00003003om000ol@0o`00
00L0o`0000<004ko003oIP00g?l00P2M0?l00`3To`00on`00?nm00030?nm00D0ohd05@3oGP0:0?l_
00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobX0o`00103o;`0]0?mN00X0
ohd0503o_@070?o/00<0i?l00P2eo`001025o`00E_l005Ko0000oiDg0?l00003003om000ol@0o`00
00L0o`0000<004ko003oIP00g?l00P2M0?l00`3To`00on`00?nm00030?nm00D0ohd05@3oGP0:0?l_
00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobX0o`00103o;`0^0?mN00/0
ohd04`3o_@070?o/00<0i?l000H0]Ol008Go001Fo`00E_l0003oU@00[Ol80?l00003001>o`3o0000
o`0002T0o`000P3l0?l00`00ocL00?mV0?l000020<`0o`<0o`000P3o0=@00`3o00000=co003om002
08Go00030>Co003ok000okd000<0okd0103oS@0E0?mN00/0obl01@3oool100000040oooo000K0?oo
o`8000000`3ooolZ0?l000D0obl0;P3oGP0=0?n=0140okd01P3ok0030>Co00060;Go001Fo`009ol0
02Oo0000ocL007ko203o00000`00ol@0o`3D0?l0000V0?l000030?l0e000g?l0o`0000800?o400<0
0?l702Oo0000ocL00P00[Ol00`3<0?l00?o409d0o`020<`0o`03003om00?0?l00?o40080E_l000<0
]Ol00?o/003o_@000`3o_@040?n=01D0oeh02`3o;`040?ooo`8000000@3oool001/0oooo00<00000
0?ooo`3oool00P3ooolZ0?l000D0obl0<@3oGP0>0?n=00h0okd01@3ok0030>Co00060;Go003o0000
o`2U0?l0Y@00oiD03`3o0`3o00000`3o0:D0o`000?l00002003oa003003oIP3o07H00:go008004ko
9@3o00001000[Ol00?lg02Oo000Wo`0205Ko0006003o1`3l0?l0o03o00l0o`00O_l09ol00P00o`L0
0`3o00000=co003o=`02003o1`0305Ko003ok000okd00080okd01@3oS@0D0?mN00`0obl01@3oool1
00000040oooo000K0?ooo`030000003oool0oooo0080oooo;03o00050?l_0300oeh03`3oS@0>0?nm
00<0on`00`3To`001P2eo`009ol0003oU@00oiD0?`3o001>o`@0o`0000@0c03o0?l00000oiD00?nE
0P00o`L00`00ofH0o`000?l0000O0?l000030<`0o`0?0?l0o`0000<0o`0000@00?od003o1`1Fo`00
E_l00P25o`00101Fo`000?l7003o1`00o`L205Ko00809ol000<00?mV003om01Fo`000P2eo`000`3T
o`00okd00?nm00020?nm00<0ohd05P3oGP0<0?l_00D0oooo0@0000010?ooo`006`3oool00`000000
oooo0?ooo`020?ooob`0o`001@3o;`0`0?mN00l0ohd03P3o_@030?o/00<0i?l000H0]Ol002Oo0000
oiD00?nE03l0o`00C_l40?l000040<`0o`3o00000?nE003oU@800?l700<00?mV0?l0003o00007`3o
00000`3<0?l03`3o0?l000030?l00004003om000o`L0E_l005Ko0080QOl000@0E_l0003o1`00o`L0
0?l70P1Fo`0202Oo0003003oIP00oo@0E_l00080]Ol000<0i?l00?nm003o_@000P3o_@030?n=01H0
oeh0303o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3oool/0?l000D0obl0
<@3oGP0A0?n=00`0okd0103ok0000`3To`00]Ol008Go0002003o1`03003om03o000001oo00800?od
00<00?mV003oU@3o07H0100Wo`001P00oiD03`3o00l0o`3o0000o`1f0?l05`8007ko5`3o000200l0
o`030?l0000o0?l00?nE008001oo00@0c03o0?l0003o00000?l70`25o`050;Go0080QOl00P1Fo`00
0`00O_l00?mV0;Go00020>Co00030?o/003o_@00okd000D0ohd0503oGP0>0?l_00D0oooo0@000001
0?ooo`006`3oool00`000000oooo0?ooo`020?ooob`0o`001P3o;`0b0?mN0140ohd02P3o_@040?o/
00030>Co002eo`00E_l0008007ko0`3o0002003om003003o=`0Wo`00E_l00080QOl00P1Fo`000`00
o`L004ko001>o`020?l00006003oIP00g?l00=co0?l00000C_l0?`3o0P007ol20?l0000309d0o`3o
01L0o`0G00H0o`0000L0o`0G09d0o`0?0?l03`3o03l0o`00[Ol0o`0000800?o40P3o00001`00o`L0
0?lg003o=`3o0000o`1f003Lo`1Fo`00102eo`040>Co0080]Ol00P25o`000`00ocL00?l70;Go0002
0>Co00030?o/003o_@00okd000@0ohd05@3oGP0>0?l_00D0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`020?ooobd0o`001@3o;`0c0?mN01<0ohd0203o_@030?o/00030>Co002eo`00o`00
00800?o400<00?l70?l0e000ofH00P3o00000`00ocL0E_l008Go000408Go000505Ko00007ol001oo
03l0o`00oo@00`00o`L3003oIP800?nE00<00?o4001no`3o00002@3o00001@3o04H00:go002]o`00
ol@00?nE00<00?lg00<0o03o003o1`0Wo`000P0Wo`000`00ocL03`3o02Oo00030;Go00P0i?l00P2e
o`000`1Fo`000=co08Go00030?o/00030?nm003oS@00ohd000<0ohd0503oGP0?0?l_00D0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`020?ooobd0o`001P3o;`0c0?mN01@0ohd01`3o_@03
0?o/0004003o1`0Wo`000?lg003o=`80QOl000D0E_l009d0o`2M0?l0o`0008Go00050;Go000308Go
000Wo`009ol000809ol00`1Fo`000`0Wo`000?l7003o1`02003oIP03003om03o0000o`0000X0o`00
0P3o0:D00`00ol@00?lg003o1`0202Oo0080E_l00`25o`00101Fo`000?o408Go002eo`040>Co00<0
on`00`3To`020;Go000308Go001Fo`00]Ol00080on`000<0okd00?n=003oS@00103oS@0C0?mN0100
obl01@3oool100000040oooo000K0?ooo`8000000`3oool]0?l000H0obl0<`3oGP0D0?n=00L0okd0
0`3ok0001000o`L09ol0003o=`00ocL208Go000505Ko002M0?l0W@3o0?l00025o`001@2eo`000`25
o`009ol002Oo000202Oo00<0E_l000<09ol0003o1`00o`L00P00ofH00`00oo@0o`000?l0000:0?l0
0080o`2U00<00?o4003o=`00o`L00P0Wo`0205Ko00<0QOl000@0E_l0003oa025o`00]Ol0103To`03
0?o/00<0i?l00P2eo`000`25o`00E_l00;Go00020?o/00030?nm003oS@00ohd000@0ohd04`3oGP0@
0?l_00@0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooobd0o`001`3o;`0c0?mN
01D0ohd01`3o_@020?o/00@0i?l00P2eo`020?l0000308Go002eo`00]Ol000L0]Ol00`25o`0305Ko
000402Oo0000o`L00?mV003oIPl0o`0000<00=co003o=`0Wo`000P1Fo`0508Go0080]Ol00P3To`09
0?o/00<0i?l000<00?o40>Co003ok0000`3o_@050?n=01@0oeh0403o;`050?ooo`4000000@3oool0
01/0oooo00<000000?ooo`3oool00P3oool]0?l000L0obl0=@3oGP0E0?n=00H0okd00P3ok00A0>Co
0080]Ol00`25o`0205Ko000302Oo003o0000o`0000l0o`0000<0o`3D0?`0o`0Wo`000P1Fo`000`25
o`00]Ol00;Go00020;Go00<0i?l03`3ok0030?nm00H0ohd04`3oGP0A0?l_00D0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`020?ooobh0o`00203o;`0d0?mN01H0ohd01P3o_@0:0?o/00P0
i?l00P2eo`0308Go000505Ko0000o`L00=co003Lo`2M0?l03`3o00001000oiD00?l705Ko001Fo`03
0;Go00@0i?l0303ok0050?nm00L0ohd0503oGP0A0?l_00D0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`020?ooobh0o`00203o;`0e0?mN01P0ohd01@3o_@0;0?o/00H0i?l00`2eo`000`25
o`00E_l0003oIP0C0?l00003003o=`25o`00QOl00080]Ol0103To`070?o/00X0okd0203oS@0B0?mN
01<0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo;P3o00080?l_03D0
oeh0603oS@050?nm00/0on`01P3To`030;Go000308Go001Fo`000?mV01<0o`0000<00?lg08Go0025
o`000P2eo`040>Co00L0on`02P3o_@080?n=0180oeh04`3o;`050?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool00P3oool^0?l000T0obl0=@3oGP0H0?n=00H0okd02P3ok0050>Co00@0]Ol0
00<0E_l006h0o`3o0000403o00000`2M0?l004ko003Lo`0208Go00030;Go003To`00i?l00080i?l0
1P3ok00;0?nm00L0ohd04`3oGP0D0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?oo
o`020?ooobl0o`002@3o;`0f0?mN01L0ohd01P3o_@0:0?o/00D0i?l00`2eo`001@25o`000?mV0<`0
o`3<0?l03`3o00h0o`0000<0?`3o003oIP0Wo`000P25o`000`2eo`00i?l00>Co00020>Co00<0on`0
3@3o_@080?n=01<0oeh0503o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3o
ool_0?l000X0obl0=P3oGP0I0?n=00H0okd02@3ok0030>Co00<0]Ol000D0QOl002Oo0000ofH00?mV
001no`0?0?l000050?l0MP0Wo`00QOl008Go002eo`000P3To`040?o/00`0okd02@3oS@0C0?mN01D0
obl01@3oool100000040oooo000K0?ooo`8000000`3ooola0?l000P0obl0=`3oGP0I0?n=00L0okd0
203ok0020>Co00<0]Ol000@0QOl002Oo003<0?l0c03o3`3o00000`3<0?l0o03o003oIP02003o=`03
0;Go003To`00on`000<0on`0303o_@0:0?n=0180oeh05P3o;`040?ooo`8000000@3oool001/0oooo
00<000000?ooo`3oool00P3ooola0?l000P0obl0=`3oGP0I0?n=00L0okd0203ok0020>Co00<0]Ol0
00@0QOl002Oo003<0?l0c03o3`3o00000`3<0?l0o03o003oIP02003o=`030;Go003To`00on`000<0
on`0303o_@0:0?n=0180oeh05P3o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0
0P3ooola0?l000X0obl0=P3oGP0I0?n=00T0okd01P3ok0001P3To`00]Ol00;Go0025o`00E_l0003o
1`800?o40P3o00000`3<0?l0o`000?l000080?l000800:go00<00?o403l0o`3o00000P0Wo`000`2e
o`00i?l00?o/00020?o/00/0okd02`3oS@0A0?mN01P0obl01@3oool100000040oooo000K0?ooo`03
0000003oool0oooo0080oooo<@3o000;0?l_03L0oeh0603oS@090?nm00D0on`00`3To`000`1Fo`00
0=co003oa002003om003001no`0?0?l00=co00T0o`0000H0?`3o003oU@00oiD00?mV0?`0o`00ocL2
08Go00030;Go003ok000on`000/0okd0303oS@0B0?mN01P0obl01@3oool100000040oooo000K0?oo
o`030000003oool0oooo0080oooo<P3o000;0?l_03L0oeh06@3oS@0:0?nm00<0on`00P3To`000`25
o`000?nE06h0o`02001no`0300l0o`00ofH00?nE0080o`0000<007ko0?l0Y@3o00000`3o00001`00
[Ol00?nE003o1`00o`L09ol0003oU@00g?l00P1Fo`000`3To`00on`00?o/000:0?nm00d0ohd04@3o
GP0I0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooc80o`002`3o;`0h
0?mN01T0ohd02P3o_@040?o/00030>Co002eo`00QOl000800?lg00<007ko003o1`00o`L00P00ocL0
0`00O_l0o`000?l000030?l00007001>o`00ocL09ol002Oo001Fo`00QOl005Ko000208Go0080on`0
2@3o_@0=0?n=0180oeh06P3o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3o
oolb0?l000/0obl0>03oGP0I0?n=00X0okd0103ok0000`3To`00]Ol008Go0002003o=`03001no`00
o`L00?l700800?lg00<007ko0?l0003o00000`3o00001`00C_l00?lg02Oo000Wo`00E_l008Go001F
o`000P25o`020?o/00T0okd03@3oS@0B0?mN01X0obl01@3oool100000040oooo000K0?ooo`030000
003oool0oooo0080oooo<`3o000;0?l_03P0oeh06@3oS@0:0?nm00<0on`00P3To`001P2eo`000?mV
003oIP0Wo`00E_l002Oo00800?l700<00?o409d0o`3o00000P3o00000`3l0?l0o`00002]o`0205Ko
000308Go002eo`00]Ol00080i?l00P3ok0070?nm00l0ohd04@3oGP0K0?l_00D0oooo0@0000010?oo
o`006`3oool2000000<0oooo<`3o000<0?l_03T0oeh0603oS@0:0?nm00<0on`00P3To`020;Go0080
QOl000H0E_l0003oU@00oiD0KP3o002]o`0?0?l30?l000800?o40P25o`020;Go00<0i?l000<0on`0
0?nm003o_@001@3o_@0?0?n=0100oeh07@3o;`040?ooo`8000000@3oool001/0oooo00<000000?oo
o`3oool00P3ooolc0?l000h0obl0>03oGP0I0?n=00X0okd00P3ok0030>Co0080]Ol000H0QOl005Ko
001Fo`000?lg003oIP00ol@20?l00003003oa000ocL09ol00080QOl000<0]Ol00>Co003To`000`3o
k0060?nm00l0ohd0403oGP0N0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`02
0?oooc@0o`003P3o;`0h0?mN01T0ohd02P3o_@000`3ok000i?l00>Co00020>Co0080]Ol00P25o`00
0`1Fo`009ol0001no`020?l00003002]o`0Wo`00E_l00080QOl000<0]Ol00>Co003To`000`3ok005
0?nm00l0ohd04@3oGP0N0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oo
oc@0o`003P3o;`0h0?mN01T0ohd02P3o_@000`3ok000i?l00>Co00020>Co0080]Ol00P25o`000`1F
o`009ol0001no`020?l00003002]o`0Wo`00E_l00080QOl000<0]Ol00>Co003To`000`3ok0050?nm
00l0ohd04@3oGP0N0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooc@0
o`003`3o;`0h0?mN01P0ohd02P3o_@020?o/00@0i?l00`2eo`000`1Fo`009ol0003o=`020?l00003
003oIP0Wo`00E_l00080QOl00P3To`040?o/00@0okd0403oS@0@0?mN01l0obl01@3oool100000040
oooo000K0?ooo`030000003oool0oooo0080oooo=P3o000>0?l_03P0oeh0603oS@0:0?nm00<0on`0
0P3To`030;Go000308Go000Wo`000?l700800=co00<00?od003o=`1Fo`000P25o`000`2eo`00i?l0
0?o/00020?o/00<0okd0403oS@0A0?mN0200obl01@3oool100000040oooo000C0?ooo`D000000`3o
ool00`000000oooo0?ooo`020?ooocH0o`00403o;`0i0?mN01H0ohd02@3o_@030?o/0080i?l00`2e
o`000`25o`009ol0003oIP02003oa003003o=`1^0?l00?lg00800?l700<0]Ol00>Co003ok0000P3o
k0020?nm0100ohd0403oGP0R0?l_00D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo=`3o000@0?l_03T0oeh05@3oS@090?nm00@0on`000<0i?l0
0;Go0025o`000P25o`001`00ocL0o`2U02Oo000Wo`00E_l0003o1`00ol@00P00C_l00`0Wo`00]Ol0
0?o/00020?o/0080okd03`3oS@0?0?mN02@0obl01@3oool100000040oooo000E0?ooo`030000003o
ool0oooo00<0oooo0P0000030?ooocL0o`00403o;`0i0?mN01D0ohd02@3o_@040?o/00030>Co002e
o`00QOl00080QOl000L00?lg0?l0Y@0Wo`009ol005Ko0000o`L00?o4008004ko00<09ol00;Go003o
k0000P3ok0020?nm00l0ohd03`3oGP0T0?l_00@0oooo0P0000010?ooo`005@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo=`3o000A0?l_03T0oeh05P3oS@080?nm00<0on`0
00L0i?l00;Go0025o`00QOl005Ko0000ocL00?l700@0QOl00`1Fo`000`00oo@00:go0?o/00030?nm
00l0ohd03`3oGP0U0?l_00D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo>03o000A0?l_03X0oeh05@3oS@070?nm00@0on`000H0]Ol0003o1`00
o`L00?nE0?`0o`00o`L30;Go0080i?l00P2eo`000`00ofH0]Ol00?o/00020?nm00h0ohd03`3oGP0W
0?l_00D0oooo0@0000010?ooo`00503oool2000000D0oooo00<000000?ooo`3oool00P3ooolh0?l0
01<0obl0>P3oGP0C0?n=00L0okd0103ok0001P2eo`000?l7003o1`3o00000?l708Go0080]Ol01@3T
o`000`2eo`00i?l00?nm00020?nm00d0ohd03`3oGP0X0?l_00D0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`020?ooocT0o`00503o;`0i0?mN01<0ohd01P3o_@040?o/00060;Go0000o`L0
0?l700l0o`00ol@0i?l0203ok0020?nm00h0ohd03`3oGP0Y0?l_00D0oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`020?ooocT0o`00503o;`0i0?mN01<0ohd01P3o_@040?o/00060;Go0000
o`L00?l700l0o`00ol@0i?l0203ok0020?nm00h0ohd03`3oGP0Y0?l_00D0oooo0@0000010?ooo`00
6`3oool00`000000oooo0?ooo`020?ooocT0o`005@3o;`0k0?mN0140ohd01@3o_@030?o/00070>Co
002eo`000?l7003o1`1Fo`00]Ol00>Co00050?o/00@0okd03P3oS@0?0?mN02X0obl01@3oool10000
0040oooo000K0?ooo`030000003oool0oooo0080oooo>`3o000E0?l_03X0oeh04P3oS@030?nm00<0
on`000H0i?l008Go0000[Ol00:go08Go003To`040?o/00D0okd03@3oS@0>0?mN02d0obl01@3oool1
00000040oooo000K0?ooo`030000003oool0oooo0080oooo>`3o000G0?l_03/0oeh0403oS@020?nm
00<0on`000L0i?l005Ko0000o`L00?l705Ko003To`00on`000L0okd0303oS@0?0?mN02h0obl01@3o
ool100000040oooo000K0?ooo`8000000`3oooll0?l001L0obl0?03oGP0?0?n=00<0okd000<0i?l0
08Go002eo`000P3To`000`25o`00on`00?nm00050?nm00d0ohd03@3oGP0a0?l_00@0oooo0P000001
0?ooo`006`3oool00`000000oooo0?ooo`020?oooc`0o`005`3o;`0l0?mN00l0ohd00`3o_@000`3T
o`00QOl00;Go00020>Co000308Go003ok000okd000D0okd03@3oS@0=0?mN0340obl01@3oool10000
0040oooo000K0?ooo`030000003oool0oooo0080oooo?@3o000I0?l_03`0oeh03@3oS@030?nm0003
0>Co003ok000on`00080on`01P3o_@0;0?n=00l0oeh0<P3o;`050?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool00P3ooolm0?l001X0obl0?@3oGP0>0?n=00X0okd02P3oS@0?0?mN03@0obl0
1@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo?P3o000L0?l_03d0oeh0703o
S@0@0?mN03H0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo?P3o000N
0?l_0400oeh04P3oS@0C0?mN03P0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo
0080oooo?P3o000N0?l_0400oeh04P3oS@0C0?mN03P0obl01@3oool100000040oooo000K0?ooo`03
0000003oool0oooo0080oooo?`3o000P0?l_05l0oeh0>`3o;`050?ooo`4000000@3oool001/0oooo
0P0000030?oood40o`00803o;`1K0?mN03d0obl0103oool200000040oooo000K0?ooo`030000003o
ool0oooo0080oooo@@3o000S0?l_05H0oeh0?`3o;`050?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool00P3ooom20?l002@0obl0D03oGP130?l_00D0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`020?oood80o`00903o;`1@0?mN04<0obl01@3oool100000040oooo000K0?ooo`03
0000003oool0oooo0080oooo@`3o000W0?l_04T0oeh0AP3o;`050?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool00P3ooom30?l002/0obl0@P3oGP190?l_00D0oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`020?oood@0o`00;@3o;`0k0?mN04d0obl01@3oool100000040oooo000K
0?ooo`030000003oool0oooo0080ooooAP3o000`0?l_0340oeh0DP3o;`050?ooo`4000000@3oool0
01/0oooo0P0000030?ooodH0o`00<03o;`0a0?mN0580obl0103oool200000040oooo000K0?ooo`03
0000003oool0oooo0080ooooAP3o000f0?l_02D0oeh0F03o;`050?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool00P3ooom70?l003l0obl04@3oGP1R0?l_00D0oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`020?ooodP0o`00/@3o;`050?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool00P3ooom90?l00;00obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo
0080ooooB@3o002`0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?ooodT0
o`00/03o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooom;0?l00:h0obl0
1@3oool100000040oooo000K0?ooo`030000003oool0oooo0080ooooC03o002]0?l_00D0oooo0@00
00010?ooo`006`3oool2000000<0ooooC@3o002/0?l_00@0oooo0P0000010?ooo`006`3oool00`00
0000oooo0?ooo`020?ooodd0o`00[03o;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool00P3ooom>0?l00:/0obl01@3oool100000040oooo000K0?ooo`030000003oool0oooo0080oooo
D03o002Y0?l_00D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`020?oooe40o`00Z03o
;`050?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool00P3ooomB0?l00:L0obl01@3oool1
00000040oooo00070?ooo`D000000P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo
0080ooooDP3o002W0?l_00D0oooo0@0000010?ooo`002@3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3ooomB0?l00:L0obl01@3oool10000
0040oooo00090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool2000000<0
ooooD`3o002V0?l_00@0oooo0P0000010?ooo`002@3oool00`000000oooo0?ooo`080?ooo`800000
1@3oool00`000000oooo0?ooo`3o0?ooo`40oooo0@0000010?ooo`002@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool10?ooo`4000000@3o
ool000P0oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool00P3oool100000040oooo000K0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo0@0000010?ooo`006`3ooooo000000D000000@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.952, -1.79805, 0.0140201, \
0.0120172}}]
}, Open  ]],

Cell[BoxData[
    \(TraditionalForm\`\(mandelbrotC1 = 
        Compile[{x, y, 
            lim}, \[IndentingNewLine]Module[{z, 
              ct = 0}, \[IndentingNewLine]z = 
              x + I\ y; \[IndentingNewLine]While[
              Abs[z] < 3.0 && ct < lim, \[IndentingNewLine]z = 
                z\ z\ z + \((x + 
                      I\ y)\); \[IndentingNewLine]\(++ct\)]; \
\[IndentingNewLine]ct]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(gr22 = 
        DensityPlot[
          mandelbrotC1[x, y, 90], \[IndentingNewLine]{x, \(-1.5\), 
            1.5}, {y, \(-1.5\), 1.5}, PlotPoints \[Rule] 200, Mesh -> False, 
          ColorFunction \[Rule] Hue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.320513 0.5 0.320513 [
[.01923 -0.0125 -12 -9 ]
[.01923 -0.0125 12 0 ]
[.17949 -0.0125 -6 -9 ]
[.17949 -0.0125 6 0 ]
[.33974 -0.0125 -12 -9 ]
[.33974 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66026 -0.0125 -9 -9 ]
[.66026 -0.0125 9 0 ]
[.82051 -0.0125 -3 -9 ]
[.82051 -0.0125 3 0 ]
[.98077 -0.0125 -9 -9 ]
[.98077 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -24 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .17949 -12 -4.5 ]
[-0.0125 .17949 0 4.5 ]
[-0.0125 .33974 -24 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66026 -18 -4.5 ]
[-0.0125 .66026 0 4.5 ]
[-0.0125 .82051 -6 -4.5 ]
[-0.0125 .82051 0 4.5 ]
[-0.0125 .98077 -18 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1.5)] .01923 -0.0125 0 1 Mshowa
.17949 0 m
.17949 .00625 L
s
[(-1)] .17949 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(-0.5)] .33974 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66026 0 m
.66026 .00625 L
s
[(0.5)] .66026 -0.0125 0 1 Mshowa
.82051 0 m
.82051 .00625 L
s
[(1)] .82051 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1.5)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.05128 0 m
.05128 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.46795 0 m
.46795 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.72436 0 m
.72436 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.85256 0 m
.85256 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-1.5)] -0.0125 .01923 1 0 Mshowa
0 .17949 m
.00625 .17949 L
s
[(-1)] -0.0125 .17949 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(-0.5)] -0.0125 .33974 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .66026 m
.00625 .66026 L
s
[(0.5)] -0.0125 .66026 1 0 Mshowa
0 .82051 m
.00625 .82051 L
s
[(1)] -0.0125 .82051 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1.5)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05128 m
.00375 .05128 L
s
0 .08333 m
.00375 .08333 L
s
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .21154 m
.00375 .21154 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .46795 m
.00375 .46795 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .59615 m
.00375 .59615 L
s
0 .62821 m
.00375 .62821 L
s
0 .69231 m
.00375 .69231 L
s
0 .72436 m
.00375 .72436 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .85256 m
.00375 .85256 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.17949 .99375 m
.17949 1 L
s
.33974 .99375 m
.33974 1 L
s
.5 .99375 m
.5 1 L
s
.66026 .99375 m
.66026 1 L
s
.82051 .99375 m
.82051 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.05128 .99625 m
.05128 1 L
s
.08333 .99625 m
.08333 1 L
s
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.21154 .99625 m
.21154 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.46795 .99625 m
.46795 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.59615 .99625 m
.59615 1 L
s
.62821 .99625 m
.62821 1 L
s
.69231 .99625 m
.69231 1 L
s
.72436 .99625 m
.72436 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.85256 .99625 m
.85256 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .17949 m
1 .17949 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .5 m
1 .5 L
s
.99375 .66026 m
1 .66026 L
s
.99375 .82051 m
1 .82051 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05128 m
1 .05128 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .46795 m
1 .46795 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .72436 m
1 .72436 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .85256 m
1 .85256 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
600 string
200 200 8 [200 0 0 200 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF7700
FF5500FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF7700FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF7700FF8800
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF8800FF7700FF4400FF4400
FF4400FF4400FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF3300FF3300FF3300FF3300FF4400FF5500FF4400FF5500FF5500FF6600FF8800
FF5500FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF8800FF6600FF5500FF5500
FF4400FF5500FF4400FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF3300FF3300FF3300FF3300FF9900FF8800FF6600FF6600FF8800FF0000CCFF00
FF6600FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4400FF4400FF4400FF4400FF4400FF5500FF6600CCFF00FF0000FF8800FF6600
FF6600FF8800FF9900FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF3300FF3300FF3300FF3300FF3300FF4400FF5500FFFF00FFBB00BBFF00FF000033FF00
FF7700FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF770033FF00FF0000BBFF00FFBB00
FFFF00FF5500FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF660066FF00FFCC0088FF00
FF7700FF6600FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF5500FF5500FF6600FF770088FF00FFCC0066FF00FF6600
FF5500FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF6600FF7700FFAA00
FFAA00FF9900FFCC00FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF5500FF5500FFCC00FF9900FFAA00FFAA00FF7700FF6600FF5500
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600FF7700
FFDD00FFEE00FF7700FF6600FF5500FF5500FF5500FF4400FF5500FF5500FF5500FF5500
FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF5500
FF4400FF5500FF5500FF5500FF6600FF7700FFEE00FFDD00FF7700FF6600FF5500FF5500
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FF6600
FF770000FF88FF7700FF6600FF5500FF5500FF5500FF5500FF5500FF5500FF6600FF9900
FF6600FF5500FF5500FF5500FF5500FF5500FF5500FF6600FF9900FF6600FF5500FF5500
FF5500FF5500FF5500FF5500FF6600FF770000FF88FF7700FF6600FF5500FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FF6600
FF8800FFAA00FF7700FF6600FF6600FF6600FF5500FF5500FF6600FF6600FF7700CCFF00
FF6600FF5500FF5500FF5500FF5500FF5500FF5500FF6600CCFF00FF7700FF6600FF6600
FF5500FF5500FF6600FF6600FF6600FF7700FFAA00FF8800FF6600FF5500FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FFAA00
FFBB00FFEE00FF8800FF7700FF7700FF7700FF6600FF660000FF33FF7700FFAA00FF9900
FF7700FF6600FF6600FF6600FF6600FF6600FF6600FF7700FF9900FFAA00FF770000FF33
FF6600FF6600FF7700FF7700FF7700FF8800FFEE00FFBB00FFAA00FF5500FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF6600FF7700
FFBB0077FF0033FF00FF9900FF9900FFAA00FF7700FF7700CCFF00DDFF00BBFF00FFDD00
FF8800FF8800FF9900FF6600FF6600FF9900FF8800FF8800FFDD00BBFF00DDFF00CCFF00
FF7700FF7700FFAA00FF9900FF990033FF0077FF00FFBB00FF7700FF6600FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600FF8800
FF9900BBFF00FF0000FFFF0000FF33FFAA00FF990077FF00FFCC00FF0000FF0000DDFF00
FFFF00EEFF00FF9900FF7700FF7700FF9900EEFF00FFFF00DDFF00FF0000FF0000FFCC00
77FF00FF9900FFAA0000FF33FFFF00FF0000BBFF00FF9900FF8800FF6600FF5500FF5500
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF5500FF6600FF6600FF8800
77FF00FF0000FF0000FF0000FF000000FFDDFFBB004400FFAA00FFFF0000FF0000FF0000
FF0000FF00000044FFFFAA00FFAA000044FFFF0000FF0000FF0000FF0000FF0000AA00FF
4400FFFFBB0000FFDDFF0000FF0000FF0000FF000077FF00FF8800FF6600FF6600FF5500
FF5500FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF6600FF7700FF7700FF770033FF00
FFEE00FF0000FF0000FF0000FF00000022FF11FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000055FF0055FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000011FF000022FFFF0000FF0000FF0000FF0000FFEE0033FF00FF7700FF7700FF7700
FF6600FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FFCC00FF8800FFAA00FFDD00FFDD00
FF0000FF0000FF0000FF0000FF000066FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000066FF00FF0000FF0000FF0000FF0000FF0000FFDD00FFDD00FFAA00FF8800
FFCC00FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF6600FFBB00FFDD00EE00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EE00FFFFDD00FFBB00FF6600
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF7700FFBB0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FFBB00FF7700FF5500
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600FF8800FFAA00
EEFF0000FF5555FF0000FF55FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF5555FF0000FF55EEFF00FFAA00FF8800FF6600FF5500
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600FF7700FF8800
FF9900FFCC00DDFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000DDFF00FFCC00FF9900FF8800FF7700FF6600FF5500
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600FF7700FF8800
66FF00FFEE000077FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000077FFFFEE0066FF00FF8800FF7700FF6600FF5500
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF6600FF7700FF7700FF8800
FF9900CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FF9900FF8800FF7700FF7700FF6600
FF5500FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF7700FF8800BBFF0077FF00FF9900
FFAA00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFAA00FF990077FF00BBFF00FF8800
FF7700FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF7700DDFF00FF990044FF00FFCC00
FFFF0066FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000066FF00FFFF00FFCC0044FF00FF9900DDFF00
FF7700FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF6600FF7700FF770022FF0088FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000088FF0022FF00FF7700FF7700
FF6600FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FF6600FF6600FF880000FF11
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF11FF8800FF6600FF6600
FF5500FF5500FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF6600FFAA00FFCC00
00FF77FF000000FF22FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF22FF000000FF77FFCC00FFAA00FF6600FF5500
FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF6600FF7700FF9900
33FF00FFDD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFDD0033FF00FF9900FF7700FF6600FF5500
FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF6600FF7700
FF9900FFCC00DDFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000DDFF00FFCC00FF9900FF7700FF6600FF5500FF5500
FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF6600FF7700
AAFF00DDFF0011FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000011FF00DDFF00AAFF00FF7700FF6600FF5500FF5500
FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF6600FF7700
FF9900FF9900DDFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000DDFF00FF9900FF9900FF7700FF6600FF5500FF5500
FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF6600FF6600
FF7700FF8800FFBB00FFEE00FF00AAFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00AAFFEE00FFBB00FF8800FF7700FF6600FF6600FF5500FF5500
FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF6600FF6600
FF7700FF7700FF8800EEFF000044FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000044FFEEFF00FF8800FF7700FF7700FF6600FF6600FF5500FF5500
FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF6600FF6600FF6600
FF7700FF7700FF8800FF9900FFBB0000FFAAFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFAAFFBB00FF9900FF8800FF7700FF7700FF6600FF6600FF6600FF5500
FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF5500FF6600FF6600FF6600
FF7700FF7700FF8800FF8800FF9900FFBB00FFEE006600FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
6600FFFFEE00FFBB00FF9900FF8800FF8800FF7700FF7700FF6600FF6600FF6600FF5500
FF5500FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF5500FF6600FF6600FF6600FF7700
FF7700FF7700FF8800FF9900FF9900FFAA00FFBB00FFDD00AAFF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000AAFF00
FFDD00FFBB00FFAA00FF9900FF9900FF8800FF7700FF7700FF7700FF6600FF6600FF6600
FF5500FF5500FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF4400FF5500FF5500FF5500FF6600FF6600FF6600FF6600FF6600FF6600FF7700FF8800
FF8800FF8800FF9900FFAA00FFAA00FFBB00FFCC00FFDD00FFFF00DDFF0099FF0033FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000033FF0099FF00DDFF00FFFF00
FFDD00FFCC00FFBB00FFAA00FFAA00FF9900FF8800FF8800FF8800FF7700FF6600FF6600
FF6600FF6600FF6600FF6600FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF5500FF5500FF5500FF6600FFAA00FF9900FF7700FF7700FF7700FF7700FF88006600FF
FFAA00FFAA0099FF0033FF000011FFFF0000FF000022FF0000FF44FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF44
22FF00FF0000FF00000011FF33FF0099FF00FFAA00FFAA006600FFFF8800FF7700FF7700
FF7700FF7700FF9900FFAA00FF6600FF5500FF5500FF5500FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF5500
FF5500FF5500FF6600FF7700DDFF0066FF00FF9900FF8800FF88000077FFFFDD0000CCFF
FFDD00CCFF00FF0000FF000000FF22FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF22FF0000FF0000CCFF00FFDD0000CCFFFFDD000077FFFF8800
FF8800FF990066FF00DDFF00FF7700FF6600FF5500FF5500FF5500FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500
FF6600FF6600FF7700FFEE0033FF00FF0088FFAA00FF9900DDFF0022FF00FF0000FF0000
99FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000099FF00FF0000FF000022FF00DDFF00
FF9900FFAA00FF008833FF00FFEE00FF7700FF6600FF6600FF5500FF5500FF5500FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500
FF6600DDFF00FF5500FF5500FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF6600
FFEE00FFAA00FFAA00FFBB0033FF00FF000000FFBBFFBB00FFCC00EEFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EEFF00FFCC00
FFBB0000FFBBFF000033FF00FFBB00FFAA00FFAA00FFEE00FF6600FF5500FF5500FF5500
FF5500FF4400FF4400FF4400FF5500FF5500DDFF00FF6600FF5500FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FFDD00FF6600
FF9900FF8800FF6600FF5500FF5500FF5500FF5500FF5500FF5500FF5500FF5500FF6600
FF9900FF0000FFFF00FF0000FF0000FF0000FF0000FFEE00FF000000FF11FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF11FF0000
FFEE00FF0000FF0000FF0000FF0000FFFF00FF0000FF9900FF6600FF5500FF5500FF5500
FF5500FF5500FF5500FF5500FF5500FF6600FF8800FF9900FF6600FFDD00FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FFDD0099FF00
FF0000FF7700FF6600FF6600FF5500FF5500FF5500FF5500FF5500FF5500FF6600FF7700
EEFF00FFFF00FF0000FF0000FF0000FF0000FF000066FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
66FF00FF0000FF0000FF0000FF0000FF0000FFFF00EEFF00FF7700FF6600FF5500FF5500
FF5500FF5500FF5500FF5500FF6600FF6600FF7700FF000099FF00FFDD00FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF6600FF8800
FFBB00FF8800FF7700FF7700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7700
FF8800FFAA0077FF00FF0000FF0000FF00000099FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000099FFFF0000FF0000FF000077FF00FFAA00FF8800FF7700FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7700FF7700FF8800FFBB00FF8800FF6600FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF6600FF9900
FFCC00FF9900FF9900BBFF00FF8800FF7700FF7700FF6600FF6600FF6600FF7700FF7700
FF8800FFAA0022FF0000BBFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000BBFF22FF00FFAA00FF8800FF7700FF7700FF6600FF6600
FF6600FF7700FF7700FF8800BBFF00FF9900FF9900FFCC00FF9900FF6600FF5500FF4400
FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF550000FFDDEEFF00
FFEE00AAFF00EEFF0099FF0000FF77FFCC00EEFF00AAFF00FF7700FF7700FF7700FF8800
DDFF0000AAFFFFEE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFEE0000AAFFDDFF00FF8800FF7700FF7700FF7700
AAFF00EEFF00FFCC0000FF7799FF00EEFF00AAFF00FFEE00EEFF0000FFDDFF5500FF4400
FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF6600FF7700FF9900
FFAA0044FF00FF0000FF0000FFEE00FFDD0000FF88FFAA00FF8800FF8800FF880088FF00
1100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00001100FF88FF00FF8800FF8800FF8800
FFAA0000FF88FFDD00FFEE00FF0000FF000044FF00FFAA00FF9900FF7700FF6600FF4400
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF6600FF7700
FF9900EEFF00FF0000FF0000FF0000FF00DDFF0000EE00FFFFAA00FF9900FF9900FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF9900FF9900FFAA00
EE00FFFF0000FF00DDFF0000FF0000FF0000EEFF00FF9900FF7700FF6600FF5500FF4400
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF6600FFCC00
55FF00FF0000FF0000FF0000FF0000FF0000FF00000066FFFFFF00FFAA00FFAA00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFAA00FFAA00FFFF00
0066FFFF0000FF0000FF0000FF0000FF0000FF000055FF00FFCC00FF6600FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF660022FF00
00FFEEFF0000FF0000FF0000FF0000FF0000FF0000FF000077FF00FFCC00AAFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000AAFF00FFCC0077FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFEE22FF00FF6600FF5500FF5500
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF5500FF5500FF6600FF7700FF8800
DDFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000DDFF00FF8800FF7700FF6600FF5500
FF5500FF5500FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FFEE00FF6600FF6600FF6600FF770022FF00FFEE00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000BBFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000BBFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFEE0022FF00FF7700FF6600
FF6600FF6600FFEE00FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF7700FF9900FF7700FF7700FF7700FFCC00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FF7700FF7700
FF7700FF9900FF7700FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF4400FF6600FF880000FF77FFCC00FF9900FF9900FFCC00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FF9900FF9900
FFCC0000FF77FF8800FF6600FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF4400FF5500FF6600FF7700FF9900CCFF00FFDD00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFDD00CCFF00
FF9900FF7700FF6600FF5500FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF5500FF7700FFCC00FFBB00FFFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFBB00
FFCC00FF7700FF5500FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF7700FFDD00FF8800FF9900CCFF0055FF00
FF00DDFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00DD55FF00CCFF00FF9900FF8800
FFDD00FF7700FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF6600FF6600FF8800FF8800FFAA00
FFFF00FF000011FF00FF0000FF0000BBFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000BBFF00FF0000FF000011FF00FF0000FFFF00FFAA00FF8800FF8800FF6600
FF6600FF5500FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600FF660099FF00
55FF00FFDD00FFFF00FFCC00FFCC00EEFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000EEFF00FFCC00FFCC00FFFF00FFDD0055FF0099FF00FF6600FF6600FF5500
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF5500FF6600
FF7700FF8800FF8800FF9900FFCC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FFCC00FF9900FF8800FF8800FF7700FF6600FF5500FF5500FF5500
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FF6600
FF6600FF7700FF8800FF990066FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000066FF00FF9900FF8800FF7700FF6600FF6600FF5500FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FF5500
FF6600FF770022FF00FFBB00BBFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000BBFF00FFBB0022FF00FF7700FF6600FF5500FF5500FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FF5500
FF6600FF770055FF00FF000066FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000066FF00FF000055FF00FF7700FF6600FF5500FF5500FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600
FF6600FF770011FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000011FF00FF7700FF6600FF6600FF5500FF5500FF4400
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF6600FF6600
FF7700FF880000BBFF0066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000066FF00BBFFFF8800FF7700FF6600FF6600FF5500FF4400
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FFEE00FF7700FF7700
FF7700FF8800FFAA00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFAA00FF8800FF7700FF7700FF7700FFEE00FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FFAA00FF9900FF9900
FF9900FF0099FFBB00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFBB00FF0099FF9900FF9900FF9900FFAA00FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF8800FFCC00FF0000
BBFF00FF0000FF0000CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CCFF00FF0000FF0000BBFF00FF0000FFCC00FF8800FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF550000FF77BBFF0000FFEE
FF0000FF0000FF0000FF0077FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0077FF0000FF0000FF000000FFEEBBFF0000FF77FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF6600FF88008800FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008800FFFF8800FF6600FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF6600FF7700FFCC00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FF7700FF6600FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FFAA00FF9900FFCC00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FF9900FFAA00FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FFAA00FFDD00DDFF00
FF000077FF000033FFDDFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000DDFF000033FF77FF00FF0000DDFF00FFDD00FFAA00FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FFCC00FF0000
FF9900FFAA00FFAA000099FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000099FFFFAA00FFAA00FF9900FF0000FFCC00FF5500FF4400
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF5500FF6600
FF6600FF7700FF99007700FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00007700FFFF9900FF7700FF6600FF6600FF5500FF5500FF4400
FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500
FF6600FF7700FF9900FFDD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FFDD00FF9900FF7700FF6600FF5500FF5500FF4400FF4400
FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500
FF6600FFBB00FFBB0000FFEE77FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000077FF0000FFEEFFBB00FFBB00FF6600FF5500FF4400FF4400FF4400
FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500
FF5500FFDD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFDD00FF5500FF5500FF4400FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400
FF5500FF6600FFAA00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFAA00FF6600FF5500FF4400FF4400FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400
FF5500FF6600BBFF00FF000000FF774400FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00004400FF00FF77FF0000BBFF00FF6600FF5500FF4400FF4400FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400
FF4400FF5500FF7700FF8800FF99000066FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000066FFFF9900FF8800FF7700FF5500FF4400FF4400FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400
FF4400FF5500FF5500FF660000FF9944FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000044FF0000FF99FF6600FF5500FF5500FF4400FF4400FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400
FF4400FF4400FF5500FF5500FF7700FFCC00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FFCC00FF7700FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF5500FF5500FF6600FF8800FF990022FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
22FF00FF9900FF8800FF6600FF5500FF5500FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF4400FF5500FF5500FF6600FF7700FFDD00AAFF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000AAFF00
FFDD00FF7700FF6600FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF4400FF5500FF5500FF5500FF6600FF770088FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000088FF00
FF7700FF6600FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF4400FF5500FF5500FF5500FF6600FF6600FF7700FF8800EEFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EEFF00FF8800FF7700
FF6600FF6600FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF4400FF5500FF5500FF5500FF6600FF6600FF7700FF7700FF8800FFAA00
22FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000022FF00FFAA00FF8800FF7700FF7700
FF6600FF6600FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF4400FF5500FF5500FF5500FF6600FF6600FF7700FF7700FF8800FFAA00
22FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000022FF00FFAA00FF8800FF7700FF7700
FF6600FF6600FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF4400FF5500FF5500FF5500FF6600FF6600FF7700FF8800EEFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EEFF00FF8800FF7700
FF6600FF6600FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF4400FF5500FF5500FF5500FF6600FF770088FF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000088FF00
FF7700FF6600FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF4400FF5500FF5500FF6600FF7700FFDD00AAFF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000AAFF00
FFDD00FF7700FF6600FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF5500FF5500FF6600FF8800FF990022FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
22FF00FF9900FF8800FF6600FF5500FF5500FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400
FF4400FF4400FF5500FF5500FF7700FFCC00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FFCC00FF7700FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400
FF4400FF5500FF5500FF660000FF9944FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000044FF0000FF99FF6600FF5500FF5500FF4400FF4400FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400
FF4400FF5500FF7700FF8800FF99000066FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000066FFFF9900FF8800FF7700FF5500FF4400FF4400FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400
FF5500FF6600BBFF00FF000000FF774400FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00004400FF00FF77FF0000BBFF00FF6600FF5500FF4400FF4400FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400
FF5500FF6600FFAA00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFAA00FF6600FF5500FF4400FF4400FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500
FF5500FFDD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFDD00FF5500FF5500FF4400FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500
FF6600FFBB00FFBB0000FFEE77FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000077FF0000FFEEFFBB00FFBB00FF6600FF5500FF4400FF4400FF4400
FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500
FF6600FF7700FF9900FFDD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FFDD00FF9900FF7700FF6600FF5500FF5500FF4400FF4400
FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF5500FF6600
FF6600FF7700FF99007700FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00007700FFFF9900FF7700FF6600FF6600FF5500FF5500FF4400
FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FFCC00FF0000
FF9900FFAA00FFAA000099FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000099FFFFAA00FFAA00FF9900FF0000FFCC00FF5500FF4400
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FFAA00FFDD00DDFF00
FF000077FF000033FFDDFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000DDFF000033FF77FF00FF0000DDFF00FFDD00FFAA00FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FFAA00FF9900FFCC00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FF9900FFAA00FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF6600FF7700FFCC00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FF7700FF6600FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF6600FF88008800FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00008800FFFF8800FF6600FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF550000FF77BBFF0000FFEE
FF0000FF0000FF0000FF0077FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0077FF0000FF0000FF000000FFEEBBFF0000FF77FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF8800FFCC00FF0000
BBFF00FF0000FF0000CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000CCFF00FF0000FF0000BBFF00FF0000FFCC00FF8800FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FFAA00FF9900FF9900
FF9900FF0099FFBB00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFBB00FF0099FF9900FF9900FF9900FFAA00FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FFEE00FF7700FF7700
FF7700FF8800FFAA00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFAA00FF8800FF7700FF7700FF7700FFEE00FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF6600FF6600
FF7700FF880000BBFF0066FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000066FF00BBFFFF8800FF7700FF6600FF6600FF5500FF4400
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600
FF6600FF770011FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000011FF00FF7700FF6600FF6600FF5500FF5500FF4400
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FF5500
FF6600FF770055FF00FF000066FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000066FF00FF000055FF00FF7700FF6600FF5500FF5500FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FF5500
FF6600FF770022FF00FFBB00BBFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000BBFF00FFBB0022FF00FF7700FF6600FF5500FF5500FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FF6600
FF6600FF7700FF8800FF990066FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000066FF00FF9900FF8800FF7700FF6600FF6600FF5500FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF5500FF6600
FF7700FF8800FF8800FF9900FFCC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FFCC00FF9900FF8800FF8800FF7700FF6600FF5500FF5500FF5500
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600FF660099FF00
55FF00FFDD00FFFF00FFCC00FFCC00EEFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000EEFF00FFCC00FFCC00FFFF00FFDD0055FF0099FF00FF6600FF6600FF5500
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF6600FF6600FF8800FF8800FFAA00
FFFF00FF000011FF00FF0000FF0000BBFF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000BBFF00FF0000FF000011FF00FF0000FFFF00FFAA00FF8800FF8800FF6600
FF6600FF5500FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF7700FFDD00FF8800FF9900CCFF0055FF00
FF00DDFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00DD55FF00CCFF00FF9900FF8800
FFDD00FF7700FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF5500FF7700FFCC00FFBB00FFFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFBB00
FFCC00FF7700FF5500FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF4400FF5500FF6600FF7700FF9900CCFF00FFDD00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFDD00CCFF00
FF9900FF7700FF6600FF5500FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF4400FF6600FF880000FF77FFCC00FF9900FF9900FFCC00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FF9900FF9900
FFCC0000FF77FF8800FF6600FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF7700FF9900FF7700FF7700FF7700FFCC00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCC00FF7700FF7700
FF7700FF9900FF7700FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FFEE00FF6600FF6600FF6600FF770022FF00FFEE00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000BBFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000BBFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFEE0022FF00FF7700FF6600
FF6600FF6600FFEE00FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF5500FF5500FF6600FF7700FF8800
DDFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000DDFF00FF8800FF7700FF6600FF5500
FF5500FF5500FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF660022FF00
00FFEEFF0000FF0000FF0000FF0000FF0000FF0000FF000077FF00FFCC00AAFF00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000AAFF00FFCC0077FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF000000FFEE22FF00FF6600FF5500FF5500
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF6600FFCC00
55FF00FF0000FF0000FF0000FF0000FF0000FF00000066FFFFFF00FFAA00FFAA00FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFAA00FFAA00FFFF00
0066FFFF0000FF0000FF0000FF0000FF0000FF000055FF00FFCC00FF6600FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF6600FF7700
FF9900EEFF00FF0000FF0000FF0000FF00DDFF0000EE00FFFFAA00FF9900FF9900FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF9900FF9900FFAA00
EE00FFFF0000FF00DDFF0000FF0000FF0000EEFF00FF9900FF7700FF6600FF5500FF4400
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF6600FF7700FF9900
FFAA0044FF00FF0000FF0000FFEE00FFDD0000FF88FFAA00FF8800FF8800FF880088FF00
1100FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00001100FF88FF00FF8800FF8800FF8800
FFAA0000FF88FFDD00FFEE00FF0000FF000044FF00FFAA00FF9900FF7700FF6600FF4400
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF550000FFDDEEFF00
FFEE00AAFF00EEFF0099FF0000FF77FFCC00EEFF00AAFF00FF7700FF7700FF7700FF8800
DDFF0000AAFFFFEE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFEE0000AAFFDDFF00FF8800FF7700FF7700FF7700
AAFF00EEFF00FFCC0000FF7799FF00EEFF00AAFF00FFEE00EEFF0000FFDDFF5500FF4400
FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF6600FF9900
FFCC00FF9900FF9900BBFF00FF8800FF7700FF7700FF6600FF6600FF6600FF7700FF7700
FF8800FFAA0022FF0000BBFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000BBFF22FF00FFAA00FF8800FF7700FF7700FF6600FF6600
FF6600FF7700FF7700FF8800BBFF00FF9900FF9900FFCC00FF9900FF6600FF5500FF4400
FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF6600FF8800
FFBB00FF8800FF7700FF7700FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7700
FF8800FFAA0077FF00FF0000FF0000FF00000099FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000099FFFF0000FF0000FF000077FF00FFAA00FF8800FF7700FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7700FF7700FF8800FFBB00FF8800FF6600FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FFDD0099FF00
FF0000FF7700FF6600FF6600FF5500FF5500FF5500FF5500FF5500FF5500FF6600FF7700
EEFF00FFFF00FF0000FF0000FF0000FF0000FF000066FF00FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
66FF00FF0000FF0000FF0000FF0000FF0000FFFF00EEFF00FF7700FF6600FF5500FF5500
FF5500FF5500FF5500FF5500FF6600FF6600FF7700FF000099FF00FFDD00FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FFDD00FF6600
FF9900FF8800FF6600FF5500FF5500FF5500FF5500FF5500FF5500FF5500FF5500FF6600
FF9900FF0000FFFF00FF0000FF0000FF0000FF0000FFEE00FF000000FF11FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF11FF0000
FFEE00FF0000FF0000FF0000FF0000FFFF00FF0000FF9900FF6600FF5500FF5500FF5500
FF5500FF5500FF5500FF5500FF5500FF6600FF8800FF9900FF6600FFDD00FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500
FF6600DDFF00FF5500FF5500FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF6600
FFEE00FFAA00FFAA00FFBB0033FF00FF000000FFBBFFBB00FFCC00EEFF00FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EEFF00FFCC00
FFBB0000FFBBFF000033FF00FFBB00FFAA00FFAA00FFEE00FF6600FF5500FF5500FF5500
FF5500FF4400FF4400FF4400FF5500FF5500DDFF00FF6600FF5500FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500
FF6600FF6600FF7700FFEE0033FF00FF0088FFAA00FF9900DDFF0022FF00FF0000FF0000
99FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF000099FF00FF0000FF000022FF00DDFF00
FF9900FFAA00FF008833FF00FFEE00FF7700FF6600FF6600FF5500FF5500FF5500FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF5500
FF5500FF5500FF6600FF7700DDFF0066FF00FF9900FF8800FF88000077FFFFDD0000CCFF
FFDD00CCFF00FF0000FF000000FF22FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000000FF22FF0000FF0000CCFF00FFDD0000CCFFFFDD000077FFFF8800
FF8800FF990066FF00DDFF00FF7700FF6600FF5500FF5500FF5500FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF5500FF5500FF5500FF6600FFAA00FF9900FF7700FF7700FF7700FF7700FF88006600FF
FFAA00FFAA0099FF0033FF000011FFFF0000FF000022FF0000FF44FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF44
22FF00FF0000FF00000011FF33FF0099FF00FFAA00FFAA006600FFFF8800FF7700FF7700
FF7700FF7700FF9900FFAA00FF6600FF5500FF5500FF5500FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF4400FF5500FF5500FF5500FF6600FF6600FF6600FF6600FF6600FF6600FF7700FF8800
FF8800FF8800FF9900FFAA00FFAA00FFBB00FFCC00FFDD00FFFF00DDFF0099FF0033FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000033FF0099FF00DDFF00FFFF00
FFDD00FFCC00FFBB00FFAA00FFAA00FF9900FF8800FF8800FF8800FF7700FF6600FF6600
FF6600FF6600FF6600FF6600FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF5500FF6600FF6600FF6600FF7700
FF7700FF7700FF8800FF9900FF9900FFAA00FFBB00FFDD00AAFF00FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000AAFF00
FFDD00FFBB00FFAA00FF9900FF9900FF8800FF7700FF7700FF7700FF6600FF6600FF6600
FF5500FF5500FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF5500FF6600FF6600FF6600
FF7700FF7700FF8800FF8800FF9900FFBB00FFEE006600FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
6600FFFFEE00FFBB00FF9900FF8800FF8800FF7700FF7700FF6600FF6600FF6600FF5500
FF5500FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF6600FF6600FF6600
FF7700FF7700FF8800FF9900FFBB0000FFAAFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FFAAFFBB00FF9900FF8800FF7700FF7700FF6600FF6600FF6600FF5500
FF5500FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF6600FF6600
FF7700FF7700FF8800EEFF000044FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000044FFEEFF00FF8800FF7700FF7700FF6600FF6600FF5500FF5500
FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF6600FF6600
FF7700FF8800FFBB00FFEE00FF00AAFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00AAFFEE00FFBB00FF8800FF7700FF6600FF6600FF5500FF5500
FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF6600FF7700
FF9900FF9900DDFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000DDFF00FF9900FF9900FF7700FF6600FF5500FF5500
FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF6600FF7700
AAFF00DDFF0011FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000011FF00DDFF00AAFF00FF7700FF6600FF5500FF5500
FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF6600FF7700
FF9900FFCC00DDFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000DDFF00FFCC00FF9900FF7700FF6600FF5500FF5500
FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF6600FF7700FF9900
33FF00FFDD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFDD0033FF00FF9900FF7700FF6600FF5500
FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF6600FFAA00FFCC00
00FF77FF000000FF22FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF22FF000000FF77FFCC00FFAA00FF6600FF5500
FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FF6600FF6600FF880000FF11
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF11FF8800FF6600FF6600
FF5500FF5500FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF6600FF7700FF770022FF0088FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000088FF0022FF00FF7700FF7700
FF6600FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF7700DDFF00FF990044FF00FFCC00
FFFF0066FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF000066FF00FFFF00FFCC0044FF00FF9900DDFF00
FF7700FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF7700FF8800BBFF0077FF00FF9900
FFAA00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFAA00FF990077FF00BBFF00FF8800
FF7700FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF6600FF7700FF7700FF8800
FF9900CCFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000CCFF00FF9900FF8800FF7700FF7700FF6600
FF5500FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600FF7700FF8800
66FF00FFEE000077FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000077FFFFEE0066FF00FF8800FF7700FF6600FF5500
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600FF7700FF8800
FF9900FFCC00DDFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000DDFF00FFCC00FF9900FF8800FF7700FF6600FF5500
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600FF8800FFAA00
EEFF0000FF5555FF0000FF55FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF000000FF5555FF0000FF55EEFF00FFAA00FF8800FF6600FF5500
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF7700FFBB0000FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000FF00FFBB00FF7700FF5500
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF6600FFBB00FFDD00EE00FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000EE00FFFFDD00FFBB00FF6600
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FFCC00FF8800FFAA00FFDD00FFDD00
FF0000FF0000FF0000FF0000FF000066FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000066FF00FF0000FF0000FF0000FF0000FF0000FFDD00FFDD00FFAA00FF8800
FFCC00FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF6600FF7700FF7700FF770033FF00
FFEE00FF0000FF0000FF0000FF00000022FF11FF00FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF000055FF0055FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF000011FF000022FFFF0000FF0000FF0000FF0000FFEE0033FF00FF7700FF7700FF7700
FF6600FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF5500FF6600FF6600FF8800
77FF00FF0000FF0000FF0000FF000000FFDDFFBB004400FFAA00FFFF0000FF0000FF0000
FF0000FF00000044FFFFAA00FFAA000044FFFF0000FF0000FF0000FF0000FF0000AA00FF
4400FFFFBB0000FFDDFF0000FF0000FF0000FF000077FF00FF8800FF6600FF6600FF5500
FF5500FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600FF8800
FF9900BBFF00FF0000FFFF0000FF33FFAA00FF990077FF00FFCC00FF0000FF0000DDFF00
FFFF00EEFF00FF9900FF7700FF7700FF9900EEFF00FFFF00DDFF00FF0000FF0000FFCC00
77FF00FF9900FFAA0000FF33FFFF00FF0000BBFF00FF9900FF8800FF6600FF5500FF5500
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF6600FF7700
FFBB0077FF0033FF00FF9900FF9900FFAA00FF7700FF7700CCFF00DDFF00BBFF00FFDD00
FF8800FF8800FF9900FF6600FF6600FF9900FF8800FF8800FFDD00BBFF00DDFF00CCFF00
FF7700FF7700FFAA00FF9900FF990033FF0077FF00FFBB00FF7700FF6600FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FFAA00
FFBB00FFEE00FF8800FF7700FF7700FF7700FF6600FF660000FF33FF7700FFAA00FF9900
FF7700FF6600FF6600FF6600FF6600FF6600FF6600FF7700FF9900FFAA00FF770000FF33
FF6600FF6600FF7700FF7700FF7700FF8800FFEE00FFBB00FFAA00FF5500FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FF6600
FF8800FFAA00FF7700FF6600FF6600FF6600FF5500FF5500FF6600FF6600FF7700CCFF00
FF6600FF5500FF5500FF5500FF5500FF5500FF5500FF6600CCFF00FF7700FF6600FF6600
FF5500FF5500FF6600FF6600FF6600FF7700FFAA00FF8800FF6600FF5500FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF5500FF6600
FF770000FF88FF7700FF6600FF5500FF5500FF5500FF5500FF5500FF5500FF6600FF9900
FF6600FF5500FF5500FF5500FF5500FF5500FF5500FF6600FF9900FF6600FF5500FF5500
FF5500FF5500FF5500FF5500FF6600FF770000FF88FF7700FF6600FF5500FF5500FF4400
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF5500FF6600FF7700
FFDD00FFEE00FF7700FF6600FF5500FF5500FF5500FF4400FF5500FF5500FF5500FF5500
FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF5500FF5500FF5500
FF4400FF5500FF5500FF5500FF6600FF7700FFEE00FFDD00FF7700FF6600FF5500FF5500
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF6600FF7700FFAA00
FFAA00FF9900FFCC00FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF5500FF5500FFCC00FF9900FFAA00FFAA00FF7700FF6600FF5500
FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF660066FF00FFCC0088FF00
FF7700FF6600FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF5500FF5500FF6600FF770088FF00FFCC0066FF00FF6600
FF5500FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF3300FF3300FF3300FF3300FF3300FF4400FF5500FFFF00FFBB00BBFF00FF000033FF00
FF7700FF5500FF5500FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF4400
FF4400FF4400FF4400FF4400FF4400FF5500FF5500FF770033FF00FF0000BBFF00FFBB00
FFFF00FF5500FF4400FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF3300FF3300FF3300FF3300FF9900FF8800FF6600FF6600FF8800FF0000CCFF00
FF6600FF5500FF4400FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4400FF4400FF4400FF4400FF4400FF5500FF6600CCFF00FF0000FF8800FF6600
FF6600FF8800FF9900FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF3300FF3300FF3300FF3300FF4400FF5500FF4400FF5500FF5500FF6600FF8800
FF5500FF4400FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF5500FF8800FF6600FF5500FF5500
FF4400FF5500FF4400FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF4400FF7700FF8800
FF5500FF4400FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4400FF4400FF4400FF5500FF8800FF7700FF4400FF4400
FF4400FF4400FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF7700
FF5500FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF7700FF4400FF4400FF3300
FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF5500
FF4400FF4400FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4400FF4400FF5500FF4400FF3300FF3300
FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200FF2200
FF2200FF2200FF2200FF2200FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
FF1100FF1100FF1100FF1100FF1100FF1100FF1100FF1100
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`006`3oool500000080oooo0P0000040?ooo`800000803oool5000001l0oooo0P0000040?oo
o`800000103oool2000001h0oooo0P00000Q0?ooo`800000103oool2000000@0oooo0P00000P0?oo
o`D000007P3oool500000080oooo0P0000040?ooo`8000000`3oool001d0oooo00<000000?ooo`3o
ool01`3oool010000000oooo0?ooo`00000Q0?ooo`030000003oool0oooo01h0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000L0?ooo`040000003oool0oooo000001l0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000Q0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000020?ooo`007@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07P3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo01X0oooo00@000000?ooo`3oool000007`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?ooo`005@3oool4000000@0oooo00<0
00000?ooo`3oool0203oool2000001X0oooo100000040?ooo`030000003oool0oooo01P0oooo1000
00020?ooo`040000003oool0oooo000000T0oooo0P00000M0?ooo`040000003oool0oooo000001l0
oooo00@000000?ooo`3oool000002@3oool200000280oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`080?ooo`8000000`3oool001d0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0L0?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`00703oool2000000X0oooo0`00000P0?ooo`8000008@3oool2
000000X0oooo0`00000M0?ooo`8000008@3oool2000000X0oooo0`00000P0?ooo`8000008@3oool2
000000X0oooo0`0000020?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`006`3ooooo0000004000001@3oool001/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000D0oooo000K0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0
oooo00D000000?ooo`3oool0oooo000000050?ooo`001`3oool500000080oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`3l0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3l0?ooo`03
0000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P3oool200000?`0oooo0P0000050?ooo`0000<0oooo0000000000000P0000040?ooo`030000003o
ool0oooo00P0oooo0P0000050?ooo`030000003oool0oooo0080ooooC`3o4@1H0?lR04l0oa40103o
ool00`000000oooo0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3ooom=0?lA05`0ob80C@3o4@040?ooo`030000003oool0
oooo00<0oooo00080?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool00P3ooom;0?lA
0600ob80B`3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
ooooB`3o4@1P0?lR04/0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo
0?ooo`020?ooodX0oa40HP3o8P1:0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3ooom90?lA06@0ob80B@3o4@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080ooooA`3o4@1X0?lR04L0oa40103oool00`000000oooo0?ooo`03
0?ooo`006`3oool2000000<0ooooAP3o4@1Z0?lR04H0oa400`3oool2000000D0oooo000K0?ooo`03
0000003oool0oooo0080ooooAP3o4@1Z0?lR04H0oa40103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?oood@0oa40KP3o8P140?lA00@0oooo00<000000?ooo`3oool0
0`3oool001/0oooo00<000000?ooo`3oool00P3ooom20?lA0280ob803@3o<`0D0?lR00d0oc<08P3o
8P120?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooom1
0?lA01l0ob80=P3o<`0O0?lR0440oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?oood00oa407`3o8P0h0?lc01l0ob80@03o4@040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo@03o4@0O0?lR03P0oc<07`3o8P100?lA00@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolo0?lA01h0ob80
203o<`000`3oA000oeD00?m400020?m40280oc<00`3oA0000`3oE@00od@00?lc00070?lc01h0ob80
?`3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo?@3o
4@0O0?lR00P0oc<00P3oA0000`3oM`00oeD00?mE00020?m40200oc<00P3oA0020?mE00030?mg003o
A000od@000P0oc<07P3o8P0n0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P000003
0?ooocd0oa407P3o8P050?lc00D0od@000@0ogL00?n8003oE@00oeD00`3oA00N0?lc00<0od@00P3o
E@000`3oR000ogL00?m400040?m400D0oc<07@3o8P0n0?lA00<0oooo0P0000050?ooo`006`3oool0
0`000000oooo0?ooo`020?oooc`0oa407P3o8P050?lc00030?m4003oE@00od@000<0oeD000@0ofH0
0?n8003oE@00oeD0103oA00L0?lc00@0od@00P3oE@000`3oR000ofH00?mE00020?mE00030?m4003o
E@00od@000D0oc<07P3o8P0l0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<00000
0?ooo`3oool00P3ooolk0?lA01l0ob801@3o<`000`3oV@00ohP00?mV00020?mV00030?n8003o0000
c?l00080ofH000<0oeD00?m4003oA000103oA00F0?lc00H0od@000H0oeD00?mV003oIP00c?l00?l0
003oR0030?mV00030?n8003oV@00oc<000@0oc<07`3o8P0k0?lA00@0oooo00<000000?ooo`3oool0
0`3oool001/0oooo00<000000?ooo`3oool00P3ooolk0?lA01l0ob801@3o<`000`3oV@00ohP00?mV
00020?mV00030?n8003o0000c?l00080ofH000<0oeD00?m4003oA000103oA00F0?lc00H0od@000H0
oeD00?mV003oIP00c?l00?l0003oR0030?mV00030?n8003oV@00oc<000@0oc<07`3o8P0k0?lA00@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolj0?lA01l0ob80
1P3o<`000`3oA000oeD00?oo00020?nk00030;_o003o0000<ol00080ogL00P3oE@0:0?m400`0oc<0
2P3oA0020?mE0080ogL000<0<ol00?l0002ko`000P3o^`000`3oo`00oeD00?m400060?lc01l0ob80
>P3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo>@3o
4@0P0?lR00H0oc<00P3oA0001P3oE@00ofH00?mV001Vo`00ol`008So0080ogL000<0ofH00?mE003o
E@007P3oA0020?mE00060?mV003oM`00ogL008So003oc000I_l00P3oIP000`3oE@00od@00?m40006
0?lc0200ob80>@3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo
0080oooo=`3o4@0P0?lR00P0oc<00`3oA0020?mE00030?mV003oM`00ojX00080ojX000@0oiT00?o<
003oE@00oeD0703oA0020?mE00030?o<003oV@00ojX00080ojX000@0ogL00?mV003oE@00oeD00`3o
A0080?lc0200ob80=`3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooo=`3o4@0P0?lR00P0oc<00`3oA0030?mE00070?mV003oM`00omd00?oM003okP00ogL0
0?mV00040?mE00030?m4003oE@00oeD000@0oeD0203oA0060?mE00030?m4003oE@00oeD00080oeD0
00<0ofH00?mg003okP000P3og@000`3oM`00ofH00?mE00020?mE00<0od@0203o<`0P0?lR03L0oa40
103oool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0oooo=`3o4@0P0?lR00P0oc<00`3o
A0030?mE00070?mV003oM`00omd00?oM003okP00ogL00?mV00040?mE00030?m4003oE@00oeD000@0
oeD0203oA0060?mE00030?m4003oE@00oeD00080oeD000<0ofH00?mg003okP000P3og@000`3oM`00
ofH00?mE00020?mE00<0od@0203o<`0P0?lR03L0oa400`3oool2000000D0oooo000K0?ooo`030000
003oool0oooo0080oooo=P3o4@0Q0?lR00P0oc<01@3oA0020?mE00060?mV003oM`00ogL0003oR03o
M`00ofH0203oE@000`3oIP00oiT00?mV00080?mE00030?mV003oV@00ofH000P0oeD000<0ofH00?mg
0000ohP00P3oM`000`3oIP00oeD00?mE00050?m400P0oc<08@3o8P0f0?lA00@0oooo00<000000?oo
o`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooole0?lA0240ob802@3o<`050?m40080
oeD000D0ofH00?n8003oR000ojX00?mg00040?mV0080oeD00`3oIP000`3oM`00c?l00?mV00080?mE
00030?mV003<o`00ogL000<0ofH00P3oE@040?mV00050?mg003oZP00ohP00?n8003oIP000P3oE@05
0?m400T0oc<08@3o8P0e0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3ooold0?lA0280ob802@3o<`050?m40080oeD000D0ojX00?nk003o^`00onh00?n80004
0?mg0080ofH000H00?lc0?mg003oM`00ojX00?nI003oM`080?mV00030?mg003oV@00ojX00080ogL0
00<00?lc0?mV003oIP00103oM`001@3oR000onh00?nk003o^`00ojX00080oeD01@3oA0090?lc0280
ob80=03o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo
=03o4@0R0?lR00T0oc<01@3oA0000`3oE@00ofH00?mg00020?nk000407Oo000co`00oiT00?nI0080
ojX00P3oM`001@3<o`00gOl00=go002ko`00omd000<0ohP000@0oiT00?mV003oIP00oiT00`3oR000
1@3og@00^ol00=go003Mo`00c?l00080ogL00P3oZP020?nI000703?o001go`00ok/00?nk003oM`00
ofH00?mE00050?m400T0oc<08P3o8P0d0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo
00<000000?ooo`3oool00P3ooold0?lA0280ob802@3o<`050?m400030?mE003oIP00ogL00080ok/0
00@0Mol003?o003oV@00oiT00P3oZP020?mg00050<co003Mo`00gOl00;_o003og@000`3oR000103o
V@00ofH00?mV003oV@030?n800050?oM002ko`00gOl00=go003<o`000P3oM`020?nZ0080oiT000L0
<ol007Oo003o^`00ok/00?mg003oIP00oeD000D0od@02@3o<`0R0?lR03@0oa40103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooc80oa408`3o8P0:0?lc00<0od@0
0`3oE@00203oIP00ohP00?nI003oV@00^ol00?l0003oo`000?lc0P3oZP000`3oV@00Mol00?o<0003
0?l000050=go003oo`00k_l00>ko003oV@000P3oM`001@3oV@00k_l00>ko003oo`00gOl000<0o`00
00<0ol`007Oo003oV@000P3oZP001000oc<0ool00?l0002ko`020?nI00030?n8003oIP00oeD00080
oeD00`3oA00:0?lc02<0ob80<P3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000
003oool0oooo0080oooo<@3o4@0T0?lR00X0oc<00P3oA0030?mE0080ofH000<0ohP007Oo001go`00
103o0002003og@030?nk00140?l0ZP3o00L0o`0000@004Co0?nZ003oZP0004Co1`3o00000`2Z0?l0
A03o0?nk0002003og@@0o`000P1go`000`3oR000ofH00?mV00030?mE0080od@02P3o<`0T0?lR0340
oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0oooo<@3o4@0T0?lR00X0oc<0
0P3oA0000`3oIP00ogL00?mg00020?mg000303?o003okP00onh000@0o`000P008_l00`0Ao`00o`00
0?l000080?l00080EOl02P3o00000`0Ao`0002;o000Ro`040?l00080onh000<0<ol00?mg003oM`00
0P3oM`000`3oIP00od@00?m4000:0?lc02@0ob80<@3o4@030?ooo`8000001@3oool001/0oooo00<0
00000?ooo`3oool00P3oool`0?lA02@0ob802@3o<`040?m400040?o<003oR000ohP00?nZ0080omd0
1P3o000206Ko01P0o`000P1Vo`060?l00080omd000@0ojX00?n8003oR000ol`0103oA0090?lc02@0
ob80<03o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo
<03o4@0T0?lR00T0oc<0103oA0001P3oE@00ofH00?mV003o^`00omd00>h0obP0o`0000<0kP3o0?oM
003o^`000P3oIP000`3oE@00od@00?m400020?m400T0oc<0903o8P0`0?lA00@0oooo00<000000?oo
o`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool`0?lA02@0ob802@3o<`040?m40006
0?mE003oIP00ofH00?nk003og@00kP3o:03o00000`3^0?l0omd00?nk00020?mV00030?mE003oA000
od@00080od@02@3o<`0T0?lR0300oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?ooobl0oa408`3o8P0;0?lc00@0od@00`3oE@000`3oM`00ok/0003o000X0?l0
0003003o003o^`00ogL000<0oeD0103oA00;0?lc02<0ob80;`3o4@040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo;P3o4@0T0?lR00/0oc<0103oA0030?mE0003
0?mV003oR000ojX00080k_l000<00?mE05Go0000oeD07P3o00000`00oeD0EOl0003oE@020>ko0003
0?nZ003oR000ofH000<0oeD0103oA00;0?lc02@0ob80;P3o4@040?ooo`030000003oool0oooo00<0
oooo000C0?ooo`D000000`3oool00`000000oooo0?ooo`020?ooobh0oa408`3o8P0<0?lc00@0od@0
0`3oE@000`3oIP00ogL00?n800020?nI00030?o<003Mo`00o`0001l0o`0000L0gOl00?o<003oV@00
oiT00?n8003oM`00ofH000<0oeD0103oA00<0?lc02<0ob80;P3o4@040?ooo`030000003oool0oooo
00<0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool/0?lA02D0
ob80303o<`040?m400<0oeD000<0ofH00?mg003oR0000P1Vo`000`3okP0007Oo0?l0000O0?l00007
001go`3okP00I_l006Ko003oR000ogL00?mV00030?mE00@0od@0303o<`0U0?lR02`0oa40103oool0
0`000000oooo0?ooo`030?ooo`005@3oool00`000000oooo0?ooo`030?ooo`8000000`3oool/0?lA
02D0ob80303o<`040?m400<0oeD000<0ofH00?mg003oR0000P1Vo`000`3okP0007Oo0?l0000O0?l0
0007001go`3okP00I_l006Ko003oR000ogL00?mV00030?mE00@0od@0303o<`0U0?lR02`0oa400`3o
ool2000000D0oooo000=0?ooo`@00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo;03o4@0T0?lR00`0oc<01@3oA0000`3oE@00ofH00?mV00020?mg00040?n8003oV@00
oiT00<co0280o`0000@0c?l00?nI003oV@00ohP00P3oM`020?mV00030?mE003oA000od@000<0od@0
303o<`0T0?lR02`0oa40103oool00`000000oooo0?ooo`030?ooo`005@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo:`3o4@0T0?lR00d0oc<0103oA0001`3oE@00ogL00?n8
003oR000^ol007Oo003oV@000P3oZP000`3oo`00o`000?l0000P0?l000060?oo003oZP00ojX00?nI
001go`00^ol00P3oR0000`3oM`00oeD00?m400030?m400d0oc<0903o8P0[0?lA00@0oooo00<00000
0?ooo`3oool00`3oool001@0oooo0P0000050?ooo`030000003oool0oooo0080oooo:`3o4@0T0?lR
00d0oc<0103oA0001`3oE@00ogL00=go003Mo`00oiT004Co003oc0000P3oo`000`1Vo`00o`000?l0
000P0?l0000606Ko003oo`00ool00?o<0014o`00oiT00P3Mo`000`3oM`00oeD00?m400030?m400d0
oc<0903o8P0[0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool0
0P3ooolZ0?lA02<0ob803`3o<`040?m400030?mE003oIP00ogL00080ogL000<08_l008So003o0000
9`3o00000`28o`008_l00?mg00020?mg00030?mV003oE@00od@000<0od@03`3o<`0S0?lR02X0oa40
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooobX0oa408`3o
8P0?0?lc00@0od@000<0oeD00?mV003oM`000P3oM`000`0Ro`00R?l00?l0000W0?l0000308So000R
o`00ogL00080ogL000<0ofH00?mE003oA0000`3oA00?0?lc02<0ob80:P3o4@040?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo:P3o4@0R0?lR00l0oc<01@3oA002
0?mE00<0ofH000<0ohP0003o4@3o00009`3o00000`00oa40ohP00?mV00020?mV0080oeD01@3oA00?
0?lc0280ob80:P3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo
0080oooo:@3o4@0S0?lR00l0oc<01P3oA0030?mE00030?mV003oZP00ol`000800?mg00<0o`00003o
8P3o00007`3o00001`00ob80o`00003oM`00ogL0ol`00?nZ003oIP000`3oE@060?m400l0oc<08`3o
8P0Y0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?ooobT0oa408P3o8P0@
0?lc00H0od@00`3oE@000`3oIP00ogL00?nI000203?o00030?oM003o0000o`000200o`0000H0omd0
03?o000co`00oiT00?mg003oIP030?mE00H0od@0403o<`0R0?lR02T0oa400`3oool2000000D0oooo
000K0?ooo`030000003oool0oooo0080oooo9`3o4@0S0?lR0100oc<01`3oA0040?mE00060?mV003o
M`00oiT00?nI003oc000gOl0803o00001P3Mo`00ol`00?nI003oV@00ogL00?mV00@0oeD01`3oA00@
0?lc02<0ob809`3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo
0080oooo9`3o4@0R0?lR0140oc<01`3oA0040?mE00060?mV003oM`00Z_l00:[o003Mo`004Ol0803o
00001P0Ao`00gOl00:[o002Zo`00ogL00?mV00@0oeD01`3oA00A0?lc0280ob809`3o4@040?ooo`03
0000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo9`3o4@0R0?lR0140oc<0
1`3oA0040?mE00060?mV003oM`00Z_l00:[o003Mo`004Ol0803o00001P0Ao`00gOl00:[o002Zo`00
ogL00?mV00@0oeD01`3oA00A0?lc0280ob809`3o4@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo9P3o4@0Q0?lR0180oc<0203oA0040?mE00030?mV003oM`00
oiT00080oiT000<0gOl00?l0003o00007P3o00001P3Mo`00oiT00?nI003oV@00ogL00?mV00@0oeD0
203oA00B0?lc0240ob809P3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003o
ool0oooo0080oooo9P3o4@0P0?lR0140oc<02@3oA0050?mE0080ofH00P3oM`00103oR000ok/00?o^
003o0:XL0?l000040?l0ZP3okP00ok/00?n80080ogL00P3oIP050?mE00T0od@04@3o<`0P0?lR02H0
oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooobH0oa40
7`3o8P0A0?lc00X0od@01@3oE@020?mV00<0ogL000<0ohP00>ko0000A?l0703o00000`00A?l0k_l0
0?n800030?mg0080ofH01@3oE@0:0?m40140oc<07`3o8P0V0?lA00@0oooo00<000000?ooo`3oool0
0`3oool001/0oooo00<000000?ooo`3oool00P3ooolU0?lA0200ob80403o<`0:0?m400D0oeD00`3o
IP030?mg00030?n8003oV@00ok/000800?nZ603o0002003oZP030?nk003oV@00ohP000<0ogL00`3o
IP050?mE00X0od@0403o<`0P0?lR02D0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool0
0`000000oooo0?ooo`020?ooobD0oa40803o8P0@0?lc00X0od@01@3oE@030?mV00<0ogL000<0ohP0
0?nI003o^`000P00ojXH0?l000800?nZ00<0ok/00?nI003oR0000`3oM`030?mV00D0oeD02P3oA00@
0?lc0200ob809@3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3ooolU0?lA
01l0ob80403o<`090?m400L0oeD00`3oIP030?mg0080ohP000D0oiT00?nk003o^`00onh006H0o`0D
0?l0000506H0o`3okP00ok/00?nk003oV@000P3oR0030?mg00<0ofH01`3oE@090?m40100oc<07`3o
8P0U0?lA00<0oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?ooob@0oa407P3o8P0@
0?lc00X0od@01P3oE@040?mV00@0ogL000<0ohP00?nI003oV@000P3oZP000`3o^`00omd00:[o000B
0?l000030:[o003og@00ok/00080ojX00P3oV@000`3oR000ogL00?mg00020?mg00@0ofH01P3oE@0:
0?m40100oc<07P3o8P0T0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3ooolT0?lA01d0ob803`3o<`0:0?m400<0oeD0203oIP000`3oM`00ohP00?n800020?n8
00030?nI003oZP00ojX00080ok/000<0ol`00?oM003oo`000P3Mo`000`2Io`00<ol00?l000090?l0
000703?o002Io`00gOl00=go003oo`00omd00?o<00020?nk0080ojX000<0oiT00?n8003oR0000P3o
R0000`3oM`00ofH00?mV00060?mV00<0oeD02P3oA00?0?lc01d0ob80903o4@040?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo903o4@0M0?lR00/0oc<03@3oA003
0?mE00040?mV003oZP00ojX00?nI00D0ogL000<0ohP006H0o`3oZP000P3oZP000`2Io`00<ol0000A
o`030?l0000302;o0000od@0o`000140o`0000<00?m402;o003o00000P3o00000`004Ol0<ol009Wo
00030?nZ000306H0o`3oR000ogL000@0ogL000@0oiT00?nZ003oZP00ofH00`3oE@0=0?m400/0oc<0
7@3o8P0T0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3o
oolT0?lA01d0ob802`3o<`0=0?m400<0oeD000@0ofH00?nZ003oZP00oiT01@3oM`000`3oR000IP3o
0?nZ00020?nZ000309Wo000co`00017o00<0o`0000<08_l0003oA03o00004@3o00000`00od@08_l0
0?l000020?l00003000Ao`0co`00VOl000<0ojX000<0IP3o0?n8003oM`00103oM`00103oV@00ojX0
0?nZ003oIP030?mE00d0od@02`3o<`0M0?lR02@0oa40103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?ooob80oa407P3o8P090?lc00h0od@0103oE@001P3oIP00ogL0
0=go003Mo`00I_l00?nI00<0ohP000<007Oo0?oM0000c?l00P3og@00103<o`00o`000?l00000ob8L
0?l00004003o8P3o0000o`000<co0080omd000<00<co0?oM0000Mol00`3oR0001P3oV@00I_l00=go
003Mo`00ogL00?mV00@0oeD03P3oA0090?lc01h0ob808P3o4@040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo8P3o4@0M0?lR00P0oc<03P3oA0040?mE0080ofH0
00L0ogL00?o^000co`00<ol00?l0R03oZP00oiT00080gOl000<08_l00?l0003o00000P2Io`0T0?l0
0080VOl00P3o00001P0Ro`00gOl00=go003oV@00ojX00?l0R080<ol000@0onh00?mg003oIP00ofH0
103oE@0>0?m400P0oc<07@3o8P0R0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3ooolR0?lA01d0ob801`3o<`030?m400030?mE003oIP00gOl000<0oeD00`3o
A0050?mE0080ofH000@0onh00?nZ003oZP00ok/00P0co`000`3o00000?nk0?nk00020?o<00030>ko
003o0000o`0002X0o`0000H0k_l00?o<003oc000ok/0003o^`3o000203?o00040?nk003oZP00ojX0
0?o^0080ofH01@3oE@030?m400<0oeD000<0gOl00?mV003oE@000`3oA0070?lc01d0ob808P3o4@04
0?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3ooolQ0?lA01`0ob80203o<`020?m4
0080omd000@0ofH00?nI003oR000ofH02P3oE@020?mV00030?nI003o0000ool000D0o`0000@0onh0
0?l0003o00000?lA;03o00001000oa40o`000?l0003okP050?l000030?oo003o0000oiT00080ofH0
2P3oE@00103oIP00ohP00?nI003oIP020?oM0080od@01`3o<`0M0?lR0240oa400`3oool2000000D0
oooo000K0?ooo`030000003oool0oooo0080oooo8@3o4@0L0?lR00P0oc<00P3oA0020?oM000309Wo
003o0000ogL000<0ofH01`3oE@001@3oIP00ogL00?mg003^o`00ool000H0o`0000<0I_l00?l0003o
0000<03o00000`1Vo`00o`000?l000040?l000050?oo003^o`00ogL00?mg003oIP001`3oE@030?mV
00030?mg003o0000VOl00080omd00P3oA0070?lc01d0ob808@3o4@040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo8@3o4@0L0?lR00P0oc<00P3oA0020?oM0003
09Wo003o0000ogL000<0ofH01`3oE@001@3oIP00ogL00?mg003^o`00ool000H0o`0000<0I_l00?l0
003o0000<03o00000`1Vo`00o`000?l000040?l000050?oo003^o`00ogL00?mg003oIP001`3oE@03
0?mV00030?mg003o0000VOl00080omd00P3oA0070?lc01d0ob808@3o4@040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo8@3o4@0K0?lR00T0oc<00P3oA0020?mV
00030?n8003o^`00ohP000<0ogL0203oIP020?mg00030?n8003oZP00Mol000@0o`0000<009Wo0?l0
003o0000<P3o00000`00VOl0o`000?l000020?l0000307Oo003oZP00ohP00080ogL0203oIP030?mg
00030?n8003o^`00ohP00080ofH00P3oA0090?lc01/0ob808@3o4@040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo803o4@0L0?lR00P0oc<00P3oA0001@3oE@00
ofH00?mV003oV@00ol`00080oiT00P2ko`000`3oR000ogL00?mg00040?mV00<0ogL000@0ohP00?nZ
000Ro`000;_o?03o00001000^ol08_l00?nZ003oR0030?mg00@0ofH00P3oM`000`3oR000^ol00;_o
00020?nI00050?o<003oV@00ofH00?mV003oE@000P3oA0080?lc01`0ob80803o4@040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo803o4@0K0?lR00T0oc<00P3o
A0001`3oE@000?oM003og@3^o`00onh00:[o003^o`000P2Io`000`00ogL0ol`00>ko00020:[o00<0
ogL00P3oR0000`3Mo`000:[o0?o^000n0?l000030?o^0000Z_l0gOl00080ohP00`3oM`020:[o0003
0>ko003oc0000?mg0080VOl000@0k_l00:[o003okP00k_l00P00omd00`3oE@00od@00?m400090?lc
01/0ob80803o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo803o4@0K0?lR00L0oc<0103oA0001P3oIP00ogL00?mg003oV@00ojX004Co00<0o`0000<0onh0
0?oM0000ohP00P3oZP030?n80080R?l000<04@3o0?l0003o0000@03o00000`0A0?l0R?l008So0003
0?n80080ojX000<00?n80?oM003okP000`3o00000`14o`00ojX00?nI00020?mg00030?mV003oA000
od@00080od@01`3o<`0K0?lR0200oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?ooob00oa406`3o8P070?lc00@0od@000H0ofH00?mg003oM`00oiT00?nZ0014
o`030?l000030?o^003og@000?n80080ojX00`3oR00208So00030140o`3o0000o`000400o`0000<0
4@3o08So0028o`000`3oR0020?nZ0003003oR03og@00onh000<0o`0000<0A?l00?nZ003oV@000P3o
M`000`3oIP00od@00?m400020?m400L0oc<06`3o8P0P0?lA00@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo0P0000030?oooal0oa406`3o8P080?lc00@0od@000H0oeD00?mV003oIP00ogL00?nI
003^o`040?l000050?l0g@3o0000kP3o0>h0o`3oZP000P3oV@180?l00080oiT000D0ojX00>h0o`3^
0?l0o`000?l0g@040?l000030>ko003oV@00ogL00080ofH000<0oeD00?m4003oA0000P3oA0080?lc
01/0ob807`3o4@030?ooo`8000001@3oool001/0oooo00<000000?ooo`3oool00P3ooolO0?lA01/0
ob801`3o<`050?m400050?mE003oIP00ofH00?o<001Eo`001`3o0002001Vo`030?oo003oZP00ojX0
04P0o`000P3oZP000`3oo`0006Ko001Vo`070?l0000505Go003oc000ofH00?mV003oE@001@3oA007
0?lc01/0ob807`3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo
0080oooo7`3o4@0K0?lR00L0oc<0103oA0020?mE0080ofH000<08_l0003okP3o0000203o00000`1g
o`00ol`00:[o00180?l000030:[o003oc000Mol000T0o`0000@00?o^02;o003oIP00ofH00P3oE@04
0?m400L0oc<06`3o8P0O0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3ooolN0?lA01`0ob801P3o<`020?m400@0oeD000D0ofH00?mg003oM`00ohP00=go000:
0?l000030?oo003o0000o`0004P0o`0000<0ool00?l0003o0000203o00001@3Mo`00ohP00?mg003o
M`00ofH000@0oeD00P3oA0060?lc01`0ob807P3o4@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo7P3o4@0K0?lR00L0oc<000<0od@00?o^003oIP000`3oIP00
103oM`008_l002;o003okP0;0?l000030;_o003o0000o`0004P0o`0000<0^ol00?l0003o00002@3o
0000103okP008_l002;o003oM`040?mV00030?o^003oA000oc<000H0oc<06`3o8P0N0?lA00@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolN0?lA01/0ob801`3o
<`000`3oA000onh00?mV00030?mV00040?mg000Ro`008_l00?o^00/0o`0000<0^ol00?l0003o0000
B03o00000`2ko`00o`000?l000090?l000040?o^000Ro`008_l00?mg00@0ofH000<0onh00?m4003o
<`001P3o<`0K0?lR01h0oa40103oool00`000000oooo0?ooo`030?ooo`00203oool2000000@0oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`020?oooah0oa406`3o8P060?lc0080od@0
00<0ogL00?nI003oV@000`3oM`020?o<06@0o`000P3oc0030?mg0080oiT000<0ogL00?m4003oA000
1P3o<`0K0?lR01h0oa40103oool00`000000oooo0?ooo`030?ooo`001`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3ooolN0?lA01/0
ob801P3o<`000`3oA000ofH00?n80002003oM`030?o<003oV@00oiT00080ol`0I03o00020?o<0080
oiT000H0ol`0003oM`00ogL0ohP00?mV003oA0060?lc01/0ob807P3o4@040?ooo`030000003oool0
oooo00<0oooo00070?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool2
000000<0oooo703o4@0M0?lR00H0oc<000<0od@00?mE003oIP000P3oM`000`3oV@00c?l00?oM001X
0?l000030?oM003<o`00oiT00080ogL000<0ofH00?mE003oA0001P3o<`0M0?lR01`0oa400`3oool2
000000D0oooo00000`3oool000000000000200000080oooo00@000000?ooo`3oool000002@3oool2
000000D0oooo00<000000?ooo`3oool00P3ooolL0?lA01d0ob801P3o<`020?m400060?mE003oM`00
ogL00?o<003o^`00ool0J03o00000`3oo`00ok/00?o<00020?mg00030?mE003oA000od@000H0oc<0
7@3o8P0L0?lA00@0oooo00<000000?ooo`3oool00`3oool000L0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo703o4@0M0?lR00H0oc<0
0P3oA0001P3oE@00ogL00?mg003oc000ok/00?oo06P0o`0000<0ool00?nk003oc0000P3oM`000`3o
E@00od@00?m400060?lc01d0ob80703o4@040?ooo`030000003oool0oooo00<0oooo00080?ooo`80
00002P3oool3000000@0oooo00<000000?ooo`3oool00P3ooolL0?lA01d0ob801`3o<`020?m40080
ogL000<0omd00?n8003oV@000P3<o`000`1Eo`00o`3M0?l0001O0?l000070?l0g@1Eo`00c?l00<co
003oV@00ohP00?oM00020?mg0080od@01`3o<`0M0?lR01`0oa40103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?oooa`0oa407@3o8P070?lc0080od@00P3oE@020?mV
00<0ohP000@0ojX00?oo003o00004Ol00`3o00000`2ko`00o`000?l0001B0?l000080;_o003o0000
o`000?l0000Ao`00o`000?oo003oZP030?n80080ofH00P3oE@020?m400L0oc<07@3o8P0L0?lA00@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolL0?lA01d0ob80
1`3o<`040?m40080oeD00`3oIP00102Io`00EOl00?oM003oo`030?o<00030>ko003o0000o`000580
o`0000P0k_l00?o<003oc000ol`00?oo003og@00EOl009Wo00<0ofH00P3oE@040?m400L0oc<07@3o
8P0L0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolK
0?lA01h0ob80203o<`040?m400@0oeD000@0ofH00?mg003oR000ohP00P3oV@000`3oc000o`000?l0
001D0?l000030?o<003oV@00oiT00080ohP000<0ogL00?mV003oE@000`3oE@040?m400P0oc<07P3o
8P0K0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolK
0?lA01h0ob80203o<`040?m400@0oeD000@0ofH00?mg003oR000ohP00P3oV@000`3oc000o`000?l0
001D0?l000030?o<003oV@00oiT00080ohP000<0ogL00?mV003oE@000`3oE@040?m400P0oc<07P3o
8P0K0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?oooa/0oa407P3o8P08
0?lc00D0od@00`3oE@020?mV00050?mg003oR000oiT00?nI001Vo`00EP3o00001@1Vo`00oiT00?nI
003oR000ogL00080ofH00`3oE@050?m400P0oc<07P3o8P0K0?lA00<0oooo0P0000050?ooo`006`3o
ool00`000000oooo0?ooo`020?oooa/0oa407P3o8P080?lc00D0od@0103oE@000`3oIP00ogL002;o
00020?nk00030;_o003o0000o`0005@0o`0000H0^ol00?nk003o^`008_l00?mg003oIP040?mE00D0
od@0203o<`0N0?lR01/0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo
0?ooo`020?oooa/0oa407P3o8P080?lc00D0od@0103oE@000`3oIP00ogL005Go00020?l0000306Ko
003o0000o`0005@0o`0000H0I_l00?l0003o0000EOl00?mg003oIP040?mE00D0od@0203o<`0N0?lR
01/0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooa/0
oa407P3o8P090?lc00@0od@00`3oE@020?mV00030?mg000Ao`00o`0005/0o`0000@04Ol00?mg003o
IP00ofH00`3oE@040?m400T0oc<07P3o8P0K0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0
oooo00<000000?ooo`3oool00P3ooolJ0?lA01l0ob802@3o<`040?m400070?mE003oIP00ofH00?mV
003oM`00ohP0002ko`02001VoeP0o`000P00I_l00`00^ol0ohP00?mg00030?mV00030?mE003oA000
od@00080od@02@3o<`0O0?lR01X0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?oooaX0oa407`3o8P090?lc00@0od@000L0oeD00?mV003oIP00ofH00?mg003o
R0000;_o008006KoF03o0002001Vo`03002ko`3oR000ogL000<0ofH000<0oeD00?m4003oA0000P3o
A0090?lc01l0ob806P3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooo6P3o4@0O0?lR00T0oc<00`3oA0000`3oE@00onh00?mg00030?mg00030?n8003oZP00
o`0005/0o`0000<0ojX00?n8003oM`000`3oM`000`3okP00oeD00?m400020?m400T0oc<07`3o8P0J
0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolJ0?lA
01l0ob802@3o<`030?m400030?mE003oZP00oiT000<0oiT000<0o`2I0?nk003o0000F`3o00000`3o
^`00o`2I0?nI00030?nI00030?nZ003oE@00od@00080od@02@3o<`0O0?lR01X0oa40103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaX0oa407`3o8P090?lc00<0
od@000H0oeD00?n8003oc000ol`00?l0002ko`020?l00080c?l0F03o00020<co0080o`0000H0^ol0
0?l0003oc000ol`00?n8003oE@030?m400T0oc<07`3o8P0J0?lA00@0oooo00<000000?ooo`3oool0
0`3oool001/0oooo0P0000030?oooaX0oa407`3o8P090?lc00<0od@000D0oeD0003oM`2ko`00^ol0
003okP030?l00080o`1gF03o00020?l0M`<0o`0000D00?o^0;_o002ko`000?mg0?mE00030?m400T0
oc<07`3o8P0J0?lA00<0oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?oooaX0oa40
7`3o8P090?lc00<0od@000D0oeD0003oM`2ko`00^ol0003okP030?l00080o`1gF03o00020?l0M`<0
o`0000D00?o^0;_o002ko`000?mg0?mE00030?m400T0oc<07`3o8P0J0?lA00@0oooo00<000000?oo
o`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolJ0?lA01l0ob802@3o<`030?m40005
0?mE003oIP00ohP00?n800280?l0HP3o00001@280?l0ohP00?n8003oIP00oeD000<0od@02@3o<`0O
0?lR01X0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
oaX0oa407`3o8P090?lc00<0od@000D0oeD00?mV003oM`00ogL00?o<001R0?l000050?o<003oM`00
ogL00?mV003oE@000`3oA0090?lc01l0ob806P3o4@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo6@3o4@0P0?lR00T0oc<00`3oA0001@3oE@00ojX00?nI003o
V@00ol`00680o`0000D0ol`00?nI003oV@00ojX00?mE00030?m400T0oc<0803o8P0I0?lA00@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolI0?lA0200ob802@3o
<`030?m400080?mE003oZP00omd00?oM003Mo`00o`0007Oo0000<ol20=go05P0o`000P3Mo`001000
<ol0Mol00?l0003Mo`020?oM00030?nZ003oE@00od@00080od@02@3o<`0P0?lR01T0oa40103oool0
0`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaT0oa40803o8P090?lc
00<0od@000P0oeD00?nZ003og@00omd00=go003o0000Mol0000co`80gOl0F03o00020=go0004000c
o`1go`00o`000=go0080omd000<0ojX00?mE003oA0000P3oA0090?lc0200ob806@3o4@040?ooo`03
0000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo6@3o4@0P0?lR00T0oc<0
103oA0001@3oE@00ol`00?o<003o0000oiT00080ojX00P00VOmH0?l0008009Wo0P3oZP001@3oV@00
o`000?o<003oc000oeD000@0od@02@3o<`0P0?lR01T0oa40103oool00`000000oooo0?ooo`030?oo
o`006`3oool2000000<0oooo6@3o4@0Q0?lR00X0oc<00P3oA0030?mE0080ofH000@0ogL00?nI001g
0?l0M`3oF03o000207L0o`040?nI003oM`00ofH00?mV00<0oeD00P3oA00:0?lc0240ob806@3o4@03
0?ooo`8000001@3oool001/0oooo00<000000?ooo`3oool00P3ooolI0?lA0240ob802P3o<`030?m4
00<0oeD000<0ofH00?mg003oV@000P3og@1H0?l00080omd000<0oiT00?mg003oIP000`3oE@030?m4
00X0oc<08@3o8P0I0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3ooolI0?lA0240ob802P3o<`050?m400040?mE003oIP00ok/00?nk00800?o^00<0Mol00?l0
003o0000E03o00000`1go`000?o^003okP020?nk00030?mV003oE@00od@000@0od@02P3o<`0Q0?lR
01T0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaT0
oa408@3o8P0;0?lc00@0od@00P3oE@000`3og@00o`000?l0001L0?l000030?oM003oE@00oeD000@0
od@02`3o<`0Q0?lR01T0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo
0?ooo`020?oooaT0oa408@3o8P0;0?lc00@0od@00P3oE@000`3og@00o`000?l0001L0?l000030?oM
003oE@00oeD000@0od@02`3o<`0Q0?lR01T0oa40103oool00`000000oooo0?ooo`030?ooo`006`3o
ool00`000000oooo0?ooo`020?oooaT0oa408@3o8P0;0?lc00D0od@000<0oeD00?mV003oZP00G03o
00000`3oZP00ofH00?mE00050?m400/0oc<08@3o8P0I0?lA00@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3ooolI0?lA0240ob802`3o<`050?m400030?mE003oIP00
^ol00080o`0000<00?mg04@0o`3o0000D`3o00001`140?l00?mg0?l0003o0000^ol00?mV003oE@00
1@3oA00;0?lc0240ob806@3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003o
ool0oooo0080oooo6@3o4@0Q0?lR00`0oc<01@3oA0001P3oE@00ogL00?n8003oR000oiT0001Voe@0
o`0000H006Ko0?nI003oR000ohP00?mg003oE@050?m400`0oc<08@3o8P0I0?lA00@0oooo00<00000
0?ooo`3oool00`3oool001/0oooo0P0000030?oooaT0oa408@3o8P0<0?lc00D0od@00P3oE@020?mV
0003003oV@14o`00o`0005<0o`0000@0A?l0003oV@3oIP00ofH00P3oE@050?m400`0oc<08@3o8P0I
0?lA00<0oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?oooaT0oa408@3o8P0<0?lc
00D0od@00P3oE@020?mV0003003oV@14o`00o`0005<0o`0000@0A?l0003oV@3oIP00ofH00P3oE@05
0?m400`0oc<08@3o8P0I0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3ooolI0?lA0240ob80303o<`060?m400<0oeD000<0ogL00?o<003o0000D`3o00000`3o
c000ogL00?mE00020?mE00H0od@0303o<`0Q0?lR01T0oa40103oool00`000000oooo0?ooo`030?oo
o`006`3oool00`000000oooo0?ooo`020?oooaT0oa408@3o8P0=0?lc00D0od@00`3oE@000`3oIP00
ohP00?nI000202;o04h0o`000P0Ro`000`3oV@00ohP00?mV00030?mE00D0od@03@3o<`0Q0?lR01T0
oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaT0oa40
8@3o8P0=0?lc00H0od@00`3oE@001@3oIP00ogL00?oM003og@00Z_l004`0o`0000D0Z_l00?oM003o
g@00ogL00?mV00030?mE00H0od@03@3o<`0Q0?lR01T0oa40103oool00`000000oooo0?ooo`030?oo
o`006`3oool00`000000oooo0?ooo`020?oooaT0oa408@3o8P0=0?lc00H0od@0103oE@00103oIP00
ogL00?mg0028o`1<0?l0000408So003oM`00ogL00?mV00@0oeD01P3oA00=0?lc0240ob806@3o4@04
0?ooo`030000003oool0oooo00<0oooo000D0?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
oaT0oa408@3o8P0=0?lc00H0od@0103oE@00103oIP00ogL00?mg0028o`1<0?l0000408So003oM`00
ogL00?mV00@0oeD01P3oA00=0?lc0240ob806@3o4@040?ooo`030000003oool0oooo00<0oooo000C
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3ooolI0?lA0240ob803@3o
<`060?m400@0oeD00`3oIP000`3oM`00ohP00>ko00180?l000030>ko003oR000ogL000<0ofH0103o
E@060?m400d0oc<08@3o8P0I0?lA00@0oooo00<000000?ooo`3oool00`3oool001<0oooo00@00000
0?ooo`3oool00000103oool2000000<0oooo6@3o4@0Q0?lR00d0oc<01P3oA0040?mE00<0ofH00P3o
M`00103oR000ojX00?nZ000Ro`120?l0000402;o003oZP00ojX00?n80080ogL00`3oIP040?mE00H0
od@03@3o<`0Q0?lR01T0oa400`3oool2000000D0oooo000C0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3ooolI0?lA0240ob803@3o<`060?m400@0oeD00`3oIP020?mg0004
0?n8003oZP00ojX002;o0480o`0000@08_l00?nZ003oZP00ohP00P3oM`030?mV00@0oeD01P3oA00=
0?lc0240ob806@3o4@040?ooo`030000003oool0oooo00<0oooo000C0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3ooolI0?lA0240ob803@3o<`060?m400@0oeD00`3oIP00
0`3oM`00ohP00>ko00180?l000030>ko003oR000ogL000<0ofH0103oE@060?m400d0oc<08@3o8P0I
0?lA00@0oooo00<000000?ooo`3oool00`3oool001@0oooo0P0000050?ooo`030000003oool0oooo
0080oooo6@3o4@0Q0?lR00d0oc<01P3oA0040?mE00040?mV003oM`00ogL008So04`0o`0000@0R?l0
0?mg003oM`00ofH0103oE@060?m400d0oc<08@3o8P0I0?lA00@0oooo00<000000?ooo`3oool00`3o
ool001/0oooo00<000000?ooo`3oool00P3ooolI0?lA0240ob803@3o<`060?m400@0oeD000@0ofH0
0?mg003oM`00R?l0C03o00001028o`00ogL00?mg003oIP040?mE00H0od@03@3o<`0Q0?lR01T0oa40
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaT0oa408@3o
8P0=0?lc00H0od@00`3oE@001@3oIP00ogL00?oM003og@00Z_l004`0o`0000D0Z_l00?oM003og@00
ogL00?mV00030?mE00H0od@03@3o<`0Q0?lR01T0oa40103oool00`000000oooo0?ooo`030?ooo`00
6`3oool00`000000oooo0?ooo`020?oooaT0oa408@3o8P0=0?lc00D0od@00`3oE@000`3oIP00ohP0
0?nI000202;o04h0o`000P0Ro`000`3oV@00ohP00?mV00030?mE00D0od@03@3o<`0Q0?lR01T0oa40
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaT0oa408@3o
8P0<0?lc00H0od@00`3oE@000`3oM`00ol`00?l0001C0?l000030?o<003oM`00oeD00080oeD01P3o
A00<0?lc0240ob806@3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3ooolI
0?lA0240ob80303o<`050?m40080oeD00P3oIP000`00oiT0A?l00?l0001C0?l0000404Co0000oiT0
ofH00?mV0080oeD01@3oA00<0?lc0240ob806@3o4@030?ooo`8000001@3oool001/0oooo00<00000
0?ooo`3oool00P3ooolI0?lA0240ob80303o<`050?m40080oeD00P3oIP000`00oiT0A?l00?l0001C
0?l0000404Co0000oiT0ofH00?mV0080oeD01@3oA00<0?lc0240ob806@3o4@040?ooo`030000003o
ool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo6@3o4@0Q0?lR00`0oc<01@3oA000
1P3oE@00ogL00?n8003oR000oiT0001Voe@0o`0000H006Ko0?nI003oR000ohP00?mg003oE@050?m4
00`0oc<08@3o8P0I0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3ooolI0?lA0240ob802`3o<`050?m400030?mE003oIP00^ol00080o`0000<00?mg04@0o`3o
0000D`3o00001`140?l00?mg0?l0003o0000^ol00?mV003oE@001@3oA00;0?lc0240ob806@3o4@04
0?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo6@3o4@0Q0?lR
00/0oc<01@3oA0000`3oE@00ofH00?nZ001L0?l000030?nZ003oIP00oeD000D0od@02`3o<`0Q0?lR
01T0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaT0
oa408@3o8P0;0?lc00@0od@00P3oE@000`3og@00o`000?l0001L0?l000030?oM003oE@00oeD000@0
od@02`3o<`0Q0?lR01T0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo
0?ooo`020?oooaT0oa408@3o8P0;0?lc00@0od@00P3oE@000`3og@00o`000?l0001L0?l000030?oM
003oE@00oeD000@0od@02`3o<`0Q0?lR01T0oa40103oool00`000000oooo0?ooo`030?ooo`006`3o
ool00`000000oooo0?ooo`020?oooaT0oa408@3o8P0:0?lc00D0od@000@0oeD00?mV003o^`00ok/0
0P00onh00`1go`00o`000?l0001D0?l0000307Oo0000onh00?o^0080ok/000<0ofH00?mE003oA000
103oA00:0?lc0240ob806@3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3o
oolI0?lA0240ob802P3o<`030?m400<0oeD000<0ofH00?mg003oV@000P3og@1H0?l00080omd000<0
oiT00?mg003oIP000`3oE@030?m400X0oc<08@3o8P0I0?lA00<0oooo0P0000050?ooo`006`3oool0
0`000000oooo0?ooo`020?oooaT0oa408@3o8P0:0?lc0080od@00`3oE@020?mV00040?mg003oV@00
M`3o07L0oeP0o`000P1g0?l0103oV@00ogL00?mV003oIP030?mE0080od@02P3o<`0Q0?lR01T0oa40
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaT0oa40803o
8P090?lc00@0od@000D0oeD00?o<003oc000o`000?nI00020?nZ008009WoF03o0002002Io`80ojX0
00D0oiT00?l0003oc000ol`00?mE00040?m400T0oc<0803o8P0I0?lA00@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolI0?lA0200ob802@3o<`030?m400080?mE
003oZP00omd00?oM003Mo`00o`0007Oo0000<ol20=go05P0o`000P3Mo`001000<ol0Mol00?l0003M
o`020?oM00030?nZ003oE@00od@00080od@02@3o<`0P0?lR01T0oa40103oool00`000000oooo0?oo
o`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaT0oa40803o8P090?lc00<0od@000P0oeD0
0?nZ003og@00omd00=go003o0000Mol0000co`80gOl0F03o00020=go0004000co`1go`00o`000=go
0080omd000<0ojX00?mE003oA0000P3oA0090?lc0200ob806@3o4@040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo6@3o4@0P0?lR00T0oc<00`3oA0001@3oE@00
ojX00?nI003oV@00ol`00680o`0000D0ol`00?nI003oV@00ojX00?mE00030?m400T0oc<0803o8P0I
0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolJ0?lA
01l0ob802@3o<`030?m400050?mE003oIP00ogL00?mg003oc000HP3o00001@3oc000ogL00?mg003o
IP00oeD000<0od@02@3o<`0O0?lR01X0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool0
0`000000oooo0?ooo`020?oooaX0oa407`3o8P090?lc00<0od@000D0oeD00?mV003oR000ohP008P0
o`1R0?l0000508P0o`3oR000ohP00?mV003oE@000`3oA0090?lc01l0ob806P3o4@040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo6P3o4@0O0?lR00T0oc<00`3o
A0001@3oE@000?mg0;_o002ko`000?o^00<0o`000P3o07MH0?l00080o`1g0`3o00001@00onh0^ol0
0;_o0000ogL0oeD000<0od@02@3o<`0O0?lR01X0oa40103oool00`000000oooo0?ooo`030?ooo`00
6`3oool2000000<0oooo6P3o4@0O0?lR00T0oc<00`3oA0001@3oE@000?mg0;_o002ko`000?o^00<0
o`000P3o07MH0?l00080o`1g0`3o00001@00onh0^ol00;_o0000ogL0oeD000<0od@02@3o<`0O0?lR
01X0oa400`3oool2000000D0oooo000K0?ooo`030000003oool0oooo0080oooo6P3o4@0O0?lR00T0
oc<00`3oA0001P3oE@00ohP00?o<003oc000o`000;_o0080o`000P3<o`1H0?l00080c?l00P3o0000
1P2ko`00o`000?o<003oc000ohP00?mE00<0od@02@3o<`0O0?lR01X0oa40103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooaX0oa407`3o8P090?lc00<0od@000<0
oeD00?nZ003oV@000`3oV@000`3o09T0ok/00?l0001K0?l000030?nk003o09T0oiT000<0oiT000<0
ojX00?mE003oA0000P3oA0090?lc01l0ob806P3o4@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo6P3o4@0O0?lR00T0oc<00`3oA0000`3oE@00onh00?mg0003
0?mg00030?n8003oZP00o`0005/0o`0000<0ojX00?n8003oM`000`3oM`000`3okP00oeD00?m40002
0?m400T0oc<07`3o8P0J0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?oo
o`3oool00P3ooolJ0?lA01l0ob802@3o<`040?m400070?mE003oIP00ofH00?mV003oM`00ohP0002k
o`02001VoeP0o`000P00I_l00`00^ol0ohP00?mg00030?mV00030?mE003oA000od@00080od@02@3o
<`0O0?lR01X0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`02
0?oooaX0oa407`3o8P090?lc00@0od@000L0oeD00?mV003oIP00ofH00?mg003oR0000;_o008006Ko
F03o0002001Vo`03002ko`3oR000ogL000<0ofH000<0oeD00?m4003oA0000P3oA0090?lc01l0ob80
6P3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo6`3o
4@0N0?lR00T0oc<0103oA0030?mE0080ofH000<0ogL0017o003o0000F`3o0000100Ao`00ogL00?mV
003oIP030?mE00@0od@02@3o<`0N0?lR01/0oa40103oool00`000000oooo0?ooo`030?ooo`006`3o
ool00`000000oooo0?ooo`020?oooa/0oa407P3o8P080?lc00D0od@0103oE@000`3oIP00ogL005Go
00020?l0000306Ko003o0000o`0005@0o`0000H0I_l00?l0003o0000EOl00?mg003oIP040?mE00D0
od@0203o<`0N0?lR01/0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0oooo
6`3o4@0N0?lR00P0oc<01@3oA0040?mE00030?mV003oM`008_l00080ok/000<0^ol00?l0003o0000
E03o00001P2ko`00ok/00?nk000Ro`00ogL00?mV00@0oeD01@3oA0080?lc01h0ob806`3o4@030?oo
o`8000001@3oool001/0oooo00<000000?ooo`3oool00P3ooolK0?lA01h0ob80203o<`050?m400<0
oeD00P3oIP001@3oM`00ohP00?nI003oV@00I_l005H0o`0000D0I_l00?nI003oV@00ohP00?mg0002
0?mV00<0oeD01@3oA0080?lc01h0ob806`3o4@040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo6`3o4@0N0?lR00P0oc<0103oA0040?mE00040?mV003oM`00ohP0
0?n80080oiT000<0ol`00?l0003o0000E03o00000`3oc000oiT00?nI00020?n800030?mg003oIP00
oeD000<0oeD0103oA0080?lc01h0ob806`3o4@040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo6`3o4@0N0?lR00P0oc<0103oA0040?mE00040?mV003oM`00ohP0
0?n80080oiT000<0ol`00?l0003o0000E03o00000`3oc000oiT00?nI00020?n800030?mg003oIP00
oeD000<0oeD0103oA0080?lc01h0ob806`3o4@040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo703o4@0M0?lR00L0oc<0103oA0020?mE00<0ofH000@0VOl005Go
003og@00ool00`3oc0000`3^o`00o`000?l0001B0?l000080>ko003oc000ol`00?o<003oo`00omd0
05Go002Io`030?mV0080oeD0103oA0070?lc01d0ob80703o4@040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo703o4@0M0?lR00L0oc<00P3oA0020?mE0080ofH0
0`3oR000103oZP00ool00?l0000Ao`030?l000030;_o003o0000o`000580o`0000P0^ol00?l0003o
0000o`00017o003o0000ool00?nZ00<0ohP00P3oIP020?mE0080od@01`3o<`0M0?lR01`0oa40103o
ool00`000000oooo0?ooo`030?ooo`00203oool2000000@0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`020?oooa`0oa407@3o8P070?lc0080od@00P3oM`000`3og@00ohP00?nI0002
0<co000305Go003o0=d0o`0005l0o`0000L0o`3M05Go003<o`00c?l00?nI003oR000omd00080ogL0
0P3oA0070?lc01d0ob80703o4@040?ooo`030000003oool0oooo00<0oooo00070?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oooa`0
oa407@3o8P060?lc0080od@000H0oeD00?mg003oM`00ol`00?nk003oo`1X0?l000030?oo003o^`00
ol`00080ogL000<0oeD00?m4003oA0001P3o<`0M0?lR01`0oa40103oool00`000000oooo0?ooo`03
0?ooo`001`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo0P000003
0?oooa`0oa407@3o8P060?lc0080od@000H0oeD00?mg003oM`00ol`00?nk003oo`1X0?l000030?oo
003o^`00ol`00080ogL000<0oeD00?m4003oA0001P3o<`0M0?lR01`0oa400`3oool2000000D0oooo
00070?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`030000003oool0oooo0080oooo
703o4@0M0?lR00H0oc<000<0od@00?mE003oIP000P3oM`000`3oV@00c?l00?oM001X0?l000030?oM
003<o`00oiT00080ogL000<0ofH00?mE003oA0001P3o<`0M0?lR01`0oa40103oool00`000000oooo
0?ooo`030?ooo`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3ooolN0?lA01/0ob801P3o<`000`3oA000ofH00?n80002003oM`030?o<
003oV@00oiT00080ol`0I03o00020?o<0080oiT000H0ol`0003oM`00ogL0ohP00?mV003oA0060?lc
01/0ob807P3o4@040?ooo`030000003oool0oooo00<0oooo00080?ooo`8000002P3oool3000000@0
oooo00<000000?ooo`3oool00P3ooolN0?lA01/0ob801P3o<`020?m400030?mg003oV@00oiT000<0
ogL00P3oc01T0?l00080ol`00`3oM`020?nI00030?mg003oA000od@000H0oc<06`3o8P0N0?lA00@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolN0?lA01/0ob80
1`3o<`000`3oA000onh00?mV00030?mV00040?mg000Ro`008_l00?o^00/0o`0000<0^ol00?l0003o
0000B03o00000`2ko`00o`000?l000090?l000040?o^000Ro`008_l00?mg00@0ofH000<0onh00?m4
003o<`001P3o<`0K0?lR01h0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000
oooo0?ooo`020?oooah0oa406`3o8P070?lc00030?m4003okP00ofH000<0ofH000@0ogL002;o000R
o`00onh02`3o00000`2ko`00o`000?l000180?l000030;_o003o0000o`0000T0o`0000@0onh002;o
000Ro`00ogL0103oIP000`3okP00od@00?lc00060?lc01/0ob807P3o4@040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo7P3o4@0L0?lR00H0oc<00P3oA0040?mE
00050?mV003oM`00ogL00?n8003Mo`002P3o00000`3oo`00o`000?l000180?l000030?oo003o0000
o`0000P0o`0000D0gOl00?n8003oM`00ogL00?mV00040?mE0080od@01P3o<`0L0?lR01h0oa40103o
ool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooal0oa406`3o8P07
0?lc00@0od@00P3oE@020?mV000302;o0000onh0o`0000P0o`0000<0Mol00?o<002Zo`00B03o0000
0`2Zo`00ol`007Oo00090?l00004003okP0Ro`00ofH00?mV0080oeD0103oA0070?lc01/0ob807`3o
4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3ooolO0?lA01/0ob801`3o<`05
0?m400050?mE003oIP00ofH00?o<001Eo`001`3o0002001Vo`030?oo003oZP00ojX004P0o`000P3o
ZP000`3oo`0006Ko001Vo`070?l0000505Go003oc000ofH00?mV003oE@001@3oA0070?lc01/0ob80
7`3o4@030?ooo`8000001@3oool001/0oooo00<000000?ooo`3oool00P3ooolO0?lA01/0ob80203o
<`040?m400060?mE003oIP00ofH00?mg003oV@00k_l0103o00001@3o0=d0o`000>h0o`3^0?l0ojX0
0080oiT0B03o00020?nI00050?nZ003^0?l0kP3o0?l0003o0=d0103o00000`3^o`00oiT00?mg0002
0?mV00030?mE003oA000od@00080od@0203o<`0K0?lR01l0oa40103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?ooob00oa406`3o8P070?lc00@0od@000H0ofH00?mg
003oM`00oiT00?nZ0014o`030?l000030?o^003og@000?n80080ojX00`3oR00208So00030140o`3o
0000o`000400o`0000<04@3o08So0028o`000`3oR0020?nZ0003003oR03og@00onh000<0o`0000<0
A?l00?nZ003oV@000P3oM`000`3oIP00od@00?m400020?m400L0oc<06`3o8P0P0?lA00@0oooo00<0
00000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolP0?lA01/0ob801`3o<`04
0?m400060?mV003oM`00ogL00?nI003oZP00A?l00`3o00000`3okP00omd0003oR0020?nZ00<0ohP0
0P28o`000`0A0?l0o`000?l000100?l000030140o`28o`00R?l000<0ohP00P3oZP000`00ohP0omd0
0?o^00030?l0000304Co003oZP00oiT00080ogL000<0ofH00?m4003oA0000P3oA0070?lc01/0ob80
803o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo803o
4@0K0?lR00T0oc<00P3oA0001`3oE@000?oM003og@3^o`00onh00:[o003^o`000P2Io`000`00ogL0
ol`00>ko00020:[o00<0ogL00P3oR0000`3Mo`000:[o0?o^000n0?l000030?o^0000Z_l0gOl00080
ohP00`3oM`020:[o00030>ko003oc0000?mg0080VOl000@0k_l00:[o003okP00k_l00P00omd00`3o
E@00od@00?m400090?lc01/0ob80803o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`03
0000003oool0oooo0080oooo803o4@0L0?lR00P0oc<00P3oA0001@3oE@00ofH00?mV003oV@00ol`0
0080oiT00P2ko`000`3oR000ogL00?mg00040?mV00<0ogL000@0ohP00?nZ000Ro`000;_o?03o0000
1000^ol08_l00?nZ003oR0030?mg00@0ofH00P3oM`000`3oR000^ol00;_o00020?nI00050?o<003o
V@00ofH00?mV003oE@000P3oA0080?lc01`0ob80803o4@040?ooo`030000003oool0oooo00<0oooo
000K0?ooo`030000003oool0oooo0080oooo8@3o4@0K0?lR00T0oc<00P3oA0020?mV00030?n8003o
^`00ohP000<0ogL0203oIP020?mg00030?n8003oZP00Mol000@0o`0000<009Wo0?l0003o0000<P3o
00000`00VOl0o`000?l000020?l0000307Oo003oZP00ohP00080ogL0203oIP030?mg00030?n8003o
^`00ohP00080ofH00P3oA0090?lc01/0ob808@3o4@040?ooo`030000003oool0oooo00<0oooo000K
0?ooo`030000003oool0oooo0080oooo8@3o4@0L0?lR00P0oc<00P3oA0020?oM000309Wo003o0000
ogL000<0ofH01`3oE@001@3oIP00ogL00?mg003^o`00ool000H0o`0000<0I_l00?l0003o0000<03o
00000`1Vo`00o`000?l000040?l000050?oo003^o`00ogL00?mg003oIP001`3oE@030?mV00030?mg
003o0000VOl00080omd00P3oA0070?lc01d0ob808@3o4@040?ooo`030000003oool0oooo00<0oooo
000K0?ooo`8000000`3ooolQ0?lA01`0ob80203o<`020?m40080omd000<0VOl00?l0003oM`000`3o
IP070?mE00050?mV003oM`00ogL00>ko003oo`001P3o00000`1Vo`00o`000?l0000`0?l0000306Ko
003o0000o`0000@0o`0000D0ool00>ko003oM`00ogL00?mV00070?mE00<0ofH000<0ogL00?l0002I
o`000P3og@020?m400L0oc<07@3o8P0Q0?lA00<0oooo0P0000050?ooo`006`3oool00`000000oooo
0?ooo`020?ooob40oa40703o8P080?lc0080od@00P3og@00103oIP00oiT00?n8003oIP0:0?mE0080
ofH000<0oiT00?l0003oo`001@3o0000103okP00o`000?l00000oa4/0?l00004003o4@3o0000o`00
0?o^00D0o`0000<0ool00?l0003oV@000P3oIP0:0?mE00040?mV003oR000oiT00?mV0080omd00P3o
A0070?lc01d0ob808@3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0
oooo0080oooo8P3o4@0M0?lR00L0oc<00`3oA0000`3oE@00ofH00=go00030?mE00<0od@01@3oE@02
0?mV00040?o^003oZP00ojX00?nk0080<ol000<0o`00003o^`3o^`000P3oc0000`3^o`00o`000?l0
000Z0?l000060>ko003oc000ol`00?nk0000ok/0o`000P0co`00103o^`00ojX00?nZ003okP020?mV
00D0oeD00`3oA0030?mE00030=go003oIP00oeD000<0od@01`3o<`0M0?lR0280oa40103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooob80oa407@3o8P080?lc00h0
od@0103oE@020?mV00070?mg003okP00<ol003?o003o08P0ojX00?nI00020=go000302;o003o0000
o`000080VOl0903o000209Wo0080o`0000H08_l00=go003Mo`00oiT00?nZ003o08P203?o00040?o^
003oM`00ofH00?mV00@0oeD03P3oA0080?lc01d0ob808P3o4@040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo8P3o4@0N0?lR00T0oc<03P3oA0040?mE00060?mV
003oM`00gOl00=go001Vo`00oiT00`3oR0000`00Mol0omd0003<o`020?oM00040<co003o0000o`00
003o8Q`0o`0000@00?lR0?l0003o0000c?l00P3og@000`00c?l0omd0001go`030?n800060?nI001V
o`00gOl00=go003oM`00ofH0103oE@0>0?m400T0oc<07P3o8P0R0?lA00@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolR0?lA01h0ob802@3o<`0>0?m400@0oeD0
00H0ofH00?mg003Mo`00gOl006Ko003oV@030?n80003001go`3og@000<co0080omd000@0c?l00?l0
003o00000?lR703o00001000ob80o`000?l0003<o`020?oM0003003<o`3og@0007Oo00<0ohP000H0
oiT006Ko003Mo`00gOl00?mg003oIP040?mE00h0od@02@3o<`0N0?lR0280oa40103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooob@0oa407@3o8P0;0?lc00d0od@0
0`3oE@00103oIP00ojX00?nZ003oV@050?mg00030?n8001V0?l0ojX00080ojX000<0VOl003?o0000
4Ol00`3o00000`0Ro`000?m40?l0000A0?l00003003oA00Ro`00o`000080o`0000<0017o03?o002I
o`000`3oZP000`1V0?l0ohP00?mg00040?mg00040?nI003oZP00ojX00?mV00<0oeD03@3oA00;0?lc
01d0ob80903o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo903o4@0M0?lR00l0oc<02P3oA0030?mE00P0ofH000<0ogL00?n8003oR0000P3oR0000`3oV@00
ojX00?nZ00020?nk00030?o<003og@00ool00080gOl000<0VOl003?o003o00002@3o00001`0co`00
VOl00=go003Mo`00ool00?oM003oc0000P3o^`020?nZ00030?nI003oR000ohP00080ohP000<0ogL0
0?mV003oIP001P3oIP030?mE00X0od@03`3o<`0M0?lR02@0oa40103oool00`000000oooo0?ooo`03
0?ooo`006`3oool00`000000oooo0?ooo`020?ooob@0oa407P3o8P0@0?lc00X0od@01P3oE@040?mV
00@0ogL000<0ohP00?nI003oV@000P3oZP000`3o^`00omd00:[o000B0?l000030:[o003og@00ok/0
0080ojX00P3oV@000`3oR000ogL00?mg00020?mg00@0ofH01P3oE@0:0?m40100oc<07P3o8P0T0?lA
00@0oooo00<000000?ooo`3oool00`3oool001/0oooo0P0000030?ooobD0oa407`3o8P0@0?lc00T0
od@01`3oE@030?mV00<0ogL00P3oR0001@3oV@00ok/00?nk003okP00IP3o01@0o`0000D0IP3o0?o^
003o^`00ok/00?nI00020?n800<0ogL00`3oIP070?mE00T0od@0403o<`0O0?lR02D0oa400`3oool2
000000D0oooo000K0?ooo`030000003oool0oooo0080oooo9@3o4@0P0?lR0100oc<02P3oA0050?mE
00<0ofH00`3oM`000`3oR000oiT00?nk0002003oZQP0o`000P00ojX00`3o^`00oiT00?n800030?mg
00<0ofH01@3oE@0:0?m40100oc<0803o8P0U0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0
oooo00<000000?ooo`3oool00P3ooolU0?lA0200ob80403o<`0:0?m400D0oeD00`3oIP030?mg0003
0?n8003oV@00ok/000800?nZ603o0002003oZP030?nk003oV@00ohP000<0ogL00`3oIP050?mE00X0
od@0403o<`0P0?lR02D0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo
0?ooo`020?ooobH0oa407`3o8P0A0?lc00X0od@01@3oE@020?mV00<0ogL000<0ohP00>ko0000A?l0
703o00000`00A?l0k_l00?n800030?mg0080ofH01@3oE@0:0?m40140oc<07`3o8P0V0?lA00@0oooo
00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolV0?lA0200ob804@3o
<`090?m400D0oeD00P3oIP020?mg00040?n8003o^`00onh00?l0ZQ`0o`0000@0o`2Z0?o^003o^`00
ohP00P3oM`020?mV00D0oeD02@3oA00A0?lc0200ob809P3o4@040?ooo`030000003oool0oooo00<0
oooo000K0?ooo`030000003oool0oooo0080oooo9P3o4@0Q0?lR0180oc<0203oA0040?mE00030?mV
003oM`00oiT00080oiT000<0gOl00?l0003o00007P3o00001P3Mo`00oiT00?nI003oV@00ogL00?mV
00@0oeD0203oA00B0?lc0240ob809P3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`03
0000003oool0oooo0080oooo9`3o4@0R0?lR0140oc<01`3oA0040?mE00060?mV003oM`00Z_l00:[o
003Mo`004Ol0803o00001P0Ao`00gOl00:[o002Zo`00ogL00?mV00@0oeD01`3oA00A0?lc0280ob80
9`3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo9`3o
4@0R0?lR0140oc<01`3oA0040?mE00060?mV003oM`00Z_l00:[o003Mo`004Ol0803o00001P0Ao`00
gOl00:[o002Zo`00ogL00?mV00@0oeD01`3oA00A0?lc0280ob809`3o4@040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`8000000`3ooolW0?lA02<0ob80403o<`070?m400@0oeD000H0ofH00?mg
003oV@00oiT00?o<003Mo`0P0?l000060=go003oc000oiT00?nI003oM`00ofH0103oE@070?m40100
oc<08`3o8P0W0?lA00<0oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?ooobT0oa40
8P3o8P0@0?lc00H0od@00`3oE@000`3oIP00ogL00?nI000203?o00030?oM003o0000o`000200o`00
00H0omd003?o000co`00oiT00?mg003oIP030?mE00H0od@0403o<`0R0?lR02T0oa40103oool00`00
0000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooobT0oa408`3o8P0?0?lc00H0
od@00`3oE@000`3oIP00ojX00?o<0002003oM`030?l00000ob80o`0001l0o`0000L00?lR0?l00000
ogL00?mg0?o<003oZP00ofH000<0oeD01P3oA00?0?lc02<0ob80:@3o4@040?ooo`030000003oool0
oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo:P3o4@0R0?lR00l0oc<01@3oA0020?mE
00<0ofH000<0ohP0003o4@3o00009`3o00000`00oa40ohP00?mV00020?mV0080oeD01@3oA00?0?lc
0280ob80:P3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080
oooo:P3o4@0S0?lR00l0oc<0103oA0000`3oE@00ofH00?mg00020?mg000302;o0028o`00o`0002L0
o`0000<0R?l002;o003oM`000P3oM`000`3oIP00oeD00?m400030?m400l0oc<08`3o8P0Z0?lA00@0
oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolZ0?lA02<0ob80
3`3o<`040?m400030?mE003oIP00ogL00080ogL000<08_l008So003o00009`3o00000`28o`008_l0
0?mg00020?mg00030?mV003oE@00od@000<0od@03`3o<`0S0?lR02X0oa40103oool00`000000oooo
0?ooo`030?ooo`004`3oool5000000<0oooo00<000000?ooo`3oool00P3oool[0?lA02@0ob803@3o
<`040?m400070?mE003oM`00gOl00=go003oV@00A?l00?o<00020?oo000306Ko003o0000o`000200
o`0000H0I_l00?oo003oo`00ol`004Co003oV@020=go00030?mg003oE@00od@000<0od@03@3o<`0T
0?lR02/0oa40103oool00`000000oooo0?ooo`030?ooo`005@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo:`3o4@0T0?lR00d0oc<0103oA0001`3oE@00ogL00?n8003oR000
^ol007Oo003oV@000P3oZP000`3oo`00o`000?l0000P0?l000060?oo003oZP00ojX00?nI001go`00
^ol00P3oR0000`3oM`00oeD00?m400030?m400d0oc<0903o8P0[0?lA00@0oooo00<000000?ooo`3o
ool00`3oool001D0oooo00<000000?ooo`3oool00`3oool2000000<0oooo;03o4@0T0?lR00`0oc<0
1@3oA0000`3oE@00ofH00?mV00020?mg00040?n8003oV@00oiT00<co0280o`0000@0c?l00?nI003o
V@00ohP00P3oM`020?mV00030?mE003oA000od@000<0od@0303o<`0T0?lR02`0oa400`3oool20000
00D0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool/0?lA02D0
ob80303o<`040?m400<0oeD000<0ofH00?mg003oR0000P1Vo`000`3okP0007Oo0?l0000O0?l00007
001go`3okP00I_l006Ko003oR000ogL00?mV00030?mE00@0od@0303o<`0U0?lR02`0oa40103oool0
0`000000oooo0?ooo`030?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo;03o4@0U0?lR00`0oc<0103oA0030?mE00030?mV003oM`00ohP00080I_l000<0onh0001g
o`3o00007`3o00001`00Mol0onh006Ko001Vo`00ohP00?mg003oIP000`3oE@040?m400`0oc<09@3o
8P0/0?lA00@0oooo00<000000?ooo`3oool00`3oool001@0oooo0P0000050?ooo`030000003oool0
oooo0080oooo;P3o4@0S0?lR00`0oc<0103oA0030?mE00030?mV003oM`00ohP00080oiT000<0ol`0
0=go003o00007`3o00001`3Mo`00ol`00?nI003oV@00ohP00?mg003oIP000`3oE@040?m400`0oc<0
8`3o8P0^0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3o
ool^0?lA02@0ob802`3o<`040?m400<0oeD000<0ofH00?n8003oZP000P3^o`000`00oeD0EOl0003o
E@0N0?l00003003oE@1Eo`000?mE0080k_l000<0ojX00?n8003oIP000`3oE@040?m400/0oc<0903o
8P0^0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3oool_
0?lA02<0ob802`3o<`040?m400<0oeD000<0ogL00?nk0000o`00:03o00000`00o`00ok/00?mg0003
0?mE00@0od@02`3o<`0S0?lR02l0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?oooc00oa40903o8P090?lc00@0od@000H0oeD00?mV003oIP00ok/00?oM003^
0?lX0?l000030>h0o`3og@00ok/00080ofH000<0oeD00?m4003oA0000P3oA0090?lc02@0ob80<03o
4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo<03o4@0T
0?lR00T0oc<0103oA0001P3oE@00ofH00?mV003o^`00omd00>h0obP0o`0000<0kP3o0?oM003o^`00
0P3oIP000`3oE@00od@00?m400020?m400T0oc<0903o8P0`0?lA00@0oooo00<000000?ooo`3oool0
0`3oool001/0oooo0P0000030?oooc00oa40903o8P090?lc00@0od@000@0ol`00?n8003oR000ojX0
0P3og@060?l00080I_l0603o000206Ko00H0o`000P3og@00103oZP00ohP00?n8003oc0040?m400T0
oc<0903o8P0`0?lA00<0oooo0P0000050?ooo`006`3oool00`000000oooo0?ooo`020?oooc40oa40
903o8P0:0?lc0080od@000<0ofH00?mg003oM`000P3oM`000`0co`00onh00?o^00040?l0008002;o
00<04Ol00?l0003o0000203o000205Go00X0o`0000<04Ol0000Ro`008_l0103o00020?o^000303?o
003oM`00ogL00080ogL000<0ofH00?m4003oA0002P3o<`0T0?lR0340oa40103oool00`000000oooo
0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooc40oa40903o8P0:0?lc0080od@00`3o
E@020?mV00030?n8001go`00Mol000@0o`000P00omd00`3o^`00A03o0:X0o`070?l000040014o`3o
ZP00ojX00014o`L0o`0000<0ZP3o04@0o`3o^`000P00omd40?l00080Mol000<0ohP00?mV003oIP00
0`3oE@020?m400X0oc<0903o8P0a0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<0
00000?ooo`3oool00P3ooolb0?lA02<0ob802P3o<`030?m400<0oeD000P0ofH00?n8003oV@00oiT0
0;_o003o0000ool0003o<`80ojX000<0oiT007Oo003oc0000`3o00001@3Mo`00ool00>ko003^o`00
oiT00080ogL000D0oiT00>ko003^o`00ool00=go00030?l000030?o<001go`00oiT00080ojX000@0
0?lc0?oo003o0000^ol00P3oV@000`3oR000ofH00?mE00020?mE00<0od@02P3o<`0S0?lR0380oa40
103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oooc@0oa408P3o
8P090?lc00D0od@000<0oeD00?mV003oM`000P3o^`00101go`00<ol00?nI003oV@020?nZ0080ogL0
00D0c?l00=go003Mo`00^ol00?oM00030?n800040?nI003oIP00ofH00?nI00<0ohP000D0omd00;_o
003Mo`00gOl00<co00020?mg0080ojX00P3oV@001`0co`00Mol00?nk003o^`00ogL00?mV003oE@00
1@3oA0090?lc0280ob80=03o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003o
ool0oooo0080oooo=03o4@0R0?lR00T0oc<01@3oA0000`3oE@00ofH00?mg00020?nk000407Oo000c
o`00oiT00?nI0080ojX00P3oM`001@3<o`00gOl00=go002ko`00omd000<0ohP000@0oiT00?mV003o
IP00oiT00`3oR0001@3og@00^ol00=go003Mo`00c?l00080ogL00P3oZP020?nI000703?o001go`00
ok/00?nk003oM`00ofH00?mE00050?m400T0oc<08P3o8P0d0?lA00@0oooo00<000000?ooo`3oool0
0`3oool001/0oooo00<000000?ooo`3oool00P3ooold0?lA0280ob802@3o<`050?m40080oeD000D0
ojX00?nk003o^`00onh00?n800040?mg0080ofH000H00?lc0?mg003oM`00ojX00?nI003oM`080?mV
00030?mg003oV@00ojX00080ogL000<00?lc0?mV003oIP00103oM`001@3oR000onh00?nk003o^`00
ojX00080oeD01@3oA0090?lc0280ob80=03o4@040?ooo`030000003oool0oooo00<0oooo000K0?oo
o`030000003oool0oooo0080oooo=@3o4@0Q0?lR00T0oc<01@3oA0020?mE00050?mV003oR000ohP0
0?nZ003oM`00103oIP020?mE00<0ofH000<0ogL00<co003oIP00203oE@000`3oIP00c?l00?mg0003
0?mV0080oeD0103oIP001@3oM`00ojX00?n8003oR000ofH00080oeD01@3oA0090?lc0240ob80=@3o
4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`8000000`3ooolf0?lA0240ob80203o<`05
0?m40080oeD000H0ofH00?mg003oM`000?n80?mg003oIP080?mE00030?mV003oV@00ofH000P0oeD0
00<0ofH00?nI003oIP00203oE@000`3oIP00ogL0003oR0020?mg00030?mV003oE@00oeD000D0od@0
203o<`0Q0?lR03H0oa400`3oool2000000D0oooo000K0?ooo`030000003oool0oooo0080oooo=`3o
4@0P0?lR00P0oc<00`3oA0030?mE00070?mV003oM`00omd00?oM003okP00ogL00?mV00040?mE0003
0?m4003oE@00oeD000@0oeD0203oA0060?mE00030?m4003oE@00oeD00080oeD000<0ofH00?mg003o
kP000P3og@000`3oM`00ofH00?mE00020?mE00<0od@0203o<`0P0?lR03L0oa40103oool00`000000
oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?ooocL0oa40803o8P080?lc00<0od@0
0`3oE@001`3oIP00ogL00?oM003og@00onh00?mg003oIP00103oE@000`3oA000oeD00?mE00040?mE
00P0od@01P3oE@000`3oA000oeD00?mE00020?mE00030?mV003oM`00onh00080omd000<0ogL00?mV
003oE@000P3oE@030?m400P0oc<0803o8P0g0?lA00@0oooo00<000000?ooo`3oool00`3oool001/0
oooo00<000000?ooo`3oool00P3ooolg0?lA0200ob80203o<`030?m40080oeD000<0ofH00?mg003o
ZP000P3oZP00103oV@00ol`00?mE003oE@0L0?m40080oeD000<0ol`00?nI003oZP000P3oZP00103o
M`00ofH00?mE003oE@030?m400P0oc<0803o8P0g0?lA00@0oooo00<000000?ooo`3oool00`3oool0
01/0oooo00<000000?ooo`3oool00P3oooli0?lA0200ob801P3o<`020?m400060?mE003oIP00ofH0
06Ko003oc000R?l00P3oM`000`3oIP00oeD00?mE000N0?m40080oeD000H0ofH00?mg003oM`00R?l0
0?o<001Vo`020?mV00030?mE003oA000od@000H0oc<0803o8P0i0?lA00@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolj0?lA01l0ob801P3o<`000`3oA000oeD0
0?oo00020?nk00030;_o003o0000<ol00080ogL00P3oE@0:0?m400`0oc<02P3oA0020?mE0080ogL0
00<0<ol00?l0002ko`000P3o^`000`3oo`00oeD00?m400060?lc01l0ob80>P3o4@040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo>`3o4@0O0?lR00D0oc<000<0
oiT00?n8003oIP000P3oIP000`3oR000o`000<co00020?mV00030?mE003oA000od@000@0od@05P3o
<`060?m400060?mE003oIP00ofH00<co003o0000ohP00`3oIP000`3oR000oiT00?lc00040?lc01l0
ob80>`3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo
>`3o4@0O0?lR00D0oc<000<0oiT00?n8003oIP000P3oIP000`3oR000o`000<co00020?mV00030?mE
003oA000od@000@0od@05P3o<`060?m400060?mE003oIP00ofH00<co003o0000ohP00`3oIP000`3o
R000oiT00?lc00040?lc01l0ob80>`3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`03
0000003oool0oooo0080oooo?03o4@0N0?lR00D0oc<000<0od@00?mE003oA0000`3oE@00103oIP00
ohP00?mE003oE@040?m401`0oc<0103oA0020?mE00030?n8003oIP00oeD00080oeD000<0od@00?mE
003oA0001@3o<`0N0?lR03`0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0
oooo?@3o4@0N0?lR00D0oc<01@3oA000103oM`00ohP00?mE003oE@030?m401h0oc<00`3oA0020?mE
00030?n8003oM`00od@000@0od@01@3o<`0M0?lR03h0oa400`3oool2000000D0oooo000K0?ooo`03
0000003oool0oooo0080oooo?@3o4@0O0?lR00P0oc<00P3oA0000`3oM`00oeD00?mE00020?m40200
oc<00P3oA0020?mE00030?mg003oA000od@000P0oc<07P3o8P0n0?lA00@0oooo00<000000?ooo`3o
ool00`3oool001/0oooo00<000000?ooo`3oool00P3ooolo0?lA01h0ob80203o<`000`3oA000oeD0
0?m400020?m40280oc<00`3oA0000`3oE@00od@00?lc00070?lc01h0ob80?`3o4@040?ooo`030000
003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo@03o4@0O0?lR03P0oc<07`3o
8P100?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3oool00P3ooom0
0?lA01l0ob80>03o<`0O0?lR0400oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`00
0000oooo0?ooo`020?oood40oa407`3o8P0f0?lc01l0ob80@@3o4@040?ooo`030000003oool0oooo
00<0oooo000K0?ooo`030000003oool0oooo0080oooo@P3o4@0R0?lR00d0oc<0503o8P0=0?lc0280
ob80@P3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000003oool0oooo0080oooo
A03o4@1^0?lR04@0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool2000000<0ooooAP3o
4@1Z0?lR04H0oa400`3oool2000000D0oooo000K0?ooo`030000003oool0oooo0080ooooAP3o4@1Z
0?lR04H0oa40103oool00`000000oooo0?ooo`030?ooo`006`3oool00`000000oooo0?ooo`020?oo
odL0oa40J03o8P170?lA00@0oooo00<000000?ooo`3oool00`3oool001/0oooo00<000000?ooo`3o
ool00P3ooom90?lA06@0ob80B@3o4@040?ooo`030000003oool0oooo00<0oooo000K0?ooo`030000
003oool0oooo0080ooooBP3o4@1R0?lR04X0oa40103oool00`000000oooo0?ooo`030?ooo`006`3o
ool00`000000oooo0?ooo`020?oood/0oa40H03o8P1;0?lA00@0oooo00<000000?ooo`3oool00`3o
ool000L0oooo1@0000020?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool00P3ooom;
0?lA0600ob80B`3o4@040?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo
00L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooodd0oa40G03o8P1=
0?lA00@0oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`8000000`3ooom?0?lA05P0ob80C`3o4@030?ooo`8000001@3oool000T0
oooo00<000000?ooo`3oool0203oool2000000D0oooo00<000000?ooo`3oool0o03oool00`000000
oooo0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0o03oool00`000000oooo0?ooo`030?ooo`00203oool2000000X0oooo0`00
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo02H0oooo00D000000?ooo`3oool0oooo000000050?ooo`006`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000001@3oool001/0ooooo`00
0001000000D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.89184, -1.82524, 0.0122009, \
0.0122009}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{985, 635},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 128, 5, 95, "Title"],

Cell[CellGroupData[{
Cell[1929, 62, 55, 0, 73, "Section"],
Cell[1987, 64, 415, 9, 143, "Input"],

Cell[CellGroupData[{
Cell[2427, 77, 290, 6, 48, "Input"],
Cell[2720, 85, 318365, 4751, 296, 249103, 3891, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[321122, 4841, 277, 5, 48, "Input"],
Cell[321402, 4848, 323123, 4809, 296, 249103, 3891, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[644562, 9662, 284, 6, 48, "Input"],
Cell[644849, 9670, 300753, 4447, 296, 248032, 3792, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[945617, 14120, 429, 9, 143, "Input"],

Cell[CellGroupData[{
Cell[946071, 14133, 282, 5, 48, "Input"],
Cell[946356, 14140, 334864, 5018, 296, 249777, 3963, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1281257, 19163, 275, 6, 48, "Input"],
Cell[1281535, 19171, 389668, 5517, 296, 247636, 3759, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1671240, 24693, 275, 6, 48, "Input"],
Cell[1671518, 24701, 420276, 5895, 296, 247634, 3759, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2091843, 30602, 33, 0, 73, "Section"],
Cell[2091879, 30604, 420, 9, 143, "Input"],

Cell[CellGroupData[{
Cell[2092324, 30617, 265, 5, 48, "Input"],
Cell[2092592, 30624, 312272, 4704, 296, 249500, 3924, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2404879, 35331, 425, 9, 143, "Input"],

Cell[CellGroupData[{
Cell[2405329, 35344, 266, 5, 48, "Input"],
Cell[2405598, 35351, 311306, 4664, 296, 249103, 3891, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

